var WasmJS = function(Module) {
  Module = Module || {};

var Module;
if (!Module) Module = (typeof WasmJS !== "undefined" ? WasmJS : null) || {};
var moduleOverrides = {};
for (var key in Module) {
 if (Module.hasOwnProperty(key)) {
  moduleOverrides[key] = Module[key];
 }
}
var ENVIRONMENT_IS_WEB = false;
var ENVIRONMENT_IS_WORKER = false;
var ENVIRONMENT_IS_NODE = false;
var ENVIRONMENT_IS_SHELL = false;
if (Module["ENVIRONMENT"]) {
 if (Module["ENVIRONMENT"] === "WEB") {
  ENVIRONMENT_IS_WEB = true;
 } else if (Module["ENVIRONMENT"] === "WORKER") {
  ENVIRONMENT_IS_WORKER = true;
 } else if (Module["ENVIRONMENT"] === "NODE") {
  ENVIRONMENT_IS_NODE = true;
 } else if (Module["ENVIRONMENT"] === "SHELL") {
  ENVIRONMENT_IS_SHELL = true;
 } else {
  throw new Error("The provided Module['ENVIRONMENT'] value is not valid. It must be one of: WEB|WORKER|NODE|SHELL.");
 }
} else {
 ENVIRONMENT_IS_WEB = typeof window === "object";
 ENVIRONMENT_IS_WORKER = typeof importScripts === "function";
 ENVIRONMENT_IS_NODE = typeof process === "object" && typeof require === "function" && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER;
 ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
}
if (ENVIRONMENT_IS_NODE) {
 if (!Module["print"]) Module["print"] = console.log;
 if (!Module["printErr"]) Module["printErr"] = console.warn;
 var nodeFS;
 var nodePath;
 Module["read"] = function read(filename, binary) {
  if (!nodeFS) nodeFS = require("fs");
  if (!nodePath) nodePath = require("path");
  filename = nodePath["normalize"](filename);
  var ret = nodeFS["readFileSync"](filename);
  return binary ? ret : ret.toString();
 };
 Module["readBinary"] = function readBinary(filename) {
  var ret = Module["read"](filename, true);
  if (!ret.buffer) {
   ret = new Uint8Array(ret);
  }
  assert(ret.buffer);
  return ret;
 };
 Module["load"] = function load(f) {
  globalEval(read(f));
 };
 if (!Module["thisProgram"]) {
  if (process["argv"].length > 1) {
   Module["thisProgram"] = process["argv"][1].replace(/\\/g, "/");
  } else {
   Module["thisProgram"] = "unknown-program";
  }
 }
 Module["arguments"] = process["argv"].slice(2);
 if (typeof module !== "undefined") {
  module["exports"] = Module;
 }
 process["on"]("uncaughtException", (function(ex) {
  if (!(ex instanceof ExitStatus)) {
   throw ex;
  }
 }));
 Module["inspect"] = (function() {
  return "[Emscripten Module object]";
 });
} else if (ENVIRONMENT_IS_SHELL) {
 if (!Module["print"]) Module["print"] = print;
 if (typeof printErr != "undefined") Module["printErr"] = printErr;
 if (typeof read != "undefined") {
  Module["read"] = read;
 } else {
  Module["read"] = function read() {
   throw "no read() available (jsc?)";
  };
 }
 Module["readBinary"] = function readBinary(f) {
  if (typeof readbuffer === "function") {
   return new Uint8Array(readbuffer(f));
  }
  var data = read(f, "binary");
  assert(typeof data === "object");
  return data;
 };
 if (typeof scriptArgs != "undefined") {
  Module["arguments"] = scriptArgs;
 } else if (typeof arguments != "undefined") {
  Module["arguments"] = arguments;
 }
} else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
 Module["read"] = function read(url) {
  var xhr = new XMLHttpRequest;
  xhr.open("GET", url, false);
  xhr.send(null);
  return xhr.responseText;
 };
 Module["readAsync"] = function readAsync(url, onload, onerror) {
  var xhr = new XMLHttpRequest;
  xhr.open("GET", url, true);
  xhr.responseType = "arraybuffer";
  xhr.onload = function xhr_onload() {
   if (xhr.status == 200 || xhr.status == 0 && xhr.response) {
    onload(xhr.response);
   } else {
    onerror();
   }
  };
  xhr.onerror = onerror;
  xhr.send(null);
 };
 if (typeof arguments != "undefined") {
  Module["arguments"] = arguments;
 }
 if (typeof console !== "undefined") {
  if (!Module["print"]) Module["print"] = function print(x) {
   console.log(x);
  };
  if (!Module["printErr"]) Module["printErr"] = function printErr(x) {
   console.warn(x);
  };
 } else {
  var TRY_USE_DUMP = false;
  if (!Module["print"]) Module["print"] = TRY_USE_DUMP && typeof dump !== "undefined" ? (function(x) {
   dump(x);
  }) : (function(x) {});
 }
 if (ENVIRONMENT_IS_WORKER) {
  Module["load"] = importScripts;
 }
 if (typeof Module["setWindowTitle"] === "undefined") {
  Module["setWindowTitle"] = (function(title) {
   document.title = title;
  });
 }
} else {
 throw "Unknown runtime environment. Where are we?";
}
function globalEval(x) {
 eval.call(null, x);
}
if (!Module["load"] && Module["read"]) {
 Module["load"] = function load(f) {
  globalEval(Module["read"](f));
 };
}
if (!Module["print"]) {
 Module["print"] = (function() {});
}
if (!Module["printErr"]) {
 Module["printErr"] = Module["print"];
}
if (!Module["arguments"]) {
 Module["arguments"] = [];
}
if (!Module["thisProgram"]) {
 Module["thisProgram"] = "./this.program";
}
Module.print = Module["print"];
Module.printErr = Module["printErr"];
Module["preRun"] = [];
Module["postRun"] = [];
for (var key in moduleOverrides) {
 if (moduleOverrides.hasOwnProperty(key)) {
  Module[key] = moduleOverrides[key];
 }
}
moduleOverrides = undefined;
var Runtime = {
 setTempRet0: (function(value) {
  tempRet0 = value;
 }),
 getTempRet0: (function() {
  return tempRet0;
 }),
 stackSave: (function() {
  return STACKTOP;
 }),
 stackRestore: (function(stackTop) {
  STACKTOP = stackTop;
 }),
 getNativeTypeSize: (function(type) {
  switch (type) {
  case "i1":
  case "i8":
   return 1;
  case "i16":
   return 2;
  case "i32":
   return 4;
  case "i64":
   return 8;
  case "float":
   return 4;
  case "double":
   return 8;
  default:
   {
    if (type[type.length - 1] === "*") {
     return Runtime.QUANTUM_SIZE;
    } else if (type[0] === "i") {
     var bits = parseInt(type.substr(1));
     assert(bits % 8 === 0);
     return bits / 8;
    } else {
     return 0;
    }
   }
  }
 }),
 getNativeFieldSize: (function(type) {
  return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
 }),
 STACK_ALIGN: 16,
 prepVararg: (function(ptr, type) {
  if (type === "double" || type === "i64") {
   if (ptr & 7) {
    assert((ptr & 7) === 4);
    ptr += 4;
   }
  } else {
   assert((ptr & 3) === 0);
  }
  return ptr;
 }),
 getAlignSize: (function(type, size, vararg) {
  if (!vararg && (type == "i64" || type == "double")) return 8;
  if (!type) return Math.min(size, 8);
  return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
 }),
 dynCall: (function(sig, ptr, args) {
  if (args && args.length) {
   return Module["dynCall_" + sig].apply(null, [ ptr ].concat(args));
  } else {
   return Module["dynCall_" + sig].call(null, ptr);
  }
 }),
 functionPointers: [],
 addFunction: (function(func) {
  for (var i = 0; i < Runtime.functionPointers.length; i++) {
   if (!Runtime.functionPointers[i]) {
    Runtime.functionPointers[i] = func;
    return 2 * (1 + i);
   }
  }
  throw "Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.";
 }),
 removeFunction: (function(index) {
  Runtime.functionPointers[(index - 2) / 2] = null;
 }),
 warnOnce: (function(text) {
  if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
  if (!Runtime.warnOnce.shown[text]) {
   Runtime.warnOnce.shown[text] = 1;
   Module.printErr(text);
  }
 }),
 funcWrappers: {},
 getFuncWrapper: (function(func, sig) {
  assert(sig);
  if (!Runtime.funcWrappers[sig]) {
   Runtime.funcWrappers[sig] = {};
  }
  var sigCache = Runtime.funcWrappers[sig];
  if (!sigCache[func]) {
   if (sig.length === 1) {
    sigCache[func] = function dynCall_wrapper() {
     return Runtime.dynCall(sig, func);
    };
   } else if (sig.length === 2) {
    sigCache[func] = function dynCall_wrapper(arg) {
     return Runtime.dynCall(sig, func, [ arg ]);
    };
   } else {
    sigCache[func] = function dynCall_wrapper() {
     return Runtime.dynCall(sig, func, Array.prototype.slice.call(arguments));
    };
   }
  }
  return sigCache[func];
 }),
 getCompilerSetting: (function(name) {
  throw "You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work";
 }),
 stackAlloc: (function(size) {
  var ret = STACKTOP;
  STACKTOP = STACKTOP + size | 0;
  STACKTOP = STACKTOP + 15 & -16;
  return ret;
 }),
 staticAlloc: (function(size) {
  var ret = STATICTOP;
  STATICTOP = STATICTOP + size | 0;
  STATICTOP = STATICTOP + 15 & -16;
  return ret;
 }),
 dynamicAlloc: (function(size) {
  var ret = DYNAMICTOP;
  DYNAMICTOP = DYNAMICTOP + size | 0;
  DYNAMICTOP = DYNAMICTOP + 15 & -16;
  if (DYNAMICTOP >= TOTAL_MEMORY) {
   var success = enlargeMemory();
   if (!success) {
    DYNAMICTOP = ret;
    return 0;
   }
  }
  return ret;
 }),
 alignMemory: (function(size, quantum) {
  var ret = size = Math.ceil(size / (quantum ? quantum : 16)) * (quantum ? quantum : 16);
  return ret;
 }),
 makeBigInt: (function(low, high, unsigned) {
  var ret = unsigned ? +(low >>> 0) + +(high >>> 0) * +4294967296 : +(low >>> 0) + +(high | 0) * +4294967296;
  return ret;
 }),
 GLOBAL_BASE: 8,
 QUANTUM_SIZE: 4,
 __dummy__: 0
};
Module["Runtime"] = Runtime;
var ABORT = false;
var EXITSTATUS = 0;
function assert(condition, text) {
 if (!condition) {
  abort("Assertion failed: " + text);
 }
}
function getCFunc(ident) {
 var func = Module["_" + ident];
 if (!func) {
  try {
   func = eval("_" + ident);
  } catch (e) {}
 }
 assert(func, "Cannot call unknown function " + ident + " (perhaps LLVM optimizations or closure removed it?)");
 return func;
}
var cwrap, ccall;
((function() {
 var JSfuncs = {
  "stackSave": (function() {
   Runtime.stackSave();
  }),
  "stackRestore": (function() {
   Runtime.stackRestore();
  }),
  "arrayToC": (function(arr) {
   var ret = Runtime.stackAlloc(arr.length);
   writeArrayToMemory(arr, ret);
   return ret;
  }),
  "stringToC": (function(str) {
   var ret = 0;
   if (str !== null && str !== undefined && str !== 0) {
    ret = Runtime.stackAlloc((str.length << 2) + 1);
    writeStringToMemory(str, ret);
   }
   return ret;
  })
 };
 var toC = {
  "string": JSfuncs["stringToC"],
  "array": JSfuncs["arrayToC"]
 };
 ccall = function ccallFunc(ident, returnType, argTypes, args, opts) {
  var func = getCFunc(ident);
  var cArgs = [];
  var stack = 0;
  if (args) {
   for (var i = 0; i < args.length; i++) {
    var converter = toC[argTypes[i]];
    if (converter) {
     if (stack === 0) stack = Runtime.stackSave();
     cArgs[i] = converter(args[i]);
    } else {
     cArgs[i] = args[i];
    }
   }
  }
  var ret = func.apply(null, cArgs);
  if (returnType === "string") ret = Pointer_stringify(ret);
  if (stack !== 0) {
   if (opts && opts.async) {
    EmterpreterAsync.asyncFinalizers.push((function() {
     Runtime.stackRestore(stack);
    }));
    return;
   }
   Runtime.stackRestore(stack);
  }
  return ret;
 };
 var sourceRegex = /^function\s*[a-zA-Z$_0-9]*\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;
 function parseJSFunc(jsfunc) {
  var parsed = jsfunc.toString().match(sourceRegex).slice(1);
  return {
   arguments: parsed[0],
   body: parsed[1],
   returnValue: parsed[2]
  };
 }
 var JSsource = null;
 function ensureJSsource() {
  if (!JSsource) {
   JSsource = {};
   for (var fun in JSfuncs) {
    if (JSfuncs.hasOwnProperty(fun)) {
     JSsource[fun] = parseJSFunc(JSfuncs[fun]);
    }
   }
  }
 }
 cwrap = function cwrap(ident, returnType, argTypes) {
  argTypes = argTypes || [];
  var cfunc = getCFunc(ident);
  var numericArgs = argTypes.every((function(type) {
   return type === "number";
  }));
  var numericRet = returnType !== "string";
  if (numericRet && numericArgs) {
   return cfunc;
  }
  var argNames = argTypes.map((function(x, i) {
   return "$" + i;
  }));
  var funcstr = "(function(" + argNames.join(",") + ") {";
  var nargs = argTypes.length;
  if (!numericArgs) {
   ensureJSsource();
   funcstr += "var stack = " + JSsource["stackSave"].body + ";";
   for (var i = 0; i < nargs; i++) {
    var arg = argNames[i], type = argTypes[i];
    if (type === "number") continue;
    var convertCode = JSsource[type + "ToC"];
    funcstr += "var " + convertCode.arguments + " = " + arg + ";";
    funcstr += convertCode.body + ";";
    funcstr += arg + "=(" + convertCode.returnValue + ");";
   }
  }
  var cfuncname = parseJSFunc((function() {
   return cfunc;
  })).returnValue;
  funcstr += "var ret = " + cfuncname + "(" + argNames.join(",") + ");";
  if (!numericRet) {
   var strgfy = parseJSFunc((function() {
    return Pointer_stringify;
   })).returnValue;
   funcstr += "ret = " + strgfy + "(ret);";
  }
  if (!numericArgs) {
   ensureJSsource();
   funcstr += JSsource["stackRestore"].body.replace("()", "(stack)") + ";";
  }
  funcstr += "return ret})";
  return eval(funcstr);
 };
}))();
Module["ccall"] = ccall;
Module["cwrap"] = cwrap;
function setValue(ptr, value, type, noSafe) {
 type = type || "i8";
 if (type.charAt(type.length - 1) === "*") type = "i32";
 switch (type) {
 case "i1":
  HEAP8[ptr >> 0] = value;
  break;
 case "i8":
  HEAP8[ptr >> 0] = value;
  break;
 case "i16":
  HEAP16[ptr >> 1] = value;
  break;
 case "i32":
  HEAP32[ptr >> 2] = value;
  break;
 case "i64":
  tempI64 = [ value >>> 0, (tempDouble = value, +Math_abs(tempDouble) >= +1 ? tempDouble > +0 ? (Math_min(+Math_floor(tempDouble / +4294967296), +4294967295) | 0) >>> 0 : ~~+Math_ceil((tempDouble - +(~~tempDouble >>> 0)) / +4294967296) >>> 0 : 0) ], HEAP32[ptr >> 2] = tempI64[0], HEAP32[ptr + 4 >> 2] = tempI64[1];
  break;
 case "float":
  HEAPF32[ptr >> 2] = value;
  break;
 case "double":
  HEAPF64[ptr >> 3] = value;
  break;
 default:
  abort("invalid type for setValue: " + type);
 }
}
Module["setValue"] = setValue;
function getValue(ptr, type, noSafe) {
 type = type || "i8";
 if (type.charAt(type.length - 1) === "*") type = "i32";
 switch (type) {
 case "i1":
  return HEAP8[ptr >> 0];
 case "i8":
  return HEAP8[ptr >> 0];
 case "i16":
  return HEAP16[ptr >> 1];
 case "i32":
  return HEAP32[ptr >> 2];
 case "i64":
  return HEAP32[ptr >> 2];
 case "float":
  return HEAPF32[ptr >> 2];
 case "double":
  return HEAPF64[ptr >> 3];
 default:
  abort("invalid type for setValue: " + type);
 }
 return null;
}
Module["getValue"] = getValue;
var ALLOC_NORMAL = 0;
var ALLOC_STACK = 1;
var ALLOC_STATIC = 2;
var ALLOC_DYNAMIC = 3;
var ALLOC_NONE = 4;
Module["ALLOC_NORMAL"] = ALLOC_NORMAL;
Module["ALLOC_STACK"] = ALLOC_STACK;
Module["ALLOC_STATIC"] = ALLOC_STATIC;
Module["ALLOC_DYNAMIC"] = ALLOC_DYNAMIC;
Module["ALLOC_NONE"] = ALLOC_NONE;
function allocate(slab, types, allocator, ptr) {
 var zeroinit, size;
 if (typeof slab === "number") {
  zeroinit = true;
  size = slab;
 } else {
  zeroinit = false;
  size = slab.length;
 }
 var singleType = typeof types === "string" ? types : null;
 var ret;
 if (allocator == ALLOC_NONE) {
  ret = ptr;
 } else {
  ret = [ typeof _malloc === "function" ? _malloc : Runtime.staticAlloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc ][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
 }
 if (zeroinit) {
  var ptr = ret, stop;
  assert((ret & 3) == 0);
  stop = ret + (size & ~3);
  for (; ptr < stop; ptr += 4) {
   HEAP32[ptr >> 2] = 0;
  }
  stop = ret + size;
  while (ptr < stop) {
   HEAP8[ptr++ >> 0] = 0;
  }
  return ret;
 }
 if (singleType === "i8") {
  if (slab.subarray || slab.slice) {
   HEAPU8.set(slab, ret);
  } else {
   HEAPU8.set(new Uint8Array(slab), ret);
  }
  return ret;
 }
 var i = 0, type, typeSize, previousType;
 while (i < size) {
  var curr = slab[i];
  if (typeof curr === "function") {
   curr = Runtime.getFunctionIndex(curr);
  }
  type = singleType || types[i];
  if (type === 0) {
   i++;
   continue;
  }
  if (type == "i64") type = "i32";
  setValue(ret + i, curr, type);
  if (previousType !== type) {
   typeSize = Runtime.getNativeTypeSize(type);
   previousType = type;
  }
  i += typeSize;
 }
 return ret;
}
Module["allocate"] = allocate;
function getMemory(size) {
 if (!staticSealed) return Runtime.staticAlloc(size);
 if (typeof _sbrk !== "undefined" && !_sbrk.called || !runtimeInitialized) return Runtime.dynamicAlloc(size);
 return _malloc(size);
}
Module["getMemory"] = getMemory;
function Pointer_stringify(ptr, length) {
 if (length === 0 || !ptr) return "";
 var hasUtf = 0;
 var t;
 var i = 0;
 while (1) {
  t = HEAPU8[ptr + i >> 0];
  hasUtf |= t;
  if (t == 0 && !length) break;
  i++;
  if (length && i == length) break;
 }
 if (!length) length = i;
 var ret = "";
 if (hasUtf < 128) {
  var MAX_CHUNK = 1024;
  var curr;
  while (length > 0) {
   curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
   ret = ret ? ret + curr : curr;
   ptr += MAX_CHUNK;
   length -= MAX_CHUNK;
  }
  return ret;
 }
 return Module["UTF8ToString"](ptr);
}
Module["Pointer_stringify"] = Pointer_stringify;
function AsciiToString(ptr) {
 var str = "";
 while (1) {
  var ch = HEAP8[ptr++ >> 0];
  if (!ch) return str;
  str += String.fromCharCode(ch);
 }
}
Module["AsciiToString"] = AsciiToString;
function stringToAscii(str, outPtr) {
 return writeAsciiToMemory(str, outPtr, false);
}
Module["stringToAscii"] = stringToAscii;
function UTF8ArrayToString(u8Array, idx) {
 var u0, u1, u2, u3, u4, u5;
 var str = "";
 while (1) {
  u0 = u8Array[idx++];
  if (!u0) return str;
  if (!(u0 & 128)) {
   str += String.fromCharCode(u0);
   continue;
  }
  u1 = u8Array[idx++] & 63;
  if ((u0 & 224) == 192) {
   str += String.fromCharCode((u0 & 31) << 6 | u1);
   continue;
  }
  u2 = u8Array[idx++] & 63;
  if ((u0 & 240) == 224) {
   u0 = (u0 & 15) << 12 | u1 << 6 | u2;
  } else {
   u3 = u8Array[idx++] & 63;
   if ((u0 & 248) == 240) {
    u0 = (u0 & 7) << 18 | u1 << 12 | u2 << 6 | u3;
   } else {
    u4 = u8Array[idx++] & 63;
    if ((u0 & 252) == 248) {
     u0 = (u0 & 3) << 24 | u1 << 18 | u2 << 12 | u3 << 6 | u4;
    } else {
     u5 = u8Array[idx++] & 63;
     u0 = (u0 & 1) << 30 | u1 << 24 | u2 << 18 | u3 << 12 | u4 << 6 | u5;
    }
   }
  }
  if (u0 < 65536) {
   str += String.fromCharCode(u0);
  } else {
   var ch = u0 - 65536;
   str += String.fromCharCode(55296 | ch >> 10, 56320 | ch & 1023);
  }
 }
}
Module["UTF8ArrayToString"] = UTF8ArrayToString;
function UTF8ToString(ptr) {
 return UTF8ArrayToString(HEAPU8, ptr);
}
Module["UTF8ToString"] = UTF8ToString;
function stringToUTF8Array(str, outU8Array, outIdx, maxBytesToWrite) {
 if (!(maxBytesToWrite > 0)) return 0;
 var startIdx = outIdx;
 var endIdx = outIdx + maxBytesToWrite - 1;
 for (var i = 0; i < str.length; ++i) {
  var u = str.charCodeAt(i);
  if (u >= 55296 && u <= 57343) u = 65536 + ((u & 1023) << 10) | str.charCodeAt(++i) & 1023;
  if (u <= 127) {
   if (outIdx >= endIdx) break;
   outU8Array[outIdx++] = u;
  } else if (u <= 2047) {
   if (outIdx + 1 >= endIdx) break;
   outU8Array[outIdx++] = 192 | u >> 6;
   outU8Array[outIdx++] = 128 | u & 63;
  } else if (u <= 65535) {
   if (outIdx + 2 >= endIdx) break;
   outU8Array[outIdx++] = 224 | u >> 12;
   outU8Array[outIdx++] = 128 | u >> 6 & 63;
   outU8Array[outIdx++] = 128 | u & 63;
  } else if (u <= 2097151) {
   if (outIdx + 3 >= endIdx) break;
   outU8Array[outIdx++] = 240 | u >> 18;
   outU8Array[outIdx++] = 128 | u >> 12 & 63;
   outU8Array[outIdx++] = 128 | u >> 6 & 63;
   outU8Array[outIdx++] = 128 | u & 63;
  } else if (u <= 67108863) {
   if (outIdx + 4 >= endIdx) break;
   outU8Array[outIdx++] = 248 | u >> 24;
   outU8Array[outIdx++] = 128 | u >> 18 & 63;
   outU8Array[outIdx++] = 128 | u >> 12 & 63;
   outU8Array[outIdx++] = 128 | u >> 6 & 63;
   outU8Array[outIdx++] = 128 | u & 63;
  } else {
   if (outIdx + 5 >= endIdx) break;
   outU8Array[outIdx++] = 252 | u >> 30;
   outU8Array[outIdx++] = 128 | u >> 24 & 63;
   outU8Array[outIdx++] = 128 | u >> 18 & 63;
   outU8Array[outIdx++] = 128 | u >> 12 & 63;
   outU8Array[outIdx++] = 128 | u >> 6 & 63;
   outU8Array[outIdx++] = 128 | u & 63;
  }
 }
 outU8Array[outIdx] = 0;
 return outIdx - startIdx;
}
Module["stringToUTF8Array"] = stringToUTF8Array;
function stringToUTF8(str, outPtr, maxBytesToWrite) {
 return stringToUTF8Array(str, HEAPU8, outPtr, maxBytesToWrite);
}
Module["stringToUTF8"] = stringToUTF8;
function lengthBytesUTF8(str) {
 var len = 0;
 for (var i = 0; i < str.length; ++i) {
  var u = str.charCodeAt(i);
  if (u >= 55296 && u <= 57343) u = 65536 + ((u & 1023) << 10) | str.charCodeAt(++i) & 1023;
  if (u <= 127) {
   ++len;
  } else if (u <= 2047) {
   len += 2;
  } else if (u <= 65535) {
   len += 3;
  } else if (u <= 2097151) {
   len += 4;
  } else if (u <= 67108863) {
   len += 5;
  } else {
   len += 6;
  }
 }
 return len;
}
Module["lengthBytesUTF8"] = lengthBytesUTF8;
function demangle(func) {
 var hasLibcxxabi = !!Module["___cxa_demangle"];
 if (hasLibcxxabi) {
  try {
   var buf = _malloc(func.length);
   writeStringToMemory(func.substr(1), buf);
   var status = _malloc(4);
   var ret = Module["___cxa_demangle"](buf, 0, 0, status);
   if (getValue(status, "i32") === 0 && ret) {
    return Pointer_stringify(ret);
   }
  } catch (e) {} finally {
   if (buf) _free(buf);
   if (status) _free(status);
   if (ret) _free(ret);
  }
  return func;
 }
 Runtime.warnOnce("warning: build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling");
 return func;
}
function demangleAll(text) {
 return text.replace(/__Z[\w\d_]+/g, (function(x) {
  var y = demangle(x);
  return x === y ? x : x + " [" + y + "]";
 }));
}
function jsStackTrace() {
 var err = new Error;
 if (!err.stack) {
  try {
   throw new Error(0);
  } catch (e) {
   err = e;
  }
  if (!err.stack) {
   return "(no stack trace available)";
  }
 }
 return err.stack.toString();
}
function stackTrace() {
 var js = jsStackTrace();
 if (Module["extraStackTrace"]) js += "\n" + Module["extraStackTrace"]();
 return demangleAll(js);
}
Module["stackTrace"] = stackTrace;
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
 if (x % 4096 > 0) {
  x += 4096 - x % 4096;
 }
 return x;
}
var HEAP;
var buffer;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
function updateGlobalBuffer(buf) {
 Module["buffer"] = buffer = buf;
}
function updateGlobalBufferViews() {
 Module["HEAP8"] = HEAP8 = new Int8Array(buffer);
 Module["HEAP16"] = HEAP16 = new Int16Array(buffer);
 Module["HEAP32"] = HEAP32 = new Int32Array(buffer);
 Module["HEAPU8"] = HEAPU8 = new Uint8Array(buffer);
 Module["HEAPU16"] = HEAPU16 = new Uint16Array(buffer);
 Module["HEAPU32"] = HEAPU32 = new Uint32Array(buffer);
 Module["HEAPF32"] = HEAPF32 = new Float32Array(buffer);
 Module["HEAPF64"] = HEAPF64 = new Float64Array(buffer);
}
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false;
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0;
var DYNAMIC_BASE = 0, DYNAMICTOP = 0;
if (!Module["reallocBuffer"]) Module["reallocBuffer"] = (function(size) {
 var ret;
 try {
  if (ArrayBuffer.transfer) {
   ret = ArrayBuffer.transfer(buffer, size);
  } else {
   var oldHEAP8 = HEAP8;
   ret = new ArrayBuffer(size);
   var temp = new Int8Array(ret);
   temp.set(oldHEAP8);
  }
 } catch (e) {
  return false;
 }
 var success = _emscripten_replace_memory(ret);
 if (!success) return false;
 return ret;
});
function enlargeMemory() {
 var LIMIT = Math.pow(2, 31);
 if (DYNAMICTOP >= LIMIT) return false;
 while (TOTAL_MEMORY <= DYNAMICTOP) {
  if (TOTAL_MEMORY < LIMIT / 2) {
   TOTAL_MEMORY = alignMemoryPage(2 * TOTAL_MEMORY);
  } else {
   var last = TOTAL_MEMORY;
   TOTAL_MEMORY = alignMemoryPage((3 * TOTAL_MEMORY + LIMIT) / 4);
   if (TOTAL_MEMORY <= last) return false;
  }
 }
 TOTAL_MEMORY = Math.max(TOTAL_MEMORY, 16 * 1024 * 1024);
 if (TOTAL_MEMORY >= LIMIT) return false;
 var replacement = Module["reallocBuffer"](TOTAL_MEMORY);
 if (!replacement) return false;
 updateGlobalBuffer(replacement);
 updateGlobalBufferViews();
 return true;
}
var byteLength;
try {
 byteLength = Function.prototype.call.bind(Object.getOwnPropertyDescriptor(ArrayBuffer.prototype, "byteLength").get);
 byteLength(new ArrayBuffer(4));
} catch (e) {
 byteLength = (function(buffer) {
  return buffer.byteLength;
 });
}
var TOTAL_STACK = Module["TOTAL_STACK"] || 5242880;
var TOTAL_MEMORY = Module["TOTAL_MEMORY"] || 16777216;
var totalMemory = 64 * 1024;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2 * TOTAL_STACK) {
 if (totalMemory < 16 * 1024 * 1024) {
  totalMemory *= 2;
 } else {
  totalMemory += 16 * 1024 * 1024;
 }
}
totalMemory = Math.max(totalMemory, 16 * 1024 * 1024);
if (totalMemory !== TOTAL_MEMORY) {
 TOTAL_MEMORY = totalMemory;
}
if (Module["buffer"]) {
 buffer = Module["buffer"];
} else {
 buffer = new ArrayBuffer(TOTAL_MEMORY);
}
updateGlobalBufferViews();
HEAP32[0] = 255;
if (HEAPU8[0] !== 255 || HEAPU8[3] !== 0) throw "Typed arrays 2 must be run on a little-endian system";
Module["HEAP"] = HEAP;
Module["buffer"] = buffer;
Module["HEAP8"] = HEAP8;
Module["HEAP16"] = HEAP16;
Module["HEAP32"] = HEAP32;
Module["HEAPU8"] = HEAPU8;
Module["HEAPU16"] = HEAPU16;
Module["HEAPU32"] = HEAPU32;
Module["HEAPF32"] = HEAPF32;
Module["HEAPF64"] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
 while (callbacks.length > 0) {
  var callback = callbacks.shift();
  if (typeof callback == "function") {
   callback();
   continue;
  }
  var func = callback.func;
  if (typeof func === "number") {
   if (callback.arg === undefined) {
    Runtime.dynCall("v", func);
   } else {
    Runtime.dynCall("vi", func, [ callback.arg ]);
   }
  } else {
   func(callback.arg === undefined ? null : callback.arg);
  }
 }
}
var __ATPRERUN__ = [];
var __ATINIT__ = [];
var __ATMAIN__ = [];
var __ATEXIT__ = [];
var __ATPOSTRUN__ = [];
var runtimeInitialized = false;
var runtimeExited = false;
function preRun() {
 if (Module["preRun"]) {
  if (typeof Module["preRun"] == "function") Module["preRun"] = [ Module["preRun"] ];
  while (Module["preRun"].length) {
   addOnPreRun(Module["preRun"].shift());
  }
 }
 callRuntimeCallbacks(__ATPRERUN__);
}
function ensureInitRuntime() {
 if (runtimeInitialized) return;
 runtimeInitialized = true;
 callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
 callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
 callRuntimeCallbacks(__ATEXIT__);
 runtimeExited = true;
}
function postRun() {
 if (Module["postRun"]) {
  if (typeof Module["postRun"] == "function") Module["postRun"] = [ Module["postRun"] ];
  while (Module["postRun"].length) {
   addOnPostRun(Module["postRun"].shift());
  }
 }
 callRuntimeCallbacks(__ATPOSTRUN__);
}
function addOnPreRun(cb) {
 __ATPRERUN__.unshift(cb);
}
Module["addOnPreRun"] = addOnPreRun;
function addOnInit(cb) {
 __ATINIT__.unshift(cb);
}
Module["addOnInit"] = addOnInit;
function addOnPreMain(cb) {
 __ATMAIN__.unshift(cb);
}
Module["addOnPreMain"] = addOnPreMain;
function addOnExit(cb) {
 __ATEXIT__.unshift(cb);
}
Module["addOnExit"] = addOnExit;
function addOnPostRun(cb) {
 __ATPOSTRUN__.unshift(cb);
}
Module["addOnPostRun"] = addOnPostRun;
function intArrayFromString(stringy, dontAddNull, length) {
 var len = length > 0 ? length : lengthBytesUTF8(stringy) + 1;
 var u8array = new Array(len);
 var numBytesWritten = stringToUTF8Array(stringy, u8array, 0, u8array.length);
 if (dontAddNull) u8array.length = numBytesWritten;
 return u8array;
}
Module["intArrayFromString"] = intArrayFromString;
function intArrayToString(array) {
 var ret = [];
 for (var i = 0; i < array.length; i++) {
  var chr = array[i];
  if (chr > 255) {
   chr &= 255;
  }
  ret.push(String.fromCharCode(chr));
 }
 return ret.join("");
}
Module["intArrayToString"] = intArrayToString;
function writeStringToMemory(string, buffer, dontAddNull) {
 var array = intArrayFromString(string, dontAddNull);
 var i = 0;
 while (i < array.length) {
  var chr = array[i];
  HEAP8[buffer + i >> 0] = chr;
  i = i + 1;
 }
}
Module["writeStringToMemory"] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
 for (var i = 0; i < array.length; i++) {
  HEAP8[buffer++ >> 0] = array[i];
 }
}
Module["writeArrayToMemory"] = writeArrayToMemory;
function writeAsciiToMemory(str, buffer, dontAddNull) {
 for (var i = 0; i < str.length; ++i) {
  HEAP8[buffer++ >> 0] = str.charCodeAt(i);
 }
 if (!dontAddNull) HEAP8[buffer >> 0] = 0;
}
Module["writeAsciiToMemory"] = writeAsciiToMemory;
if (!Math["imul"] || Math["imul"](4294967295, 5) !== -5) Math["imul"] = function imul(a, b) {
 var ah = a >>> 16;
 var al = a & 65535;
 var bh = b >>> 16;
 var bl = b & 65535;
 return al * bl + (ah * bl + al * bh << 16) | 0;
};
Math.imul = Math["imul"];
if (!Math["clz32"]) Math["clz32"] = (function(x) {
 x = x >>> 0;
 for (var i = 0; i < 32; i++) {
  if (x & 1 << 31 - i) return i;
 }
 return 32;
});
Math.clz32 = Math["clz32"];
if (!Math["trunc"]) Math["trunc"] = (function(x) {
 return x < 0 ? Math.ceil(x) : Math.floor(x);
});
Math.trunc = Math["trunc"];
var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;
var Math_clz32 = Math.clz32;
var Math_trunc = Math.trunc;
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null;
function getUniqueRunDependency(id) {
 return id;
}
function addRunDependency(id) {
 runDependencies++;
 if (Module["monitorRunDependencies"]) {
  Module["monitorRunDependencies"](runDependencies);
 }
}
Module["addRunDependency"] = addRunDependency;
function removeRunDependency(id) {
 runDependencies--;
 if (Module["monitorRunDependencies"]) {
  Module["monitorRunDependencies"](runDependencies);
 }
 if (runDependencies == 0) {
  if (runDependencyWatcher !== null) {
   clearInterval(runDependencyWatcher);
   runDependencyWatcher = null;
  }
  if (dependenciesFulfilled) {
   var callback = dependenciesFulfilled;
   dependenciesFulfilled = null;
   callback();
  }
 }
}
Module["removeRunDependency"] = removeRunDependency;
Module["preloadedImages"] = {};
Module["preloadedAudios"] = {};
var ASM_CONSTS = [ (function() {
 {
  return Module["providedTotalMemory"];
 }
}), (function($0, $1) {
 {
  return Module["lookupImport"](Pointer_stringify($0), Pointer_stringify($1));
 }
}), (function($0, $1) {
 {
  Module["info"].parent["HEAP32"][$0 >> 2] = $1;
 }
}), (function($0, $1) {
 {
  Module["info"].parent["HEAPF32"][$0 >> 2] = $1;
 }
}), (function($0, $1) {
 {
  Module["info"].parent["HEAPF64"][$0 >> 3] = $1;
 }
}), (function() {
 {
  return !!Module["outside"]["WASM_JS_DEBUG"];
 }
}), (function() {
 {
  Module["asmExports"] = {};
 }
}), (function($0) {
 {
  var name = Pointer_stringify($0);
  Module["asmExports"][name] = (function() {
   Module["tempArguments"] = Array.prototype.slice.call(arguments);
   Module["_call_from_js"]($0);
   return Module["tempReturn"];
  });
 }
}), (function($0, $1, $2) {
 {
  var mod = Pointer_stringify($0);
  var base = Pointer_stringify($1);
  var name = Pointer_stringify($2);
  assert(Module["lookupImport"](mod, base), "checking import " + name + " = " + mod + "." + base);
 }
}), (function() {
 {
  Module["outside"]["extraStackTrace"] = (function() {
   return Pointer_stringify(Module["_interpreter_stack_trace"]());
  });
 }
}), (function() {
 {
  return Module["tempArguments"].length;
 }
}), (function($0) {
 {
  return Module["tempArguments"][$0];
 }
}), (function() {
 {
  Module["tempReturn"] = undefined;
 }
}), (function($0) {
 {
  Module["tempReturn"] = $0;
 }
}), (function($0) {
 {
  Module["outside"]["newBuffer"] = new ArrayBuffer($0);
 }
}), (function($0, $1, $2) {
 {
  var source = Module["HEAP8"].subarray($1, $1 + $2);
  var target = new Int8Array(Module["outside"]["newBuffer"]);
  target.set(source, $0);
 }
}), (function() {
 {
  Module["tempArguments"] = [];
 }
}), (function($0, $1) {
 {
  var mod = Pointer_stringify($0);
  var base = Pointer_stringify($1);
  var tempArguments = Module["tempArguments"];
  Module["tempArguments"] = null;
  var lookup = Module["lookupImport"](mod, base);
  return lookup.apply(null, tempArguments);
 }
}), (function($0) {
 {
  Module["tempArguments"].push($0);
 }
}), (function($0, $1, $2, $3, $4) {
 {
  var addr = $0;
  var bytes = $1;
  var isFloat = $2;
  var isSigned = $3;
  var out64 = $4;
  var save0 = HEAP32[0];
  var save1 = HEAP32[1];
  for (var i = 0; i < bytes; i++) {
   HEAPU8[i] = Module["info"].parent["HEAPU8"][addr + i];
  }
  var ret;
  if (!isFloat) {
   if (bytes === 1) ret = isSigned ? HEAP8[0] : HEAPU8[0]; else if (bytes === 2) ret = isSigned ? HEAP16[0] : HEAPU16[0]; else if (bytes === 4) ret = isSigned ? HEAP32[0] : HEAPU32[0]; else if (bytes === 8) {
    for (var i = 0; i < bytes; i++) {
     HEAPU8[out64 + i] = HEAPU8[i];
    }
   } else abort();
  } else {
   if (bytes === 4) ret = HEAPF32[0]; else if (bytes === 8) ret = HEAPF64[0]; else abort();
  }
  HEAP32[0] = save0;
  HEAP32[1] = save1;
  return ret;
 }
}), (function($0) {
 {
  return Module["info"].parent["HEAP8"][$0];
 }
}), (function($0) {
 {
  return Module["info"].parent["HEAPU8"][$0];
 }
}), (function($0) {
 {
  return Module["info"].parent["HEAP16"][$0 >> 1];
 }
}), (function($0) {
 {
  return Module["info"].parent["HEAPU16"][$0 >> 1];
 }
}), (function($0) {
 {
  return Module["info"].parent["HEAP32"][$0 >> 2];
 }
}), (function($0) {
 {
  return Module["info"].parent["HEAPU32"][$0 >> 2];
 }
}), (function($0) {
 {
  return Module["info"].parent["HEAPF32"][$0 >> 2];
 }
}), (function($0) {
 {
  return Module["info"].parent["HEAPF64"][$0 >> 3];
 }
}), (function($0, $1, $2, $3) {
 {
  var addr = $0;
  var bytes = $1;
  var isFloat = $2;
  var value = $3;
  var save0 = HEAP32[0];
  var save1 = HEAP32[1];
  if (!isFloat) {
   if (bytes === 1) HEAPU8[0] = value; else if (bytes === 2) HEAPU16[0] = value; else if (bytes === 4) HEAPU32[0] = value; else abort();
  } else {
   if (bytes === 4) HEAPF32[0] = value; else if (bytes === 8) HEAPF64[0] = value; else abort();
  }
  for (var i = 0; i < bytes; i++) {
   Module["info"].parent["HEAPU8"][addr + i] = HEAPU8[i];
  }
  HEAP32[0] = save0;
  HEAP32[1] = save1;
 }
}), (function($0, $1) {
 {
  Module["info"].parent["HEAP8"][$0] = $1;
 }
}), (function($0, $1) {
 {
  Module["info"].parent["HEAP16"][$0 >> 1] = $1;
 }
}), (function($0) {
 {
  var size = $0;
  var buffer;
  try {
   buffer = new ArrayBuffer(size);
  } catch (e) {
   return;
  }
  var oldHEAP8 = Module["outside"]["HEAP8"];
  var temp = new Int8Array(buffer);
  temp.set(oldHEAP8);
  Module["outside"]["buffer"] = buffer;
 }
}), (function($0) {
 {
  abort("wasm trap: " + Pointer_stringify($0));
 }
}) ];
function _emscripten_asm_const_diiid(code, a0, a1, a2, a3) {
 return ASM_CONSTS[code](a0, a1, a2, a3);
}
function _emscripten_asm_const_dii(code, a0, a1) {
 return ASM_CONSTS[code](a0, a1);
}
function _emscripten_asm_const_di(code, a0) {
 return ASM_CONSTS[code](a0);
}
function _emscripten_asm_const_i(code) {
 return ASM_CONSTS[code]();
}
function _emscripten_asm_const_diiiii(code, a0, a1, a2, a3, a4) {
 return ASM_CONSTS[code](a0, a1, a2, a3, a4);
}
function _emscripten_asm_const_iid(code, a0, a1) {
 return ASM_CONSTS[code](a0, a1);
}
function _emscripten_asm_const_ii(code, a0) {
 return ASM_CONSTS[code](a0);
}
function _emscripten_asm_const_did(code, a0, a1) {
 return ASM_CONSTS[code](a0, a1);
}
function _emscripten_asm_const_iiii(code, a0, a1, a2) {
 return ASM_CONSTS[code](a0, a1, a2);
}
function _emscripten_asm_const_v(code) {
 return ASM_CONSTS[code]();
}
function _emscripten_asm_const_iii(code, a0, a1) {
 return ASM_CONSTS[code](a0, a1);
}
function _emscripten_asm_const_id(code, a0) {
 return ASM_CONSTS[code](a0);
}
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 67728;
__ATINIT__.push({
 func: (function() {
  __GLOBAL__I_000101();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_Vacuum_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_iostream_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_shared_constants_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_threads_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_optimizer_shared_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_simple_ast_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_parser_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_CoalesceLocals_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_DuplicateFunctionElimination_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_wasm_js_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_ReorderLocals_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_SimplifyLocals_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_PostEmscripten_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_RemoveUnusedNames_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_RemoveUnusedBrs_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_OptimizeInstructions_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_Print_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_MergeBlocks_cpp();
 })
}, {
 func: (function() {
  __GLOBAL__sub_I_DeadCodeElimination_cpp();
 })
});
allocate([ 244, 59, 0, 0, 87, 75, 0, 0, 28, 60, 0, 0, 33, 75, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 230, 74, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 207, 74, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 243, 83, 0, 0, 28, 60, 0, 0, 154, 86, 0, 0, 184, 10, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 224, 86, 0, 0, 168, 10, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 216, 88, 0, 0, 28, 60, 0, 0, 164, 88, 0, 0, 104, 0, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 107, 88, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 86, 88, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 170, 90, 0, 0, 224, 15, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 39, 91, 0, 0, 28, 60, 0, 0, 198, 90, 0, 0, 176, 0, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 73, 91, 0, 0, 244, 59, 0, 0, 17, 97, 0, 0, 28, 60, 0, 0, 176, 96, 0, 0, 208, 0, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 51, 97, 0, 0, 28, 60, 0, 0, 108, 97, 0, 0, 208, 0, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 205, 97, 0, 0, 244, 59, 0, 0, 71, 99, 0, 0, 244, 59, 0, 0, 121, 99, 0, 0, 28, 60, 0, 0, 84, 99, 0, 0, 16, 1, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 36, 111, 0, 0, 24, 11, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 215, 115, 0, 0, 28, 60, 0, 0, 83, 115, 0, 0, 56, 1, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 140, 119, 0, 0, 244, 59, 0, 0, 78, 120, 0, 0, 28, 60, 0, 0, 201, 119, 0, 0, 88, 1, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 165, 120, 0, 0, 28, 60, 0, 0, 226, 120, 0, 0, 88, 1, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 103, 121, 0, 0, 28, 60, 0, 0, 2, 127, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 129, 127, 0, 0, 132, 60, 0, 0, 175, 127, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 200, 1, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 2, 128, 0, 0, 216, 1, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 67, 128, 0, 0, 232, 1, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 127, 128, 0, 0, 28, 60, 0, 0, 171, 128, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 84, 129, 0, 0, 244, 59, 0, 0, 255, 129, 0, 0, 28, 60, 0, 0, 92, 130, 0, 0, 168, 1, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 121, 130, 0, 0, 28, 60, 0, 0, 229, 130, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 92, 131, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 88, 2, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 167, 131, 0, 0, 104, 2, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 224, 131, 0, 0, 120, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 20, 132, 0, 0, 28, 60, 0, 0, 56, 132, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 217, 132, 0, 0, 160, 2, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 241, 132, 0, 0, 176, 2, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 45, 133, 0, 0, 192, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 100, 133, 0, 0, 244, 59, 0, 0, 251, 133, 0, 0, 28, 60, 0, 0, 80, 134, 0, 0, 56, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 101, 134, 0, 0, 28, 60, 0, 0, 157, 134, 0, 0, 8, 1, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 86, 141, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 200, 141, 0, 0, 28, 60, 0, 0, 48, 142, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 171, 142, 0, 0, 232, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 196, 142, 0, 0, 28, 60, 0, 0, 45, 143, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 164, 143, 0, 0, 232, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 185, 143, 0, 0, 28, 60, 0, 0, 42, 144, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 170, 144, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 144, 3, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 254, 144, 0, 0, 160, 3, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 64, 145, 0, 0, 176, 3, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 125, 145, 0, 0, 28, 60, 0, 0, 170, 145, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 84, 146, 0, 0, 28, 60, 0, 0, 178, 146, 0, 0, 112, 3, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 208, 146, 0, 0, 28, 60, 0, 0, 85, 147, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 208, 147, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 24, 4, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 31, 148, 0, 0, 40, 4, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 92, 148, 0, 0, 56, 4, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 148, 148, 0, 0, 28, 60, 0, 0, 188, 148, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 178, 149, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 112, 4, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 46, 150, 0, 0, 128, 4, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 152, 150, 0, 0, 144, 4, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 253, 150, 0, 0, 28, 60, 0, 0, 82, 151, 0, 0, 80, 4, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 152, 151, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 200, 4, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 20, 152, 0, 0, 216, 4, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 126, 152, 0, 0, 232, 4, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 227, 152, 0, 0, 28, 60, 0, 0, 56, 153, 0, 0, 168, 4, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 126, 153, 0, 0, 28, 60, 0, 0, 215, 153, 0, 0, 248, 3, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 240, 153, 0, 0, 28, 60, 0, 0, 120, 154, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 245, 154, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 80, 5, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 70, 155, 0, 0, 96, 5, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 133, 155, 0, 0, 112, 5, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 191, 155, 0, 0, 28, 60, 0, 0, 233, 155, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 144, 156, 0, 0, 28, 60, 0, 0, 235, 156, 0, 0, 48, 5, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 6, 157, 0, 0, 28, 60, 0, 0, 142, 157, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 8, 158, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 216, 5, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 86, 158, 0, 0, 232, 5, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 146, 158, 0, 0, 248, 5, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 201, 158, 0, 0, 28, 60, 0, 0, 240, 158, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 209, 159, 0, 0, 28, 60, 0, 0, 41, 160, 0, 0, 184, 5, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 65, 160, 0, 0, 28, 60, 0, 0, 183, 160, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 49, 161, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 96, 6, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 138, 161, 0, 0, 112, 6, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 209, 161, 0, 0, 128, 6, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 13, 162, 0, 0, 144, 6, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 68, 162, 0, 0, 28, 60, 0, 0, 107, 162, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 45, 165, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 200, 6, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 124, 165, 0, 0, 216, 6, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 185, 165, 0, 0, 232, 6, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 241, 165, 0, 0, 28, 60, 0, 0, 25, 166, 0, 0, 168, 6, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 50, 166, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 32, 7, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 129, 166, 0, 0, 48, 7, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 190, 166, 0, 0, 64, 7, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 246, 166, 0, 0, 28, 60, 0, 0, 30, 167, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 55, 167, 0, 0, 28, 60, 0, 0, 143, 167, 0, 0, 64, 6, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 167, 167, 0, 0, 28, 60, 0, 0, 18, 168, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 139, 168, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 168, 7, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 216, 168, 0, 0, 184, 7, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 19, 169, 0, 0, 200, 7, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 73, 169, 0, 0, 28, 60, 0, 0, 111, 169, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 95, 170, 0, 0, 240, 7, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 159, 170, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 3, 171, 0, 0, 16, 8, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 98, 171, 0, 0, 244, 59, 0, 0, 177, 171, 0, 0, 28, 60, 0, 0, 8, 172, 0, 0, 136, 7, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 31, 172, 0, 0, 28, 60, 0, 0, 128, 172, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 241, 172, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 104, 8, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 54, 173, 0, 0, 120, 8, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 105, 173, 0, 0, 136, 8, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 151, 173, 0, 0, 28, 60, 0, 0, 181, 173, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 80, 174, 0, 0, 28, 60, 0, 0, 159, 174, 0, 0, 72, 8, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 174, 174, 0, 0, 28, 60, 0, 0, 27, 175, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 163, 175, 0, 0, 8, 1, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 201, 175, 0, 0, 240, 8, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 225, 175, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 29, 176, 0, 0, 16, 9, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 84, 176, 0, 0, 28, 60, 0, 0, 123, 176, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 111, 177, 0, 0, 28, 60, 0, 0, 199, 177, 0, 0, 64, 9, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 225, 177, 0, 0, 80, 9, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 31, 178, 0, 0, 96, 9, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 88, 178, 0, 0, 28, 60, 0, 0, 129, 178, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 39, 179, 0, 0, 244, 59, 0, 0, 129, 179, 0, 0, 28, 60, 0, 0, 202, 179, 0, 0, 152, 9, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 226, 179, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 8, 1, 0, 0, 2, 0, 0, 0, 184, 9, 0, 0, 2, 16, 0, 0, 28, 60, 0, 0, 59, 180, 0, 0, 200, 9, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 130, 180, 0, 0, 216, 9, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 190, 180, 0, 0, 232, 9, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 245, 180, 0, 0, 28, 60, 0, 0, 28, 181, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 232, 182, 0, 0, 28, 60, 0, 0, 99, 183, 0, 0, 136, 9, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 253, 183, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 119, 184, 0, 0, 28, 60, 0, 0, 249, 184, 0, 0, 160, 1, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 127, 185, 0, 0, 28, 60, 0, 0, 54, 193, 0, 0, 88, 10, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 74, 193, 0, 0, 104, 10, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 130, 193, 0, 0, 120, 10, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 181, 193, 0, 0, 28, 60, 0, 0, 17, 205, 0, 0, 144, 10, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 59, 205, 0, 0, 28, 60, 0, 0, 77, 205, 0, 0, 144, 10, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 119, 205, 0, 0, 244, 59, 0, 0, 168, 205, 0, 0, 132, 60, 0, 0, 217, 205, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 128, 10, 0, 0, 3, 244, 255, 255, 132, 60, 0, 0, 8, 206, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 152, 10, 0, 0, 3, 244, 255, 255, 132, 60, 0, 0, 55, 206, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 128, 10, 0, 0, 3, 244, 255, 255, 132, 60, 0, 0, 102, 206, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 152, 10, 0, 0, 3, 244, 255, 255, 132, 60, 0, 0, 149, 206, 0, 0, 3, 0, 0, 0, 2, 0, 0, 0, 184, 10, 0, 0, 2, 0, 0, 0, 232, 10, 0, 0, 2, 8, 0, 0, 28, 60, 0, 0, 197, 206, 0, 0, 168, 10, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 3, 207, 0, 0, 176, 10, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 27, 207, 0, 0, 168, 10, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 52, 207, 0, 0, 176, 10, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 77, 207, 0, 0, 136, 11, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 97, 207, 0, 0, 216, 15, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 119, 207, 0, 0, 136, 11, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 139, 207, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 200, 11, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 207, 207, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 224, 11, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 229, 207, 0, 0, 132, 60, 0, 0, 36, 208, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 8, 12, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 104, 208, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 224, 11, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 126, 208, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 64, 12, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 194, 208, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 88, 12, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 216, 208, 0, 0, 132, 60, 0, 0, 255, 208, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 128, 12, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 67, 209, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 88, 12, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 89, 209, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 192, 12, 0, 0, 2, 0, 0, 0, 200, 12, 0, 0, 0, 8, 0, 0, 244, 59, 0, 0, 158, 209, 0, 0, 244, 59, 0, 0, 177, 209, 0, 0, 132, 60, 0, 0, 19, 211, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 192, 12, 0, 0, 2, 0, 0, 0, 248, 12, 0, 0, 0, 8, 0, 0, 244, 59, 0, 0, 88, 211, 0, 0, 132, 60, 0, 0, 122, 211, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 32, 13, 0, 0, 0, 8, 0, 0, 244, 59, 0, 0, 191, 211, 0, 0, 132, 60, 0, 0, 212, 211, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 32, 13, 0, 0, 0, 8, 0, 0, 132, 60, 0, 0, 25, 212, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 104, 13, 0, 0, 2, 0, 0, 0, 244, 59, 0, 0, 53, 212, 0, 0, 132, 60, 0, 0, 74, 212, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 104, 13, 0, 0, 2, 0, 0, 0, 132, 60, 0, 0, 102, 212, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 104, 13, 0, 0, 2, 0, 0, 0, 132, 60, 0, 0, 130, 212, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 104, 13, 0, 0, 2, 0, 0, 0, 132, 60, 0, 0, 158, 212, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 240, 13, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 228, 212, 0, 0, 132, 60, 0, 0, 12, 213, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 24, 14, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 82, 213, 0, 0, 132, 60, 0, 0, 118, 213, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 64, 14, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 188, 213, 0, 0, 132, 60, 0, 0, 219, 213, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 104, 14, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 33, 214, 0, 0, 132, 60, 0, 0, 58, 214, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 144, 14, 0, 0, 2, 0, 0, 0, 244, 59, 0, 0, 79, 214, 0, 0, 132, 60, 0, 0, 103, 214, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 144, 14, 0, 0, 2, 0, 0, 0, 28, 60, 0, 0, 124, 214, 0, 0, 200, 14, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 158, 214, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 232, 14, 0, 0, 2, 0, 0, 0, 244, 59, 0, 0, 193, 214, 0, 0, 28, 60, 0, 0, 216, 214, 0, 0, 200, 14, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 251, 214, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 232, 14, 0, 0, 2, 0, 0, 0, 132, 60, 0, 0, 29, 215, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 232, 14, 0, 0, 2, 0, 0, 0, 132, 60, 0, 0, 63, 215, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 232, 14, 0, 0, 2, 0, 0, 0, 28, 60, 0, 0, 98, 215, 0, 0, 136, 11, 0, 0, 0, 0, 0, 0, 132, 60, 0, 0, 120, 215, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 144, 15, 0, 0, 2, 0, 0, 0, 244, 59, 0, 0, 138, 215, 0, 0, 132, 60, 0, 0, 159, 215, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 136, 11, 0, 0, 2, 0, 0, 0, 144, 15, 0, 0, 2, 0, 0, 0, 28, 60, 0, 0, 177, 215, 0, 0, 136, 11, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 198, 215, 0, 0, 136, 11, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 112, 216, 0, 0, 244, 59, 0, 0, 168, 219, 0, 0, 28, 60, 0, 0, 134, 219, 0, 0, 8, 16, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 51, 219, 0, 0, 232, 15, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 88, 219, 0, 0, 24, 16, 0, 0, 0, 0, 0, 0, 244, 59, 0, 0, 121, 219, 0, 0, 28, 60, 0, 0, 110, 220, 0, 0, 224, 15, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 153, 220, 0, 0, 224, 15, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 169, 220, 0, 0, 48, 16, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 222, 220, 0, 0, 8, 16, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 186, 220, 0, 0, 80, 16, 0, 0, 0, 0, 0, 0, 28, 60, 0, 0, 0, 221, 0, 0, 232, 15, 0, 0, 0, 0, 0, 0, 209, 191, 0, 0, 250, 191, 0, 0, 231, 191, 0, 0, 79, 187, 0, 0, 132, 67, 0, 0, 224, 191, 0, 0, 137, 67, 0, 0, 238, 191, 0, 0, 249, 185, 0, 0, 185, 191, 0, 0, 0, 0, 0, 0, 48, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 16, 0, 0, 0, 1, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 196, 255, 255, 255, 196, 255, 255, 255, 72, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 204, 16, 0, 0, 4, 17, 0, 0, 24, 17, 0, 0, 224, 16, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 184, 10, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 196, 255, 255, 255, 196, 255, 255, 255, 184, 10, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 88, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 2, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 1, 0, 0, 0, 3, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 144, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 112, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 160, 0, 0, 0, 11, 0, 0, 0, 12, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 184, 0, 0, 0, 13, 0, 0, 0, 14, 0, 0, 0, 8, 0, 0, 0, 2, 0, 0, 0, 15, 0, 0, 0, 16, 0, 0, 0, 9, 0, 0, 0, 3, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 216, 0, 0, 0, 17, 0, 0, 0, 18, 0, 0, 0, 11, 0, 0, 0, 3, 0, 0, 0, 19, 0, 0, 0, 20, 0, 0, 0, 12, 0, 0, 0, 4, 0, 0, 0, 13, 0, 0, 0, 0, 0, 0, 0, 240, 0, 0, 0, 17, 0, 0, 0, 21, 0, 0, 0, 14, 0, 0, 0, 4, 0, 0, 0, 22, 0, 0, 0, 23, 0, 0, 0, 15, 0, 0, 0, 5, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 8, 1, 0, 0, 24, 0, 0, 0, 25, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 24, 1, 0, 0, 5, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 3, 0, 0, 0, 6, 0, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 40, 1, 0, 0, 26, 0, 0, 0, 27, 0, 0, 0, 56, 0, 0, 0, 248, 255, 255, 255, 40, 1, 0, 0, 28, 0, 0, 0, 29, 0, 0, 0, 192, 255, 255, 255, 192, 255, 255, 255, 40, 1, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 88, 18, 0, 0, 188, 18, 0, 0, 248, 18, 0, 0, 12, 19, 0, 0, 32, 19, 0, 0, 52, 19, 0, 0, 228, 18, 0, 0, 208, 18, 0, 0, 128, 18, 0, 0, 108, 18, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 24, 11, 0, 0, 32, 0, 0, 0, 33, 0, 0, 0, 56, 0, 0, 0, 248, 255, 255, 255, 24, 11, 0, 0, 34, 0, 0, 0, 35, 0, 0, 0, 192, 255, 255, 255, 192, 255, 255, 255, 24, 11, 0, 0, 36, 0, 0, 0, 37, 0, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 184, 10, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 192, 255, 255, 255, 192, 255, 255, 255, 184, 10, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 56, 0, 0, 0, 0, 0, 0, 0, 232, 10, 0, 0, 38, 0, 0, 0, 39, 0, 0, 0, 200, 255, 255, 255, 200, 255, 255, 255, 232, 10, 0, 0, 40, 0, 0, 0, 41, 0, 0, 0, 127, 248, 0, 0, 103, 252, 0, 0, 0, 0, 0, 0, 64, 1, 0, 0, 42, 0, 0, 0, 43, 0, 0, 0, 17, 0, 0, 0, 7, 0, 0, 0, 44, 0, 0, 0, 45, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 18, 0, 0, 0, 0, 0, 0, 0, 96, 1, 0, 0, 46, 0, 0, 0, 47, 0, 0, 0, 19, 0, 0, 0, 8, 0, 0, 0, 48, 0, 0, 0, 49, 0, 0, 0, 4, 0, 0, 0, 8, 0, 0, 0, 20, 0, 0, 0, 0, 0, 0, 0, 120, 1, 0, 0, 46, 0, 0, 0, 50, 0, 0, 0, 21, 0, 0, 0, 9, 0, 0, 0, 51, 0, 0, 0, 52, 0, 0, 0, 5, 0, 0, 0, 9, 0, 0, 0, 22, 0, 0, 0, 0, 0, 0, 0, 144, 1, 0, 0, 53, 0, 0, 0, 54, 0, 0, 0, 23, 0, 0, 0, 10, 0, 0, 0, 55, 0, 0, 0, 56, 0, 0, 0, 24, 0, 0, 0, 10, 0, 0, 0, 25, 0, 0, 0, 0, 0, 0, 0, 168, 1, 0, 0, 57, 0, 0, 0, 58, 0, 0, 0, 1, 0, 0, 0, 4, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 168, 1, 0, 0, 26, 0, 0, 0, 0, 0, 0, 0, 216, 1, 0, 0, 26, 0, 0, 0, 0, 0, 0, 0, 240, 1, 0, 0, 59, 0, 0, 0, 60, 0, 0, 0, 27, 0, 0, 0, 11, 0, 0, 0, 61, 0, 0, 0, 62, 0, 0, 0, 28, 0, 0, 0, 11, 0, 0, 0, 29, 0, 0, 0, 0, 0, 0, 0, 16, 2, 0, 0, 63, 0, 0, 0, 64, 0, 0, 0, 1, 0, 0, 0, 4, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 16, 2, 0, 0, 26, 0, 0, 0, 0, 0, 0, 0, 40, 2, 0, 0, 53, 0, 0, 0, 65, 0, 0, 0, 30, 0, 0, 0, 12, 0, 0, 0, 66, 0, 0, 0, 67, 0, 0, 0, 31, 0, 0, 0, 12, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 56, 2, 0, 0, 68, 0, 0, 0, 69, 0, 0, 0, 1, 0, 0, 0, 5, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 56, 2, 0, 0, 33, 0, 0, 0, 0, 0, 0, 0, 104, 2, 0, 0, 33, 0, 0, 0, 0, 0, 0, 0, 128, 2, 0, 0, 59, 0, 0, 0, 70, 0, 0, 0, 34, 0, 0, 0, 13, 0, 0, 0, 71, 0, 0, 0, 72, 0, 0, 0, 35, 0, 0, 0, 13, 0, 0, 0, 36, 0, 0, 0, 0, 0, 0, 0, 144, 2, 0, 0, 37, 0, 0, 0, 0, 0, 0, 0, 176, 2, 0, 0, 37, 0, 0, 0, 0, 0, 0, 0, 208, 2, 0, 0, 68, 0, 0, 0, 73, 0, 0, 0, 1, 0, 0, 0, 5, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 208, 2, 0, 0, 33, 0, 0, 0, 0, 0, 0, 0, 232, 2, 0, 0, 24, 0, 0, 0, 74, 0, 0, 0, 1, 0, 0, 0, 6, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 248, 2, 0, 0, 53, 0, 0, 0, 75, 0, 0, 0, 38, 0, 0, 0, 14, 0, 0, 0, 76, 0, 0, 0, 77, 0, 0, 0, 39, 0, 0, 0, 14, 0, 0, 0, 40, 0, 0, 0, 0, 0, 0, 0, 16, 3, 0, 0, 53, 0, 0, 0, 78, 0, 0, 0, 41, 0, 0, 0, 15, 0, 0, 0, 79, 0, 0, 0, 80, 0, 0, 0, 42, 0, 0, 0, 15, 0, 0, 0, 43, 0, 0, 0, 0, 0, 0, 0, 32, 3, 0, 0, 24, 0, 0, 0, 81, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 56, 3, 0, 0, 53, 0, 0, 0, 82, 0, 0, 0, 44, 0, 0, 0, 16, 0, 0, 0, 83, 0, 0, 0, 84, 0, 0, 0, 45, 0, 0, 0, 16, 0, 0, 0, 46, 0, 0, 0, 0, 0, 0, 0, 72, 3, 0, 0, 24, 0, 0, 0, 85, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 96, 3, 0, 0, 53, 0, 0, 0, 86, 0, 0, 0, 47, 0, 0, 0, 17, 0, 0, 0, 87, 0, 0, 0, 88, 0, 0, 0, 48, 0, 0, 0, 17, 0, 0, 0, 49, 0, 0, 0, 0, 0, 0, 0, 112, 3, 0, 0, 89, 0, 0, 0, 90, 0, 0, 0, 1, 0, 0, 0, 9, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 112, 3, 0, 0, 50, 0, 0, 0, 0, 0, 0, 0, 160, 3, 0, 0, 50, 0, 0, 0, 0, 0, 0, 0, 184, 3, 0, 0, 59, 0, 0, 0, 91, 0, 0, 0, 51, 0, 0, 0, 18, 0, 0, 0, 92, 0, 0, 0, 93, 0, 0, 0, 52, 0, 0, 0, 18, 0, 0, 0, 53, 0, 0, 0, 0, 0, 0, 0, 208, 3, 0, 0, 89, 0, 0, 0, 94, 0, 0, 0, 1, 0, 0, 0, 9, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 208, 3, 0, 0, 50, 0, 0, 0, 0, 0, 0, 0, 232, 3, 0, 0, 53, 0, 0, 0, 95, 0, 0, 0, 54, 0, 0, 0, 19, 0, 0, 0, 96, 0, 0, 0, 97, 0, 0, 0, 55, 0, 0, 0, 19, 0, 0, 0, 56, 0, 0, 0, 0, 0, 0, 0, 248, 3, 0, 0, 98, 0, 0, 0, 99, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 248, 3, 0, 0, 57, 0, 0, 0, 0, 0, 0, 0, 40, 4, 0, 0, 57, 0, 0, 0, 0, 0, 0, 0, 64, 4, 0, 0, 59, 0, 0, 0, 100, 0, 0, 0, 58, 0, 0, 0, 20, 0, 0, 0, 101, 0, 0, 0, 102, 0, 0, 0, 59, 0, 0, 0, 20, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 80, 4, 0, 0, 103, 0, 0, 0, 104, 0, 0, 0, 1, 0, 0, 0, 11, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 80, 4, 0, 0, 61, 0, 0, 0, 0, 0, 0, 0, 128, 4, 0, 0, 61, 0, 0, 0, 0, 0, 0, 0, 152, 4, 0, 0, 103, 0, 0, 0, 105, 0, 0, 0, 1, 0, 0, 0, 11, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 152, 4, 0, 0, 61, 0, 0, 0, 0, 0, 0, 0, 168, 4, 0, 0, 106, 0, 0, 0, 107, 0, 0, 0, 1, 0, 0, 0, 12, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 168, 4, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 216, 4, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 240, 4, 0, 0, 106, 0, 0, 0, 108, 0, 0, 0, 1, 0, 0, 0, 12, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 240, 4, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 8, 5, 0, 0, 109, 0, 0, 0, 110, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 8, 5, 0, 0, 57, 0, 0, 0, 0, 0, 0, 0, 32, 5, 0, 0, 53, 0, 0, 0, 111, 0, 0, 0, 63, 0, 0, 0, 21, 0, 0, 0, 112, 0, 0, 0, 113, 0, 0, 0, 64, 0, 0, 0, 21, 0, 0, 0, 65, 0, 0, 0, 0, 0, 0, 0, 48, 5, 0, 0, 114, 0, 0, 0, 115, 0, 0, 0, 1, 0, 0, 0, 13, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 48, 5, 0, 0, 66, 0, 0, 0, 0, 0, 0, 0, 96, 5, 0, 0, 66, 0, 0, 0, 0, 0, 0, 0, 120, 5, 0, 0, 59, 0, 0, 0, 116, 0, 0, 0, 67, 0, 0, 0, 22, 0, 0, 0, 117, 0, 0, 0, 118, 0, 0, 0, 68, 0, 0, 0, 22, 0, 0, 0, 69, 0, 0, 0, 0, 0, 0, 0, 144, 5, 0, 0, 119, 0, 0, 0, 120, 0, 0, 0, 1, 0, 0, 0, 13, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 144, 5, 0, 0, 66, 0, 0, 0, 0, 0, 0, 0, 168, 5, 0, 0, 53, 0, 0, 0, 121, 0, 0, 0, 70, 0, 0, 0, 23, 0, 0, 0, 122, 0, 0, 0, 123, 0, 0, 0, 71, 0, 0, 0, 23, 0, 0, 0, 72, 0, 0, 0, 0, 0, 0, 0, 184, 5, 0, 0, 124, 0, 0, 0, 125, 0, 0, 0, 1, 0, 0, 0, 14, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 184, 5, 0, 0, 73, 0, 0, 0, 0, 0, 0, 0, 232, 5, 0, 0, 73, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 59, 0, 0, 0, 126, 0, 0, 0, 74, 0, 0, 0, 24, 0, 0, 0, 127, 0, 0, 0, 128, 0, 0, 0, 75, 0, 0, 0, 24, 0, 0, 0, 76, 0, 0, 0, 0, 0, 0, 0, 24, 6, 0, 0, 124, 0, 0, 0, 129, 0, 0, 0, 1, 0, 0, 0, 14, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 24, 6, 0, 0, 73, 0, 0, 0, 0, 0, 0, 0, 48, 6, 0, 0, 53, 0, 0, 0, 130, 0, 0, 0, 77, 0, 0, 0, 25, 0, 0, 0, 131, 0, 0, 0, 132, 0, 0, 0, 78, 0, 0, 0, 25, 0, 0, 0, 79, 0, 0, 0, 0, 0, 0, 0, 64, 6, 0, 0, 133, 0, 0, 0, 134, 0, 0, 0, 1, 0, 0, 0, 15, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 64, 6, 0, 0, 80, 0, 0, 0, 0, 0, 0, 0, 128, 6, 0, 0, 80, 0, 0, 0, 0, 0, 0, 0, 152, 6, 0, 0, 59, 0, 0, 0, 135, 0, 0, 0, 81, 0, 0, 0, 26, 0, 0, 0, 136, 0, 0, 0, 137, 0, 0, 0, 82, 0, 0, 0, 26, 0, 0, 0, 83, 0, 0, 0, 0, 0, 0, 0, 168, 6, 0, 0, 138, 0, 0, 0, 139, 0, 0, 0, 1, 0, 0, 0, 16, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 168, 6, 0, 0, 84, 0, 0, 0, 0, 0, 0, 0, 216, 6, 0, 0, 84, 0, 0, 0, 0, 0, 0, 0, 240, 6, 0, 0, 138, 0, 0, 0, 140, 0, 0, 0, 1, 0, 0, 0, 16, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 240, 6, 0, 0, 84, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 141, 0, 0, 0, 142, 0, 0, 0, 1, 0, 0, 0, 17, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 0, 7, 0, 0, 85, 0, 0, 0, 0, 0, 0, 0, 48, 7, 0, 0, 85, 0, 0, 0, 0, 0, 0, 0, 72, 7, 0, 0, 141, 0, 0, 0, 143, 0, 0, 0, 1, 0, 0, 0, 17, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 72, 7, 0, 0, 85, 0, 0, 0, 0, 0, 0, 0, 96, 7, 0, 0, 144, 0, 0, 0, 145, 0, 0, 0, 1, 0, 0, 0, 15, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 96, 7, 0, 0, 80, 0, 0, 0, 0, 0, 0, 0, 120, 7, 0, 0, 53, 0, 0, 0, 146, 0, 0, 0, 86, 0, 0, 0, 27, 0, 0, 0, 147, 0, 0, 0, 148, 0, 0, 0, 87, 0, 0, 0, 27, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 136, 7, 0, 0, 149, 0, 0, 0, 150, 0, 0, 0, 1, 0, 0, 0, 18, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 136, 7, 0, 0, 89, 0, 0, 0, 0, 0, 0, 0, 184, 7, 0, 0, 89, 0, 0, 0, 0, 0, 0, 0, 208, 7, 0, 0, 59, 0, 0, 0, 151, 0, 0, 0, 90, 0, 0, 0, 28, 0, 0, 0, 152, 0, 0, 0, 153, 0, 0, 0, 91, 0, 0, 0, 28, 0, 0, 0, 92, 0, 0, 0, 0, 0, 0, 0, 224, 7, 0, 0, 93, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 93, 0, 0, 0, 0, 0, 0, 0, 32, 8, 0, 0, 154, 0, 0, 0, 155, 0, 0, 0, 1, 0, 0, 0, 18, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 32, 8, 0, 0, 89, 0, 0, 0, 0, 0, 0, 0, 56, 8, 0, 0, 53, 0, 0, 0, 156, 0, 0, 0, 94, 0, 0, 0, 29, 0, 0, 0, 157, 0, 0, 0, 158, 0, 0, 0, 95, 0, 0, 0, 29, 0, 0, 0, 96, 0, 0, 0, 0, 0, 0, 0, 72, 8, 0, 0, 159, 0, 0, 0, 160, 0, 0, 0, 1, 0, 0, 0, 19, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 72, 8, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 120, 8, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 144, 8, 0, 0, 59, 0, 0, 0, 161, 0, 0, 0, 98, 0, 0, 0, 30, 0, 0, 0, 162, 0, 0, 0, 163, 0, 0, 0, 99, 0, 0, 0, 30, 0, 0, 0, 100, 0, 0, 0, 0, 0, 0, 0, 168, 8, 0, 0, 164, 0, 0, 0, 165, 0, 0, 0, 1, 0, 0, 0, 19, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 168, 8, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 192, 8, 0, 0, 53, 0, 0, 0, 166, 0, 0, 0, 101, 0, 0, 0, 31, 0, 0, 0, 167, 0, 0, 0, 168, 0, 0, 0, 102, 0, 0, 0, 31, 0, 0, 0, 103, 0, 0, 0, 0, 0, 0, 0, 208, 8, 0, 0, 169, 0, 0, 0, 170, 0, 0, 0, 1, 0, 0, 0, 20, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 224, 8, 0, 0, 104, 0, 0, 0, 0, 0, 0, 0, 24, 9, 0, 0, 59, 0, 0, 0, 171, 0, 0, 0, 105, 0, 0, 0, 32, 0, 0, 0, 172, 0, 0, 0, 173, 0, 0, 0, 106, 0, 0, 0, 32, 0, 0, 0, 107, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 0, 108, 0, 0, 0, 0, 0, 0, 0, 48, 9, 0, 0, 109, 0, 0, 0, 0, 0, 0, 0, 104, 9, 0, 0, 59, 0, 0, 0, 174, 0, 0, 0, 110, 0, 0, 0, 33, 0, 0, 0, 175, 0, 0, 0, 176, 0, 0, 0, 111, 0, 0, 0, 33, 0, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 80, 9, 0, 0, 113, 0, 0, 0, 0, 0, 0, 0, 136, 9, 0, 0, 177, 0, 0, 0, 178, 0, 0, 0, 1, 0, 0, 0, 21, 0, 0, 0, 2, 0, 0, 0, 34, 0, 0, 0, 240, 255, 255, 255, 136, 9, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 184, 9, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 216, 9, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 240, 9, 0, 0, 59, 0, 0, 0, 179, 0, 0, 0, 115, 0, 0, 0, 35, 0, 0, 0, 180, 0, 0, 0, 181, 0, 0, 0, 116, 0, 0, 0, 34, 0, 0, 0, 117, 0, 0, 0, 0, 0, 0, 0, 152, 9, 0, 0, 182, 0, 0, 0, 183, 0, 0, 0, 1, 0, 0, 0, 21, 0, 0, 0, 2, 0, 0, 0, 240, 255, 255, 255, 152, 9, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 8, 10, 0, 0, 177, 0, 0, 0, 184, 0, 0, 0, 1, 0, 0, 0, 21, 0, 0, 0, 2, 0, 0, 0, 36, 0, 0, 0, 118, 0, 0, 0, 240, 255, 255, 255, 8, 10, 0, 0, 119, 0, 0, 0, 0, 0, 0, 0, 24, 10, 0, 0, 53, 0, 0, 0, 185, 0, 0, 0, 120, 0, 0, 0, 37, 0, 0, 0, 186, 0, 0, 0, 187, 0, 0, 0, 121, 0, 0, 0, 35, 0, 0, 0, 122, 0, 0, 0, 0, 0, 0, 0, 48, 10, 0, 0, 53, 0, 0, 0, 188, 0, 0, 0, 123, 0, 0, 0, 38, 0, 0, 0, 189, 0, 0, 0, 190, 0, 0, 0, 124, 0, 0, 0, 36, 0, 0, 0, 125, 0, 0, 0, 198, 185, 0, 0, 216, 185, 0, 0, 0, 0, 0, 0, 72, 10, 0, 0, 126, 0, 0, 0, 0, 0, 0, 0, 104, 10, 0, 0, 126, 0, 0, 0, 168, 30, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 116, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 31, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 7, 0, 0, 0, 124, 0, 1, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 31, 0, 0, 148, 31, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 132, 4, 1, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 192, 3, 0, 0, 192, 4, 0, 0, 192, 5, 0, 0, 192, 6, 0, 0, 192, 7, 0, 0, 192, 8, 0, 0, 192, 9, 0, 0, 192, 10, 0, 0, 192, 11, 0, 0, 192, 12, 0, 0, 192, 13, 0, 0, 192, 14, 0, 0, 192, 15, 0, 0, 192, 16, 0, 0, 192, 17, 0, 0, 192, 18, 0, 0, 192, 19, 0, 0, 192, 20, 0, 0, 192, 21, 0, 0, 192, 22, 0, 0, 192, 23, 0, 0, 192, 24, 0, 0, 192, 25, 0, 0, 192, 26, 0, 0, 192, 27, 0, 0, 192, 28, 0, 0, 192, 29, 0, 0, 192, 30, 0, 0, 192, 31, 0, 0, 192, 0, 0, 0, 179, 1, 0, 0, 195, 2, 0, 0, 195, 3, 0, 0, 195, 4, 0, 0, 195, 5, 0, 0, 195, 6, 0, 0, 195, 7, 0, 0, 195, 8, 0, 0, 195, 9, 0, 0, 195, 10, 0, 0, 195, 11, 0, 0, 195, 12, 0, 0, 195, 13, 0, 0, 211, 14, 0, 0, 195, 15, 0, 0, 195, 0, 0, 12, 187, 1, 0, 12, 195, 2, 0, 12, 195, 3, 0, 12, 195, 4, 0, 12, 211, 10, 0, 0, 0, 100, 0, 0, 0, 232, 3, 0, 0, 16, 39, 0, 0, 160, 134, 1, 0, 64, 66, 15, 0, 128, 150, 152, 0, 0, 225, 245, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 164, 61, 0, 0, 104, 35, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 11, 0, 0, 0, 12, 0, 0, 0, 13, 0, 0, 0, 14, 0, 0, 0, 15, 0, 0, 0, 16, 0, 0, 0, 17, 0, 0, 0, 18, 0, 0, 0, 19, 0, 0, 0, 20, 0, 0, 0, 21, 0, 0, 0, 22, 0, 0, 0, 23, 0, 0, 0, 24, 0, 0, 0, 25, 0, 0, 0, 26, 0, 0, 0, 27, 0, 0, 0, 28, 0, 0, 0, 29, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 32, 0, 0, 0, 33, 0, 0, 0, 34, 0, 0, 0, 35, 0, 0, 0, 36, 0, 0, 0, 37, 0, 0, 0, 38, 0, 0, 0, 39, 0, 0, 0, 40, 0, 0, 0, 41, 0, 0, 0, 42, 0, 0, 0, 43, 0, 0, 0, 44, 0, 0, 0, 45, 0, 0, 0, 46, 0, 0, 0, 47, 0, 0, 0, 48, 0, 0, 0, 49, 0, 0, 0, 50, 0, 0, 0, 51, 0, 0, 0, 52, 0, 0, 0, 53, 0, 0, 0, 54, 0, 0, 0, 55, 0, 0, 0, 56, 0, 0, 0, 57, 0, 0, 0, 58, 0, 0, 0, 59, 0, 0, 0, 60, 0, 0, 0, 61, 0, 0, 0, 62, 0, 0, 0, 63, 0, 0, 0, 64, 0, 0, 0, 65, 0, 0, 0, 66, 0, 0, 0, 67, 0, 0, 0, 68, 0, 0, 0, 69, 0, 0, 0, 70, 0, 0, 0, 71, 0, 0, 0, 72, 0, 0, 0, 73, 0, 0, 0, 74, 0, 0, 0, 75, 0, 0, 0, 76, 0, 0, 0, 77, 0, 0, 0, 78, 0, 0, 0, 79, 0, 0, 0, 80, 0, 0, 0, 81, 0, 0, 0, 82, 0, 0, 0, 83, 0, 0, 0, 84, 0, 0, 0, 85, 0, 0, 0, 86, 0, 0, 0, 87, 0, 0, 0, 88, 0, 0, 0, 89, 0, 0, 0, 90, 0, 0, 0, 91, 0, 0, 0, 92, 0, 0, 0, 93, 0, 0, 0, 94, 0, 0, 0, 95, 0, 0, 0, 96, 0, 0, 0, 65, 0, 0, 0, 66, 0, 0, 0, 67, 0, 0, 0, 68, 0, 0, 0, 69, 0, 0, 0, 70, 0, 0, 0, 71, 0, 0, 0, 72, 0, 0, 0, 73, 0, 0, 0, 74, 0, 0, 0, 75, 0, 0, 0, 76, 0, 0, 0, 77, 0, 0, 0, 78, 0, 0, 0, 79, 0, 0, 0, 80, 0, 0, 0, 81, 0, 0, 0, 82, 0, 0, 0, 83, 0, 0, 0, 84, 0, 0, 0, 85, 0, 0, 0, 86, 0, 0, 0, 87, 0, 0, 0, 88, 0, 0, 0, 89, 0, 0, 0, 90, 0, 0, 0, 123, 0, 0, 0, 124, 0, 0, 0, 125, 0, 0, 0, 126, 0, 0, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 108, 41 ], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);
allocate([ 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 11, 0, 0, 0, 12, 0, 0, 0, 13, 0, 0, 0, 14, 0, 0, 0, 15, 0, 0, 0, 16, 0, 0, 0, 17, 0, 0, 0, 18, 0, 0, 0, 19, 0, 0, 0, 20, 0, 0, 0, 21, 0, 0, 0, 22, 0, 0, 0, 23, 0, 0, 0, 24, 0, 0, 0, 25, 0, 0, 0, 26, 0, 0, 0, 27, 0, 0, 0, 28, 0, 0, 0, 29, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 32, 0, 0, 0, 33, 0, 0, 0, 34, 0, 0, 0, 35, 0, 0, 0, 36, 0, 0, 0, 37, 0, 0, 0, 38, 0, 0, 0, 39, 0, 0, 0, 40, 0, 0, 0, 41, 0, 0, 0, 42, 0, 0, 0, 43, 0, 0, 0, 44, 0, 0, 0, 45, 0, 0, 0, 46, 0, 0, 0, 47, 0, 0, 0, 48, 0, 0, 0, 49, 0, 0, 0, 50, 0, 0, 0, 51, 0, 0, 0, 52, 0, 0, 0, 53, 0, 0, 0, 54, 0, 0, 0, 55, 0, 0, 0, 56, 0, 0, 0, 57, 0, 0, 0, 58, 0, 0, 0, 59, 0, 0, 0, 60, 0, 0, 0, 61, 0, 0, 0, 62, 0, 0, 0, 63, 0, 0, 0, 64, 0, 0, 0, 97, 0, 0, 0, 98, 0, 0, 0, 99, 0, 0, 0, 100, 0, 0, 0, 101, 0, 0, 0, 102, 0, 0, 0, 103, 0, 0, 0, 104, 0, 0, 0, 105, 0, 0, 0, 106, 0, 0, 0, 107, 0, 0, 0, 108, 0, 0, 0, 109, 0, 0, 0, 110, 0, 0, 0, 111, 0, 0, 0, 112, 0, 0, 0, 113, 0, 0, 0, 114, 0, 0, 0, 115, 0, 0, 0, 116, 0, 0, 0, 117, 0, 0, 0, 118, 0, 0, 0, 119, 0, 0, 0, 120, 0, 0, 0, 121, 0, 0, 0, 122, 0, 0, 0, 91, 0, 0, 0, 92, 0, 0, 0, 93, 0, 0, 0, 94, 0, 0, 0, 95, 0, 0, 0, 96, 0, 0, 0, 97, 0, 0, 0, 98, 0, 0, 0, 99, 0, 0, 0, 100, 0, 0, 0, 101, 0, 0, 0, 102, 0, 0, 0, 103, 0, 0, 0, 104, 0, 0, 0, 105, 0, 0, 0, 106, 0, 0, 0, 107, 0, 0, 0, 108, 0, 0, 0, 109, 0, 0, 0, 110, 0, 0, 0, 111, 0, 0, 0, 112, 0, 0, 0, 113, 0, 0, 0, 114, 0, 0, 0, 115, 0, 0, 0, 116, 0, 0, 0, 117, 0, 0, 0, 118, 0, 0, 0, 119, 0, 0, 0, 120, 0, 0, 0, 121, 0, 0, 0, 122, 0, 0, 0, 123, 0, 0, 0, 124, 0, 0, 0, 125, 0, 0, 0, 126, 0, 0, 0, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 5, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 13, 0, 0, 0, 17, 0, 0, 0, 19, 0, 0, 0, 23, 0, 0, 0, 29, 0, 0, 0, 31, 0, 0, 0, 37, 0, 0, 0, 41, 0, 0, 0, 43, 0, 0, 0, 47, 0, 0, 0, 53, 0, 0, 0, 59, 0, 0, 0, 61, 0, 0, 0, 67, 0, 0, 0, 71, 0, 0, 0, 73, 0, 0, 0, 79, 0, 0, 0, 83, 0, 0, 0, 89, 0, 0, 0, 97, 0, 0, 0, 101, 0, 0, 0, 103, 0, 0, 0, 107, 0, 0, 0, 109, 0, 0, 0, 113, 0, 0, 0, 127, 0, 0, 0, 131, 0, 0, 0, 137, 0, 0, 0, 139, 0, 0, 0, 149, 0, 0, 0, 151, 0, 0, 0, 157, 0, 0, 0, 163, 0, 0, 0, 167, 0, 0, 0, 173, 0, 0, 0, 179, 0, 0, 0, 181, 0, 0, 0, 191, 0, 0, 0, 193, 0, 0, 0, 197, 0, 0, 0, 199, 0, 0, 0, 211, 0, 0, 0, 1, 0, 0, 0, 11, 0, 0, 0, 13, 0, 0, 0, 17, 0, 0, 0, 19, 0, 0, 0, 23, 0, 0, 0, 29, 0, 0, 0, 31, 0, 0, 0, 37, 0, 0, 0, 41, 0, 0, 0, 43, 0, 0, 0, 47, 0, 0, 0, 53, 0, 0, 0, 59, 0, 0, 0, 61, 0, 0, 0, 67, 0, 0, 0, 71, 0, 0, 0, 73, 0, 0, 0, 79, 0, 0, 0, 83, 0, 0, 0, 89, 0, 0, 0, 97, 0, 0, 0, 101, 0, 0, 0, 103, 0, 0, 0, 107, 0, 0, 0, 109, 0, 0, 0, 113, 0, 0, 0, 121, 0, 0, 0, 127, 0, 0, 0, 131, 0, 0, 0, 137, 0, 0, 0, 139, 0, 0, 0, 143, 0, 0, 0, 149, 0, 0, 0, 151, 0, 0, 0, 157, 0, 0, 0, 163, 0, 0, 0, 167, 0, 0, 0, 169, 0, 0, 0, 173, 0, 0, 0, 179, 0, 0, 0, 181, 0, 0, 0, 187, 0, 0, 0, 191, 0, 0, 0, 193, 0, 0, 0, 197, 0, 0, 0, 199, 0, 0, 0, 209, 0, 0, 0, 0, 0, 0, 0, 144, 10, 0, 0, 191, 0, 0, 0, 192, 0, 0, 0, 0, 0, 0, 0, 168, 10, 0, 0, 193, 0, 0, 0, 194, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 5, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 2, 0, 0, 0, 128, 0, 0, 0, 5, 0, 0, 0, 37, 0, 0, 0, 3, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 176, 10, 0, 0, 195, 0, 0, 0, 196, 0, 0, 0, 39, 0, 0, 0, 11, 0, 0, 0, 3, 0, 0, 0, 6, 0, 0, 0, 129, 0, 0, 0, 130, 0, 0, 0, 12, 0, 0, 0, 131, 0, 0, 0, 132, 0, 0, 0, 39, 0, 0, 0, 13, 0, 0, 0, 40, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 184, 10, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 248, 255, 255, 255, 248, 255, 255, 255, 184, 10, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 208, 10, 0, 0, 197, 0, 0, 0, 198, 0, 0, 0, 248, 255, 255, 255, 248, 255, 255, 255, 208, 10, 0, 0, 199, 0, 0, 0, 200, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 232, 10, 0, 0, 38, 0, 0, 0, 39, 0, 0, 0, 252, 255, 255, 255, 252, 255, 255, 255, 232, 10, 0, 0, 40, 0, 0, 0, 41, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 201, 0, 0, 0, 202, 0, 0, 0, 252, 255, 255, 255, 252, 255, 255, 255, 0, 11, 0, 0, 203, 0, 0, 0, 204, 0, 0, 0, 0, 0, 0, 0, 56, 11, 0, 0, 193, 0, 0, 0, 205, 0, 0, 0, 40, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 5, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 2, 0, 0, 0, 133, 0, 0, 0, 134, 0, 0, 0, 41, 0, 0, 0, 3, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 72, 11, 0, 0, 195, 0, 0, 0, 206, 0, 0, 0, 41, 0, 0, 0, 11, 0, 0, 0, 3, 0, 0, 0, 6, 0, 0, 0, 129, 0, 0, 0, 130, 0, 0, 0, 12, 0, 0, 0, 135, 0, 0, 0, 136, 0, 0, 0, 42, 0, 0, 0, 13, 0, 0, 0, 40, 0, 0, 0, 0, 0, 0, 0, 88, 11, 0, 0, 193, 0, 0, 0, 207, 0, 0, 0, 42, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 5, 0, 0, 0, 137, 0, 0, 0, 3, 0, 0, 0, 2, 0, 0, 0, 128, 0, 0, 0, 5, 0, 0, 0, 37, 0, 0, 0, 14, 0, 0, 0, 43, 0, 0, 0, 0, 0, 0, 0, 104, 11, 0, 0, 195, 0, 0, 0, 208, 0, 0, 0, 43, 0, 0, 0, 11, 0, 0, 0, 3, 0, 0, 0, 6, 0, 0, 0, 138, 0, 0, 0, 130, 0, 0, 0, 12, 0, 0, 0, 131, 0, 0, 0, 132, 0, 0, 0, 39, 0, 0, 0, 15, 0, 0, 0, 44, 0, 0, 0, 0, 0, 0, 0, 120, 11, 0, 0, 209, 0, 0, 0, 210, 0, 0, 0, 211, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 152, 11, 0, 0, 212, 0, 0, 0, 213, 0, 0, 0, 211, 0, 0, 0, 2, 0, 0, 0, 8, 0, 0, 0, 17, 0, 0, 0, 0, 0, 0, 0, 168, 11, 0, 0, 214, 0, 0, 0, 215, 0, 0, 0, 211, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 232, 11, 0, 0, 216, 0, 0, 0, 217, 0, 0, 0, 211, 0, 0, 0, 12, 0, 0, 0, 13, 0, 0, 0, 14, 0, 0, 0, 15, 0, 0, 0, 16, 0, 0, 0, 17, 0, 0, 0, 18, 0, 0, 0, 19, 0, 0, 0, 20, 0, 0, 0, 21, 0, 0, 0, 22, 0, 0, 0, 0, 0, 0, 0, 32, 12, 0, 0, 218, 0, 0, 0, 219, 0, 0, 0, 211, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 23, 0, 0, 0, 5, 0, 0, 0, 24, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 96, 12, 0, 0, 220, 0, 0, 0, 221, 0, 0, 0, 211, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 25, 0, 0, 0, 9, 0, 0, 0, 26, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 152, 12, 0, 0, 222, 0, 0, 0, 223, 0, 0, 0, 211, 0, 0, 0, 139, 0, 0, 0, 27, 0, 0, 0, 28, 0, 0, 0, 29, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 1, 0, 0, 0, 248, 255, 255, 255, 152, 12, 0, 0, 140, 0, 0, 0, 141, 0, 0, 0, 142, 0, 0, 0, 143, 0, 0, 0, 144, 0, 0, 0, 145, 0, 0, 0, 146, 0, 0, 0, 0, 0, 0, 0, 208, 12, 0, 0, 224, 0, 0, 0, 225, 0, 0, 0, 211, 0, 0, 0, 147, 0, 0, 0, 32, 0, 0, 0, 33, 0, 0, 0, 34, 0, 0, 0, 35, 0, 0, 0, 36, 0, 0, 0, 2, 0, 0, 0, 248, 255, 255, 255, 208, 12, 0, 0, 148, 0, 0, 0, 149, 0, 0, 0, 150, 0, 0, 0, 151, 0, 0, 0, 152, 0, 0, 0, 153, 0, 0, 0, 154, 0, 0, 0, 37, 0, 0, 0, 72, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 77, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 83, 0, 0, 0, 37, 0, 0, 0, 109, 0, 0, 0, 47, 0, 0, 0, 37, 0, 0, 0, 100, 0, 0, 0, 47, 0, 0, 0, 37, 0, 0, 0, 121, 0, 0, 0, 37, 0, 0, 0, 89, 0, 0, 0, 45, 0, 0, 0, 37, 0, 0, 0, 109, 0, 0, 0, 45, 0, 0, 0, 37, 0, 0, 0, 100, 0, 0, 0, 37, 0, 0, 0, 73, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 77, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 83, 0, 0, 0, 32, 0, 0, 0, 37, 0, 0, 0, 112, 0, 0, 0, 37, 0, 0, 0, 72, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 77, 0, 0, 0, 37, 0, 0, 0, 72, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 77, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 83, 0, 0, 0, 83, 0, 0, 0, 117, 0, 0, 0, 110, 0, 0, 0, 100, 0, 0, 0, 97, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 77, 0, 0, 0, 111, 0, 0, 0, 110, 0, 0, 0, 100, 0, 0, 0, 97, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 84, 0, 0, 0, 117, 0, 0, 0, 101, 0, 0, 0, 115, 0, 0, 0, 100, 0, 0, 0, 97, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 101, 0, 0, 0, 100, 0, 0, 0, 110, 0, 0, 0, 101, 0, 0, 0, 115, 0, 0, 0, 100, 0, 0, 0, 97, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 84, 0, 0, 0, 104, 0, 0, 0, 117, 0, 0, 0, 114, 0, 0, 0, 115, 0, 0, 0, 100, 0, 0, 0, 97, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 0, 114, 0, 0, 0, 105, 0, 0, 0, 100, 0, 0, 0, 97, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 83, 0, 0, 0, 97, 0, 0, 0, 116, 0, 0, 0, 117, 0, 0, 0, 114, 0, 0, 0, 100, 0, 0, 0, 97, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 83, 0, 0, 0, 117, 0, 0, 0, 110, 0, 0, 0, 0, 0, 0, 0, 77, 0, 0, 0, 111, 0, 0, 0, 110, 0, 0, 0, 0, 0, 0, 0, 84, 0, 0, 0, 117, 0, 0, 0, 101, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 101, 0, 0, 0, 100, 0, 0, 0, 0, 0, 0, 0, 84, 0, 0, 0, 104, 0, 0, 0, 117, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 0, 114, 0, 0, 0, 105, 0, 0, 0, 0, 0, 0, 0, 83, 0, 0, 0, 97, 0, 0, 0, 116, 0, 0, 0, 0, 0, 0, 0, 74, 0, 0, 0, 97, 0, 0, 0, 110, 0, 0, 0, 117, 0, 0, 0, 97, 0, 0, 0, 114, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 0, 101, 0, 0, 0, 98, 0, 0, 0, 114, 0, 0, 0, 117, 0, 0, 0, 97, 0, 0, 0, 114, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 77, 0, 0, 0, 97, 0, 0, 0, 114, 0, 0, 0, 99, 0, 0, 0, 104, 0, 0, 0, 0, 0, 0, 0, 65, 0, 0, 0, 112, 0, 0, 0, 114, 0, 0, 0, 105, 0, 0, 0, 108, 0, 0, 0, 0, 0, 0, 0, 77, 0, 0, 0, 97, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 74, 0, 0, 0, 117, 0, 0, 0, 110, 0, 0, 0, 101, 0, 0, 0, 0, 0, 0, 0, 74, 0, 0, 0, 117, 0, 0, 0, 108, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 65, 0, 0, 0, 117, 0, 0, 0, 103, 0, 0, 0, 117, 0, 0, 0, 115, 0, 0, 0, 116, 0, 0, 0, 0, 0, 0, 0, 83, 0, 0, 0, 101, 0, 0, 0, 112, 0, 0, 0, 116, 0, 0, 0, 101, 0, 0, 0, 109, 0, 0, 0, 98, 0, 0, 0, 101, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 79, 0, 0, 0, 99, 0, 0, 0, 116, 0, 0, 0, 111, 0, 0, 0, 98, 0, 0, 0, 101, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 78, 0, 0, 0, 111, 0, 0, 0, 118, 0, 0, 0, 101, 0, 0, 0, 109, 0, 0, 0, 98, 0, 0, 0, 101, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 68, 0, 0, 0, 101, 0, 0, 0, 99, 0, 0, 0, 101, 0, 0, 0, 109, 0, 0, 0, 98, 0, 0, 0, 101, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 74, 0, 0, 0, 97, 0, 0, 0, 110, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 0, 101, 0, 0, 0, 98, 0, 0, 0, 0, 0, 0, 0, 77, 0, 0, 0, 97, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 65, 0, 0, 0, 112, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 74, 0, 0, 0, 117, 0, 0, 0, 110, 0, 0, 0, 0, 0, 0, 0, 74, 0, 0, 0, 117, 0, 0, 0, 108, 0, 0, 0, 0, 0, 0, 0, 65, 0, 0, 0, 117, 0, 0, 0, 103, 0, 0, 0, 0, 0, 0, 0, 83, 0, 0, 0, 101, 0, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 79, 0, 0, 0, 99, 0, 0, 0, 116, 0, 0, 0, 0, 0, 0, 0, 78, 0, 0, 0, 111, 0, 0, 0, 118, 0, 0, 0, 0, 0, 0, 0, 68, 0, 0, 0, 101, 0, 0, 0, 99, 0, 0, 0, 0, 0, 0, 0, 65, 0, 0, 0, 77, 0, 0, 0, 0, 0, 0, 0, 80, 0, 0, 0, 77, 0, 0, 0, 0, 0, 0, 0, 37, 0, 0, 0, 97, 0, 0, 0, 32, 0, 0, 0, 37, 0, 0, 0, 98, 0, 0, 0, 32, 0, 0, 0, 37, 0, 0, 0, 100, 0, 0, 0, 32, 0, 0, 0, 37, 0, 0, 0, 72, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 77, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 83, 0, 0, 0, 32, 0, 0, 0, 37, 0, 0, 0, 89, 0, 0, 0, 0, 0, 0, 0, 37, 0, 0, 0, 73, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 77, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 83, 0, 0, 0, 32, 0, 0, 0, 37, 0, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 37, 0, 0, 0, 109, 0, 0, 0, 47, 0, 0, 0, 37, 0, 0, 0, 100, 0, 0, 0, 47, 0, 0, 0, 37, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 37, 0, 0, 0, 72, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 77, 0, 0, 0, 58, 0, 0, 0, 37, 0, 0, 0, 83, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 0, 0, 226, 0, 0, 0, 227, 0, 0, 0, 211, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 40, 13, 0, 0, 228, 0, 0, 0, 229, 0, 0, 0, 211, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 72, 13, 0, 0, 230, 0, 0, 0, 231, 0, 0, 0, 211, 0, 0, 0, 155, 0, 0, 0, 156, 0, 0, 0, 44, 0, 0, 0, 45, 0, 0, 0, 46, 0, 0, 0, 47, 0, 0, 0, 157, 0, 0, 0, 48, 0, 0, 0, 49, 0, 0, 0, 0, 0, 0, 0, 112, 13, 0, 0, 232, 0, 0, 0, 233, 0, 0, 0, 211, 0, 0, 0, 158, 0, 0, 0, 159, 0, 0, 0, 50, 0, 0, 0, 51, 0, 0, 0, 52, 0, 0, 0, 53, 0, 0, 0, 160, 0, 0, 0, 54, 0, 0, 0, 55, 0, 0, 0, 0, 0, 0, 0, 144, 13, 0, 0, 234, 0, 0, 0, 235, 0, 0, 0, 211, 0, 0, 0, 161, 0, 0, 0, 162, 0, 0, 0, 56, 0, 0, 0, 57, 0, 0, 0, 58, 0, 0, 0, 59, 0, 0, 0, 163, 0, 0, 0, 60, 0, 0, 0, 61, 0, 0, 0, 0, 0, 0, 0, 176, 13, 0, 0, 236, 0, 0, 0, 237, 0, 0, 0, 211, 0, 0, 0, 164, 0, 0, 0, 165, 0, 0, 0, 62, 0, 0, 0, 63, 0, 0, 0, 64, 0, 0, 0, 65, 0, 0, 0, 166, 0, 0, 0, 66, 0, 0, 0, 67, 0, 0, 0, 0, 0, 0, 0, 208, 13, 0, 0, 238, 0, 0, 0, 239, 0, 0, 0, 211, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 248, 13, 0, 0, 240, 0, 0, 0, 241, 0, 0, 0, 211, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 32, 14, 0, 0, 242, 0, 0, 0, 243, 0, 0, 0, 211, 0, 0, 0, 1, 0, 0, 0, 37, 0, 0, 0, 0, 0, 0, 0, 72, 14, 0, 0, 244, 0, 0, 0, 245, 0, 0, 0, 211, 0, 0, 0, 2, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 112, 14, 0, 0, 246, 0, 0, 0, 247, 0, 0, 0, 211, 0, 0, 0, 18, 0, 0, 0, 4, 0, 0, 0, 68, 0, 0, 0, 0, 0, 0, 0, 152, 14, 0, 0, 248, 0, 0, 0, 249, 0, 0, 0, 211, 0, 0, 0, 19, 0, 0, 0, 5, 0, 0, 0, 69, 0, 0, 0, 0, 0, 0, 0, 184, 14, 0, 0, 250, 0, 0, 0, 251, 0, 0, 0, 211, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 11, 0, 0, 0, 167, 0, 0, 0, 168, 0, 0, 0, 12, 0, 0, 0, 169, 0, 0, 0, 0, 0, 0, 0, 240, 14, 0, 0, 250, 0, 0, 0, 252, 0, 0, 0, 211, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 11, 0, 0, 0, 167, 0, 0, 0, 168, 0, 0, 0, 12, 0, 0, 0, 169, 0, 0, 0, 0, 0, 0, 0, 32, 15, 0, 0, 253, 0, 0, 0, 254, 0, 0, 0, 211, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 13, 0, 0, 0, 170, 0, 0, 0, 171, 0, 0, 0, 14, 0, 0, 0, 172, 0, 0, 0, 0, 0, 0, 0, 96, 15, 0, 0, 255, 0, 0, 0, 0, 1, 0, 0, 211, 0, 0, 0, 0, 0, 0, 0, 112, 15, 0, 0, 1, 1, 0, 0, 2, 1, 0, 0, 211, 0, 0, 0, 45, 0, 0, 0, 20, 0, 0, 0, 46, 0, 0, 0, 21, 0, 0, 0, 47, 0, 0, 0, 1, 0, 0, 0, 22, 0, 0, 0, 15, 0, 0, 0, 0, 0, 0, 0, 184, 15, 0, 0, 3, 1, 0, 0, 4, 1, 0, 0, 211, 0, 0, 0, 173, 0, 0, 0, 174, 0, 0, 0, 70, 0, 0, 0, 71, 0, 0, 0, 72, 0, 0, 0, 0, 0, 0, 0, 200, 15, 0, 0, 5, 1, 0, 0, 6, 1, 0, 0, 211, 0, 0, 0, 175, 0, 0, 0, 176, 0, 0, 0, 73, 0, 0, 0, 74, 0, 0, 0, 75, 0, 0, 0, 116, 0, 0, 0, 114, 0, 0, 0, 117, 0, 0, 0, 101, 0, 0, 0, 0, 0, 0, 0, 102, 0, 0, 0, 97, 0, 0, 0, 108, 0, 0, 0, 115, 0, 0, 0, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 136, 11, 0, 0, 250, 0, 0, 0, 7, 1, 0, 0, 211, 0, 0, 0, 0, 0, 0, 0, 152, 15, 0, 0, 250, 0, 0, 0, 8, 1, 0, 0, 211, 0, 0, 0, 23, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 48, 0, 0, 0, 24, 0, 0, 0, 49, 0, 0, 0, 25, 0, 0, 0, 50, 0, 0, 0, 5, 0, 0, 0, 26, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 0, 15, 0, 0, 250, 0, 0, 0, 9, 1, 0, 0, 211, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 17, 0, 0, 0, 177, 0, 0, 0, 178, 0, 0, 0, 18, 0, 0, 0, 179, 0, 0, 0, 0, 0, 0, 0, 64, 15, 0, 0, 250, 0, 0, 0, 10, 1, 0, 0, 211, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 19, 0, 0, 0, 180, 0, 0, 0, 181, 0, 0, 0, 20, 0, 0, 0, 182, 0, 0, 0, 0, 0, 0, 0, 200, 14, 0, 0, 250, 0, 0, 0, 11, 1, 0, 0, 211, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 11, 0, 0, 0, 167, 0, 0, 0, 168, 0, 0, 0, 12, 0, 0, 0, 169, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 232, 15, 0, 0, 12, 1, 0, 0, 13, 1, 0, 0, 14, 1, 0, 0, 15, 1, 0, 0, 27, 0, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 248, 15, 0, 0, 12, 1, 0, 0, 16, 1, 0, 0, 14, 1, 0, 0, 15, 1, 0, 0, 27, 0, 0, 0, 7, 0, 0, 0, 2, 0, 0, 0, 10, 0, 0, 0, 181, 219, 0, 0, 0, 0, 0, 0, 32, 16, 0, 0, 17, 1, 0, 0, 18, 1, 0, 0, 183, 0, 0, 0, 0, 0, 0, 0, 48, 16, 0, 0, 19, 1, 0, 0, 20, 1, 0, 0, 184, 0, 0, 0, 0, 0, 0, 0, 64, 16, 0, 0, 19, 1, 0, 0, 21, 1, 0, 0, 184, 0, 0, 0, 0, 0, 0, 0, 112, 16, 0, 0, 12, 1, 0, 0, 22, 1, 0, 0, 14, 1, 0, 0, 15, 1, 0, 0, 27, 0, 0, 0, 8, 0, 0, 0, 3, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 3, 32, 2, 32, 2, 32, 2, 32, 2, 32, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 1, 96, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 8, 216, 8, 216, 8, 216, 8, 216, 8, 216, 8, 216, 8, 216, 8, 216, 8, 216, 8, 216, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 8, 213, 8, 213, 8, 213, 8, 213, 8, 213, 8, 213, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 8, 197, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 4, 192, 8, 214, 8, 214, 8, 214, 8, 214, 8, 214, 8, 214, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 8, 198, 4, 192, 4, 192, 4, 192, 4, 192, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 115, 116, 91, 48, 93, 32, 61, 61, 32, 84, 79, 80, 76, 69, 86, 69, 76, 0, 115, 114, 99, 47, 97, 115, 109, 50, 119, 97, 115, 109, 46, 104, 0, 112, 114, 111, 99, 101, 115, 115, 65, 115, 109, 0, 97, 115, 109, 70, 117, 110, 99, 116, 105, 111, 110, 91, 48, 93, 32, 61, 61, 32, 68, 69, 70, 85, 78, 0, 97, 108, 109, 111, 115, 116, 32, 97, 115, 109, 0, 98, 111, 100, 121, 91, 48, 93, 91, 48, 93, 32, 61, 61, 32, 83, 84, 65, 84, 32, 38, 38, 32, 98, 111, 100, 121, 91, 48, 93, 91, 49, 93, 91, 48, 93, 32, 61, 61, 32, 83, 84, 82, 73, 78, 71, 32, 38, 38, 32, 40, 98, 111, 100, 121, 91, 48, 93, 91, 49, 93, 91, 49, 93, 45, 62, 103, 101, 116, 73, 83, 116, 114, 105, 110, 103, 40, 41, 32, 61, 61, 32, 73, 83, 116, 114, 105, 110, 103, 40, 34, 117, 115, 101, 32, 97, 115, 109, 34, 41, 32, 124, 124, 32, 98, 111, 100, 121, 91, 48, 93, 91, 49, 93, 91, 49, 93, 45, 62, 103, 101, 116, 73, 83, 116, 114, 105, 110, 103, 40, 41, 32, 61, 61, 32, 73, 83, 116, 114, 105, 110, 103, 40, 34, 97, 108, 109, 111, 115, 116, 32, 97, 115, 109, 34, 41, 41, 0, 118, 97, 108, 117, 101, 91, 49, 93, 45, 62, 103, 101, 116, 78, 117, 109, 98, 101, 114, 40, 41, 32, 61, 61, 32, 48, 0, 118, 97, 108, 117, 101, 91, 49, 93, 32, 61, 61, 32, 79, 82, 32, 38, 38, 32, 118, 97, 108, 117, 101, 91, 51, 93, 91, 48, 93, 32, 61, 61, 32, 78, 85, 77, 32, 38, 38, 32, 118, 97, 108, 117, 101, 91, 51, 93, 91, 49, 93, 45, 62, 103, 101, 116, 78, 117, 109, 98, 101, 114, 40, 41, 32, 61, 61, 32, 48, 0, 118, 97, 108, 117, 101, 91, 49, 93, 32, 61, 61, 32, 80, 76, 85, 83, 0, 105, 109, 112, 111, 114, 116, 91, 49, 93, 45, 62, 103, 101, 116, 78, 117, 109, 98, 101, 114, 40, 41, 32, 61, 61, 32, 48, 0, 118, 97, 108, 117, 101, 91, 49, 93, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 32, 38, 38, 32, 118, 97, 108, 117, 101, 91, 49, 93, 91, 49, 93, 32, 61, 61, 32, 77, 97, 116, 104, 95, 102, 114, 111, 117, 110, 100, 32, 38, 38, 32, 118, 97, 108, 117, 101, 91, 50, 93, 91, 48, 93, 91, 48, 93, 32, 61, 61, 32, 78, 85, 77, 32, 38, 38, 32, 118, 97, 108, 117, 101, 91, 50, 93, 91, 48, 93, 91, 49, 93, 45, 62, 103, 101, 116, 78, 117, 109, 98, 101, 114, 40, 41, 32, 61, 61, 32, 48, 0, 118, 97, 108, 117, 101, 91, 48, 93, 32, 61, 61, 32, 67, 65, 76, 76, 0, 105, 110, 118, 97, 108, 105, 100, 32, 118, 105, 101, 119, 32, 105, 109, 112, 111, 114, 116, 0, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 105, 110, 118, 97, 108, 105, 100, 32, 115, 104, 111, 114, 116, 32, 118, 105, 101, 119, 32, 105, 109, 112, 111, 114, 116, 0, 118, 105, 101, 119, 115, 46, 102, 105, 110, 100, 40, 110, 97, 109, 101, 41, 32, 61, 61, 32, 118, 105, 101, 119, 115, 46, 101, 110, 100, 40, 41, 0, 105, 110, 118, 97, 108, 105, 100, 32, 118, 97, 114, 32, 101, 108, 101, 109, 101, 110, 116, 0, 112, 97, 105, 114, 91, 49, 93, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 95, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 95, 114, 101, 112, 108, 97, 99, 101, 95, 109, 101, 109, 111, 114, 121, 0, 33, 119, 97, 115, 109, 46, 99, 104, 101, 99, 107, 70, 117, 110, 99, 116, 105, 111, 110, 40, 118, 97, 108, 117, 101, 41, 0, 119, 97, 115, 109, 46, 99, 104, 101, 99, 107, 70, 117, 110, 99, 116, 105, 111, 110, 40, 118, 97, 108, 117, 101, 41, 0, 102, 117, 110, 99, 116, 105, 111, 110, 84, 97, 98, 108, 101, 83, 116, 97, 114, 116, 115, 46, 102, 105, 110, 100, 40, 116, 97, 98, 108, 101, 78, 97, 109, 101, 41, 32, 33, 61, 32, 102, 117, 110, 99, 116, 105, 111, 110, 84, 97, 98, 108, 101, 83, 116, 97, 114, 116, 115, 46, 101, 110, 100, 40, 41, 0, 87, 97, 115, 109, 86, 97, 108, 105, 100, 97, 116, 111, 114, 40, 41, 46, 118, 97, 108, 105, 100, 97, 116, 101, 40, 119, 97, 115, 109, 41, 0, 10, 102, 117, 110, 99, 58, 32, 0, 99, 117, 114, 114, 91, 48, 93, 32, 61, 61, 32, 83, 84, 65, 84, 0, 112, 114, 111, 99, 101, 115, 115, 70, 117, 110, 99, 116, 105, 111, 110, 0, 99, 117, 114, 114, 91, 48, 93, 32, 61, 61, 32, 65, 83, 83, 73, 71, 78, 32, 38, 38, 32, 99, 117, 114, 114, 91, 50, 93, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 98, 114, 101, 97, 107, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 48, 32, 38, 38, 32, 99, 111, 110, 116, 105, 110, 117, 101, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 48, 0, 112, 97, 114, 101, 110, 116, 76, 97, 98, 101, 108, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 119, 97, 115, 109, 0, 42, 114, 101, 116, 117, 114, 110, 58, 41, 42, 0, 99, 111, 100, 101, 0, 100, 97, 116, 97, 0, 97, 115, 109, 32, 112, 97, 114, 115, 105, 110, 103, 46, 46, 46, 10, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 112, 114, 111, 118, 105, 100, 101, 100, 84, 111, 116, 97, 108, 77, 101, 109, 111, 114, 121, 39, 93, 59, 32, 125, 0, 69, 114, 114, 111, 114, 58, 32, 112, 114, 111, 118, 105, 100, 101, 100, 32, 109, 101, 109, 111, 114, 121, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 111, 102, 32, 116, 104, 101, 32, 54, 52, 107, 32, 119, 97, 115, 109, 32, 112, 97, 103, 101, 32, 115, 105, 122, 101, 10, 0, 119, 97, 115, 109, 105, 110, 103, 46, 46, 46, 10, 0, 111, 112, 116, 105, 109, 105, 122, 105, 110, 103, 46, 46, 46, 10, 0, 109, 97, 112, 112, 105, 110, 103, 32, 103, 108, 111, 98, 97, 108, 115, 46, 46, 46, 10, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 108, 111, 111, 107, 117, 112, 73, 109, 112, 111, 114, 116, 39, 93, 40, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 36, 48, 41, 44, 32, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 36, 49, 41, 41, 32, 125, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 51, 50, 39, 93, 91, 36, 48, 32, 62, 62, 32, 50, 93, 32, 61, 32, 36, 49, 32, 125, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 70, 51, 50, 39, 93, 91, 36, 48, 32, 62, 62, 32, 50, 93, 32, 61, 32, 36, 49, 32, 125, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 70, 54, 52, 39, 93, 91, 36, 48, 32, 62, 62, 32, 51, 93, 32, 61, 32, 36, 49, 32, 125, 0, 119, 97, 115, 109, 45, 115, 45, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 112, 97, 114, 115, 105, 110, 103, 46, 46, 46, 10, 0, 119, 97, 115, 109, 45, 98, 105, 110, 97, 114, 121, 32, 112, 97, 114, 115, 105, 110, 103, 46, 46, 46, 10, 0, 105, 110, 115, 116, 97, 110, 116, 105, 97, 116, 105, 110, 103, 32, 109, 111, 100, 117, 108, 101, 58, 32, 10, 0, 103, 101, 110, 101, 114, 97, 116, 105, 110, 103, 32, 101, 120, 112, 111, 114, 116, 115, 46, 46, 46, 10, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 97, 115, 109, 69, 120, 112, 111, 114, 116, 115, 39, 93, 32, 61, 32, 123, 125, 59, 32, 125, 0, 123, 32, 118, 97, 114, 32, 110, 97, 109, 101, 32, 61, 32, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 36, 48, 41, 59, 32, 77, 111, 100, 117, 108, 101, 91, 39, 97, 115, 109, 69, 120, 112, 111, 114, 116, 115, 39, 93, 91, 110, 97, 109, 101, 93, 32, 61, 32, 102, 117, 110, 99, 116, 105, 111, 110, 40, 41, 32, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 65, 114, 103, 117, 109, 101, 110, 116, 115, 39, 93, 32, 61, 32, 65, 114, 114, 97, 121, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 115, 108, 105, 99, 101, 46, 99, 97, 108, 108, 40, 97, 114, 103, 117, 109, 101, 110, 116, 115, 41, 59, 32, 77, 111, 100, 117, 108, 101, 91, 39, 95, 99, 97, 108, 108, 95, 102, 114, 111, 109, 95, 106, 115, 39, 93, 40, 36, 48, 41, 59, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 82, 101, 116, 117, 114, 110, 39, 93, 59, 32, 125, 59, 32, 125, 0, 123, 32, 118, 97, 114, 32, 109, 111, 100, 32, 61, 32, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 36, 48, 41, 59, 32, 118, 97, 114, 32, 98, 97, 115, 101, 32, 61, 32, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 36, 49, 41, 59, 32, 118, 97, 114, 32, 110, 97, 109, 101, 32, 61, 32, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 36, 50, 41, 59, 32, 97, 115, 115, 101, 114, 116, 40, 77, 111, 100, 117, 108, 101, 91, 39, 108, 111, 111, 107, 117, 112, 73, 109, 112, 111, 114, 116, 39, 93, 40, 109, 111, 100, 44, 32, 98, 97, 115, 101, 41, 44, 32, 39, 99, 104, 101, 99, 107, 105, 110, 103, 32, 105, 109, 112, 111, 114, 116, 32, 39, 32, 43, 32, 110, 97, 109, 101, 32, 43, 32, 39, 32, 61, 32, 39, 32, 43, 32, 109, 111, 100, 32, 43, 32, 39, 46, 39, 32, 43, 32, 98, 97, 115, 101, 41, 59, 32, 125, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 105, 110, 115, 116, 97, 110, 99, 101, 46, 46, 46, 10, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 111, 117, 116, 115, 105, 100, 101, 39, 93, 91, 39, 101, 120, 116, 114, 97, 83, 116, 97, 99, 107, 84, 114, 97, 99, 101, 39, 93, 32, 61, 32, 102, 117, 110, 99, 116, 105, 111, 110, 40, 41, 32, 123, 32, 114, 101, 116, 117, 114, 110, 32, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 77, 111, 100, 117, 108, 101, 91, 39, 95, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 95, 115, 116, 97, 99, 107, 95, 116, 114, 97, 99, 101, 39, 93, 40, 41, 41, 59, 32, 125, 59, 32, 125, 0, 99, 97, 108, 108, 95, 102, 114, 111, 109, 95, 106, 115, 32, 0, 115, 114, 99, 47, 119, 97, 115, 109, 45, 106, 115, 46, 99, 112, 112, 0, 99, 97, 108, 108, 95, 102, 114, 111, 109, 95, 106, 115, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 65, 114, 103, 117, 109, 101, 110, 116, 115, 39, 93, 46, 108, 101, 110, 103, 116, 104, 32, 125, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 65, 114, 103, 117, 109, 101, 110, 116, 115, 39, 93, 91, 36, 48, 93, 32, 125, 0, 99, 97, 108, 108, 95, 102, 114, 111, 109, 95, 106, 115, 32, 114, 101, 116, 117, 114, 110, 105, 110, 103, 32, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 82, 101, 116, 117, 114, 110, 39, 93, 32, 61, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 32, 125, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 82, 101, 116, 117, 114, 110, 39, 93, 32, 61, 32, 36, 48, 32, 125, 0, 105, 115, 83, 116, 114, 105, 110, 103, 40, 41, 0, 103, 101, 116, 73, 83, 116, 114, 105, 110, 103, 0, 115, 0, 115, 114, 99, 47, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 45, 111, 112, 116, 105, 109, 105, 122, 101, 114, 47, 105, 115, 116, 114, 105, 110, 103, 46, 104, 0, 73, 83, 116, 114, 105, 110, 103, 0, 33, 119, 97, 115, 109, 58, 58, 84, 104, 114, 101, 97, 100, 80, 111, 111, 108, 58, 58, 105, 115, 82, 117, 110, 110, 105, 110, 103, 40, 41, 0, 115, 101, 116, 0, 115, 105, 122, 101, 0, 105, 115, 78, 117, 109, 98, 101, 114, 40, 41, 0, 103, 101, 116, 78, 117, 109, 98, 101, 114, 0, 109, 97, 112, 112, 101, 100, 71, 108, 111, 98, 97, 108, 115, 46, 102, 105, 110, 100, 40, 110, 97, 109, 101, 41, 32, 61, 61, 32, 109, 97, 112, 112, 101, 100, 71, 108, 111, 98, 97, 108, 115, 46, 101, 110, 100, 40, 41, 0, 97, 108, 108, 111, 99, 97, 116, 101, 71, 108, 111, 98, 97, 108, 0, 110, 101, 120, 116, 71, 108, 111, 98, 97, 108, 32, 60, 32, 109, 97, 120, 71, 108, 111, 98, 97, 108, 0, 105, 109, 112, 111, 114, 116, 101, 100, 91, 48, 93, 32, 61, 61, 32, 68, 79, 84, 0, 109, 111, 100, 117, 108, 101, 91, 49, 93, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 77, 97, 116, 104, 95, 105, 109, 117, 108, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 77, 97, 116, 104, 95, 99, 108, 122, 51, 50, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 77, 97, 116, 104, 95, 102, 114, 111, 117, 110, 100, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 77, 97, 116, 104, 95, 97, 98, 115, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 77, 97, 116, 104, 95, 102, 108, 111, 111, 114, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 77, 97, 116, 104, 95, 99, 101, 105, 108, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 77, 97, 116, 104, 95, 115, 113, 114, 116, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 109, 111, 100, 117, 108, 101, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 116, 101, 109, 112, 68, 111, 117, 98, 108, 101, 80, 116, 114, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 108, 108, 118, 109, 95, 99, 116, 116, 122, 95, 105, 51, 50, 46, 105, 115, 78, 117, 108, 108, 40, 41, 0, 103, 101, 116, 67, 83, 116, 114, 105, 110, 103, 0, 111, 112, 101, 114, 97, 110, 100, 115, 32, 38, 38, 32, 111, 112, 101, 114, 97, 110, 100, 115, 45, 62, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 49, 0, 103, 101, 116, 66, 117, 105, 108, 116, 105, 110, 70, 117, 110, 99, 116, 105, 111, 110, 84, 121, 112, 101, 0, 105, 105, 0, 102, 102, 0, 100, 100, 0, 105, 110, 100, 101, 120, 32, 60, 32, 117, 115, 101, 100, 69, 108, 101, 109, 101, 110, 116, 115, 0, 78, 52, 119, 97, 115, 109, 49, 51, 87, 97, 115, 109, 86, 97, 108, 105, 100, 97, 116, 111, 114, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 51, 87, 97, 115, 109, 86, 97, 108, 105, 100, 97, 116, 111, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 51, 87, 97, 115, 109, 86, 97, 108, 105, 100, 97, 116, 111, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 51, 87, 97, 115, 109, 86, 97, 108, 105, 100, 97, 116, 111, 114, 69, 118, 69, 69, 0, 98, 114, 101, 97, 107, 32, 116, 97, 114, 103, 101, 116, 115, 0, 97, 108, 108, 32, 98, 114, 101, 97, 107, 32, 116, 97, 114, 103, 101, 116, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 118, 97, 108, 105, 100, 0, 98, 108, 111, 99, 107, 43, 98, 114, 101, 97, 107, 115, 32, 109, 117, 115, 116, 32, 104, 97, 118, 101, 32, 114, 105, 103, 104, 116, 32, 116, 121, 112, 101, 32, 105, 102, 32, 98, 114, 101, 97, 107, 115, 32, 114, 101, 116, 117, 114, 110, 32, 97, 32, 118, 97, 108, 117, 101, 0, 32, 33, 61, 32, 0, 58, 32, 0, 44, 32, 111, 110, 32, 10, 0, 91, 119, 97, 115, 109, 45, 118, 97, 108, 105, 100, 97, 116, 111, 114, 32, 101, 114, 114, 111, 114, 32, 105, 110, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 0, 93, 32, 0, 91, 119, 97, 115, 109, 45, 118, 97, 108, 105, 100, 97, 116, 111, 114, 32, 101, 114, 114, 111, 114, 32, 105, 110, 32, 109, 111, 100, 117, 108, 101, 93, 32, 0, 110, 97, 109, 101, 46, 115, 116, 114, 0, 115, 114, 99, 47, 119, 97, 115, 109, 46, 104, 0, 105, 110, 116, 40, 95, 105, 100, 41, 32, 61, 61, 32, 105, 110, 116, 40, 84, 58, 58, 83, 112, 101, 99, 105, 102, 105, 99, 73, 100, 41, 0, 99, 97, 115, 116, 0, 105, 102, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 32, 109, 117, 115, 116, 32, 98, 101, 32, 118, 97, 108, 105, 100, 0, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 102, 97, 108, 115, 101, 58, 32, 0, 98, 114, 101, 97, 107, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 51, 50, 0, 98, 114, 95, 116, 97, 98, 108, 101, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 51, 50, 0, 99, 97, 108, 108, 32, 112, 97, 114, 97, 109, 32, 110, 117, 109, 98, 101, 114, 32, 109, 117, 115, 116, 32, 109, 97, 116, 99, 104, 0, 99, 97, 108, 108, 32, 112, 97, 114, 97, 109, 32, 116, 121, 112, 101, 115, 32, 109, 117, 115, 116, 32, 109, 97, 116, 99, 104, 0, 105, 109, 112, 111, 114, 116, 115, 77, 97, 112, 91, 110, 97, 109, 101, 93, 0, 103, 101, 116, 73, 109, 112, 111, 114, 116, 0, 105, 110, 100, 105, 114, 101, 99, 116, 32, 99, 97, 108, 108, 32, 116, 97, 114, 103, 101, 116, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 110, 32, 105, 51, 50, 0, 115, 101, 116, 95, 108, 111, 99, 97, 108, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 108, 111, 97, 100, 32, 112, 111, 105, 110, 116, 101, 114, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 51, 50, 0, 98, 97, 100, 32, 97, 108, 105, 103, 110, 109, 101, 110, 116, 58, 32, 0, 115, 116, 111, 114, 101, 32, 112, 111, 105, 110, 116, 101, 114, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 51, 50, 0, 115, 116, 111, 114, 101, 32, 118, 97, 108, 117, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 109, 97, 116, 99, 104, 0, 117, 110, 97, 114, 105, 101, 115, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 114, 101, 99, 101, 105, 118, 101, 32, 97, 32, 110, 111, 110, 101, 32, 97, 115, 32, 116, 104, 101, 105, 114, 32, 105, 110, 112, 117, 116, 0, 101, 113, 122, 32, 109, 117, 115, 116, 32, 114, 101, 116, 117, 114, 110, 32, 105, 51, 50, 0, 110, 111, 110, 45, 99, 111, 110, 118, 101, 114, 115, 105, 111, 110, 32, 117, 110, 97, 114, 105, 101, 115, 32, 109, 117, 115, 116, 32, 114, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 116, 121, 112, 101, 0, 101, 113, 122, 32, 105, 110, 112, 117, 116, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 51, 50, 32, 111, 114, 32, 105, 54, 52, 0, 101, 120, 116, 101, 110, 100, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 119, 114, 97, 112, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 116, 114, 117, 110, 99, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 47, 102, 51, 50, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 47, 102, 54, 52, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 99, 111, 110, 118, 101, 114, 116, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 112, 114, 111, 109, 111, 116, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 100, 101, 109, 111, 116, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 47, 105, 51, 50, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 47, 105, 54, 52, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 111, 114, 114, 101, 99, 116, 0, 32, 61, 61, 32, 0, 98, 105, 110, 97, 114, 121, 32, 99, 104, 105, 108, 100, 32, 116, 121, 112, 101, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 101, 113, 117, 97, 108, 0, 103, 114, 111, 119, 95, 109, 101, 109, 111, 114, 121, 32, 109, 117, 115, 116, 32, 104, 97, 118, 101, 32, 49, 32, 111, 112, 101, 114, 97, 110, 100, 0, 103, 114, 111, 119, 95, 109, 101, 109, 111, 114, 121, 32, 109, 117, 115, 116, 32, 104, 97, 118, 101, 32, 105, 51, 50, 32, 111, 112, 101, 114, 97, 110, 100, 0, 102, 117, 110, 99, 116, 105, 111, 110, 32, 98, 111, 100, 121, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 109, 97, 116, 99, 104, 44, 32, 105, 102, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 114, 101, 116, 117, 114, 110, 115, 0, 102, 117, 110, 99, 116, 105, 111, 110, 32, 114, 101, 115, 117, 108, 116, 32, 109, 117, 115, 116, 32, 109, 97, 116, 99, 104, 44, 32, 105, 102, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 114, 101, 116, 117, 114, 110, 115, 0, 109, 101, 109, 111, 114, 121, 32, 109, 97, 120, 32, 62, 61, 32, 105, 110, 105, 116, 105, 97, 108, 0, 116, 111, 116, 97, 108, 32, 109, 101, 109, 111, 114, 121, 32, 109, 117, 115, 116, 32, 98, 101, 32, 60, 61, 32, 52, 71, 66, 0, 115, 101, 103, 109, 101, 110, 116, 32, 111, 102, 102, 115, 101, 116, 32, 105, 115, 32, 115, 109, 97, 108, 108, 32, 101, 110, 111, 117, 103, 104, 0, 116, 111, 116, 97, 108, 32, 115, 101, 103, 109, 101, 110, 116, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 115, 109, 97, 108, 108, 32, 101, 110, 111, 117, 103, 104, 0, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 116, 114, 117, 101, 58, 32, 0, 109, 111, 100, 117, 108, 101, 32, 101, 120, 112, 111, 114, 116, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 102, 111, 117, 110, 100, 0, 109, 111, 100, 117, 108, 101, 32, 101, 120, 112, 111, 114, 116, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 117, 110, 105, 113, 117, 101, 0, 115, 116, 97, 114, 116, 32, 109, 117, 115, 116, 32, 98, 101, 32, 102, 111, 117, 110, 100, 0, 115, 116, 97, 114, 116, 32, 109, 117, 115, 116, 32, 104, 97, 118, 101, 32, 48, 32, 112, 97, 114, 97, 109, 115, 0, 115, 116, 97, 114, 116, 32, 109, 117, 115, 116, 32, 110 ], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 10600);
allocate([ 111, 116, 32, 114, 101, 116, 117, 114, 110, 32, 97, 32, 118, 97, 108, 117, 101, 0, 34, 40, 110, 117, 108, 108, 41, 34, 0, 91, 93, 0, 110, 117, 108, 108, 0, 34, 58, 32, 0, 102, 117, 110, 99, 45, 62, 108, 111, 99, 97, 108, 73, 110, 100, 105, 99, 101, 115, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 102, 117, 110, 99, 45, 62, 112, 97, 114, 97, 109, 115, 46, 115, 105, 122, 101, 40, 41, 0, 115, 114, 99, 47, 119, 97, 115, 109, 45, 98, 117, 105, 108, 100, 101, 114, 46, 104, 0, 97, 100, 100, 80, 97, 114, 97, 109, 0, 102, 117, 110, 99, 45, 62, 108, 111, 99, 97, 108, 73, 110, 100, 105, 99, 101, 115, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 102, 117, 110, 99, 45, 62, 112, 97, 114, 97, 109, 115, 46, 115, 105, 122, 101, 40, 41, 32, 43, 32, 102, 117, 110, 99, 45, 62, 118, 97, 114, 115, 46, 115, 105, 122, 101, 40, 41, 0, 97, 100, 100, 86, 97, 114, 0, 67, 111, 117, 108, 100, 32, 110, 111, 116, 32, 102, 105, 110, 100, 32, 112, 97, 115, 115, 58, 32, 0, 70, 97, 116, 97, 108, 58, 32, 0, 97, 115, 109, 50, 119, 97, 115, 109, 32, 61, 61, 32, 110, 117, 108, 108, 112, 116, 114, 32, 38, 38, 32, 115, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 80, 97, 114, 115, 101, 114, 32, 61, 61, 32, 110, 117, 108, 108, 112, 116, 114, 32, 38, 38, 32, 115, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 87, 97, 115, 109, 66, 117, 105, 108, 100, 101, 114, 32, 61, 61, 32, 110, 117, 108, 108, 112, 116, 114, 32, 38, 38, 32, 105, 110, 115, 116, 97, 110, 99, 101, 32, 61, 61, 32, 110, 117, 108, 108, 112, 116, 114, 0, 112, 114, 101, 112, 97, 114, 101, 50, 119, 97, 115, 109, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 33, 33, 77, 111, 100, 117, 108, 101, 91, 39, 111, 117, 116, 115, 105, 100, 101, 39, 93, 91, 39, 87, 65, 83, 77, 95, 74, 83, 95, 68, 69, 66, 85, 71, 39, 93, 32, 125, 0, 47, 47, 32, 69, 77, 83, 67, 82, 73, 80, 84, 69, 78, 95, 83, 84, 65, 82, 84, 95, 70, 85, 78, 67, 83, 0, 114, 101, 116, 117, 114, 110, 32, 116, 114, 117, 101, 59, 0, 102, 117, 110, 99, 116, 105, 111, 110, 32, 0, 115, 116, 114, 115, 116, 114, 40, 103, 114, 111, 119, 116, 104, 70, 117, 110, 99, 83, 116, 97, 114, 116, 32, 43, 32, 49, 44, 32, 34, 102, 117, 110, 99, 116, 105, 111, 110, 32, 34, 41, 32, 61, 61, 32, 48, 0, 112, 114, 111, 99, 101, 115, 115, 0, 103, 114, 111, 119, 116, 104, 70, 117, 110, 99, 69, 110, 100, 32, 62, 32, 103, 114, 111, 119, 116, 104, 70, 117, 110, 99, 83, 116, 97, 114, 116, 32, 43, 32, 53, 0, 97, 32, 60, 61, 32, 115, 116, 100, 58, 58, 110, 117, 109, 101, 114, 105, 99, 95, 108, 105, 109, 105, 116, 115, 60, 97, 100, 100, 114, 101, 115, 115, 95, 116, 62, 58, 58, 109, 97, 120, 40, 41, 0, 65, 100, 100, 114, 101, 115, 115, 0, 115, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 0, 115, 114, 99, 47, 119, 97, 115, 109, 45, 115, 45, 112, 97, 114, 115, 101, 114, 46, 104, 0, 112, 97, 114, 115, 101, 0, 115, 116, 97, 99, 107, 32, 105, 115, 32, 110, 111, 116, 32, 101, 109, 112, 116, 121, 0, 78, 52, 119, 97, 115, 109, 49, 52, 80, 97, 114, 115, 101, 69, 120, 99, 101, 112, 116, 105, 111, 110, 69, 0, 101, 120, 112, 101, 99, 116, 101, 100, 32, 108, 105, 115, 116, 0, 32, 41, 0, 109, 111, 100, 117, 108, 101, 91, 48, 93, 45, 62, 115, 116, 114, 40, 41, 32, 61, 61, 32, 77, 79, 68, 85, 76, 69, 0, 83, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 87, 97, 115, 109, 66, 117, 105, 108, 100, 101, 114, 0, 33, 105, 115, 76, 105, 115, 116, 95, 0, 115, 116, 114, 0, 99, 95, 115, 116, 114, 0, 119, 114, 105, 116, 101, 32, 62, 61, 32, 100, 97, 116, 97, 46, 100, 97, 116, 97, 40, 41, 0, 115, 116, 114, 105, 110, 103, 84, 111, 66, 105, 110, 97, 114, 121, 0, 97, 99, 116, 117, 97, 108, 32, 60, 61, 32, 100, 97, 116, 97, 46, 115, 105, 122, 101, 40, 41, 0, 117, 110, 107, 110, 111, 119, 110, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0, 102, 117, 110, 99, 46, 105, 115, 76, 105, 115, 116, 40, 41, 0, 112, 97, 114, 115, 101, 84, 121, 112, 101, 0, 117, 110, 107, 110, 111, 119, 110, 32, 116, 121, 112, 101, 0, 102, 117, 110, 99, 116, 105, 111, 110, 84, 121, 112, 101, 115, 77, 97, 112, 91, 110, 97, 109, 101, 93, 0, 103, 101, 116, 70, 117, 110, 99, 116, 105, 111, 110, 84, 121, 112, 101, 0, 110, 111, 32, 110, 97, 109, 101, 32, 102, 111, 114, 32, 105, 109, 112, 111, 114, 116, 0, 98, 97, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 116, 121, 112, 101, 32, 102, 111, 114, 32, 105, 109, 112, 111, 114, 116, 0, 98, 97, 100, 32, 105, 109, 112, 111, 114, 116, 32, 101, 108, 101, 109, 101, 110, 116, 0, 114, 101, 115, 117, 108, 116, 91, 48, 93, 45, 62, 115, 116, 114, 40, 41, 32, 61, 61, 32, 82, 69, 83, 85, 76, 84, 0, 112, 97, 114, 115, 101, 73, 109, 112, 111, 114, 116, 0, 98, 97, 100, 32, 109, 111, 100, 117, 108, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 0, 117, 110, 107, 110, 111, 119, 110, 32, 109, 111, 100, 117, 108, 101, 32, 101, 108, 101, 109, 101, 110, 116, 0, 99, 117, 114, 114, 70, 117, 110, 99, 116, 105, 111, 110, 45, 62, 114, 101, 115, 117, 108, 116, 32, 61, 61, 32, 114, 101, 115, 117, 108, 116, 0, 112, 97, 114, 115, 101, 70, 117, 110, 99, 116, 105, 111, 110, 0, 97, 98, 111, 114, 116, 95, 111, 110, 32, 0, 98, 97, 100, 32, 116, 121, 112, 101, 32, 102, 111, 114, 32, 0, 32, 118, 115, 32, 118, 97, 108, 117, 101, 32, 116, 121, 112, 101, 32, 0, 119, 97, 107, 97, 32, 0, 103, 101, 116, 95, 108, 111, 99, 97, 108, 0, 115, 101, 116, 95, 108, 111, 99, 97, 108, 0, 108, 111, 97, 100, 0, 115, 116, 111, 114, 101, 0, 117, 110, 97, 114, 121, 0, 104, 111, 115, 116, 0, 110, 111, 110, 101, 0, 105, 51, 50, 0, 105, 54, 52, 0, 102, 51, 50, 0, 102, 54, 52, 0, 98, 97, 100, 32, 99, 111, 110, 115, 116, 0, 109, 111, 100, 105, 102, 105, 101, 114, 32, 63, 32, 112, 111, 115, 105, 116, 105, 118, 101, 91, 52, 93, 32, 61, 61, 32, 39, 48, 39, 32, 38, 38, 32, 112, 111, 115, 105, 116, 105, 118, 101, 91, 53, 93, 32, 61, 61, 32, 39, 120, 39, 32, 58, 32, 49, 0, 115, 114, 99, 47, 112, 97, 114, 115, 105, 110, 103, 46, 104, 0, 112, 97, 114, 115, 101, 67, 111, 110, 115, 116, 0, 114, 101, 116, 45, 62, 118, 97, 108, 117, 101, 46, 116, 121, 112, 101, 32, 61, 61, 32, 116, 121, 112, 101, 0, 78, 83, 116, 51, 95, 95, 50, 49, 57, 98, 97, 115, 105, 99, 95, 105, 115, 116, 114, 105, 110, 103, 115, 116, 114, 101, 97, 109, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 99, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 53, 98, 97, 115, 105, 99, 95, 115, 116, 114, 105, 110, 103, 98, 117, 102, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 99, 69, 69, 69, 69, 0, 116, 121, 112, 101, 32, 61, 61, 32, 87, 97, 115, 109, 84, 121, 112, 101, 58, 58, 105, 51, 50, 0, 99, 97, 115, 116, 84, 111, 70, 51, 50, 0, 116, 121, 112, 101, 32, 61, 61, 32, 87, 97, 115, 109, 84, 121, 112, 101, 58, 58, 105, 54, 52, 0, 99, 97, 115, 116, 84, 111, 70, 54, 52, 0, 101, 120, 116, 114, 97, 91, 49, 93, 32, 61, 61, 32, 39, 54, 39, 0, 109, 97, 107, 101, 76, 111, 97, 100, 0, 101, 120, 116, 114, 97, 91, 49, 93, 32, 61, 61, 32, 39, 50, 39, 0, 101, 113, 0, 98, 97, 100, 32, 111, 102, 102, 115, 101, 116, 0, 98, 97, 100, 32, 108, 111, 97, 100, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 109, 97, 107, 101, 83, 116, 111, 114, 101, 0, 98, 97, 100, 32, 115, 116, 111, 114, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 108, 97, 98, 101, 108, 83, 116, 97, 99, 107, 46, 98, 97, 99, 107, 40, 41, 32, 61, 61, 32, 99, 117, 114, 114, 45, 62, 110, 97, 109, 101, 0, 109, 97, 107, 101, 66, 108, 111, 99, 107, 0, 105, 110, 118, 97, 108, 105, 100, 0, 114, 101, 116, 45, 62, 102, 117, 108, 108, 84, 121, 112, 101, 0, 109, 97, 107, 101, 67, 97, 108, 108, 73, 110, 100, 105, 114, 101, 99, 116, 0, 108, 111, 99, 97, 108, 73, 110, 100, 105, 99, 101, 115, 46, 99, 111, 117, 110, 116, 40, 110, 97, 109, 101, 41, 32, 62, 32, 48, 0, 103, 101, 116, 76, 111, 99, 97, 108, 73, 110, 100, 101, 120, 0, 105, 102, 45, 116, 114, 117, 101, 0, 105, 102, 45, 101, 108, 115, 101, 0, 78, 52, 119, 97, 115, 109, 49, 49, 66, 114, 101, 97, 107, 83, 101, 101, 107, 101, 114, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 49, 66, 114, 101, 97, 107, 83, 101, 101, 107, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 49, 66, 114, 101, 97, 107, 83, 101, 101, 107, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 49, 66, 114, 101, 97, 107, 83, 101, 101, 107, 101, 114, 69, 118, 69, 69, 0, 108, 111, 111, 112, 45, 111, 117, 116, 0, 108, 111, 111, 112, 45, 105, 110, 0, 99, 117, 114, 114, 91, 48, 93, 45, 62, 115, 116, 114, 40, 41, 32, 61, 61, 32, 83, 69, 71, 77, 69, 78, 84, 0, 112, 97, 114, 115, 101, 77, 101, 109, 111, 114, 121, 0, 115, 91, 50, 93, 45, 62, 115, 116, 114, 40, 41, 32, 61, 61, 32, 77, 69, 77, 79, 82, 89, 0, 112, 97, 114, 115, 101, 69, 120, 112, 111, 114, 116, 0, 109, 101, 109, 111, 114, 121, 32, 101, 120, 112, 111, 114, 116, 101, 100, 32, 98, 117, 116, 32, 110, 111, 32, 109, 101, 109, 111, 114, 121, 0, 117, 110, 102, 97, 109, 105, 108, 105, 97, 114, 32, 115, 101, 99, 116, 105, 111, 110, 58, 32, 0, 112, 111, 115, 32, 61, 61, 32, 98, 101, 102, 111, 114, 101, 32, 43, 32, 115, 101, 99, 116, 105, 111, 110, 83, 105, 122, 101, 0, 115, 114, 99, 47, 119, 97, 115, 109, 45, 98, 105, 110, 97, 114, 121, 46, 104, 0, 114, 101, 97, 100, 0, 61, 61, 32, 114, 101, 97, 100, 72, 101, 97, 100, 101, 114, 0, 115, 117, 114, 112, 114, 105, 115, 105, 110, 103, 32, 118, 97, 108, 117, 101, 0, 60, 61, 61, 0, 103, 101, 116, 73, 110, 116, 51, 50, 58, 32, 0, 32, 61, 61, 62, 0, 103, 101, 116, 73, 110, 116, 49, 54, 58, 32, 0, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 110, 100, 32, 111, 102, 32, 105, 110, 112, 117, 116, 0, 103, 101, 116, 73, 110, 116, 56, 58, 32, 0, 32, 40, 97, 116, 32, 0, 103, 101, 116, 85, 51, 50, 76, 69, 66, 58, 32, 0, 115, 116, 100, 58, 58, 105, 115, 95, 115, 105, 103, 110, 101, 100, 60, 84, 62, 58, 58, 118, 97, 108, 117, 101, 32, 38, 38, 32, 108, 97, 115, 116, 32, 38, 38, 32, 34, 100, 114, 111, 112, 112, 101, 100, 32, 98, 105, 116, 115, 32, 111, 110, 108, 121, 32, 118, 97, 108, 105, 100, 32, 102, 111, 114, 32, 115, 105, 103, 110, 101, 100, 32, 76, 69, 66, 34, 0, 115, 105, 122, 101, 95, 116, 40, 115, 104, 105, 102, 116, 41, 32, 60, 32, 115, 105, 122, 101, 111, 102, 40, 84, 41, 32, 42, 32, 56, 32, 38, 38, 32, 34, 76, 69, 66, 32, 111, 118, 101, 114, 102, 108, 111, 119, 34, 0, 78, 83, 116, 51, 95, 95, 50, 49, 55, 98, 97, 100, 95, 102, 117, 110, 99, 116, 105, 111, 110, 95, 99, 97, 108, 108, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 55, 87, 97, 115, 109, 66, 105, 110, 97, 114, 121, 66, 117, 105, 108, 100, 101, 114, 57, 103, 101, 116, 85, 51, 50, 76, 69, 66, 69, 118, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 52, 95, 69, 69, 70, 104, 118, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 98, 97, 115, 101, 73, 70, 104, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 55, 87, 97, 115, 109, 66, 105, 110, 97, 114, 121, 66, 117, 105, 108, 100, 101, 114, 57, 103, 101, 116, 85, 51, 50, 76, 69, 66, 69, 118, 69, 85, 108, 118, 69, 95, 0, 112, 111, 115, 32, 43, 32, 115, 101, 99, 116, 105, 111, 110, 83, 105, 122, 101, 32, 60, 61, 32, 105, 110, 112, 117, 116, 46, 115, 105, 122, 101, 40, 41, 0, 61, 61, 32, 114, 101, 97, 100, 83, 116, 97, 114, 116, 0, 61, 61, 32, 114, 101, 97, 100, 77, 101, 109, 111, 114, 121, 0, 61, 61, 32, 114, 101, 97, 100, 83, 105, 103, 110, 97, 116, 117, 114, 101, 115, 0, 110, 117, 109, 58, 32, 0, 114, 101, 97, 100, 32, 111, 110, 101, 0, 102, 111, 114, 109, 32, 61, 61, 32, 66, 105, 110, 97, 114, 121, 67, 111, 110, 115, 116, 115, 58, 58, 84, 121, 112, 101, 70, 111, 114, 109, 115, 58, 58, 66, 97, 115, 105, 99, 0, 114, 101, 97, 100, 83, 105, 103, 110, 97, 116, 117, 114, 101, 115, 0, 110, 117, 109, 32, 112, 97, 114, 97, 109, 115, 58, 32, 0, 110, 117, 109, 82, 101, 115, 117, 108, 116, 115, 32, 61, 61, 32, 49, 0, 61, 61, 32, 114, 101, 97, 100, 73, 109, 112, 111, 114, 116, 115, 0, 105, 109, 112, 111, 114, 116, 36, 0, 105, 110, 100, 101, 120, 32, 60, 32, 119, 97, 115, 109, 46, 102, 117, 110, 99, 116, 105, 111, 110, 84, 121, 112, 101, 115, 46, 115, 105, 122, 101, 40, 41, 0, 114, 101, 97, 100, 73, 109, 112, 111, 114, 116, 115, 0, 99, 117, 114, 114, 45, 62, 116, 121, 112, 101, 45, 62, 110, 97, 109, 101, 46, 105, 115, 40, 41, 0, 105, 32, 60, 32, 102, 117, 110, 99, 116, 105, 111, 110, 84, 121, 112, 101, 115, 46, 115, 105, 122, 101, 40, 41, 0, 103, 101, 116, 73, 110, 108, 105, 110, 101, 83, 116, 114, 105, 110, 103, 58, 32, 0, 61, 61, 32, 114, 101, 97, 100, 70, 117, 110, 99, 116, 105, 111, 110, 83, 105, 103, 110, 97, 116, 117, 114, 101, 115, 0, 61, 61, 32, 114, 101, 97, 100, 70, 117, 110, 99, 116, 105, 111, 110, 115, 0, 114, 101, 97, 100, 32, 111, 110, 101, 32, 97, 116, 32, 0, 115, 105, 122, 101, 32, 62, 32, 48, 0, 114, 101, 97, 100, 70, 117, 110, 99, 116, 105, 111, 110, 115, 0, 114, 101, 97, 100, 105, 110, 103, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 102, 117, 110, 99, 116, 105, 111, 110, 58, 32, 0, 98, 114, 101, 97, 107, 83, 116, 97, 99, 107, 46, 101, 109, 112, 116, 121, 40, 41, 0, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 83, 116, 97, 99, 107, 46, 101, 109, 112, 116, 121, 40, 41, 0, 100, 101, 112, 116, 104, 32, 61, 61, 32, 48, 0, 112, 111, 115, 32, 61, 61, 32, 101, 110, 100, 79, 102, 70, 117, 110, 99, 116, 105, 111, 110, 0, 118, 97, 114, 36, 0, 122, 122, 32, 114, 101, 99, 117, 114, 115, 101, 32, 105, 110, 116, 111, 32, 0, 32, 97, 116, 32, 0, 114, 101, 97, 100, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 115, 101, 101, 105, 110, 103, 32, 0, 98, 97, 100, 32, 99, 111, 100, 101, 32, 48, 120, 0, 122, 122, 32, 114, 101, 99, 117, 114, 115, 101, 32, 102, 114, 111, 109, 32, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 66, 108, 111, 99, 107, 0, 101, 110, 100, 32, 62, 61, 32, 115, 116, 97, 114, 116, 0, 118, 105, 115, 105, 116, 66, 108, 111, 99, 107, 0, 10, 32, 122, 122, 32, 66, 108, 111, 99, 107, 32, 101, 108, 101, 109, 101, 110, 116, 32, 0, 108, 97, 98, 101, 108, 36, 0, 112, 111, 115, 32, 62, 32, 48, 0, 117, 110, 103, 101, 116, 73, 110, 116, 56, 0, 117, 110, 103, 101, 116, 73, 110, 116, 56, 32, 40, 97, 116, 32, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 73, 102, 0, 108, 97, 115, 116, 83, 101, 112, 97, 114, 97, 116, 111, 114, 32, 61, 61, 32, 66, 105, 110, 97, 114, 121, 67, 111, 110, 115, 116, 115, 58, 58, 69, 110, 100, 0, 118, 105, 115, 105, 116, 73, 102, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 76, 111, 111, 112, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 66, 114, 101, 97, 107, 0, 97, 114, 105, 116, 121, 32, 61, 61, 32, 48, 32, 124, 124, 32, 97, 114, 105, 116, 121, 32, 61, 61, 32, 49, 0, 118, 105, 115, 105, 116, 66, 114, 101, 97, 107, 0, 98, 114, 101, 97, 107, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 45, 32, 49, 32, 45, 32, 111, 102, 102, 115, 101, 116, 32, 60, 32, 98, 114, 101, 97, 107, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 0, 103, 101, 116, 66, 114, 101, 97, 107, 78, 97, 109, 101, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 83, 119, 105, 116, 99, 104, 0, 118, 105, 115, 105, 116, 83, 119, 105, 116, 99, 104, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 67, 97, 108, 108, 0, 110, 117, 109, 32, 61, 61, 32, 97, 114, 105, 116, 121, 0, 118, 105, 115, 105, 116, 67, 97, 108, 108, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 67, 97, 108, 108, 73, 109, 112, 111, 114, 116, 0, 118, 105, 115, 105, 116, 67, 97, 108, 108, 73, 109, 112, 111, 114, 116, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 67, 97, 108, 108, 73, 109, 112, 111, 114, 116, 32, 0, 32, 119, 105, 116, 104, 32, 116, 121, 112, 101, 32, 0, 32, 97, 110, 100, 32, 0, 32, 112, 97, 114, 97, 109, 115, 10, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 67, 97, 108, 108, 73, 110, 100, 105, 114, 101, 99, 116, 0, 118, 105, 115, 105, 116, 67, 97, 108, 108, 73, 110, 100, 105, 114, 101, 99, 116, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 71, 101, 116, 76, 111, 99, 97, 108, 32, 0, 99, 117, 114, 114, 45, 62, 105, 110, 100, 101, 120, 32, 60, 32, 99, 117, 114, 114, 70, 117, 110, 99, 116, 105, 111, 110, 45, 62, 103, 101, 116, 78, 117, 109, 76, 111, 99, 97, 108, 115, 40, 41, 0, 118, 105, 115, 105, 116, 71, 101, 116, 76, 111, 99, 97, 108, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 83, 101, 116, 76, 111, 99, 97, 108, 0, 118, 105, 115, 105, 116, 83, 101, 116, 76, 111, 99, 97, 108, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 83, 101, 108, 101, 99, 116, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 82, 101, 116, 117, 114, 110, 0, 118, 105, 115, 105, 116, 82, 101, 116, 117, 114, 110, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 78, 111, 112, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 85, 110, 114, 101, 97, 99, 104, 97, 98, 108, 101, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 66, 105, 110, 97, 114, 121, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 85, 110, 97, 114, 121, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 67, 111, 110, 115, 116, 0, 118, 97, 108, 117, 101, 32, 60, 32, 48, 32, 38, 38, 32, 34, 115, 105, 103, 110, 45, 101, 120, 116, 101, 110, 100, 32, 115, 104, 111, 117, 108, 100, 32, 112, 114, 111, 100, 117, 99, 101, 115, 32, 97, 32, 110, 101, 103, 97, 116, 105, 118, 101, 32, 118, 97, 108, 117, 101, 34, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 55, 87, 97, 115, 109, 66, 105, 110, 97, 114, 121, 66, 117, 105, 108, 100, 101, 114, 57, 103, 101, 116, 83, 51, 50, 76, 69, 66, 69, 118, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 52, 95, 69, 69, 70, 97, 118, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 98, 97, 115, 101, 73, 70, 97, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 55, 87, 97, 115, 109, 66, 105, 110, 97, 114, 121, 66, 117, 105, 108, 100, 101, 114, 57, 103, 101, 116, 83, 51, 50, 76, 69, 66, 69, 118, 69, 85, 108, 118, 69, 95, 0, 103, 101, 116, 85, 54, 52, 76, 69, 66, 58, 32, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 55, 87, 97, 115, 109, 66, 105, 110, 97, 114, 121, 66, 117, 105, 108, 100, 101, 114, 57, 103, 101, 116, 83, 54, 52, 76, 69, 66, 69, 118, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 52, 95, 69, 69, 70, 97, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 55, 87, 97, 115, 109, 66, 105, 110, 97, 114, 121, 66, 117, 105, 108, 100, 101, 114, 57, 103, 101, 116, 83, 54, 52, 76, 69, 66, 69, 118, 69, 85, 108, 118, 69, 95, 0, 103, 101, 116, 70, 108, 111, 97, 116, 51, 50, 58, 32, 0, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 102, 51, 50, 0, 103, 101, 116, 70, 108, 111, 97, 116, 54, 52, 58, 32, 0, 103, 101, 116, 73, 110, 116, 54, 52, 58, 32, 0, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 102, 54, 52, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 76, 111, 97, 100, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 83, 116, 111, 114, 101, 0, 122, 122, 32, 110, 111, 100, 101, 58, 32, 72, 111, 115, 116, 0, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 62, 32, 48, 0, 112, 111, 112, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0, 61, 61, 32, 114, 101, 97, 100, 69, 120, 112, 111, 114, 116, 115, 0, 105, 110, 100, 101, 120, 32, 60, 32, 102, 117, 110, 99, 116, 105, 111, 110, 84, 121, 112, 101, 115, 46, 115, 105, 122, 101, 40, 41, 0, 114, 101, 97, 100, 69, 120, 112, 111, 114, 116, 115, 0, 61, 61, 32, 114, 101, 97, 100, 68, 97, 116, 97, 83, 101, 103, 109, 101, 110, 116, 115, 0, 61, 61, 32, 114, 101, 97, 100, 70, 117, 110, 99, 116, 105, 111, 110, 84, 97, 98, 108, 101, 0, 61, 61, 32, 114, 101, 97, 100, 78, 97, 109, 101, 115, 0, 110, 117, 109, 76, 111, 99, 97, 108, 115, 32, 61, 61, 32, 48, 0, 114, 101, 97, 100, 78, 97, 109, 101, 115, 0, 105, 110, 100, 101, 120, 32, 60, 32, 119, 97, 115, 109, 46, 102, 117, 110, 99, 116, 105, 111, 110, 115, 46, 115, 105, 122, 101, 40, 41, 0, 112, 114, 111, 99, 101, 115, 115, 70, 117, 110, 99, 116, 105, 111, 110, 115, 0, 78, 52, 119, 97, 115, 109, 52, 80, 97, 115, 115, 69, 0, 90, 49, 49, 105, 110, 115, 116, 97, 110, 116, 105, 97, 116, 101, 69, 49, 57, 74, 83, 69, 120, 116, 101, 114, 110, 97, 108, 73, 110, 116, 101, 114, 102, 97, 99, 101, 0, 78, 52, 119, 97, 115, 109, 49, 52, 77, 111, 100, 117, 108, 101, 73, 110, 115, 116, 97, 110, 99, 101, 49, 55, 69, 120, 116, 101, 114, 110, 97, 108, 73, 110, 116, 101, 114, 102, 97, 99, 101, 69, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 111, 117, 116, 115, 105, 100, 101, 39, 93, 91, 39, 110, 101, 119, 66, 117, 102, 102, 101, 114, 39, 93, 32, 61, 32, 110, 101, 119, 32, 65, 114, 114, 97, 121, 66, 117, 102, 102, 101, 114, 40, 36, 48, 41, 59, 32, 125, 0, 123, 32, 118, 97, 114, 32, 115, 111, 117, 114, 99, 101, 32, 61, 32, 77, 111, 100, 117, 108, 101, 91, 39, 72, 69, 65, 80, 56, 39, 93, 46, 115, 117, 98, 97, 114, 114, 97, 121, 40, 36, 49, 44, 32, 36, 49, 32, 43, 32, 36, 50, 41, 59, 32, 118, 97, 114, 32, 116, 97, 114, 103, 101, 116, 32, 61, 32, 110, 101, 119, 32, 73, 110, 116, 56, 65, 114, 114, 97, 121, 40, 77, 111, 100, 117, 108, 101, 91, 39, 111, 117, 116, 115, 105, 100, 101, 39, 93, 91, 39, 110, 101, 119, 66, 117, 102, 102, 101, 114, 39, 93, 41, 59, 32, 116, 97, 114, 103, 101, 116, 46, 115, 101, 116, 40, 115, 111, 117, 114, 99, 101, 44, 32, 36, 48, 41, 59, 32, 125, 0, 99, 97, 108, 108, 105, 110, 103, 32, 105, 109, 112, 111, 114, 116, 32, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 65, 114, 103, 117, 109, 101, 110, 116, 115, 39, 93, 32, 61, 32, 91, 93, 59, 32, 125, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 65, 114, 103, 117, 109, 101, 110, 116, 115, 39, 93, 46, 112, 117, 115, 104, 40, 36, 48, 41, 32, 125, 0, 123, 32, 118, 97, 114, 32, 109, 111, 100, 32, 61, 32, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 36, 48, 41, 59, 32, 118, 97, 114, 32, 98, 97, 115, 101, 32, 61, 32, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 36, 49, 41, 59, 32, 118, 97, 114, 32, 116, 101, 109, 112, 65, 114, 103, 117, 109, 101, 110, 116, 115, 32, 61, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 65, 114, 103, 117, 109, 101, 110, 116, 115, 39, 93, 59, 32, 77, 111, 100, 117, 108, 101, 91, 39, 116, 101, 109, 112, 65, 114, 103, 117, 109, 101, 110, 116, 115, 39, 93, 32, 61, 32, 110, 117, 108, 108, 59, 32, 118, 97, 114, 32, 108, 111, 111, 107, 117, 112, 32, 61, 32, 77, 111, 100, 117, 108, 101, 91, 39, 108, 111, 111, 107, 117, 112, 73, 109, 112, 111, 114, 116, 39, 93, 40, 109, 111, 100, 44, 32, 98, 97, 115, 101, 41, 59, 32, 114, 101, 116, 117, 114, 110, 32, 108, 111, 111, 107, 117, 112, 46, 97, 112, 112, 108, 121, 40, 110, 117, 108, 108, 44, 32, 116, 101, 109, 112, 65, 114, 103, 117, 109, 101, 110, 116, 115, 41, 59, 32, 125, 0, 99, 97, 108, 108, 105, 110, 103, 32, 105, 109, 112, 111, 114, 116, 32, 114, 101, 116, 117, 114, 110, 105, 110, 103, 32, 0, 123, 32, 118, 97, 114, 32, 97, 100, 100, 114, 32, 61, 32, 36, 48, 59, 32, 118, 97, 114, 32, 98, 121, 116, 101, 115, 32, 61, 32, 36, 49, 59, 32, 118, 97, 114, 32, 105, 115, 70, 108, 111, 97, 116, 32, 61, 32, 36, 50, 59, 32, 118, 97, 114, 32, 105, 115, 83, 105, 103, 110, 101, 100, 32, 61, 32, 36, 51, 59, 32, 118, 97, 114, 32, 111, 117, 116, 54, 52, 32, 61, 32, 36, 52, 59, 32, 118, 97, 114, 32, 115, 97, 118, 101, 48, 32, 61, 32, 72, 69, 65, 80, 51, 50, 91, 48, 93, 59, 32, 118, 97, 114, 32, 115, 97, 118, 101, 49, 32, 61, 32, 72, 69, 65, 80, 51, 50, 91, 49, 93, 59, 32, 102, 111, 114, 32, 40, 118, 97, 114, 32, 105, 32, 61, 32, 48, 59, 32, 105, 32, 60, 32, 98, 121, 116, 101, 115, 59, 32, 105, 43, 43, 41, 32, 123, 32, 72, 69, 65, 80, 85, 56, 91, 105, 93, 32, 61, 32, 77, 111, 100, 117, 108, 101, 91, 34, 105, 110, 102, 111, 34, 93, 46, 112, 97, 114, 101, 110, 116, 91, 34, 72, 69, 65, 80, 85, 56, 34, 93, 91, 97, 100, 100, 114, 32, 43, 32, 105, 93, 59, 32, 125, 32, 118, 97, 114, 32, 114, 101, 116, 59, 32, 105, 102, 32, 40, 33, 105, 115, 70, 108, 111, 97, 116, 41, 32, 123, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 49, 41, 32, 114, 101, 116, 32, 61, 32, 105, 115, 83, 105, 103, 110, 101, 100, 32, 63, 32, 72, 69, 65, 80, 56, 91, 48, 93, 32, 58, 32, 72, 69, 65, 80, 85, 56, 91, 48, 93, 59, 32, 101, 108, 115, 101, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 50, 41, 32, 114, 101, 116, 32, 61, 32, 105, 115, 83, 105, 103, 110, 101, 100, 32, 63, 32, 72, 69, 65, 80, 49, 54, 91, 48, 93, 32, 58, 32, 72, 69, 65, 80, 85, 49, 54, 91, 48, 93, 59, 32, 101, 108, 115, 101, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 52, 41, 32, 114, 101, 116, 32, 61, 32, 105, 115, 83, 105, 103, 110, 101, 100, 32, 63, 32, 72, 69, 65, 80, 51, 50, 91, 48, 93, 32, 58, 32, 72, 69, 65, 80, 85, 51, 50, 91, 48, 93, 59, 32, 101, 108, 115, 101, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 56, 41, 32, 123, 32, 102, 111, 114, 32, 40, 118, 97, 114, 32, 105, 32, 61, 32, 48, 59, 32, 105, 32, 60, 32, 98, 121, 116, 101, 115, 59, 32, 105, 43, 43, 41, 32, 123, 32, 72, 69, 65, 80, 85, 56, 91, 111, 117, 116, 54, 52, 32, 43, 32, 105, 93, 32, 61, 32, 72, 69, 65, 80, 85, 56, 91, 105, 93, 59, 32, 125, 32, 125, 32, 101, 108, 115, 101, 32, 97, 98, 111, 114, 116, 40, 41, 59, 32, 125, 32, 101, 108, 115, 101, 32, 123, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 52, 41, 32, 114, 101, 116, 32, 61, 32, 72, 69, 65, 80, 70, 51, 50, 91, 48, 93, 59, 32, 101, 108, 115, 101, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 56, 41, 32, 114, 101, 116, 32, 61, 32, 72, 69, 65, 80, 70, 54, 52, 91, 48, 93, 59, 32, 101, 108, 115, 101, 32, 97, 98, 111, 114, 116, 40, 41, 59, 32, 125, 32, 72, 69, 65, 80, 51, 50, 91, 48, 93, 32, 61, 32, 115, 97, 118, 101, 48, 59, 32, 72, 69, 65, 80, 51, 50, 91, 49, 93, 32, 61, 32, 115, 97, 118, 101, 49, 59, 32, 114, 101, 116, 117, 114, 110, 32, 114, 101, 116, 59, 32, 125, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 56, 39, 93, 91, 36, 48, 93, 32, 125, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 85, 56, 39, 93, 91, 36, 48, 93, 32, 125, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 49, 54, 39, 93, 91, 36, 48, 32, 62, 62, 32, 49, 93, 32, 125, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 85, 49, 54, 39, 93, 91, 36, 48, 32, 62, 62, 32, 49, 93, 32, 125, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 51, 50, 39, 93, 91, 36, 48, 32, 62, 62, 32, 50, 93, 32, 125, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 85, 51, 50, 39, 93, 91, 36, 48, 32, 62, 62, 32, 50, 93, 32, 125, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 70, 51, 50, 39, 93, 91, 36, 48, 32, 62, 62, 32, 50, 93, 32, 125, 0, 123, 32, 114, 101, 116, 117, 114, 110, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 70, 54, 52, 39, 93, 91, 36, 48, 32, 62, 62, 32, 51, 93, 32, 125, 0, 123, 32, 118, 97, 114, 32, 97, 100, 100, 114, 32, 61, 32, 36, 48, 59, 32, 118, 97, 114, 32, 98, 121, 116, 101, 115, 32, 61, 32, 36, 49, 59, 32, 118, 97, 114, 32, 105, 115, 70, 108, 111, 97, 116, 32, 61, 32, 36, 50, 59, 32, 118, 97, 114, 32, 118, 97, 108, 117, 101, 32, 61, 32, 36, 51, 59, 32, 118, 97, 114, 32, 115, 97, 118, 101, 48, 32, 61, 32, 72, 69, 65, 80, 51, 50, 91, 48, 93, 59, 32, 118, 97, 114, 32, 115, 97, 118, 101, 49, 32, 61, 32, 72, 69, 65, 80, 51, 50, 91, 49, 93, 59, 32, 105, 102, 32, 40, 33, 105, 115, 70, 108, 111, 97, 116, 41, 32, 123, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 49, 41, 32, 72, 69, 65, 80, 85, 56, 91, 48, 93, 32, 61, 32, 118, 97, 108, 117, 101, 59, 32, 101, 108, 115, 101, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 50, 41, 32, 72, 69, 65, 80, 85, 49, 54, 91, 48, 93, 32, 61, 32, 118, 97, 108, 117, 101, 59, 32, 101, 108, 115, 101, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 52, 41, 32, 72, 69, 65, 80, 85, 51, 50, 91, 48, 93, 32, 61, 32, 118, 97, 108, 117, 101, 59, 32, 101, 108, 115, 101, 32, 97, 98, 111, 114, 116, 40, 41, 59, 32, 125, 32, 101, 108, 115, 101, 32, 123, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 52, 41, 32, 72, 69, 65, 80, 70, 51, 50, 91, 48, 93, 32, 61, 32, 118, 97, 108, 117, 101, 59, 32, 101, 108, 115, 101, 32, 105, 102, 32, 40, 98, 121, 116, 101, 115, 32, 61, 61, 61, 32, 56, 41, 32, 72, 69, 65, 80, 70, 54, 52, 91, 48, 93, 32, 61, 32, 118, 97, 108, 117, 101, 59, 32, 101, 108, 115, 101, 32, 97, 98, 111, 114, 116, 40, 41, 59, 32, 125, 32, 102, 111, 114, 32, 40, 118, 97, 114, 32, 105, 32, 61, 32, 48, 59, 32, 105, 32, 60, 32, 98, 121, 116, 101, 115, 59, 32, 105, 43, 43, 41, 32, 123, 32, 77, 111, 100, 117, 108, 101, 91, 34, 105, 110, 102, 111, 34, 93, 46, 112, 97, 114, 101, 110, 116, 91, 34, 72, 69, 65, 80, 85, 56, 34, 93, 91, 97, 100, 100, 114, 32, 43, 32, 105, 93, 32, 61, 32, 72, 69, 65, 80, 85, 56, 91, 105, 93, 59, 32, 125, 32, 72, 69, 65, 80, 51, 50, 91, 48, 93, 32, 61, 32, 115, 97, 118, 101, 48, 59, 32, 72, 69, 65, 80, 51, 50, 91, 49, 93, 32, 61, 32, 115, 97, 118, 101, 49, 59, 32, 125, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 56, 39, 93, 91, 36, 48, 93, 32, 61, 32, 36, 49, 32, 125, 0, 123, 32, 77, 111, 100, 117, 108, 101, 91, 39, 105, 110, 102, 111, 39, 93, 46, 112, 97, 114, 101, 110, 116, 91, 39, 72, 69, 65, 80, 49, 54, 39, 93, 91, 36, 48, 32, 62, 62, 32, 49, 93, 32, 61, 32, 36, 49, 32, 125, 0, 103, 101, 116, 105, 54, 52, 0, 123, 32, 118, 97, 114, 32, 115, 105, 122, 101, 32, 61, 32, 36, 48, 59, 32, 118, 97, 114, 32, 98, 117, 102, 102, 101, 114, 59, 32, 116, 114, 121, 32, 123, 32, 98, 117, 102, 102, 101, 114, 32, 61, 32, 110, 101, 119, 32, 65, 114, 114, 97, 121, 66, 117, 102, 102, 101, 114, 40, 115, 105, 122, 101, 41, 59, 32, 125, 32, 99, 97, 116, 99, 104, 40, 101, 41, 32, 123, 32, 114, 101, 116, 117, 114, 110, 59, 32, 125, 32, 118, 97, 114, 32, 111, 108, 100, 72, 69, 65, 80, 56, 32, 61, 32, 77, 111, 100, 117, 108, 101, 91, 39, 111, 117, 116, 115, 105, 100, 101, 39, 93, 91, 39, 72, 69, 65, 80, 56, 39, 93, 59, 32, 118, 97, 114, 32, 116, 101, 109, 112, 32, 61, 32, 110, 101, 119, 32, 73, 110, 116, 56, 65, 114, 114, 97, 121, 40, 98, 117, 102, 102, 101, 114, 41, 59, 32, 116, 101, 109, 112, 46, 115, 101, 116, 40, 111, 108, 100, 72, 69, 65, 80, 56, 41, 59, 32, 77, 111, 100, 117, 108, 101, 91, 39, 111, 117, 116, 115, 105, 100, 101, 39, 93, 91, 39, 98, 117, 102, 102, 101, 114, 39, 93, 32, 61, 32, 98, 117, 102, 102, 101, 114, 59, 32, 125, 0, 123, 32, 97, 98, 111, 114, 116, 40, 34, 119, 97, 115, 109, 32, 116, 114, 97, 112, 58, 32, 34, 32, 43, 32, 80, 111, 105, 110, 116, 101, 114, 95, 115, 116, 114, 105, 110, 103, 105, 102, 121, 40, 36, 48, 41, 41, 59, 32, 125, 0, 115, 116, 97, 99, 107, 32, 108, 105, 109, 105, 116, 0, 115, 114, 99, 47, 119, 97, 115, 109, 45, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 46, 104, 0, 99, 97, 108, 108, 70, 117, 110, 99, 116, 105, 111, 110, 73, 110, 116, 101, 114, 110, 97, 108, 0, 33, 102, 108, 111, 119, 46, 98, 114, 101, 97, 107, 105, 110, 103, 40, 41, 32, 124, 124, 32, 102, 108, 111, 119, 46, 98, 114, 101, 97, 107, 84, 111, 32, 61, 61, 32, 82, 69, 84, 85, 82, 78, 95, 70, 76, 79, 87, 0, 102, 117, 110, 99, 116, 105, 111, 110, 45, 62, 114, 101, 115, 117, 108, 116, 32, 61, 61, 32, 114, 101, 116, 46, 116, 121, 112, 101, 0, 70, 117, 110, 99, 116, 105, 111, 110, 32, 96, 0, 96, 32, 101, 120, 112, 101, 99, 116, 115, 32, 0, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 44, 32, 103, 111, 116, 32, 0, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 46, 0, 102, 117, 110, 99, 116, 105, 111, 110, 45, 62, 105, 115, 80, 97, 114, 97, 109, 40, 105, 41, 0, 70, 117, 110, 99, 116, 105, 111, 110, 83, 99, 111, 112, 101, 0, 96, 32, 101, 120, 112, 101, 99, 116, 115, 32, 116, 121, 112, 101, 32, 0, 32, 102, 111, 114, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 0, 44, 32, 103, 111, 116, 32, 0, 102, 117, 110, 99, 116, 105, 111, 110, 45, 62, 105, 115, 86, 97, 114, 40, 105, 41, 0, 99, 97, 108, 108, 73, 110, 100, 105, 114, 101, 99, 116, 58, 32, 111, 118, 101, 114, 102, 108, 111, 119, 0, 99, 97, 108, 108, 73, 110, 100, 105, 114, 101, 99, 116, 58, 32, 98, 97, 100, 32, 116, 121, 112, 101, 0, 102, 108, 111, 119, 46, 118, 97, 108, 117, 101, 46, 116, 121, 112, 101, 32, 61, 61, 32, 99, 117, 114, 114, 45, 62, 116, 121, 112, 101, 0, 111, 102, 102, 115, 101, 116, 32, 62, 32, 109, 101, 109, 111, 114, 121, 0, 102, 105, 110, 97, 108, 32, 62, 32, 109, 101, 109, 111, 114, 121, 0, 98, 121, 116, 101, 115, 32, 62, 32, 109, 101, 109, 111, 114, 121, 0, 104, 105, 103, 104, 101, 115, 116, 32, 62, 32, 109, 101, 109, 111, 114, 121, 0, 32, 62, 32, 0, 78, 83, 116, 51, 95, 95, 50, 49, 56, 98, 97, 115, 105, 99, 95, 115, 116, 114, 105, 110, 103, 115, 116, 114, 101, 97, 109, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 99, 69, 69, 69, 69, 0, 101, 120, 116, 101, 110, 100, 84, 111, 83, 73, 54, 52, 0, 101, 120, 116, 101, 110, 100, 84, 111, 85, 73, 54, 52, 0, 116, 114, 117, 110, 99, 97, 116, 101, 84, 111, 73, 51, 50, 0, 116, 114, 117, 110, 99, 83, 70, 108, 111, 97, 116, 32, 111, 102, 32, 110, 97, 110, 0, 105, 51, 50, 46, 116, 114, 117, 110, 99, 83, 70, 108, 111, 97, 116, 32, 111, 118, 101, 114, 102, 108, 111, 119, 0, 105, 54, 52, 46, 116, 114, 117, 110, 99, 83, 70, 108, 111, 97, 116, 32, 111, 118, 101, 114, 102, 108, 111, 119, 0, 116, 121, 112, 101, 32, 61, 61, 32, 87, 97, 115, 109, 84, 121, 112, 101, 58, 58, 102, 51, 50, 0, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 105, 51, 50, 0, 116, 121, 112, 101, 32, 61, 61, 32, 87, 97, 115, 109, 84, 121, 112, 101, 58, 58, 102, 54, 52, 0, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 105, 54, 52, 0, 116, 114, 117, 110, 99, 85, 70, 108, 111, 97, 116, 32, 111, 102, 32, 110, 97, 110, 0, 105, 51, 50, 46, 116, 114, 117, 110, 99, 85, 70, 108, 111, 97, 116, 32, 111, 118, 101, 114, 102, 108, 111, 119, 0, 105, 54, 52, 46, 116, 114, 117, 110, 99, 85, 70, 108, 111, 97, 116, 32, 111, 118, 101, 114, 102, 108, 111, 119, 0, 99, 97, 115, 116, 84, 111, 73, 51, 50, 0, 101, 120, 116, 101, 110, 100, 84, 111, 70, 54, 52, 0, 99, 97, 115, 116, 84, 111, 73, 54, 52, 0, 116, 114, 117, 110, 99, 97, 116, 101, 84, 111, 70, 51, 50, 0, 105, 115, 67, 111, 110, 99, 114, 101, 116, 101, 87, 97, 115, 109, 84, 121, 112, 101, 40, 99, 117, 114, 114, 45, 62, 108, 101, 102, 116, 45, 62, 116, 121, 112, 101, 41, 32, 63, 32, 108, 101, 102, 116, 46, 116, 121, 112, 101, 32, 61, 61, 32, 99, 117, 114, 114, 45, 62, 108, 101, 102, 116, 45, 62, 116, 121, 112, 101, 32, 58, 32, 116, 114, 117, 101, 0, 118, 105, 115, 105, 116, 66, 105, 110, 97, 114, 121, 0, 105, 115, 67, 111, 110, 99, 114, 101, 116, 101, 87, 97, 115, 109, 84, 121, 112, 101, 40, 99, 117, 114, 114, 45, 62, 114, 105, 103, 104, 116, 45, 62, 116, 121, 112, 101, 41, 32, 63, 32, 114, 105, 103, 104, 116, 46, 116, 121, 112, 101, 32, 61, 61, 32, 99, 117, 114, 114, 45, 62, 114, 105, 103, 104, 116, 45, 62, 116, 121, 112, 101, 32, 58, 32, 116, 114, 117, 101, 0, 105, 51, 50, 46, 100, 105, 118, 95, 115, 32, 98, 121, 32, 48, 0, 105, 51, 50, 46, 100, 105, 118, 95, 115, 32, 111, 118, 101, 114, 102, 108, 111, 119, 0, 105, 51, 50, 46, 100, 105, 118, 95, 117, 32, 98, 121, 32, 48, 0, 105, 51, 50, 46, 114, 101, 109, 95, 115, 32, 98, 121, 32, 48, 0, 105, 51, 50, 46, 114, 101, 109, 95, 117, 32, 98, 121, 32, 48, 0, 105, 54, 52, 46, 100, 105, 118, 95, 115, 32, 98, 121, 32, 48, 0, 105, 54, 52, 46, 100, 105, 118, 95, 115, 32, 111, 118, 101, 114, 102, 108, 111, 119, 0, 105, 54, 52, 46, 100, 105, 118, 95, 117, 32, 98, 121, 32, 48, 0, 105, 54, 52, 46, 114, 101, 109, 95, 115, 32, 98, 121, 32, 48, 0, 105, 54, 52, 46, 114, 101, 109, 95, 117, 32, 98, 121, 32, 48, 0, 115, 116, 100, 58, 58, 105, 115, 110, 97, 110, 40, 102, 41, 32, 38, 38, 32, 34, 101, 120, 112, 101, 99, 116, 101, 100, 32, 97, 32, 78, 97, 78, 34, 0, 115, 101, 116, 81, 117, 105, 101, 116, 78, 97, 78, 0, 103, 114, 111, 119, 77, 101, 109, 111, 114, 121, 58, 32, 100, 101, 108, 116, 97, 32, 114, 101, 108, 97, 116, 105, 118, 101, 108, 121, 32, 116, 111, 111, 32, 98, 105, 103, 0, 103, 114, 111, 119, 77, 101, 109, 111, 114, 121, 58, 32, 100, 101, 108, 116, 97, 32, 111, 98, 106, 101, 99, 116, 105, 118, 101, 108, 121, 32, 116, 111, 111, 32, 98, 105, 103, 0, 103, 114, 111, 119, 77, 101, 109, 111, 114, 121, 58, 32, 101, 120, 99, 101, 101, 100, 115, 32, 109, 97, 120, 0, 47, 61, 61, 32, 40, 98, 105, 110, 97, 114, 121, 101, 110, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 32, 115, 116, 97, 99, 107, 32, 116, 114, 97, 99, 101, 41, 10, 0, 124, 58, 32, 0, 92, 61, 61, 10, 0, 101, 120, 112, 111, 114, 116, 115, 77, 97, 112, 91, 110, 97, 109, 101, 93, 0, 103, 101, 116, 69, 120, 112, 111, 114, 116, 0, 102, 117, 110, 99, 116, 105, 111, 110, 115, 77, 97, 112, 91, 110, 97, 109, 101, 93, 0, 103, 101, 116, 70, 117, 110, 99, 116, 105, 111, 110, 0, 99, 97, 108, 108, 69, 120, 112, 111, 114, 116, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 0, 46, 99, 111, 110, 115, 116, 32, 0, 58, 48, 120, 0, 78, 97, 78, 80, 97, 121, 108, 111, 97, 100, 0, 45, 48, 0, 37, 108, 102, 0, 100, 32, 62, 61, 32, 48, 0, 110, 117, 109, 84, 111, 83, 116, 114, 105, 110, 103, 0, 48, 120, 37, 108, 108, 120, 0, 37, 108, 108, 117, 0, 37, 108, 108, 120, 0, 37, 101, 0, 37, 46, 48, 102, 0, 110, 117, 109, 32, 60, 32, 49, 48, 48, 48, 0, 103, 101, 116, 105, 51, 50, 0, 103, 101, 116, 102, 51, 50, 0, 103, 101, 116, 102, 54, 52, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 53, 65, 115, 109, 50, 87, 97, 115, 109, 66, 117, 105, 108, 100, 101, 114, 49, 53, 112, 114, 111, 99, 101, 115, 115, 70, 117, 110, 99, 116, 105, 111, 110, 69, 78, 54, 99, 97, 115, 104, 101, 119, 51, 82, 101, 102, 69, 69, 51, 36, 95, 49, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 54, 95, 69, 69, 70, 80, 78, 83, 50, 95, 49, 48, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 69, 83, 53, 95, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 98, 97, 115, 101, 73, 70, 80, 78, 52, 119, 97, 115, 109, 49, 48, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 69, 78, 54, 99, 97, 115, 104, 101, 119, 51, 82, 101, 102, 69, 69, 69, 69, 0, 97, 116, 58, 32, 0, 109, 97, 112, 112, 101, 100, 71, 108, 111, 98, 97, 108, 115, 46, 102, 105, 110, 100, 40, 110, 97, 109, 101, 41, 32, 33, 61, 32, 109, 97, 112, 112, 101, 100, 71, 108, 111, 98, 97, 108, 115, 46, 101, 110, 100, 40, 41, 0, 116, 97, 114, 103, 101, 116, 91, 49, 93, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 118, 105, 101, 119, 115, 46, 102, 105, 110, 100, 40, 104, 101, 97, 112, 41, 32, 33, 61, 32, 118, 105, 101, 119, 115, 46, 101, 110, 100, 40, 41, 0, 99, 111, 110, 102, 117, 115, 105, 110, 103, 32, 97, 115, 115, 105, 103, 110, 0, 100, 100, 100, 0, 118, 0, 116, 97, 114, 103, 101, 116, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 98, 97, 100, 32, 117, 110, 97, 114, 121, 0, 97, 115, 116, 91, 50, 93, 45, 62, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 50, 0, 97, 115, 116, 91, 50, 93, 45, 62, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 49, 0, 99, 111, 110, 102, 117, 115, 105, 110, 103, 32, 102, 114, 111, 117, 110, 100, 32, 116, 97, 114, 103, 101, 116, 0, 116, 97, 114, 103, 101, 116, 91, 48, 93, 32, 61, 61, 32, 83, 85, 66, 32, 38, 38, 32, 116, 97, 114, 103, 101, 116, 91, 49, 93, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 32, 38, 38, 32, 116, 97, 114, 103, 101, 116, 91, 50, 93, 91, 48, 93, 32, 61, 61, 32, 66, 73, 78, 65, 82, 89, 32, 38, 38, 32, 116, 97, 114, 103, 101, 116, 91, 50, 93, 91, 49, 93, 32, 61, 61, 32, 65, 78, 68, 32, 38, 38, 32, 116, 97, 114, 103, 101, 116, 91, 50, 93, 91, 51, 93, 91, 48, 93, 32, 61, 61, 32, 78, 85, 77, 0, 102, 117, 110, 99, 116, 105, 111, 110, 45, 62, 114, 101, 115, 117, 108, 116, 32, 61, 61, 32, 116, 121, 112, 101, 0, 98, 114, 101, 97, 107, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 62, 32, 48, 0, 99, 111, 110, 116, 105, 110, 117, 101, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 62, 32, 48, 0, 119, 104, 105, 108, 101, 45, 111, 117, 116, 0, 119, 104, 105, 108, 101, 45, 105, 110, 0, 100, 111, 45, 111, 110, 99, 101, 0, 117, 110, 108, 105, 107, 101, 108, 121, 45, 99, 111, 110, 116, 105, 110, 117, 101, 0, 100, 111, 45, 111, 117, 116, 0, 100, 111, 45, 105, 110, 0, 102, 111, 114, 45, 111, 117, 116, 0, 102, 111, 114, 45, 105, 110, 0, 98, 114, 45, 62, 99, 111, 110, 100, 105, 116, 105, 111, 110, 45, 62, 116, 121, 112, 101, 32, 61, 61, 32, 105, 51, 50, 0, 99, 111, 110, 100, 105, 116, 105, 111, 110, 91, 48, 93, 32, 61, 61, 32, 78, 85, 77, 32, 124, 124, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 91, 48, 93, 32, 61, 61, 32, 85, 78, 65, 82, 89, 95, 80, 82, 69, 70, 73, 88, 0, 115, 119, 105, 116, 99, 104, 45, 100, 101, 102, 97, 117, 108, 116, 0, 105, 110, 100, 101, 120, 32, 62, 61, 32, 109, 105, 110, 0, 105, 110, 100, 101, 120, 32, 62, 61, 32, 48, 0, 115, 119, 105, 116, 99, 104, 45, 99, 97, 115, 101, 0, 99, 111, 110, 102, 117, 115, 105, 110, 103, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0, 98, 97, 100, 32, 119, 97, 115, 109, 32, 98, 105, 110, 97, 114, 121, 32, 111, 112, 0, 102, 97, 108, 115, 101, 32, 38, 38, 32, 34, 101, 120, 112, 101, 99, 116, 101, 100, 32, 115, 105, 103, 110, 101, 100, 32, 111, 114, 32, 117, 110, 115, 105, 103, 110, 101, 100, 32, 105, 110, 116, 51, 50, 34, 0, 99, 104, 101, 99, 107, 76, 105, 116, 101, 114, 97, 108, 0, 100, 101, 116, 101, 99, 116, 65, 115, 109, 84, 121, 112, 101, 0, 97, 115, 116, 91, 48, 93, 32, 61, 61, 32, 67, 65, 76, 76, 32, 38, 38, 32, 97, 115, 116, 91, 49, 93, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 110, 111, 116, 101, 73, 109, 112, 111, 114, 116, 101, 100, 70, 117, 110, 99, 116, 105, 111, 110, 67, 97, 108, 108, 0, 116, 121, 112, 101, 36, 0, 108, 97, 98, 101, 108, 36, 98, 114, 101, 97, 107, 36, 0, 108, 97, 98, 101, 108, 36, 99, 111, 110, 116, 105, 110, 117, 101, 36, 0, 102, 109, 111, 100, 40, 103, 101, 116, 78, 117, 109, 98, 101, 114, 40, 41, 44, 32, 49, 41, 32, 61, 61, 32, 48, 0, 103, 101, 116, 73, 110, 116, 101, 103, 101, 114, 0, 100, 111, 117, 98, 108, 101, 40, 114, 101, 116, 41, 32, 61, 61, 32, 103, 101, 116, 78, 117, 109, 98, 101, 114, 40, 41, 0, 90, 78, 52, 119, 97, 115, 109, 49, 53, 65, 115, 109, 50, 87, 97, 115, 109, 66, 117, 105, 108, 100, 101, 114, 49, 53, 112, 114, 111, 99, 101, 115, 115, 70, 117, 110, 99, 116, 105, 111, 110, 69, 78, 54, 99, 97, 115, 104, 101, 119, 51, 82, 101, 102, 69, 69, 51, 36, 95, 49, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 53, 65, 115, 109, 50, 87, 97, 115, 109, 66, 117, 105, 108, 100, 101, 114, 49, 53, 112, 114, 111, 99, 101, 115, 115, 70, 117, 110, 99, 116, 105, 111, 110, 69, 78, 54, 99, 97, 115, 104, 101, 119, 51, 82, 101, 102, 69, 69, 51, 36, 95, 50, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 54, 95, 69, 69, 70, 80, 78, 83, 50, 95, 49, 48, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 69, 83, 53, 95, 106, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 98, 97, 115, 101, 73, 70, 80, 78, 52, 119, 97, 115, 109, 49, 48, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 69, 78, 54, 99, 97, 115, 104, 101, 119, 51, 82, 101, 102, 69, 106, 69, 69, 69, 0, 98, 97, 100, 32, 112, 114, 111, 99, 101, 115, 115, 85, 110, 115, 104, 105, 102, 116, 101, 100, 0, 90, 78, 52, 119, 97, 115, 109, 49, 53, 65, 115, 109, 50, 87, 97, 115, 109, 66, 117, 105, 108, 100, 101, 114, 49, 53, 112, 114, 111, 99, 101, 115, 115, 70, 117, 110, 99, 116, 105, 111, 110, 69, 78, 54, 99, 97, 115, 104, 101, 119, 51, 82, 101, 102, 69, 69, 51, 36, 95, 50, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 53, 65, 115, 109, 50, 87, 97, 115, 109, 66, 117, 105, 108, 100, 101, 114, 49, 53, 112, 114, 111, 99, 101, 115, 115, 70, 117, 110, 99, 116, 105, 111, 110, 69, 78, 54, 99, 97, 115, 104, 101, 119, 51, 82, 101, 102, 69, 69, 51, 36, 95, 51, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 54, 95, 69, 69, 70, 80, 78, 83, 50, 95, 49, 48, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 69, 83, 53, 95, 106, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 53 ], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 20840);
allocate([ 65, 115, 109, 50, 87, 97, 115, 109, 66, 117, 105, 108, 100, 101, 114, 49, 53, 112, 114, 111, 99, 101, 115, 115, 70, 117, 110, 99, 116, 105, 111, 110, 69, 78, 54, 99, 97, 115, 104, 101, 119, 51, 82, 101, 102, 69, 69, 51, 36, 95, 51, 0, 59, 0, 112, 117, 115, 104, 95, 98, 97, 99, 107, 0, 103, 101, 116, 65, 114, 114, 97, 121, 0, 115, 114, 99, 32, 62, 32, 115, 116, 97, 114, 116, 0, 115, 114, 99, 47, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 45, 111, 112, 116, 105, 109, 105, 122, 101, 114, 47, 112, 97, 114, 115, 101, 114, 46, 104, 0, 70, 114, 97, 103, 0, 115, 116, 114, 99, 109, 112, 40, 115, 116, 114, 46, 115, 116, 114, 44, 32, 115, 116, 97, 114, 116, 41, 32, 61, 61, 32, 48, 0, 102, 114, 97, 103, 32, 112, 97, 114, 115, 105, 110, 103, 0, 37, 115, 58, 10, 61, 61, 61, 61, 61, 61, 61, 61, 61, 61, 10, 0, 10, 10, 0, 110, 97, 109, 101, 46, 116, 121, 112, 101, 32, 61, 61, 32, 83, 69, 80, 65, 82, 65, 84, 79, 82, 32, 38, 38, 32, 110, 97, 109, 101, 46, 115, 116, 114, 91, 48, 93, 32, 61, 61, 32, 39, 40, 39, 0, 42, 115, 114, 99, 32, 61, 61, 32, 39, 40, 39, 0, 97, 114, 103, 46, 116, 121, 112, 101, 32, 61, 61, 32, 73, 68, 69, 78, 84, 0, 102, 117, 110, 99, 91, 48, 93, 32, 61, 61, 32, 68, 69, 70, 85, 78, 0, 97, 112, 112, 101, 110, 100, 65, 114, 103, 117, 109, 101, 110, 116, 84, 111, 70, 117, 110, 99, 116, 105, 111, 110, 0, 42, 115, 114, 99, 32, 61, 61, 32, 39, 123, 39, 0, 112, 97, 114, 115, 101, 66, 114, 97, 99, 107, 101, 116, 101, 100, 66, 108, 111, 99, 107, 0, 59, 125, 0, 42, 115, 114, 99, 32, 61, 61, 32, 39, 125, 39, 0, 110, 97, 109, 101, 46, 116, 121, 112, 101, 32, 61, 61, 32, 73, 68, 69, 78, 84, 0, 112, 97, 114, 115, 101, 86, 97, 114, 0, 59, 44, 0, 118, 97, 114, 91, 48, 93, 32, 61, 61, 32, 86, 65, 82, 0, 97, 112, 112, 101, 110, 100, 84, 111, 86, 97, 114, 0, 104, 97, 115, 67, 104, 97, 114, 40, 115, 101, 112, 115, 44, 32, 42, 115, 114, 99, 41, 0, 112, 97, 114, 115, 101, 82, 101, 116, 117, 114, 110, 0, 112, 97, 114, 115, 101, 80, 97, 114, 101, 110, 110, 101, 100, 0, 42, 115, 114, 99, 32, 61, 61, 32, 39, 41, 39, 0, 110, 101, 120, 116, 46, 116, 121, 112, 101, 32, 61, 61, 32, 75, 69, 89, 87, 79, 82, 68, 32, 38, 38, 32, 110, 101, 120, 116, 46, 115, 116, 114, 32, 61, 61, 32, 87, 72, 73, 76, 69, 0, 112, 97, 114, 115, 101, 68, 111, 0, 112, 97, 114, 115, 101, 83, 119, 105, 116, 99, 104, 0, 118, 97, 108, 117, 101, 46, 116, 121, 112, 101, 32, 61, 61, 32, 79, 80, 69, 82, 65, 84, 79, 82, 0, 118, 97, 108, 117, 101, 46, 115, 116, 114, 32, 61, 61, 32, 77, 73, 78, 85, 83, 0, 118, 97, 108, 117, 101, 50, 46, 105, 115, 78, 117, 109, 98, 101, 114, 40, 41, 0, 42, 115, 114, 99, 32, 61, 61, 32, 39, 58, 39, 0, 115, 119, 105, 116, 99, 104, 95, 91, 48, 93, 32, 61, 61, 32, 83, 87, 73, 84, 67, 72, 0, 97, 112, 112, 101, 110, 100, 67, 97, 115, 101, 84, 111, 83, 119, 105, 116, 99, 104, 0, 97, 112, 112, 101, 110, 100, 68, 101, 102, 97, 117, 108, 116, 84, 111, 83, 119, 105, 116, 99, 104, 0, 97, 112, 112, 101, 110, 100, 67, 111, 100, 101, 84, 111, 83, 119, 105, 116, 99, 104, 0, 99, 111, 100, 101, 91, 48, 93, 32, 61, 61, 32, 66, 76, 79, 67, 75, 0, 112, 97, 114, 115, 101, 70, 111, 114, 0, 42, 115, 114, 99, 32, 61, 61, 32, 39, 59, 39, 0, 112, 97, 114, 115, 101, 67, 97, 108, 108, 0, 44, 41, 0, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 80, 97, 114, 116, 115, 83, 116, 97, 99, 107, 46, 98, 97, 99, 107, 40, 41, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 48, 0, 99, 97, 108, 108, 91, 48, 93, 32, 61, 61, 32, 67, 65, 76, 76, 0, 97, 112, 112, 101, 110, 100, 84, 111, 67, 97, 108, 108, 0, 42, 115, 114, 99, 32, 61, 61, 32, 39, 91, 39, 0, 112, 97, 114, 115, 101, 73, 110, 100, 101, 120, 105, 110, 103, 0, 42, 115, 114, 99, 32, 61, 61, 32, 39, 93, 39, 0, 42, 115, 114, 99, 32, 61, 61, 32, 39, 46, 39, 0, 112, 97, 114, 115, 101, 68, 111, 116, 116, 105, 110, 103, 0, 107, 101, 121, 46, 116, 121, 112, 101, 32, 61, 61, 32, 73, 68, 69, 78, 84, 0, 98, 97, 100, 32, 112, 97, 114, 115, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 115, 116, 97, 116, 101, 0, 105, 32, 60, 32, 40, 105, 110, 116, 41, 112, 97, 114, 116, 115, 46, 115, 105, 122, 101, 40, 41, 45, 49, 32, 38, 38, 32, 105, 32, 62, 61, 32, 51, 0, 112, 97, 114, 115, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0, 112, 97, 114, 116, 115, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 49, 0, 105, 115, 78, 111, 100, 101, 0, 103, 101, 116, 78, 111, 100, 101, 0, 33, 105, 115, 78, 111, 100, 101, 0, 103, 101, 116, 79, 112, 0, 107, 101, 121, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 109, 97, 107, 101, 68, 111, 116, 0, 112, 97, 114, 115, 101, 65, 102, 116, 101, 114, 80, 97, 114, 101, 110, 0, 42, 115, 114, 99, 0, 112, 97, 114, 115, 101, 65, 102, 116, 101, 114, 66, 114, 97, 99, 101, 0, 44, 93, 0, 97, 114, 114, 97, 121, 91, 48, 93, 32, 61, 61, 32, 65, 82, 82, 65, 89, 0, 97, 112, 112, 101, 110, 100, 84, 111, 65, 114, 114, 97, 121, 0, 112, 97, 114, 115, 101, 65, 102, 116, 101, 114, 67, 117, 114, 108, 121, 0, 107, 101, 121, 46, 116, 121, 112, 101, 32, 61, 61, 32, 73, 68, 69, 78, 84, 32, 124, 124, 32, 107, 101, 121, 46, 116, 121, 112, 101, 32, 61, 61, 32, 83, 84, 82, 73, 78, 71, 0, 44, 125, 0, 97, 114, 114, 97, 121, 91, 48, 93, 32, 61, 61, 32, 79, 66, 74, 69, 67, 84, 0, 97, 112, 112, 101, 110, 100, 84, 111, 79, 98, 106, 101, 99, 116, 0, 98, 108, 111, 99, 107, 91, 48, 93, 32, 61, 61, 32, 66, 76, 79, 67, 75, 0, 97, 112, 112, 101, 110, 100, 84, 111, 66, 108, 111, 99, 107, 0, 112, 97, 115, 115, 73, 110, 102, 111, 115, 46, 102, 105, 110, 100, 40, 110, 97, 109, 101, 41, 32, 61, 61, 32, 112, 97, 115, 115, 73, 110, 102, 111, 115, 46, 101, 110, 100, 40, 41, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 112, 97, 115, 115, 46, 99, 112, 112, 0, 114, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 0, 91, 80, 97, 115, 115, 82, 117, 110, 110, 101, 114, 93, 32, 114, 117, 110, 110, 105, 110, 103, 32, 112, 97, 115, 115, 101, 115, 46, 46, 46, 0, 91, 80, 97, 115, 115, 82, 117, 110, 110, 101, 114, 93, 32, 32, 32, 114, 117, 110, 110, 105, 110, 103, 32, 112, 97, 115, 115, 58, 32, 0, 46, 46, 46, 32, 0, 32, 115, 101, 99, 111, 110, 100, 115, 46, 0, 91, 80, 97, 115, 115, 82, 117, 110, 110, 101, 114, 93, 32, 112, 97, 115, 115, 101, 115, 32, 116, 111, 111, 107, 32, 0, 100, 99, 101, 0, 114, 101, 109, 111, 118, 101, 115, 32, 117, 110, 114, 101, 97, 99, 104, 97, 98, 108, 101, 32, 99, 111, 100, 101, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 57, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 98, 97, 115, 101, 73, 70, 80, 78, 52, 119, 97, 115, 109, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 57, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 57, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 57, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 57, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 57, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 98, 97, 115, 101, 73, 70, 78, 52, 119, 97, 115, 109, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 99, 117, 114, 114, 45, 62, 105, 102, 70, 97, 108, 115, 101, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 46, 99, 112, 112, 0, 100, 111, 65, 102, 116, 101, 114, 73, 102, 69, 108, 115, 101, 84, 114, 117, 101, 0, 114, 101, 97, 99, 104, 97, 98, 108, 101, 0, 97, 100, 100, 66, 114, 101, 97, 107, 0, 114, 101, 97, 99, 104, 97, 98, 108, 101, 66, 114, 101, 97, 107, 115, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 48, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 57, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 49, 57, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 57, 68, 101, 97, 100, 67, 111, 100, 101, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 109, 101, 114, 103, 101, 45, 98, 108, 111, 99, 107, 115, 0, 109, 101, 114, 103, 101, 115, 32, 98, 108, 111, 99, 107, 115, 32, 116, 111, 32, 116, 104, 101, 105, 114, 32, 112, 97, 114, 101, 110, 116, 115, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 49, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 49, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 49, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 49, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 49, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 49, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 52, 69, 102, 102, 101, 99, 116, 65, 110, 97, 108, 121, 122, 101, 114, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 69, 102, 102, 101, 99, 116, 65, 110, 97, 108, 121, 122, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 69, 102, 102, 101, 99, 116, 65, 110, 97, 108, 121, 122, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 52, 69, 102, 102, 101, 99, 116, 65, 110, 97, 108, 121, 122, 101, 114, 69, 118, 69, 69, 0, 117, 115, 101, 100, 69, 108, 101, 109, 101, 110, 116, 115, 32, 62, 32, 48, 0, 115, 114, 99, 47, 109, 105, 120, 101, 100, 95, 97, 114, 101, 110, 97, 46, 104, 0, 98, 97, 99, 107, 0, 111, 117, 116, 101, 114, 45, 62, 108, 105, 115, 116, 46, 98, 97, 99, 107, 40, 41, 32, 61, 61, 32, 99, 117, 114, 114, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 46, 99, 112, 112, 0, 111, 112, 116, 105, 109, 105, 122, 101, 0, 112, 111, 112, 95, 98, 97, 99, 107, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 49, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 49, 49, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 49, 77, 101, 114, 103, 101, 66, 108, 111, 99, 107, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 55, 80, 114, 105, 110, 116, 101, 114, 69, 0, 10, 0, 27, 91, 51, 49, 109, 0, 27, 91, 49, 109, 0, 27, 91, 51, 53, 109, 0, 27, 91, 48, 109, 0, 32, 32, 0, 32, 32, 32, 32, 0, 40, 115, 101, 103, 109, 101, 110, 116, 32, 0, 32, 34, 0, 34, 41, 0, 92, 110, 0, 92, 48, 100, 0, 92, 116, 0, 92, 48, 99, 0, 92, 48, 56, 0, 92, 92, 0, 92, 34, 0, 92, 39, 0, 10, 32, 32, 0, 101, 120, 112, 111, 114, 116, 32, 0, 27, 91, 51, 50, 109, 0, 32, 109, 101, 109, 111, 114, 121, 41, 0, 32, 40, 102, 117, 110, 99, 0, 27, 91, 51, 51, 109, 0, 114, 101, 115, 117, 108, 116, 32, 0, 41, 41, 0, 105, 109, 112, 111, 114, 116, 32, 0, 102, 117, 110, 99, 32, 0, 40, 116, 121, 112, 101, 32, 0, 112, 97, 114, 97, 109, 32, 0, 108, 111, 99, 97, 108, 32, 0, 108, 111, 111, 112, 0, 99, 117, 114, 114, 45, 62, 105, 110, 46, 105, 115, 40, 41, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 80, 114, 105, 110, 116, 46, 99, 112, 112, 0, 118, 105, 115, 105, 116, 76, 111, 111, 112, 0, 98, 114, 95, 105, 102, 32, 0, 98, 114, 32, 0, 98, 114, 95, 116, 97, 98, 108, 101, 0, 99, 97, 108, 108, 32, 0, 99, 97, 108, 108, 95, 105, 109, 112, 111, 114, 116, 32, 0, 99, 97, 108, 108, 95, 105, 110, 100, 105, 114, 101, 99, 116, 32, 0, 103, 101, 116, 95, 108, 111, 99, 97, 108, 32, 0, 115, 101, 116, 95, 108, 111, 99, 97, 108, 32, 0, 46, 108, 111, 97, 100, 0, 49, 54, 0, 51, 50, 0, 95, 115, 0, 95, 117, 0, 32, 111, 102, 102, 115, 101, 116, 61, 0, 32, 97, 108, 105, 103, 110, 61, 0, 46, 115, 116, 111, 114, 101, 0, 105, 51, 50, 46, 99, 108, 122, 0, 105, 51, 50, 46, 99, 116, 122, 0, 105, 51, 50, 46, 112, 111, 112, 99, 110, 116, 0, 105, 51, 50, 46, 101, 113, 122, 0, 105, 54, 52, 46, 99, 108, 122, 0, 105, 54, 52, 46, 99, 116, 122, 0, 105, 54, 52, 46, 112, 111, 112, 99, 110, 116, 0, 105, 54, 52, 46, 101, 113, 122, 0, 102, 51, 50, 46, 110, 101, 103, 0, 102, 51, 50, 46, 97, 98, 115, 0, 102, 51, 50, 46, 99, 101, 105, 108, 0, 102, 51, 50, 46, 102, 108, 111, 111, 114, 0, 102, 51, 50, 46, 116, 114, 117, 110, 99, 0, 102, 51, 50, 46, 110, 101, 97, 114, 101, 115, 116, 0, 102, 51, 50, 46, 115, 113, 114, 116, 0, 102, 54, 52, 46, 110, 101, 103, 0, 102, 54, 52, 46, 97, 98, 115, 0, 102, 54, 52, 46, 99, 101, 105, 108, 0, 102, 54, 52, 46, 102, 108, 111, 111, 114, 0, 102, 54, 52, 46, 116, 114, 117, 110, 99, 0, 102, 54, 52, 46, 110, 101, 97, 114, 101, 115, 116, 0, 102, 54, 52, 46, 115, 113, 114, 116, 0, 105, 54, 52, 46, 101, 120, 116, 101, 110, 100, 95, 115, 47, 105, 51, 50, 0, 105, 54, 52, 46, 101, 120, 116, 101, 110, 100, 95, 117, 47, 105, 51, 50, 0, 105, 51, 50, 46, 119, 114, 97, 112, 47, 105, 54, 52, 0, 105, 51, 50, 46, 116, 114, 117, 110, 99, 95, 115, 47, 102, 51, 50, 0, 105, 54, 52, 46, 116, 114, 117, 110, 99, 95, 115, 47, 102, 51, 50, 0, 105, 51, 50, 46, 116, 114, 117, 110, 99, 95, 117, 47, 102, 51, 50, 0, 105, 54, 52, 46, 116, 114, 117, 110, 99, 95, 117, 47, 102, 51, 50, 0, 105, 51, 50, 46, 116, 114, 117, 110, 99, 95, 115, 47, 102, 54, 52, 0, 105, 54, 52, 46, 116, 114, 117, 110, 99, 95, 115, 47, 102, 54, 52, 0, 105, 51, 50, 46, 116, 114, 117, 110, 99, 95, 117, 47, 102, 54, 52, 0, 105, 54, 52, 46, 116, 114, 117, 110, 99, 95, 117, 47, 102, 54, 52, 0, 105, 51, 50, 46, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 47, 102, 51, 50, 0, 105, 54, 52, 46, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 47, 102, 54, 52, 0, 102, 51, 50, 46, 99, 111, 110, 118, 101, 114, 116, 95, 117, 47, 105, 51, 50, 0, 102, 54, 52, 46, 99, 111, 110, 118, 101, 114, 116, 95, 117, 47, 105, 51, 50, 0, 102, 51, 50, 46, 99, 111, 110, 118, 101, 114, 116, 95, 115, 47, 105, 51, 50, 0, 102, 54, 52, 46, 99, 111, 110, 118, 101, 114, 116, 95, 115, 47, 105, 51, 50, 0, 102, 51, 50, 46, 99, 111, 110, 118, 101, 114, 116, 95, 117, 47, 105, 54, 52, 0, 102, 54, 52, 46, 99, 111, 110, 118, 101, 114, 116, 95, 117, 47, 105, 54, 52, 0, 102, 51, 50, 46, 99, 111, 110, 118, 101, 114, 116, 95, 115, 47, 105, 54, 52, 0, 102, 54, 52, 46, 99, 111, 110, 118, 101, 114, 116, 95, 115, 47, 105, 54, 52, 0, 102, 54, 52, 46, 112, 114, 111, 109, 111, 116, 101, 47, 102, 51, 50, 0, 102, 51, 50, 46, 100, 101, 109, 111, 116, 101, 47, 102, 54, 52, 0, 102, 51, 50, 46, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 47, 105, 51, 50, 0, 102, 54, 52, 46, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 47, 105, 54, 52, 0, 105, 51, 50, 46, 97, 100, 100, 0, 105, 51, 50, 46, 115, 117, 98, 0, 105, 51, 50, 46, 109, 117, 108, 0, 105, 51, 50, 46, 100, 105, 118, 95, 115, 0, 105, 51, 50, 46, 100, 105, 118, 95, 117, 0, 105, 51, 50, 46, 114, 101, 109, 95, 115, 0, 105, 51, 50, 46, 114, 101, 109, 95, 117, 0, 105, 51, 50, 46, 97, 110, 100, 0, 105, 51, 50, 46, 111, 114, 0, 105, 51, 50, 46, 120, 111, 114, 0, 105, 51, 50, 46, 115, 104, 108, 0, 105, 51, 50, 46, 115, 104, 114, 95, 117, 0, 105, 51, 50, 46, 115, 104, 114, 95, 115, 0, 105, 51, 50, 46, 114, 111, 116, 108, 0, 105, 51, 50, 46, 114, 111, 116, 114, 0, 105, 51, 50, 46, 101, 113, 0, 105, 51, 50, 46, 110, 101, 0, 105, 51, 50, 46, 108, 116, 95, 115, 0, 105, 51, 50, 46, 108, 116, 95, 117, 0, 105, 51, 50, 46, 108, 101, 95, 115, 0, 105, 51, 50, 46, 108, 101, 95, 117, 0, 105, 51, 50, 46, 103, 116, 95, 115, 0, 105, 51, 50, 46, 103, 116, 95, 117, 0, 105, 51, 50, 46, 103, 101, 95, 115, 0, 105, 51, 50, 46, 103, 101, 95, 117, 0, 105, 54, 52, 46, 97, 100, 100, 0, 105, 54, 52, 46, 115, 117, 98, 0, 105, 54, 52, 46, 109, 117, 108, 0, 105, 54, 52, 46, 100, 105, 118, 95, 115, 0, 105, 54, 52, 46, 100, 105, 118, 95, 117, 0, 105, 54, 52, 46, 114, 101, 109, 95, 115, 0, 105, 54, 52, 46, 114, 101, 109, 95, 117, 0, 105, 54, 52, 46, 97, 110, 100, 0, 105, 54, 52, 46, 111, 114, 0, 105, 54, 52, 46, 120, 111, 114, 0, 105, 54, 52, 46, 115, 104, 108, 0, 105, 54, 52, 46, 115, 104, 114, 95, 117, 0, 105, 54, 52, 46, 115, 104, 114, 95, 115, 0, 105, 54, 52, 46, 114, 111, 116, 108, 0, 105, 54, 52, 46, 114, 111, 116, 114, 0, 105, 54, 52, 46, 101, 113, 0, 105, 54, 52, 46, 110, 101, 0, 105, 54, 52, 46, 108, 116, 95, 115, 0, 105, 54, 52, 46, 108, 116, 95, 117, 0, 105, 54, 52, 46, 108, 101, 95, 115, 0, 105, 54, 52, 46, 108, 101, 95, 117, 0, 105, 54, 52, 46, 103, 116, 95, 115, 0, 105, 54, 52, 46, 103, 116, 95, 117, 0, 105, 54, 52, 46, 103, 101, 95, 115, 0, 105, 54, 52, 46, 103, 101, 95, 117, 0, 102, 51, 50, 46, 97, 100, 100, 0, 102, 51, 50, 46, 115, 117, 98, 0, 102, 51, 50, 46, 109, 117, 108, 0, 102, 51, 50, 46, 100, 105, 118, 0, 102, 51, 50, 46, 99, 111, 112, 121, 115, 105, 103, 110, 0, 102, 51, 50, 46, 109, 105, 110, 0, 102, 51, 50, 46, 109, 97, 120, 0, 102, 51, 50, 46, 101, 113, 0, 102, 51, 50, 46, 110, 101, 0, 102, 51, 50, 46, 108, 116, 0, 102, 51, 50, 46, 108, 101, 0, 102, 51, 50, 46, 103, 116, 0, 102, 51, 50, 46, 103, 101, 0, 102, 54, 52, 46, 97, 100, 100, 0, 102, 54, 52, 46, 115, 117, 98, 0, 102, 54, 52, 46, 109, 117, 108, 0, 102, 54, 52, 46, 100, 105, 118, 0, 102, 54, 52, 46, 99, 111, 112, 121, 115, 105, 103, 110, 0, 102, 54, 52, 46, 109, 105, 110, 0, 102, 54, 52, 46, 109, 97, 120, 0, 102, 54, 52, 46, 101, 113, 0, 102, 54, 52, 46, 110, 101, 0, 102, 54, 52, 46, 108, 116, 0, 102, 54, 52, 46, 108, 101, 0, 102, 54, 52, 46, 103, 116, 0, 102, 54, 52, 46, 103, 101, 0, 115, 101, 108, 101, 99, 116, 0, 112, 97, 103, 101, 115, 105, 122, 101, 0, 99, 117, 114, 114, 101, 110, 116, 95, 109, 101, 109, 111, 114, 121, 0, 103, 114, 111, 119, 95, 109, 101, 109, 111, 114, 121, 0, 104, 97, 115, 102, 101, 97, 116, 117, 114, 101, 32, 0, 110, 111, 112, 0, 117, 110, 114, 101, 97, 99, 104, 97, 98, 108, 101, 0, 112, 114, 105, 110, 116, 32, 105, 110, 32, 115, 45, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 102, 111, 114, 109, 97, 116, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 55, 80, 114, 105, 110, 116, 101, 114, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 55, 80, 114, 105, 110, 116, 101, 114, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 112, 114, 105, 110, 116, 45, 109, 105, 110, 105, 102, 105, 101, 100, 0, 112, 114, 105, 110, 116, 32, 105, 110, 32, 109, 105, 110, 105, 102, 105, 101, 100, 32, 115, 45, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 102, 111, 114, 109, 97, 116, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 53, 77, 105, 110, 105, 102, 105, 101, 100, 80, 114, 105, 110, 116, 101, 114, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 53, 77, 105, 110, 105, 102, 105, 101, 100, 80, 114, 105, 110, 116, 101, 114, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 53, 77, 105, 110, 105, 102, 105, 101, 100, 80, 114, 105, 110, 116, 101, 114, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 112, 114, 105, 110, 116, 45, 102, 117, 108, 108, 0, 112, 114, 105, 110, 116, 32, 105, 110, 32, 102, 117, 108, 108, 32, 115, 45, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 102, 111, 114, 109, 97, 116, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 49, 70, 117, 108, 108, 80, 114, 105, 110, 116, 101, 114, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 49, 70, 117, 108, 108, 80, 114, 105, 110, 116, 101, 114, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 49, 70, 117, 108, 108, 80, 114, 105, 110, 116, 101, 114, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 111, 112, 116, 105, 109, 105, 122, 101, 45, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 0, 111, 112, 116, 105, 109, 105, 122, 101, 115, 32, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 32, 99, 111, 109, 98, 105, 110, 97, 116, 105, 111, 110, 115, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 50, 48, 79, 112, 116, 105, 109, 105, 122, 101, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 50, 48, 79, 112, 116, 105, 109, 105, 122, 101, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 50, 48, 79, 112, 116, 105, 109, 105, 122, 101, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 50, 48, 79, 112, 116, 105, 109, 105, 122, 101, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 50, 48, 79, 112, 116, 105, 109, 105, 122, 101, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 50, 48, 79, 112, 116, 105, 109, 105, 122, 101, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 50, 48, 79, 112, 116, 105, 109, 105, 122, 101, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 50, 48, 79, 112, 116, 105, 109, 105, 122, 101, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 50, 48, 79, 112, 116, 105, 109, 105, 122, 101, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 114, 101, 109, 111, 118, 101, 45, 117, 110, 117, 115, 101, 100, 45, 98, 114, 115, 0, 114, 101, 109, 111, 118, 101, 115, 32, 98, 114, 101, 97, 107, 115, 32, 102, 114, 111, 109, 32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 32, 116, 104, 97, 116, 32, 97, 114, 101, 32, 110, 111, 116, 32, 110, 101, 101, 100, 101, 100, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 115, 101, 108, 102, 45, 62, 105, 102, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 62, 32, 48, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 46, 99, 112, 112, 0, 118, 105, 115, 105, 116, 65, 110, 121, 0, 105, 102, 83, 116, 97, 99, 107, 46, 101, 109, 112, 116, 121, 40, 41, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 90, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 83, 101, 108, 101, 99, 116, 105, 102, 105, 101, 114, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 53, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 90, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 83, 101, 108, 101, 99, 116, 105, 102, 105, 101, 114, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 90, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 83, 101, 108, 101, 99, 116, 105, 102, 105, 101, 114, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 90, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 83, 101, 108, 101, 99, 116, 105, 102, 105, 101, 114, 118, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 83, 101, 108, 101, 99, 116, 105, 102, 105, 101, 114, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 90, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 84, 121, 112, 101, 85, 112, 100, 97, 116, 101, 114, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 53, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 90, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 84, 121, 112, 101, 85, 112, 100, 97, 116, 101, 114, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 90, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 84, 121, 112, 101, 85, 112, 100, 97, 116, 101, 114, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 90, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 84, 121, 112, 101, 85, 112, 100, 97, 116, 101, 114, 118, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 49, 52, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 49, 49, 84, 121, 112, 101, 85, 112, 100, 97, 116, 101, 114, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 53, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 66, 114, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 114, 101, 109, 111, 118, 101, 45, 117, 110, 117, 115, 101, 100, 45, 110, 97, 109, 101, 115, 0, 114, 101, 109, 111, 118, 101, 115, 32, 110, 97, 109, 101, 115, 32, 102, 114, 111, 109, 32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 32, 116, 104, 97, 116, 32, 97, 114, 101, 32, 110, 101, 118, 101, 114, 32, 98, 114, 97, 110, 99, 104, 101, 100, 32, 116, 111, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 55, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 78, 97, 109, 101, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 55, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 78, 97, 109, 101, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 55, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 78, 97, 109, 101, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 55, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 78, 97, 109, 101, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 55, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 78, 97, 109, 101, 115, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 55, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 78, 97, 109, 101, 115, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 55, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 78, 97, 109, 101, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 49, 55, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 78, 97, 109, 101, 115, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 55, 82, 101, 109, 111, 118, 101, 85, 110, 117, 115, 101, 100, 78, 97, 109, 101, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 112, 111, 115, 116, 45, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 0, 109, 105, 115, 99, 101, 108, 108, 97, 110, 101, 111, 117, 115, 32, 111, 112, 116, 105, 109, 105, 122, 97, 116, 105, 111, 110, 115, 32, 102, 111, 114, 32, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 45, 103, 101, 110, 101, 114, 97, 116, 101, 100, 32, 99, 111, 100, 101, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 52, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 52, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 52, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 97, 100, 100, 45, 62, 116, 121, 112, 101, 32, 61, 61, 32, 105, 51, 50, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 46, 99, 112, 112, 0, 118, 105, 115, 105, 116, 77, 101, 109, 111, 114, 121, 79, 112, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 49, 52, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 52, 80, 111, 115, 116, 69, 109, 115, 99, 114, 105, 112, 116, 101, 110, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 115, 105, 109, 112, 108, 105, 102, 121, 45, 108, 111, 99, 97, 108, 115, 0, 109, 105, 115, 99, 101, 108, 108, 97, 110, 101, 111, 117, 115, 32, 108, 111, 99, 97, 108, 115, 45, 114, 101, 108, 97, 116, 101, 100, 32, 111, 112, 116, 105, 109, 105, 122, 97, 116, 105, 111, 110, 115, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 50, 49, 76, 105, 110, 101, 97, 114, 69, 120, 101, 99, 117, 116, 105, 111, 110, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97 ], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 31080);
allocate([ 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 50, 49, 76, 105, 110, 101, 97, 114, 69, 120, 101, 99, 117, 116, 105, 111, 110, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 99, 117, 114, 114, 0, 118, 105, 115, 105, 116, 0, 108, 111, 99, 97, 108, 115, 87, 114, 105, 116, 116, 101, 110, 46, 115, 105, 122, 101, 40, 41, 32, 43, 32, 108, 111, 99, 97, 108, 115, 82, 101, 97, 100, 46, 115, 105, 122, 101, 40, 41, 32, 60, 61, 32, 49, 0, 115, 114, 99, 47, 97, 115, 116, 95, 117, 116, 105, 108, 115, 46, 104, 0, 105, 110, 118, 97, 108, 105, 100, 97, 116, 101, 115, 0, 98, 108, 111, 99, 107, 45, 62, 108, 105, 115, 116, 46, 98, 97, 99, 107, 40, 41, 32, 61, 61, 32, 97, 98, 111, 118, 101, 0, 105, 115, 82, 101, 115, 117, 108, 116, 85, 115, 101, 100, 0, 97, 98, 111, 118, 101, 32, 61, 61, 32, 105, 102, 102, 45, 62, 105, 102, 84, 114, 117, 101, 32, 124, 124, 32, 97, 98, 111, 118, 101, 32, 61, 61, 32, 105, 102, 102, 45, 62, 105, 102, 70, 97, 108, 115, 101, 0, 115, 101, 108, 102, 45, 62, 115, 105, 110, 107, 97, 98, 108, 101, 115, 46, 99, 111, 117, 110, 116, 40, 105, 110, 100, 101, 120, 41, 32, 61, 61, 32, 48, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 46, 99, 112, 112, 0, 118, 105, 115, 105, 116, 80, 111, 115, 116, 0, 105, 102, 102, 45, 62, 105, 102, 70, 97, 108, 115, 101, 0, 100, 111, 78, 111, 116, 101, 73, 102, 69, 108, 115, 101, 70, 97, 108, 115, 101, 0, 111, 112, 116, 105, 109, 105, 122, 101, 73, 102, 82, 101, 116, 117, 114, 110, 0, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 83, 116, 97, 99, 107, 46, 98, 97, 99, 107, 40, 41, 32, 61, 61, 32, 105, 102, 102, 0, 105, 102, 84, 114, 117, 101, 66, 108, 111, 99, 107, 45, 62, 116, 121, 112, 101, 32, 33, 61, 32, 110, 111, 110, 101, 0, 105, 102, 102, 45, 62, 116, 121, 112, 101, 32, 33, 61, 32, 110, 111, 110, 101, 0, 40, 42, 99, 117, 114, 114, 112, 41, 45, 62, 99, 97, 115, 116, 60, 73, 102, 62, 40, 41, 45, 62, 105, 102, 70, 97, 108, 115, 101, 0, 100, 111, 78, 111, 116, 101, 73, 102, 69, 108, 115, 101, 84, 114, 117, 101, 0, 100, 111, 78, 111, 116, 101, 73, 102, 69, 108, 115, 101, 67, 111, 110, 100, 105, 116, 105, 111, 110, 0, 33, 98, 114, 101, 97, 107, 115, 91, 48, 93, 46, 98, 114, 45, 62, 118, 97, 108, 117, 101, 0, 111, 112, 116, 105, 109, 105, 122, 101, 66, 108, 111, 99, 107, 82, 101, 116, 117, 114, 110, 0, 33, 98, 114, 101, 97, 107, 115, 91, 106, 93, 46, 98, 114, 45, 62, 118, 97, 108, 117, 101, 0, 33, 99, 117, 114, 114, 45, 62, 99, 97, 115, 116, 60, 73, 102, 62, 40, 41, 45, 62, 105, 102, 70, 97, 108, 115, 101, 0, 100, 111, 78, 111, 116, 101, 78, 111, 110, 76, 105, 110, 101, 97, 114, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 71, 101, 116, 76, 111, 99, 97, 108, 67, 111, 117, 110, 116, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 71, 101, 116, 76, 111, 99, 97, 108, 67, 111, 117, 110, 116, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 71, 101, 116, 76, 111, 99, 97, 108, 67, 111, 117, 110, 116, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 53, 71, 101, 116, 76, 111, 99, 97, 108, 67, 111, 117, 110, 116, 101, 114, 69, 118, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 53, 71, 101, 116, 76, 111, 99, 97, 108, 67, 111, 117, 110, 116, 101, 114, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 83, 101, 116, 76, 111, 99, 97, 108, 82, 101, 109, 111, 118, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 83, 101, 116, 76, 111, 99, 97, 108, 82, 101, 109, 111, 118, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 53, 83, 101, 116, 76, 111, 99, 97, 108, 82, 101, 109, 111, 118, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 53, 83, 101, 116, 76, 111, 99, 97, 108, 82, 101, 109, 111, 118, 101, 114, 69, 118, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 53, 83, 101, 116, 76, 111, 99, 97, 108, 82, 101, 109, 111, 118, 101, 114, 69, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 52, 83, 105, 109, 112, 108, 105, 102, 121, 76, 111, 99, 97, 108, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 114, 101, 111, 114, 100, 101, 114, 45, 108, 111, 99, 97, 108, 115, 0, 115, 111, 114, 116, 115, 32, 108, 111, 99, 97, 108, 115, 32, 98, 121, 32, 97, 99, 99, 101, 115, 115, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 110, 101, 119, 84, 111, 79, 108, 100, 91, 105, 93, 32, 60, 32, 99, 117, 114, 114, 45, 62, 112, 97, 114, 97, 109, 115, 46, 115, 105, 122, 101, 40, 41, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 46, 99, 112, 112, 0, 118, 105, 115, 105, 116, 70, 117, 110, 99, 116, 105, 111, 110, 0, 90, 78, 52, 119, 97, 115, 109, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 49, 51, 118, 105, 115, 105, 116, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 57, 82, 101, 73, 110, 100, 101, 120, 101, 114, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 90, 78, 83, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 49, 51, 118, 105, 115, 105, 116, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 57, 82, 101, 73, 110, 100, 101, 120, 101, 114, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 90, 78, 83, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 49, 51, 118, 105, 115, 105, 116, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 57, 82, 101, 73, 110, 100, 101, 120, 101, 114, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 90, 78, 83, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 49, 51, 118, 105, 115, 105, 116, 70, 117, 110, 99, 116, 105, 111, 110, 69, 80, 78, 83, 95, 56, 70, 117, 110, 99, 116, 105, 111, 110, 69, 69, 57, 82, 101, 73, 110, 100, 101, 120, 101, 114, 118, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 51, 82, 101, 111, 114, 100, 101, 114, 76, 111, 99, 97, 108, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 118, 97, 99, 117, 117, 109, 0, 114, 101, 109, 111, 118, 101, 115, 32, 111, 98, 118, 105, 111, 117, 115, 108, 121, 32, 117, 110, 110, 101, 101, 100, 101, 100, 32, 99, 111, 100, 101, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 54, 86, 97, 99, 117, 117, 109, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 54, 86, 97, 99, 117, 117, 109, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 54, 86, 97, 99, 117, 117, 109, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 54, 86, 97, 99, 117, 117, 109, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 54, 86, 97, 99, 117, 117, 109, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 54, 86, 97, 99, 117, 117, 109, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 54, 86, 97, 99, 117, 117, 109, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 54, 86, 97, 99, 117, 117, 109, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 54, 86, 97, 99, 117, 117, 109, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 100, 117, 112, 108, 105, 99, 97, 116, 101, 45, 102, 117, 110, 99, 116, 105, 111, 110, 45, 101, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 0, 114, 101, 109, 111, 118, 101, 115, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 50, 56, 68, 117, 112, 108, 105, 99, 97, 116, 101, 70, 117, 110, 99, 116, 105, 111, 110, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 50, 56, 68, 117, 112, 108, 105, 99, 97, 116, 101, 70, 117, 110, 99, 116, 105, 111, 110, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 0, 78, 52, 119, 97, 115, 109, 49, 52, 70, 117, 110, 99, 116, 105, 111, 110, 72, 97, 115, 104, 101, 114, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 70, 117, 110, 99, 116, 105, 111, 110, 72, 97, 115, 104, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 70, 117, 110, 99, 116, 105, 111, 110, 72, 97, 115, 104, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 52, 70, 117, 110, 99, 116, 105, 111, 110, 72, 97, 115, 104, 101, 114, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 52, 70, 117, 110, 99, 116, 105, 111, 110, 72, 97, 115, 104, 101, 114, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 100, 105, 103, 101, 115, 116, 32, 61, 61, 32, 48, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 68, 117, 112, 108, 105, 99, 97, 116, 101, 70, 117, 110, 99, 116, 105, 111, 110, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 46, 99, 112, 112, 0, 109, 97, 112, 58, 58, 97, 116, 58, 32, 32, 107, 101, 121, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 70, 117, 110, 99, 116, 105, 111, 110, 72, 97, 115, 104, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 49, 54, 70, 117, 110, 99, 116, 105, 111, 110, 82, 101, 112, 108, 97, 99, 101, 114, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 54, 70, 117, 110, 99, 116, 105, 111, 110, 82, 101, 112, 108, 97, 99, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 54, 70, 117, 110, 99, 116, 105, 111, 110, 82, 101, 112, 108, 97, 99, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 54, 70, 117, 110, 99, 116, 105, 111, 110, 82, 101, 112, 108, 97, 99, 101, 114, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 54, 70, 117, 110, 99, 116, 105, 111, 110, 82, 101, 112, 108, 97, 99, 101, 114, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 54, 70, 117, 110, 99, 116, 105, 111, 110, 82, 101, 112, 108, 97, 99, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 50, 56, 68, 117, 112, 108, 105, 99, 97, 116, 101, 70, 117, 110, 99, 116, 105, 111, 110, 69, 108, 105, 109, 105, 110, 97, 116, 105, 111, 110, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 78, 52, 119, 97, 115, 109, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 87, 97, 108, 107, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 57, 67, 70, 71, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 50, 95, 118, 69, 69, 78, 83, 95, 56, 76, 105, 118, 101, 110, 101, 115, 115, 69, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 57, 67, 70, 71, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 78, 83, 95, 56, 76, 105, 118, 101, 110, 101, 115, 115, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 118, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 50, 95, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 78, 83, 50, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 52, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 50, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 65, 95, 69, 69, 70, 78, 83, 50, 95, 49, 53, 84, 104, 114, 101, 97, 100, 87, 111, 114, 107, 83, 116, 97, 116, 101, 69, 118, 69, 69, 69, 0, 98, 114, 97, 110, 99, 104, 101, 115, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 48, 0, 115, 114, 99, 47, 99, 102, 103, 47, 99, 102, 103, 45, 116, 114, 97, 118, 101, 114, 115, 97, 108, 46, 104, 0, 100, 111, 87, 97, 108, 107, 70, 117, 110, 99, 116, 105, 111, 110, 0, 105, 102, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 48, 0, 108, 111, 111, 112, 83, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 48, 0, 99, 117, 114, 114, 45, 62, 99, 111, 110, 116, 101, 110, 116, 115, 46, 101, 110, 100, 46, 115, 105, 122, 101, 40, 41, 32, 60, 32, 108, 105, 118, 101, 46, 115, 105, 122, 101, 40, 41, 0, 115, 114, 99, 47, 112, 97, 115, 115, 101, 115, 47, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 46, 99, 112, 112, 0, 102, 108, 111, 119, 76, 105, 118, 101, 110, 101, 115, 115, 0, 99, 117, 114, 114, 45, 62, 99, 111, 110, 116, 101, 110, 116, 115, 46, 115, 116, 97, 114, 116, 46, 115, 105, 122, 101, 40, 41, 32, 60, 32, 108, 105, 118, 101, 46, 115, 105, 122, 101, 40, 41, 0, 108, 111, 119, 32, 60, 32, 104, 105, 103, 104, 0, 105, 110, 116, 101, 114, 102, 101, 114, 101, 76, 111, 119, 72, 105, 103, 104, 0, 105, 110, 100, 105, 99, 101, 115, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 110, 117, 109, 76, 111, 99, 97, 108, 115, 0, 97, 112, 112, 108, 121, 73, 110, 100, 105, 99, 101, 115, 0, 90, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 49, 50, 100, 111, 87, 97, 108, 107, 77, 111, 100, 117, 108, 101, 69, 80, 78, 83, 95, 54, 77, 111, 100, 117, 108, 101, 69, 69, 85, 108, 118, 69, 95, 0, 111, 114, 100, 101, 114, 91, 105, 93, 32, 61, 61, 32, 105, 0, 112, 105, 99, 107, 73, 110, 100, 105, 99, 101, 115, 70, 114, 111, 109, 79, 114, 100, 101, 114, 0, 78, 52, 119, 97, 115, 109, 50, 54, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 87, 105, 116, 104, 76, 101, 97, 114, 110, 105, 110, 103, 69, 0, 109, 97, 120, 73, 110, 100, 101, 120, 32, 60, 61, 32, 112, 97, 114, 101, 110, 116, 45, 62, 110, 117, 109, 76, 111, 99, 97, 108, 115, 0, 99, 97, 108, 99, 117, 108, 97, 116, 101, 70, 105, 116, 110, 101, 115, 115, 0, 115, 105, 122, 101, 32, 62, 61, 32, 49, 0, 109, 97, 107, 101, 77, 105, 120, 116, 117, 114, 101, 0, 99, 111, 97, 108, 101, 115, 99, 101, 45, 108, 111, 99, 97, 108, 115, 0, 114, 101, 100, 117, 99, 101, 32, 35, 32, 111, 102, 32, 108, 111, 99, 97, 108, 115, 32, 98, 121, 32, 99, 111, 97, 108, 101, 115, 99, 105, 110, 103, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 49, 52, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 99, 111, 97, 108, 101, 115, 99, 101, 45, 108, 111, 99, 97, 108, 115, 45, 108, 101, 97, 114, 110, 105, 110, 103, 0, 114, 101, 100, 117, 99, 101, 32, 35, 32, 111, 102, 32, 108, 111, 99, 97, 108, 115, 32, 98, 121, 32, 99, 111, 97, 108, 101, 115, 99, 105, 110, 103, 32, 97, 110, 100, 32, 108, 101, 97, 114, 110, 105, 110, 103, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 102, 117, 110, 99, 116, 105, 111, 110, 54, 95, 95, 102, 117, 110, 99, 73, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 50, 95, 50, 54, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 87, 105, 116, 104, 76, 101, 97, 114, 110, 105, 110, 103, 69, 69, 67, 49, 69, 80, 75, 99, 83, 55, 95, 69, 85, 108, 118, 69, 95, 78, 83, 95, 57, 97, 108, 108, 111, 99, 97, 116, 111, 114, 73, 83, 56, 95, 69, 69, 70, 80, 78, 83, 50, 95, 52, 80, 97, 115, 115, 69, 118, 69, 69, 69, 0, 90, 78, 52, 119, 97, 115, 109, 49, 50, 82, 101, 103, 105, 115, 116, 101, 114, 80, 97, 115, 115, 73, 78, 83, 95, 50, 54, 67, 111, 97, 108, 101, 115, 99, 101, 76, 111, 99, 97, 108, 115, 87, 105, 116, 104, 76, 101, 97, 114, 110, 105, 110, 103, 69, 69, 67, 49, 69, 80, 75, 99, 83, 52, 95, 69, 85, 108, 118, 69, 95, 0, 43, 45, 42, 47, 37, 60, 62, 38, 94, 124, 126, 61, 33, 44, 63, 58, 46, 0, 40, 91, 59, 123, 125, 0, 116, 111, 112, 108, 101, 118, 101, 108, 0, 100, 101, 102, 117, 110, 0, 115, 116, 97, 116, 0, 97, 115, 115, 105, 103, 110, 0, 110, 97, 109, 101, 0, 118, 97, 114, 0, 99, 111, 110, 115, 116, 0, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 0, 98, 105, 110, 97, 114, 121, 0, 114, 101, 116, 117, 114, 110, 0, 105, 102, 0, 119, 104, 105, 108, 101, 0, 100, 111, 0, 102, 111, 114, 0, 115, 101, 113, 0, 115, 117, 98, 0, 110, 117, 109, 0, 108, 97, 98, 101, 108, 0, 98, 114, 101, 97, 107, 0, 99, 111, 110, 116, 105, 110, 117, 101, 0, 115, 119, 105, 116, 99, 104, 0, 115, 116, 114, 105, 110, 103, 0, 116, 101, 109, 112, 82, 101, 116, 48, 0, 103, 101, 116, 84, 101, 109, 112, 82, 101, 116, 48, 0, 95, 108, 108, 118, 109, 95, 99, 116, 116, 122, 95, 105, 51, 50, 0, 95, 95, 95, 117, 100, 105, 118, 109, 111, 100, 100, 105, 52, 0, 117, 110, 97, 114, 121, 45, 112, 114, 101, 102, 105, 120, 0, 117, 110, 97, 114, 121, 45, 112, 111, 115, 116, 102, 105, 120, 0, 77, 97, 116, 104, 95, 102, 114, 111, 117, 110, 100, 0, 83, 73, 77, 68, 95, 70, 108, 111, 97, 116, 51, 50, 120, 52, 0, 83, 73, 77, 68, 95, 70, 108, 111, 97, 116, 54, 52, 120, 50, 0, 83, 73, 77, 68, 95, 73, 110, 116, 56, 120, 49, 54, 0, 83, 73, 77, 68, 95, 73, 110, 116, 49, 54, 120, 56, 0, 83, 73, 77, 68, 95, 73, 110, 116, 51, 50, 120, 52, 0, 62, 62, 62, 0, 116, 101, 109, 112, 68, 111, 117, 98, 108, 101, 80, 116, 114, 0, 72, 69, 65, 80, 56, 0, 72, 69, 65, 80, 49, 54, 0, 72, 69, 65, 80, 51, 50, 0, 72, 69, 65, 80, 70, 51, 50, 0, 72, 69, 65, 80, 85, 56, 0, 72, 69, 65, 80, 85, 49, 54, 0, 72, 69, 65, 80, 85, 51, 50, 0, 72, 69, 65, 80, 70, 54, 52, 0, 102, 48, 0, 102, 117, 110, 99, 116, 105, 111, 110, 0, 91, 0, 123, 0, 125, 0, 63, 0, 58, 0, 100, 101, 102, 97, 117, 108, 116, 0, 100, 111, 116, 0, 110, 101, 119, 0, 97, 114, 114, 97, 121, 0, 111, 98, 106, 101, 99, 116, 0, 118, 97, 114, 32, 99, 111, 110, 115, 116, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 105, 102, 32, 101, 108, 115, 101, 32, 100, 111, 32, 119, 104, 105, 108, 101, 32, 102, 111, 114, 32, 98, 114, 101, 97, 107, 32, 99, 111, 110, 116, 105, 110, 117, 101, 32, 114, 101, 116, 117, 114, 110, 32, 115, 119, 105, 116, 99, 104, 32, 99, 97, 115, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 116, 104, 114, 111, 119, 32, 116, 114, 121, 32, 99, 97, 116, 99, 104, 32, 102, 105, 110, 97, 108, 108, 121, 32, 116, 114, 117, 101, 32, 102, 97, 108, 115, 101, 32, 110, 117, 108, 108, 32, 110, 101, 119, 0, 33, 32, 126, 32, 43, 32, 45, 0, 42, 32, 47, 32, 37, 0, 43, 32, 45, 0, 60, 60, 32, 62, 62, 32, 62, 62, 62, 0, 60, 32, 60, 61, 32, 62, 32, 62, 61, 0, 61, 61, 32, 33, 61, 0, 63, 32, 58, 0, 97, 115, 115, 105, 103, 110, 32, 99, 97, 108, 108, 32, 98, 105, 110, 97, 114, 121, 32, 117, 110, 97, 114, 121, 45, 112, 114, 101, 102, 105, 120, 32, 110, 97, 109, 101, 32, 110, 117, 109, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 100, 111, 116, 32, 110, 101, 119, 32, 115, 117, 98, 32, 115, 101, 113, 32, 115, 116, 114, 105, 110, 103, 32, 111, 98, 106, 101, 99, 116, 32, 97, 114, 114, 97, 121, 0, 105, 115, 65, 114, 114, 97, 121, 40, 41, 0, 115, 114, 99, 47, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 45, 111, 112, 116, 105, 109, 105, 122, 101, 114, 47, 115, 105, 109, 112, 108, 101, 95, 97, 115, 116, 46, 104, 0, 83, 73, 77, 68, 95, 73, 110, 116, 56, 120, 49, 54, 95, 99, 104, 101, 99, 107, 0, 83, 73, 77, 68, 95, 73, 110, 116, 49, 54, 120, 56, 95, 99, 104, 101, 99, 107, 0, 83, 73, 77, 68, 95, 73, 110, 116, 51, 50, 120, 52, 95, 99, 104, 101, 99, 107, 0, 83, 73, 77, 68, 95, 70, 108, 111, 97, 116, 51, 50, 120, 52, 95, 99, 104, 101, 99, 107, 0, 83, 73, 77, 68, 95, 70, 108, 111, 97, 116, 54, 52, 120, 50, 95, 99, 104, 101, 99, 107, 0, 110, 111, 100, 101, 91, 49, 93, 32, 61, 61, 32, 65, 83, 77, 95, 70, 76, 79, 65, 84, 95, 90, 69, 82, 79, 0, 115, 114, 99, 47, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 45, 111, 112, 116, 105, 109, 105, 122, 101, 114, 47, 111, 112, 116, 105, 109, 105, 122, 101, 114, 45, 115, 104, 97, 114, 101, 100, 46, 99, 112, 112, 0, 100, 101, 116, 101, 99, 116, 84, 121, 112, 101, 0, 110, 111, 100, 101, 91, 49, 93, 91, 48, 93, 32, 61, 61, 32, 78, 65, 77, 69, 0, 0, 1, 28, 2, 29, 14, 24, 3, 30, 22, 20, 15, 25, 17, 4, 8, 31, 27, 13, 23, 21, 19, 16, 7, 26, 12, 18, 6, 11, 5, 10, 9, 31, 22, 30, 21, 18, 10, 29, 2, 20, 17, 15, 13, 9, 6, 28, 1, 23, 19, 11, 3, 16, 14, 7, 24, 12, 4, 8, 25, 5, 26, 27, 0, 66, 73, 78, 65, 82, 89, 69, 78, 95, 67, 79, 82, 69, 83, 0, 111, 108, 100, 32, 61, 61, 32, 116, 104, 114, 101, 97, 100, 115, 46, 115, 105, 122, 101, 40, 41, 0, 115, 114, 99, 47, 115, 117, 112, 112, 111, 114, 116, 47, 116, 104, 114, 101, 97, 100, 115, 46, 99, 112, 112, 0, 114, 101, 115, 101, 116, 84, 104, 114, 101, 97, 100, 115, 65, 114, 101, 82, 101, 97, 100, 121, 0, 33, 84, 104, 114, 101, 97, 100, 80, 111, 111, 108, 58, 58, 103, 101, 116, 40, 41, 45, 62, 105, 115, 82, 117, 110, 110, 105, 110, 103, 40, 41, 0, 84, 104, 114, 101, 97, 100, 0, 116, 104, 114, 101, 97, 100, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 32, 102, 97, 105, 108, 101, 100, 0, 126, 84, 104, 114, 101, 97, 100, 0, 100, 111, 87, 111, 114, 107, 101, 114, 115, 46, 115, 105, 122, 101, 40, 41, 32, 62, 32, 48, 0, 119, 111, 114, 107, 0, 100, 111, 87, 111, 114, 107, 101, 114, 115, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 110, 117, 109, 0, 33, 114, 117, 110, 110, 105, 110, 103, 0, 70, 85, 78, 67, 83, 73, 71, 36, 0, 103, 108, 111, 98, 97, 108, 0, 78, 97, 78, 0, 73, 110, 102, 105, 110, 105, 116, 121, 0, 116, 111, 112, 109, 111, 115, 116, 0, 73, 110, 116, 56, 65, 114, 114, 97, 121, 0, 73, 110, 116, 49, 54, 65, 114, 114, 97, 121, 0, 73, 110, 116, 51, 50, 65, 114, 114, 97, 121, 0, 85, 105, 110, 116, 56, 65, 114, 114, 97, 121, 0, 85, 105, 110, 116, 49, 54, 65, 114, 114, 97, 121, 0, 85, 105, 110, 116, 51, 50, 65, 114, 114, 97, 121, 0, 70, 108, 111, 97, 116, 51, 50, 65, 114, 114, 97, 121, 0, 70, 108, 111, 97, 116, 54, 52, 65, 114, 114, 97, 121, 0, 105, 109, 112, 111, 115, 115, 105, 98, 108, 101, 45, 99, 111, 110, 116, 105, 110, 117, 101, 0, 77, 97, 116, 104, 0, 105, 109, 117, 108, 0, 99, 108, 122, 51, 50, 0, 102, 114, 111, 117, 110, 100, 0, 97, 115, 109, 50, 119, 97, 115, 109, 0, 102, 54, 52, 45, 114, 101, 109, 0, 102, 54, 52, 45, 116, 111, 45, 105, 110, 116, 0, 103, 108, 111, 98, 97, 108, 46, 77, 97, 116, 104, 0, 97, 98, 115, 0, 102, 108, 111, 111, 114, 0, 99, 101, 105, 108, 0, 115, 113, 114, 116, 0, 97, 115, 109, 50, 119, 97, 115, 109, 95, 105, 51, 50, 95, 116, 101, 109, 112, 0, 100, 101, 98, 117, 103, 103, 101, 114, 0, 95, 95, 103, 114, 111, 119, 87, 97, 115, 109, 77, 101, 109, 111, 114, 121, 0, 110, 101, 119, 83, 105, 122, 101, 0, 109, 111, 100, 117, 108, 101, 0, 115, 116, 97, 114, 116, 0, 102, 117, 110, 99, 0, 112, 97, 114, 97, 109, 0, 114, 101, 115, 117, 108, 116, 0, 109, 101, 109, 111, 114, 121, 0, 115, 101, 103, 109, 101, 110, 116, 0, 101, 120, 112, 111, 114, 116, 0, 105, 109, 112, 111, 114, 116, 0, 116, 97, 98, 108, 101, 0, 108, 111, 99, 97, 108, 0, 116, 121, 112, 101, 0, 99, 97, 108, 108, 0, 99, 97, 108, 108, 95, 105, 109, 112, 111, 114, 116, 0, 99, 97, 108, 108, 95, 105, 110, 100, 105, 114, 101, 99, 116, 0, 98, 108, 111, 99, 107, 0, 98, 114, 95, 105, 102, 0, 116, 104, 101, 110, 0, 101, 108, 115, 101, 0, 45, 105, 110, 102, 105, 110, 105, 116, 121, 0, 45, 110, 97, 110, 0, 99, 97, 115, 101, 0, 98, 114, 0, 117, 115, 101, 32, 97, 115, 109, 0, 98, 117, 102, 102, 101, 114, 0, 101, 110, 118, 0, 102, 97, 107, 101, 95, 114, 101, 116, 117, 114, 110, 95, 119, 97, 107, 97, 49, 50, 51, 0, 77, 97, 116, 104, 95, 105, 109, 117, 108, 0, 77, 97, 116, 104, 95, 99, 108, 122, 51, 50, 0, 77, 97, 116, 104, 95, 99, 116, 122, 51, 50, 0, 77, 97, 116, 104, 95, 112, 111, 112, 99, 110, 116, 51, 50, 0, 77, 97, 116, 104, 95, 97, 98, 115, 0, 77, 97, 116, 104, 95, 99, 101, 105, 108, 0, 77, 97, 116, 104, 95, 102, 108, 111, 111, 114, 0, 77, 97, 116, 104, 95, 116, 114, 117, 110, 99, 0, 77, 97, 116, 104, 95, 78, 69, 65, 82, 69, 83, 84, 0, 77, 97, 116, 104, 95, 115, 113, 114, 116, 0, 77, 97, 116, 104, 95, 109, 97, 120, 0, 77, 97, 116, 104, 95, 109, 105, 110, 0, 97, 115, 115, 101, 114, 116, 95, 114, 101, 116, 117, 114, 110, 0, 97, 115, 115, 101, 114, 116, 95, 116, 114, 97, 112, 0, 97, 115, 115, 101, 114, 116, 95, 105, 110, 118, 97, 108, 105, 100, 0, 115, 112, 101, 99, 116, 101, 115, 116, 0, 112, 114, 105, 110, 116, 0, 105, 110, 118, 111, 107, 101, 0, 101, 120, 105, 116, 0, 78, 52, 119, 97, 115, 109, 49, 48, 84, 121, 112, 101, 83, 101, 101, 107, 101, 114, 69, 0, 78, 52, 119, 97, 115, 109, 49, 48, 80, 111, 115, 116, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 48, 84, 121, 112, 101, 83, 101, 101, 107, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 54, 87, 97, 108, 107, 101, 114, 73, 78, 83, 95, 49, 48, 84, 121, 112, 101, 83, 101, 101, 107, 101, 114, 69, 78, 83, 95, 55, 86, 105, 115, 105, 116, 111, 114, 73, 83, 49, 95, 118, 69, 69, 69, 69, 0, 78, 52, 119, 97, 115, 109, 55, 86, 105, 115, 105, 116, 111, 114, 73, 78, 83, 95, 49, 48, 84, 121, 112, 101, 83, 101, 101, 107, 101, 114, 69, 118, 69, 69, 0, 115, 116, 97, 99, 107, 46, 115, 105, 122, 101, 40, 41, 32, 61, 61, 32, 48, 0, 115, 114, 99, 47, 119, 97, 115, 109, 45, 116, 114, 97, 118, 101, 114, 115, 97, 108, 46, 104, 0, 119, 97, 108, 107, 0, 42, 116, 97, 115, 107, 46, 99, 117, 114, 114, 112, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 255, 255, 255, 255, 255, 255, 255, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 255, 255, 255, 255, 255, 255, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 1, 2, 4, 7, 3, 6, 5, 0, 105, 110, 102, 105, 110, 105, 116, 121, 0, 17, 0, 10, 0, 17, 17, 17, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 15, 10, 17, 17, 17, 3, 10, 7, 0, 1, 19, 9, 11, 11, 0, 0, 9, 6, 11, 0, 0, 11, 0, 6, 17, 0, 0, 0, 17, 17, 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 10, 10, 17, 17, 17, 0, 10, 0, 0, 2, 0, 9, 11, 0, 0, 0, 9, 0, 11, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 12, 0, 0, 0, 0, 9, 12, 0, 0, 0, 0, 0, 12, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 0, 0, 0, 4, 13, 0, 0, 0, 0, 9, 14, 0, 0, 0, 0, 0, 14, 0, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 0, 0, 0, 0, 15, 0, 0, 0, 0, 9, 16, 0, 0, 0, 0, 0, 16, 0, 0, 16, 0, 0, 18, 0, 0, 0, 18, 18, 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 0, 0, 0, 18, 18, 18, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 10, 0, 0, 0, 0, 9, 11, 0, 0, 0, 0, 0, 11, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 12, 0, 0, 0, 0, 9, 12, 0, 0, 0, 0, 0, 12, 0, 0, 12, 0, 0, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 65, 66, 67, 68, 69, 70, 45, 43, 32, 32, 32, 48, 88, 48, 120, 0, 84, 33, 34, 25, 13, 1, 2, 3, 17, 75, 28, 12, 16, 4, 11, 29, 18, 30, 39, 104, 110, 111, 112, 113, 98, 32, 5, 6, 15, 19, 20, 21, 26, 8, 22, 7, 40, 36, 23, 24, 9, 10, 14, 27, 31, 37, 35, 131, 130, 125, 38, 42, 43, 60, 61, 62, 63, 67, 71, 74, 77, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 99, 100, 101, 102, 103, 105, 106, 107, 108, 114, 115, 116, 121, 122, 123, 124, 0, 73, 108, 108, 101, 103, 97, 108, 32, 98, 121, 116, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 0, 68, 111, 109, 97, 105, 110, 32, 101, 114, 114, 111, 114, 0, 82, 101, 115, 117, 108, 116, 32, 110, 111, 116, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 98, 108, 101, 0, 78, 111, 116, 32, 97, 32, 116, 116, 121, 0, 80, 101, 114, 109, 105, 115, 115, 105, 111, 110, 32, 100, 101, 110, 105, 101, 100, 0, 79, 112, 101, 114, 97, 116, 105, 111, 110, 32, 110, 111, 116, 32, 112, 101, 114, 109, 105, 116, 116, 101, 100, 0, 78, 111, 32, 115, 117, 99, 104, 32, 102, 105, 108, 101, 32, 111, 114, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 0, 78, 111, 32, 115, 117, 99, 104, 32, 112, 114, 111, 99, 101, 115, 115, 0, 70, 105, 108, 101, 32, 101, 120, 105, 115, 116, 115, 0, 86, 97, 108, 117, 101, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 32, 102, 111, 114, 32, 100, 97, 116, 97, 32, 116, 121, 112, 101, 0, 78, 111, 32, 115, 112, 97, 99, 101, 32, 108, 101, 102, 116, 32, 111, 110, 32, 100, 101, 118, 105, 99, 101, 0, 79, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 0, 82, 101, 115, 111, 117, 114, 99, 101, 32, 98, 117, 115, 121, 0, 73, 110, 116, 101, 114, 114, 117, 112, 116, 101, 100, 32, 115, 121, 115, 116, 101, 109, 32, 99, 97, 108, 108, 0, 82, 101, 115, 111, 117, 114, 99, 101, 32, 116, 101, 109, 112, 111, 114, 97, 114, 105, 108, 121, 32, 117, 110, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 73, 110, 118, 97, 108, 105, 100, 32, 115, 101, 101, 107, 0, 67, 114, 111, 115, 115, 45, 100, 101, 118, 105, 99, 101, 32, 108, 105, 110, 107, 0, 82, 101, 97, 100, 45, 111, 110, 108, 121, 32, 102, 105, 108, 101, 32, 115, 121, 115, 116, 101, 109, 0, 68, 105, 114, 101, 99, 116, 111, 114, 121, 32, 110, 111, 116, 32, 101, 109, 112, 116, 121, 0, 67, 111, 110, 110, 101, 99, 116, 105, 111, 110, 32, 114, 101, 115, 101, 116, 32, 98, 121, 32, 112, 101, 101, 114, 0, 79, 112, 101, 114, 97, 116, 105, 111, 110, 32, 116, 105, 109, 101, 100, 32, 111, 117, 116, 0, 67, 111, 110, 110, 101, 99, 116, 105, 111, 110, 32, 114, 101, 102, 117, 115, 101, 100, 0, 72, 111, 115, 116, 32, 105, 115, 32, 100, 111, 119, 110, 0, 72, 111, 115, 116, 32, 105, 115, 32, 117, 110, 114, 101, 97, 99, 104, 97, 98, 108, 101, 0, 65, 100, 100, 114, 101, 115, 115, 32, 105, 110, 32, 117, 115, 101, 0, 66, 114, 111, 107, 101, 110, 32, 112, 105, 112, 101, 0, 73, 47, 79, 32, 101, 114, 114, 111, 114, 0, 78, 111, 32, 115, 117, 99, 104, 32, 100, 101, 118, 105, 99, 101, 32, 111, 114, 32, 97, 100, 100, 114, 101, 115, 115, 0, 66, 108, 111, 99, 107, 32, 100, 101, 118, 105, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 0, 78, 111, 32, 115, 117, 99, 104, 32, 100, 101, 118, 105, 99, 101, 0, 78, 111, 116, 32, 97, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 0, 73, 115, 32, 97, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 0, 84, 101, 120, 116, 32, 102, 105, 108, 101, 32, 98, 117, 115, 121, 0, 69, 120, 101, 99, 32, 102, 111, 114, 109, 97, 116, 32, 101, 114, 114, 111, 114, 0, 73, 110, 118, 97, 108, 105, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0, 65, 114, 103, 117, 109, 101, 110, 116, 32, 108, 105, 115, 116, 32, 116, 111, 111, 32, 108, 111, 110, 103, 0, 83, 121, 109, 98, 111, 108, 105, 99, 32, 108, 105, 110, 107, 32, 108, 111, 111, 112, 0, 70, 105, 108, 101, 110, 97, 109, 101, 32, 116, 111, 111, 32, 108, 111, 110, 103, 0, 84, 111, 111, 32, 109, 97, 110, 121, 32, 111, 112, 101, 110, 32, 102, 105, 108, 101, 115, 32, 105, 110, 32, 115, 121, 115, 116, 101, 109, 0, 78, 111, 32, 102, 105, 108, 101, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 115, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 66, 97, 100, 32, 102, 105, 108, 101, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 0, 78, 111, 32, 99, 104, 105, 108, 100, 32, 112, 114, 111, 99, 101, 115, 115, 0, 66, 97, 100, 32, 97, 100, 100, 114, 101, 115, 115, 0, 70, 105, 108, 101, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0, 84, 111, 111, 32, 109, 97, 110, 121, 32, 108, 105, 110, 107, 115, 0, 78, 111, 32, 108, 111, 99, 107, 115, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 82, 101, 115, 111, 117, 114, 99, 101, 32, 100, 101, 97, 100, 108, 111, 99, 107, 32, 119, 111, 117, 108, 100, 32, 111, 99, 99, 117, 114, 0, 83, 116, 97, 116, 101, 32, 110, 111, 116, 32, 114, 101, 99, 111, 118, 101, 114, 97, 98, 108, 101, 0, 80, 114, 101, 118, 105, 111, 117, 115, 32, 111, 119, 110, 101, 114, 32, 100, 105, 101, 100, 0, 79, 112, 101, 114, 97, 116, 105, 111, 110, 32, 99, 97, 110, 99, 101, 108, 101, 100, 0, 70, 117, 110, 99, 116, 105, 111, 110, 32, 110, 111, 116, 32, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 0, 78, 111, 32, 109, 101, 115, 115, 97, 103, 101, 32, 111, 102, 32, 100, 101, 115, 105, 114, 101, 100, 32, 116, 121, 112, 101, 0, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 32, 114, 101, 109, 111, 118, 101, 100 ], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 41320);
allocate([ 0, 68, 101, 118, 105, 99, 101, 32, 110, 111, 116, 32, 97, 32, 115, 116, 114, 101, 97, 109, 0, 78, 111, 32, 100, 97, 116, 97, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 68, 101, 118, 105, 99, 101, 32, 116, 105, 109, 101, 111, 117, 116, 0, 79, 117, 116, 32, 111, 102, 32, 115, 116, 114, 101, 97, 109, 115, 32, 114, 101, 115, 111, 117, 114, 99, 101, 115, 0, 76, 105, 110, 107, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 115, 101, 118, 101, 114, 101, 100, 0, 80, 114, 111, 116, 111, 99, 111, 108, 32, 101, 114, 114, 111, 114, 0, 66, 97, 100, 32, 109, 101, 115, 115, 97, 103, 101, 0, 70, 105, 108, 101, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 32, 105, 110, 32, 98, 97, 100, 32, 115, 116, 97, 116, 101, 0, 78, 111, 116, 32, 97, 32, 115, 111, 99, 107, 101, 116, 0, 68, 101, 115, 116, 105, 110, 97, 116, 105, 111, 110, 32, 97, 100, 100, 114, 101, 115, 115, 32, 114, 101, 113, 117, 105, 114, 101, 100, 0, 77, 101, 115, 115, 97, 103, 101, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0, 80, 114, 111, 116, 111, 99, 111, 108, 32, 119, 114, 111, 110, 103, 32, 116, 121, 112, 101, 32, 102, 111, 114, 32, 115, 111, 99, 107, 101, 116, 0, 80, 114, 111, 116, 111, 99, 111, 108, 32, 110, 111, 116, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 80, 114, 111, 116, 111, 99, 111, 108, 32, 110, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 0, 83, 111, 99, 107, 101, 116, 32, 116, 121, 112, 101, 32, 110, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 0, 78, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 0, 80, 114, 111, 116, 111, 99, 111, 108, 32, 102, 97, 109, 105, 108, 121, 32, 110, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 0, 65, 100, 100, 114, 101, 115, 115, 32, 102, 97, 109, 105, 108, 121, 32, 110, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 98, 121, 32, 112, 114, 111, 116, 111, 99, 111, 108, 0, 65, 100, 100, 114, 101, 115, 115, 32, 110, 111, 116, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 78, 101, 116, 119, 111, 114, 107, 32, 105, 115, 32, 100, 111, 119, 110, 0, 78, 101, 116, 119, 111, 114, 107, 32, 117, 110, 114, 101, 97, 99, 104, 97, 98, 108, 101, 0, 67, 111, 110, 110, 101, 99, 116, 105, 111, 110, 32, 114, 101, 115, 101, 116, 32, 98, 121, 32, 110, 101, 116, 119, 111, 114, 107, 0, 67, 111, 110, 110, 101, 99, 116, 105, 111, 110, 32, 97, 98, 111, 114, 116, 101, 100, 0, 78, 111, 32, 98, 117, 102, 102, 101, 114, 32, 115, 112, 97, 99, 101, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 83, 111, 99, 107, 101, 116, 32, 105, 115, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 0, 83, 111, 99, 107, 101, 116, 32, 110, 111, 116, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 0, 67, 97, 110, 110, 111, 116, 32, 115, 101, 110, 100, 32, 97, 102, 116, 101, 114, 32, 115, 111, 99, 107, 101, 116, 32, 115, 104, 117, 116, 100, 111, 119, 110, 0, 79, 112, 101, 114, 97, 116, 105, 111, 110, 32, 97, 108, 114, 101, 97, 100, 121, 32, 105, 110, 32, 112, 114, 111, 103, 114, 101, 115, 115, 0, 79, 112, 101, 114, 97, 116, 105, 111, 110, 32, 105, 110, 32, 112, 114, 111, 103, 114, 101, 115, 115, 0, 83, 116, 97, 108, 101, 32, 102, 105, 108, 101, 32, 104, 97, 110, 100, 108, 101, 0, 82, 101, 109, 111, 116, 101, 32, 73, 47, 79, 32, 101, 114, 114, 111, 114, 0, 81, 117, 111, 116, 97, 32, 101, 120, 99, 101, 101, 100, 101, 100, 0, 78, 111, 32, 109, 101, 100, 105, 117, 109, 32, 102, 111, 117, 110, 100, 0, 87, 114, 111, 110, 103, 32, 109, 101, 100, 105, 117, 109, 32, 116, 121, 112, 101, 0, 78, 111, 32, 101, 114, 114, 111, 114, 32, 105, 110, 102, 111, 114, 109, 97, 116, 105, 111, 110, 0, 0, 40, 110, 117, 108, 108, 41, 0, 45, 48, 88, 43, 48, 88, 32, 48, 88, 45, 48, 120, 43, 48, 120, 32, 48, 120, 0, 105, 110, 102, 0, 73, 78, 70, 0, 110, 97, 110, 0, 78, 65, 78, 0, 80, 79, 83, 73, 88, 0, 99, 108, 111, 99, 107, 95, 103, 101, 116, 116, 105, 109, 101, 40, 67, 76, 79, 67, 75, 95, 77, 79, 78, 79, 84, 79, 78, 73, 67, 41, 32, 102, 97, 105, 108, 101, 100, 0, 99, 111, 110, 100, 105, 116, 105, 111, 110, 95, 118, 97, 114, 105, 97, 98, 108, 101, 58, 58, 119, 97, 105, 116, 58, 32, 109, 117, 116, 101, 120, 32, 110, 111, 116, 32, 108, 111, 99, 107, 101, 100, 0, 99, 111, 110, 100, 105, 116, 105, 111, 110, 95, 118, 97, 114, 105, 97, 98, 108, 101, 32, 119, 97, 105, 116, 32, 102, 97, 105, 108, 101, 100, 0, 78, 83, 116, 51, 95, 95, 50, 57, 98, 97, 115, 105, 99, 95, 105, 111, 115, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 56, 105, 111, 115, 95, 98, 97, 115, 101, 69, 0, 78, 83, 116, 51, 95, 95, 50, 57, 98, 97, 115, 105, 99, 95, 105, 111, 115, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 53, 98, 97, 115, 105, 99, 95, 115, 116, 114, 101, 97, 109, 98, 117, 102, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 53, 98, 97, 115, 105, 99, 95, 115, 116, 114, 101, 97, 109, 98, 117, 102, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 51, 98, 97, 115, 105, 99, 95, 105, 115, 116, 114, 101, 97, 109, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 51, 98, 97, 115, 105, 99, 95, 105, 115, 116, 114, 101, 97, 109, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 51, 98, 97, 115, 105, 99, 95, 111, 115, 116, 114, 101, 97, 109, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 51, 98, 97, 115, 105, 99, 95, 111, 115, 116, 114, 101, 97, 109, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 52, 98, 97, 115, 105, 99, 95, 105, 111, 115, 116, 114, 101, 97, 109, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 115, 116, 100, 105, 110, 98, 117, 102, 73, 99, 69, 69, 0, 117, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 108, 111, 99, 97, 108, 101, 32, 102, 111, 114, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 105, 110, 112, 117, 116, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 115, 116, 100, 105, 110, 98, 117, 102, 73, 119, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 49, 95, 95, 115, 116, 100, 111, 117, 116, 98, 117, 102, 73, 99, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 49, 95, 95, 115, 116, 100, 111, 117, 116, 98, 117, 102, 73, 119, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 55, 99, 111, 108, 108, 97, 116, 101, 73, 99, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 54, 108, 111, 99, 97, 108, 101, 53, 102, 97, 99, 101, 116, 69, 0, 78, 83, 116, 51, 95, 95, 50, 55, 99, 111, 108, 108, 97, 116, 101, 73, 119, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 55, 110, 117, 109, 95, 103, 101, 116, 73, 99, 78, 83, 95, 49, 57, 105, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 57, 95, 95, 110, 117, 109, 95, 103, 101, 116, 73, 99, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 52, 95, 95, 110, 117, 109, 95, 103, 101, 116, 95, 98, 97, 115, 101, 69, 0, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 97, 98, 99, 100, 101, 102, 65, 66, 67, 68, 69, 70, 120, 88, 43, 45, 112, 80, 105, 73, 110, 78, 0, 67, 0, 37, 112, 0, 78, 83, 116, 51, 95, 95, 50, 55, 110, 117, 109, 95, 103, 101, 116, 73, 119, 78, 83, 95, 49, 57, 105, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 57, 95, 95, 110, 117, 109, 95, 103, 101, 116, 73, 119, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 55, 110, 117, 109, 95, 112, 117, 116, 73, 99, 78, 83, 95, 49, 57, 111, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 57, 95, 95, 110, 117, 109, 95, 112, 117, 116, 73, 99, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 52, 95, 95, 110, 117, 109, 95, 112, 117, 116, 95, 98, 97, 115, 101, 69, 0, 37, 0, 0, 0, 0, 0, 76, 0, 37, 112, 0, 0, 0, 0, 78, 83, 116, 51, 95, 95, 50, 55, 110, 117, 109, 95, 112, 117, 116, 73, 119, 78, 83, 95, 49, 57, 111, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 57, 95, 95, 110, 117, 109, 95, 112, 117, 116, 73, 119, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 56, 116, 105, 109, 101, 95, 103, 101, 116, 73, 99, 78, 83, 95, 49, 57, 105, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 57, 116, 105, 109, 101, 95, 98, 97, 115, 101, 69, 0, 78, 83, 116, 51, 95, 95, 50, 50, 48, 95, 95, 116, 105, 109, 101, 95, 103, 101, 116, 95, 99, 95, 115, 116, 111, 114, 97, 103, 101, 73, 99, 69, 69, 0, 37, 72, 58, 37, 77, 58, 37, 83, 37, 109, 47, 37, 100, 47, 37, 121, 37, 89, 45, 37, 109, 45, 37, 100, 37, 73, 58, 37, 77, 58, 37, 83, 32, 37, 112, 37, 72, 58, 37, 77, 37, 72, 58, 37, 77, 58, 37, 83, 83, 117, 110, 100, 97, 121, 0, 77, 111, 110, 100, 97, 121, 0, 84, 117, 101, 115, 100, 97, 121, 0, 87, 101, 100, 110, 101, 115, 100, 97, 121, 0, 84, 104, 117, 114, 115, 100, 97, 121, 0, 70, 114, 105, 100, 97, 121, 0, 83, 97, 116, 117, 114, 100, 97, 121, 0, 83, 117, 110, 0, 77, 111, 110, 0, 84, 117, 101, 0, 87, 101, 100, 0, 84, 104, 117, 0, 70, 114, 105, 0, 83, 97, 116, 0, 74, 97, 110, 117, 97, 114, 121, 0, 70, 101, 98, 114, 117, 97, 114, 121, 0, 77, 97, 114, 99, 104, 0, 65, 112, 114, 105, 108, 0, 77, 97, 121, 0, 74, 117, 110, 101, 0, 74, 117, 108, 121, 0, 65, 117, 103, 117, 115, 116, 0, 83, 101, 112, 116, 101, 109, 98, 101, 114, 0, 79, 99, 116, 111, 98, 101, 114, 0, 78, 111, 118, 101, 109, 98, 101, 114, 0, 68, 101, 99, 101, 109, 98, 101, 114, 0, 74, 97, 110, 0, 70, 101, 98, 0, 77, 97, 114, 0, 65, 112, 114, 0, 74, 117, 110, 0, 74, 117, 108, 0, 65, 117, 103, 0, 83, 101, 112, 0, 79, 99, 116, 0, 78, 111, 118, 0, 68, 101, 99, 0, 65, 77, 0, 80, 77, 0, 37, 97, 32, 37, 98, 32, 37, 100, 32, 37, 72, 58, 37, 77, 58, 37, 83, 32, 37, 89, 0, 37, 73, 58, 37, 77, 58, 37, 83, 32, 37, 112, 0, 37, 109, 47, 37, 100, 47, 37, 121, 0, 37, 72, 58, 37, 77, 58, 37, 83, 0, 78, 83, 116, 51, 95, 95, 50, 56, 116, 105, 109, 101, 95, 103, 101, 116, 73, 119, 78, 83, 95, 49, 57, 105, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 50, 48, 95, 95, 116, 105, 109, 101, 95, 103, 101, 116, 95, 99, 95, 115, 116, 111, 114, 97, 103, 101, 73, 119, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 56, 116, 105, 109, 101, 95, 112, 117, 116, 73, 99, 78, 83, 95, 49, 57, 111, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 95, 95, 116, 105, 109, 101, 95, 112, 117, 116, 69, 0, 78, 83, 116, 51, 95, 95, 50, 56, 116, 105, 109, 101, 95, 112, 117, 116, 73, 119, 78, 83, 95, 49, 57, 111, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 109, 111, 110, 101, 121, 112, 117, 110, 99, 116, 73, 99, 76, 98, 48, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 109, 111, 110, 101, 121, 95, 98, 97, 115, 101, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 109, 111, 110, 101, 121, 112, 117, 110, 99, 116, 73, 99, 76, 98, 49, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 109, 111, 110, 101, 121, 112, 117, 110, 99, 116, 73, 119, 76, 98, 48, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 109, 111, 110, 101, 121, 112, 117, 110, 99, 116, 73, 119, 76, 98, 49, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 57, 109, 111, 110, 101, 121, 95, 103, 101, 116, 73, 99, 78, 83, 95, 49, 57, 105, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 49, 95, 95, 109, 111, 110, 101, 121, 95, 103, 101, 116, 73, 99, 69, 69, 0, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 0, 37, 76, 102, 0, 78, 83, 116, 51, 95, 95, 50, 57, 109, 111, 110, 101, 121, 95, 103, 101, 116, 73, 119, 78, 83, 95, 49, 57, 105, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 49, 95, 95, 109, 111, 110, 101, 121, 95, 103, 101, 116, 73, 119, 69, 69, 0, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 0, 78, 83, 116, 51, 95, 95, 50, 57, 109, 111, 110, 101, 121, 95, 112, 117, 116, 73, 99, 78, 83, 95, 49, 57, 111, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 99, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 99, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 49, 95, 95, 109, 111, 110, 101, 121, 95, 112, 117, 116, 73, 99, 69, 69, 0, 37, 46, 48, 76, 102, 0, 78, 83, 116, 51, 95, 95, 50, 57, 109, 111, 110, 101, 121, 95, 112, 117, 116, 73, 119, 78, 83, 95, 49, 57, 111, 115, 116, 114, 101, 97, 109, 98, 117, 102, 95, 105, 116, 101, 114, 97, 116, 111, 114, 73, 119, 78, 83, 95, 49, 49, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 73, 119, 69, 69, 69, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 49, 95, 95, 109, 111, 110, 101, 121, 95, 112, 117, 116, 73, 119, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 56, 109, 101, 115, 115, 97, 103, 101, 115, 73, 99, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 51, 109, 101, 115, 115, 97, 103, 101, 115, 95, 98, 97, 115, 101, 69, 0, 78, 83, 116, 51, 95, 95, 50, 56, 109, 101, 115, 115, 97, 103, 101, 115, 73, 119, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 54, 95, 95, 110, 97, 114, 114, 111, 119, 95, 116, 111, 95, 117, 116, 102, 56, 73, 76, 106, 51, 50, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 55, 99, 111, 100, 101, 99, 118, 116, 73, 68, 105, 99, 49, 49, 95, 95, 109, 98, 115, 116, 97, 116, 101, 95, 116, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 50, 99, 111, 100, 101, 99, 118, 116, 95, 98, 97, 115, 101, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 55, 95, 95, 119, 105, 100, 101, 110, 95, 102, 114, 111, 109, 95, 117, 116, 102, 56, 73, 76, 106, 51, 50, 69, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 55, 99, 111, 100, 101, 99, 118, 116, 73, 99, 99, 49, 49, 95, 95, 109, 98, 115, 116, 97, 116, 101, 95, 116, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 55, 99, 111, 100, 101, 99, 118, 116, 73, 119, 99, 49, 49, 95, 95, 109, 98, 115, 116, 97, 116, 101, 95, 116, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 55, 99, 111, 100, 101, 99, 118, 116, 73, 68, 115, 99, 49, 49, 95, 95, 109, 98, 115, 116, 97, 116, 101, 95, 116, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 54, 108, 111, 99, 97, 108, 101, 53, 95, 95, 105, 109, 112, 69, 0, 78, 83, 116, 51, 95, 95, 50, 53, 99, 116, 121, 112, 101, 73, 99, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 49, 48, 99, 116, 121, 112, 101, 95, 98, 97, 115, 101, 69, 0, 78, 83, 116, 51, 95, 95, 50, 53, 99, 116, 121, 112, 101, 73, 119, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 56, 110, 117, 109, 112, 117, 110, 99, 116, 73, 99, 69, 69, 0, 78, 83, 116, 51, 95, 95, 50, 56, 110, 117, 109, 112, 117, 110, 99, 116, 73, 119, 69, 69, 0, 33, 34, 118, 101, 99, 116, 111, 114, 32, 108, 101, 110, 103, 116, 104, 95, 101, 114, 114, 111, 114, 34, 0, 47, 109, 101, 100, 105, 97, 47, 97, 108, 111, 110, 47, 100, 54, 57, 100, 100, 57, 98, 50, 45, 52, 55, 57, 49, 45, 52, 98, 56, 101, 45, 97, 101, 98, 51, 45, 102, 54, 51, 53, 51, 98, 52, 53, 100, 55, 49, 48, 47, 104, 111, 109, 101, 47, 97, 108, 111, 110, 47, 68, 101, 118, 47, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 47, 115, 121, 115, 116, 101, 109, 47, 105, 110, 99, 108, 117, 100, 101, 47, 108, 105, 98, 99, 120, 120, 47, 118, 101, 99, 116, 111, 114, 0, 33, 34, 118, 101, 99, 116, 111, 114, 32, 111, 117, 116, 95, 111, 102, 95, 114, 97, 110, 103, 101, 34, 0, 78, 83, 116, 51, 95, 95, 50, 49, 52, 95, 95, 115, 104, 97, 114, 101, 100, 95, 99, 111, 117, 110, 116, 69, 0, 109, 117, 116, 101, 120, 32, 108, 111, 99, 107, 32, 102, 97, 105, 108, 101, 100, 0, 101, 99, 32, 61, 61, 32, 48, 0, 47, 109, 101, 100, 105, 97, 47, 97, 108, 111, 110, 47, 100, 54, 57, 100, 100, 57, 98, 50, 45, 52, 55, 57, 49, 45, 52, 98, 56, 101, 45, 97, 101, 98, 51, 45, 102, 54, 51, 53, 51, 98, 52, 53, 100, 55, 49, 48, 47, 104, 111, 109, 101, 47, 97, 108, 111, 110, 47, 68, 101, 118, 47, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 47, 115, 121, 115, 116, 101, 109, 47, 108, 105, 98, 47, 108, 105, 98, 99, 120, 120, 47, 109, 117, 116, 101, 120, 46, 99, 112, 112, 0, 117, 110, 108, 111, 99, 107, 0, 33, 34, 98, 97, 115, 105, 99, 95, 115, 116, 114, 105, 110, 103, 32, 108, 101, 110, 103, 116, 104, 95, 101, 114, 114, 111, 114, 34, 0, 47, 109, 101, 100, 105, 97, 47, 97, 108, 111, 110, 47, 100, 54, 57, 100, 100, 57, 98, 50, 45, 52, 55, 57, 49, 45, 52, 98, 56, 101, 45, 97, 101, 98, 51, 45, 102, 54, 51, 53, 51, 98, 52, 53, 100, 55, 49, 48, 47, 104, 111, 109, 101, 47, 97, 108, 111, 110, 47, 68, 101, 118, 47, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 47, 115, 121, 115, 116, 101, 109, 47, 105, 110, 99, 108, 117, 100, 101, 47, 108, 105, 98, 99, 120, 120, 47, 115, 116, 114, 105, 110, 103, 0, 95, 95, 116, 104, 114, 111, 119, 95, 108, 101, 110, 103, 116, 104, 95, 101, 114, 114, 111, 114, 0, 33, 34, 98, 97, 115, 105, 99, 95, 115, 116, 114, 105, 110, 103, 32, 111, 117, 116, 95, 111, 102, 95, 114, 97, 110, 103, 101, 34, 0, 95, 95, 116, 104, 114, 111, 119, 95, 111, 117, 116, 95, 111, 102, 95, 114, 97, 110, 103, 101, 0, 33, 34, 97, 108, 108, 111, 99, 97, 116, 111, 114, 60, 84, 62, 58, 58, 97, 108, 108, 111, 99, 97, 116, 101, 58, 58, 98, 97, 100, 95, 97, 108, 108, 111, 99, 34, 0, 47, 109, 101, 100, 105, 97, 47, 97, 108, 111, 110, 47, 100, 54, 57, 100, 100, 57, 98, 50, 45, 52, 55, 57, 49, 45, 52, 98, 56, 101, 45, 97, 101, 98, 51, 45, 102, 54, 51, 53, 51, 98, 52, 53, 100, 55, 49, 48, 47, 104, 111, 109, 101, 47, 97, 108, 111, 110, 47, 68, 101, 118, 47, 101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 47, 115, 121, 115, 116, 101, 109, 47, 105, 110, 99, 108, 117, 100, 101, 47, 108, 105, 98, 99, 120, 120, 47, 109, 101, 109, 111, 114, 121, 0, 97, 108, 108, 111, 99, 97, 116, 101, 0, 115, 116, 111, 105, 0, 58, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101, 0, 37, 115, 10, 0, 58, 32, 110, 111, 32, 99, 111, 110, 118, 101, 114, 115, 105, 111, 110, 0, 37, 117, 0, 99, 97, 110, 110, 111, 116, 32, 122, 101, 114, 111, 32, 111, 117, 116, 32, 116, 104, 114, 101, 97, 100, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 95, 95, 99, 120, 97, 95, 103, 101, 116, 95, 103, 108, 111, 98, 97, 108, 115, 40, 41, 0, 99, 97, 110, 110, 111, 116, 32, 99, 114, 101, 97, 116, 101, 32, 112, 116, 104, 114, 101, 97, 100, 32, 107, 101, 121, 32, 102, 111, 114, 32, 95, 95, 99, 120, 97, 95, 103, 101, 116, 95, 103, 108, 111, 98, 97, 108, 115, 40, 41, 0, 112, 116, 104, 114, 101, 97, 100, 95, 111, 110, 99, 101, 32, 102, 97, 105, 108, 117, 114, 101, 32, 105, 110, 32, 95, 95, 99, 120, 97, 95, 103, 101, 116, 95, 103, 108, 111, 98, 97, 108, 115, 95, 102, 97, 115, 116, 40, 41, 0, 78, 49, 48, 95, 95, 99, 120, 120, 97, 98, 105, 118, 49, 50, 48, 95, 95, 115, 105, 95, 99, 108, 97, 115, 115, 95, 116, 121, 112, 101, 95, 105, 110, 102, 111, 69, 0, 78, 49, 48, 95, 95, 99, 120, 120, 97, 98, 105, 118, 49, 49, 54, 95, 95, 115, 104, 105, 109, 95, 116, 121, 112, 101, 95, 105, 110, 102, 111, 69, 0, 83, 116, 57, 116, 121, 112, 101, 95, 105, 110, 102, 111, 0, 78, 49, 48, 95, 95, 99, 120, 120, 97, 98, 105, 118, 49, 49, 55, 95, 95, 99, 108, 97, 115, 115, 95, 116, 121, 112, 101, 95, 105, 110, 102, 111, 69, 0, 83, 116, 57, 101, 120, 99, 101, 112, 116, 105, 111, 110, 0, 117, 110, 99, 97, 117, 103, 104, 116, 0, 116, 101, 114, 109, 105, 110, 97, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 37, 115, 32, 101, 120, 99, 101, 112, 116, 105, 111, 110, 32, 111, 102, 32, 116, 121, 112, 101, 32, 37, 115, 58, 32, 37, 115, 0, 116, 101, 114, 109, 105, 110, 97, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 37, 115, 32, 101, 120, 99, 101, 112, 116, 105, 111, 110, 32, 111, 102, 32, 116, 121, 112, 101, 32, 37, 115, 0, 116, 101, 114, 109, 105, 110, 97, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 37, 115, 32, 102, 111, 114, 101, 105, 103, 110, 32, 101, 120, 99, 101, 112, 116, 105, 111, 110, 0, 116, 101, 114, 109, 105, 110, 97, 116, 105, 110, 103, 0, 116, 101, 114, 109, 105, 110, 97, 116, 101, 95, 104, 97, 110, 100, 108, 101, 114, 32, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 108, 121, 32, 114, 101, 116, 117, 114, 110, 101, 100, 0, 83, 116, 57, 98, 97, 100, 95, 97, 108, 108, 111, 99, 0, 115, 116, 100, 58, 58, 98, 97, 100, 95, 97, 108, 108, 111, 99, 0, 115, 116, 100, 58, 58, 101, 120, 99, 101, 112, 116, 105, 111, 110, 0, 83, 116, 49, 49, 108, 111, 103, 105, 99, 95, 101, 114, 114, 111, 114, 0, 83, 116, 49, 50, 111, 117, 116, 95, 111, 102, 95, 114, 97, 110, 103, 101, 0, 78, 49, 48, 95, 95, 99, 120, 120, 97, 98, 105, 118, 49, 49, 57, 95, 95, 112, 111, 105, 110, 116, 101, 114, 95, 116, 121, 112, 101, 95, 105, 110, 102, 111, 69, 0, 78, 49, 48, 95, 95, 99, 120, 120, 97, 98, 105, 118, 49, 49, 55, 95, 95, 112, 98, 97, 115, 101, 95, 116, 121, 112, 101, 95, 105, 110, 102, 111, 69, 0, 78, 49, 48, 95, 95, 99, 120, 120, 97, 98, 105, 118, 49, 50, 49, 95, 95, 118, 109, 105, 95, 99, 108, 97, 115, 115, 95, 116, 121, 112, 101, 95, 105, 110, 102, 111, 69, 0, 32, 99, 111, 110, 115, 116, 0, 32, 118, 111, 108, 97, 116, 105, 108, 101, 0, 32, 114, 101, 115, 116, 114, 105, 99, 116, 0, 118, 111, 105, 100, 0, 119, 99, 104, 97, 114, 95, 116, 0, 98, 111, 111, 108, 0, 99, 104, 97, 114, 0, 115, 105, 103, 110, 101, 100, 32, 99, 104, 97, 114, 0, 117, 110, 115, 105, 103, 110, 101, 100, 32, 99, 104, 97, 114, 0, 115, 104, 111, 114, 116, 0, 117, 110, 115, 105, 103, 110, 101, 100, 32, 115, 104, 111, 114, 116, 0, 105, 110, 116, 0, 117, 110, 115, 105, 103, 110, 101, 100, 32, 105, 110, 116, 0, 108, 111, 110, 103, 0, 117, 110, 115, 105, 103, 110, 101, 100, 32, 108, 111, 110, 103, 0, 108, 111, 110, 103, 32, 108, 111, 110, 103, 0, 117, 110, 115, 105, 103, 110, 101, 100, 32, 108, 111, 110, 103, 32, 108, 111, 110, 103, 0, 95, 95, 105, 110, 116, 49, 50, 56, 0, 117, 110, 115, 105, 103, 110, 101, 100, 32, 95, 95, 105, 110, 116, 49, 50, 56, 0, 102, 108, 111, 97, 116, 0, 100, 111, 117, 98, 108, 101, 0, 108, 111, 110, 103, 32, 100, 111, 117, 98, 108, 101, 0, 95, 95, 102, 108, 111, 97, 116, 49, 50, 56, 0, 46, 46, 46, 0, 95, 71, 76, 79, 66, 65, 76, 95, 95, 78, 0, 40, 97, 110, 111, 110, 121, 109, 111, 117, 115, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 41, 0, 100, 101, 99, 105, 109, 97, 108, 54, 52, 0, 100, 101, 99, 105, 109, 97, 108, 49, 50, 56, 0, 100, 101, 99, 105, 109, 97, 108, 51, 50, 0, 100, 101, 99, 105, 109, 97, 108, 49, 54, 0, 99, 104, 97, 114, 51, 50, 95, 116, 0, 99, 104, 97, 114, 49, 54, 95, 116, 0, 97, 117, 116, 111, 0, 115, 116, 100, 58, 58, 110, 117, 108, 108, 112, 116, 114, 95, 116, 0, 32, 91, 0, 32, 91, 93, 0, 93, 0, 40, 0, 41, 0, 102, 97, 108, 115, 101, 0, 116, 114, 117, 101, 0, 117, 0, 108, 0, 117, 108, 0, 108, 108, 0, 117, 108, 108, 0, 37, 97, 102, 0, 37, 97, 0, 37, 76, 97, 76, 0, 102, 112, 0, 38, 38, 0, 62, 0, 41, 32, 0, 32, 40, 0, 38, 0, 38, 61, 0, 61, 0, 97, 108, 105, 103, 110, 111, 102, 32, 40, 0, 99, 111, 110, 115, 116, 95, 99, 97, 115, 116, 60, 0, 62, 40, 0, 44, 0, 126, 0, 41, 40, 0, 58, 58, 0, 100, 101, 108, 101, 116, 101, 91, 93, 32, 0, 100, 121, 110, 97, 109, 105, 99, 95, 99, 97, 115, 116, 60, 0, 42, 0, 100, 101, 108, 101, 116, 101, 32, 0, 111, 112, 101, 114, 97, 116, 111, 114, 38, 38, 0, 111, 112, 101, 114, 97, 116, 111, 114, 38, 0, 111, 112, 101, 114, 97, 116, 111, 114, 38, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 40, 41, 0, 111, 112, 101, 114, 97, 116, 111, 114, 44, 0, 111, 112, 101, 114, 97, 116, 111, 114, 126, 0, 111, 112, 101, 114, 97, 116, 111, 114, 32, 0, 111, 112, 101, 114, 97, 116, 111, 114, 32, 100, 101, 108, 101, 116, 101, 91, 93, 0, 111, 112, 101, 114, 97, 116, 111, 114, 42, 0, 111, 112, 101, 114, 97, 116, 111, 114, 32, 100, 101, 108, 101, 116, 101, 0, 111, 112, 101, 114, 97, 116, 111, 114, 47, 0, 111, 112, 101, 114, 97, 116, 111, 114, 47, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 94, 0, 111, 112, 101, 114, 97, 116, 111, 114, 94, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 61, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 62, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 62, 0, 111, 112, 101, 114, 97, 116, 111, 114, 91, 93, 0, 111, 112, 101, 114, 97, 116, 111, 114, 60, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 34, 34, 32, 0, 111, 112, 101, 114, 97, 116, 111, 114, 60, 60, 0, 111, 112, 101, 114, 97, 116, 111, 114, 60, 60, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 60, 0, 111, 112, 101, 114, 97, 116, 111, 114, 45, 0, 111, 112, 101, 114, 97, 116, 111, 114, 45, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 42, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 45, 45, 0, 111, 112, 101, 114, 97, 116, 111, 114, 32, 110, 101, 119, 91, 93, 0, 111, 112, 101, 114, 97, 116, 111, 114, 33, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 33, 0, 111, 112, 101, 114, 97, 116, 111, 114, 32, 110, 101, 119, 0, 111, 112, 101, 114, 97, 116, 111, 114, 124, 124, 0, 111, 112, 101, 114, 97, 116, 111, 114, 124, 0, 111, 112, 101, 114, 97, 116, 111, 114, 124, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 45, 62, 42, 0, 111, 112, 101, 114, 97, 116, 111, 114, 43, 0, 111, 112, 101, 114, 97, 116, 111, 114, 43, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 43, 43, 0, 111, 112, 101, 114, 97, 116, 111, 114, 45, 62, 0, 111, 112, 101, 114, 97, 116, 111, 114, 63, 0, 111, 112, 101, 114, 97, 116, 111, 114, 37, 0, 111, 112, 101, 114, 97, 116, 111, 114, 37, 61, 0, 111, 112, 101, 114, 97, 116, 111, 114, 62, 62, 0, 111, 112, 101, 114, 97, 116, 111, 114, 62, 62, 61, 0, 60, 0, 44, 32, 0, 32, 62, 0, 100, 101, 99, 108, 116, 121, 112, 101, 40, 0, 115, 116, 100, 58, 58, 97, 108, 108, 111, 99, 97, 116, 111, 114, 0, 115, 116, 100, 58, 58, 98, 97, 115, 105, 99, 95, 115, 116, 114, 105, 110, 103, 0, 115, 116, 100, 58, 58, 115, 116, 114, 105, 110, 103, 0, 115, 116, 100, 58, 58, 105, 115, 116, 114, 101, 97, 109, 0, 115, 116, 100, 58, 58, 111, 115, 116, 114, 101, 97, 109, 0, 115, 116, 100, 58, 58, 105, 111, 115, 116, 114, 101, 97, 109, 0, 115, 116, 100, 58, 58, 98, 97, 115, 105, 99, 95, 115, 116, 114, 105, 110, 103, 60, 99, 104, 97, 114, 44, 32, 115, 116, 100, 58, 58, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 60, 99, 104, 97, 114, 62, 44, 32, 115, 116, 100, 58, 58, 97, 108, 108, 111, 99, 97, 116, 111, 114, 60, 99, 104, 97, 114, 62, 32, 62, 0, 98, 97, 115, 105, 99, 95, 115, 116, 114, 105, 110, 103, 0, 115, 116, 100, 58, 58, 98, 97, 115, 105, 99, 95, 105, 115, 116, 114, 101, 97, 109, 60, 99, 104, 97, 114, 44, 32, 115, 116, 100, 58, 58, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 60, 99, 104, 97, 114, 62, 32, 62, 0, 98, 97, 115, 105, 99, 95, 105, 115, 116, 114, 101, 97, 109, 0, 115, 116, 100, 58, 58, 98, 97, 115, 105, 99, 95, 111, 115, 116, 114, 101, 97, 109, 60, 99, 104, 97, 114, 44, 32, 115, 116, 100, 58, 58, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 60, 99, 104, 97, 114, 62, 32, 62, 0, 98, 97, 115, 105, 99, 95, 111, 115, 116, 114, 101, 97, 109, 0, 115, 116, 100, 58, 58, 98, 97, 115, 105, 99, 95, 105, 111, 115, 116, 114, 101, 97, 109, 60, 99, 104, 97, 114, 44, 32, 115, 116, 100, 58, 58, 99, 104, 97, 114, 95, 116, 114, 97, 105, 116, 115, 60, 99, 104, 97, 114, 62, 32, 62, 0, 98, 97, 115, 105, 99, 95, 105, 111, 115, 116, 114, 101, 97, 109, 0, 39, 117, 110, 110, 97, 109, 101, 100, 0, 39, 108, 97, 109, 98, 100, 97, 39, 40, 0, 115, 116, 100, 58, 58, 0, 46, 42, 0, 46, 0, 47, 0, 47, 61, 0, 94, 0, 94, 61, 0, 61, 61, 0, 62, 61, 0, 41, 91, 0, 60, 61, 0, 60, 60, 0, 60, 60, 61, 0, 45, 0, 45, 61, 0, 42, 61, 0, 45, 45, 0, 41, 45, 45, 0, 91, 93, 32, 0, 32, 0, 33, 61, 0, 33, 0, 110, 111, 101, 120, 99, 101, 112, 116, 32, 40, 0, 124, 124, 0, 124, 0, 124, 61, 0, 45, 62, 42, 0, 43, 0, 43, 61, 0, 43, 43, 0, 41, 43, 43, 0, 45, 62, 0, 41, 32, 63, 32, 40, 0, 41, 32, 58, 32, 40, 0, 114, 101, 105, 110, 116, 101, 114, 112, 114, 101, 116, 95, 99, 97, 115, 116, 60, 0, 37, 0, 37, 61, 0, 62, 62, 0, 62, 62, 61, 0, 115, 116, 97, 116, 105, 99, 95, 99, 97, 115, 116, 60, 0, 115, 105, 122, 101, 111, 102, 32, 40, 0, 115, 105, 122, 101, 111, 102, 46, 46, 46, 40, 0, 116, 121, 112, 101, 105, 100, 40, 0, 116, 104, 114, 111, 119, 0, 116, 104, 114, 111, 119, 32, 0, 32, 99, 111, 109, 112, 108, 101, 120, 0, 32, 38, 0, 32, 38, 38, 0, 32, 105, 109, 97, 103, 105, 110, 97, 114, 121, 0, 58, 58, 42, 0, 111, 98, 106, 99, 95, 111, 98, 106, 101, 99, 116, 60, 0, 105, 100, 0, 111, 98, 106, 99, 112, 114, 111, 116, 111, 0, 115, 116, 100, 0, 58, 58, 115, 116, 114, 105, 110, 103, 32, 108, 105, 116, 101, 114, 97, 108, 0, 32, 118, 101, 99, 116, 111, 114, 91, 0, 112, 105, 120, 101, 108, 32, 118, 101, 99, 116, 111, 114, 91, 0, 118, 116, 97, 98, 108, 101, 32, 102, 111, 114, 32, 0, 86, 84, 84, 32, 102, 111, 114, 32, 0, 116, 121, 112, 101, 105, 110, 102, 111, 32, 102, 111, 114, 32, 0, 116, 121, 112, 101, 105, 110, 102, 111, 32, 110, 97, 109, 101, 32, 102, 111, 114, 32, 0, 99, 111, 118, 97, 114, 105, 97, 110, 116, 32, 114, 101, 116, 117, 114, 110, 32, 116, 104, 117, 110, 107, 32, 116, 111, 32, 0, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 32, 118, 116, 97, 98, 108, 101, 32, 102, 111, 114, 32, 0, 45, 105, 110, 45, 0, 118, 105, 114, 116, 117, 97, 108, 32, 116, 104, 117, 110, 107, 32, 116, 111, 32, 0, 110, 111, 110, 45, 118, 105, 114, 116, 117, 97, 108, 32, 116, 104, 117, 110, 107, 32, 116, 111, 32, 0, 103, 117, 97, 114, 100, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 102, 111, 114, 32, 0, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 101, 109, 112, 111, 114, 97, 114, 121, 32, 102, 111, 114, 32, 0, 95, 98, 108, 111, 99, 107, 95, 105, 110, 118, 111, 107, 101, 0, 105, 110, 118, 111, 99, 97, 116, 105, 111, 110, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 102, 111, 114, 32, 98, 108, 111, 99, 107, 32, 105, 110, 32, 0 ], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 51560);
var tempDoublePtr = STATICTOP;
STATICTOP += 16;
function _atexit(func, arg) {
 __ATEXIT__.unshift({
  func: func,
  arg: arg
 });
}
function ___cxa_atexit() {
 return _atexit.apply(null, arguments);
}
function _emscripten_get_now() {
 abort();
}
function _emscripten_get_now_is_monotonic() {
 return ENVIRONMENT_IS_NODE || typeof dateNow !== "undefined" || (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) && self["performance"] && self["performance"]["now"];
}
var ERRNO_CODES = {
 EPERM: 1,
 ENOENT: 2,
 ESRCH: 3,
 EINTR: 4,
 EIO: 5,
 ENXIO: 6,
 E2BIG: 7,
 ENOEXEC: 8,
 EBADF: 9,
 ECHILD: 10,
 EAGAIN: 11,
 EWOULDBLOCK: 11,
 ENOMEM: 12,
 EACCES: 13,
 EFAULT: 14,
 ENOTBLK: 15,
 EBUSY: 16,
 EEXIST: 17,
 EXDEV: 18,
 ENODEV: 19,
 ENOTDIR: 20,
 EISDIR: 21,
 EINVAL: 22,
 ENFILE: 23,
 EMFILE: 24,
 ENOTTY: 25,
 ETXTBSY: 26,
 EFBIG: 27,
 ENOSPC: 28,
 ESPIPE: 29,
 EROFS: 30,
 EMLINK: 31,
 EPIPE: 32,
 EDOM: 33,
 ERANGE: 34,
 ENOMSG: 42,
 EIDRM: 43,
 ECHRNG: 44,
 EL2NSYNC: 45,
 EL3HLT: 46,
 EL3RST: 47,
 ELNRNG: 48,
 EUNATCH: 49,
 ENOCSI: 50,
 EL2HLT: 51,
 EDEADLK: 35,
 ENOLCK: 37,
 EBADE: 52,
 EBADR: 53,
 EXFULL: 54,
 ENOANO: 55,
 EBADRQC: 56,
 EBADSLT: 57,
 EDEADLOCK: 35,
 EBFONT: 59,
 ENOSTR: 60,
 ENODATA: 61,
 ETIME: 62,
 ENOSR: 63,
 ENONET: 64,
 ENOPKG: 65,
 EREMOTE: 66,
 ENOLINK: 67,
 EADV: 68,
 ESRMNT: 69,
 ECOMM: 70,
 EPROTO: 71,
 EMULTIHOP: 72,
 EDOTDOT: 73,
 EBADMSG: 74,
 ENOTUNIQ: 76,
 EBADFD: 77,
 EREMCHG: 78,
 ELIBACC: 79,
 ELIBBAD: 80,
 ELIBSCN: 81,
 ELIBMAX: 82,
 ELIBEXEC: 83,
 ENOSYS: 38,
 ENOTEMPTY: 39,
 ENAMETOOLONG: 36,
 ELOOP: 40,
 EOPNOTSUPP: 95,
 EPFNOSUPPORT: 96,
 ECONNRESET: 104,
 ENOBUFS: 105,
 EAFNOSUPPORT: 97,
 EPROTOTYPE: 91,
 ENOTSOCK: 88,
 ENOPROTOOPT: 92,
 ESHUTDOWN: 108,
 ECONNREFUSED: 111,
 EADDRINUSE: 98,
 ECONNABORTED: 103,
 ENETUNREACH: 101,
 ENETDOWN: 100,
 ETIMEDOUT: 110,
 EHOSTDOWN: 112,
 EHOSTUNREACH: 113,
 EINPROGRESS: 115,
 EALREADY: 114,
 EDESTADDRREQ: 89,
 EMSGSIZE: 90,
 EPROTONOSUPPORT: 93,
 ESOCKTNOSUPPORT: 94,
 EADDRNOTAVAIL: 99,
 ENETRESET: 102,
 EISCONN: 106,
 ENOTCONN: 107,
 ETOOMANYREFS: 109,
 EUSERS: 87,
 EDQUOT: 122,
 ESTALE: 116,
 ENOTSUP: 95,
 ENOMEDIUM: 123,
 EILSEQ: 84,
 EOVERFLOW: 75,
 ECANCELED: 125,
 ENOTRECOVERABLE: 131,
 EOWNERDEAD: 130,
 ESTRPIPE: 86
};
function ___setErrNo(value) {
 if (Module["___errno_location"]) HEAP32[Module["___errno_location"]() >> 2] = value;
 return value;
}
function _clock_gettime(clk_id, tp) {
 var now;
 if (clk_id === 0) {
  now = Date.now();
 } else if (clk_id === 1 && _emscripten_get_now_is_monotonic()) {
  now = _emscripten_get_now();
 } else {
  ___setErrNo(ERRNO_CODES.EINVAL);
  return -1;
 }
 HEAP32[tp >> 2] = now / 1e3 | 0;
 HEAP32[tp + 4 >> 2] = now % 1e3 * 1e3 * 1e3 | 0;
 return 0;
}
Module["_i64Subtract"] = _i64Subtract;
function ___assert_fail(condition, filename, line, func) {
 ABORT = true;
 throw "Assertion failed: " + Pointer_stringify(condition) + ", at: " + [ filename ? Pointer_stringify(filename) : "unknown filename", line, func ? Pointer_stringify(func) : "unknown function" ] + " at " + stackTrace();
}
function __ZSt18uncaught_exceptionv() {
 return !!__ZSt18uncaught_exceptionv.uncaught_exception;
}
var EXCEPTIONS = {
 last: 0,
 caught: [],
 infos: {},
 deAdjust: (function(adjusted) {
  if (!adjusted || EXCEPTIONS.infos[adjusted]) return adjusted;
  for (var ptr in EXCEPTIONS.infos) {
   var info = EXCEPTIONS.infos[ptr];
   if (info.adjusted === adjusted) {
    return ptr;
   }
  }
  return adjusted;
 }),
 addRef: (function(ptr) {
  if (!ptr) return;
  var info = EXCEPTIONS.infos[ptr];
  info.refcount++;
 }),
 decRef: (function(ptr) {
  if (!ptr) return;
  var info = EXCEPTIONS.infos[ptr];
  assert(info.refcount > 0);
  info.refcount--;
  if (info.refcount === 0) {
   if (info.destructor) {
    Runtime.dynCall("vi", info.destructor, [ ptr ]);
   }
   delete EXCEPTIONS.infos[ptr];
   ___cxa_free_exception(ptr);
  }
 }),
 clearRef: (function(ptr) {
  if (!ptr) return;
  var info = EXCEPTIONS.infos[ptr];
  info.refcount = 0;
 })
};
function ___resumeException(ptr) {
 if (!EXCEPTIONS.last) {
  EXCEPTIONS.last = ptr;
 }
 EXCEPTIONS.clearRef(EXCEPTIONS.deAdjust(ptr));
 throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";
}
function ___cxa_find_matching_catch() {
 var thrown = EXCEPTIONS.last;
 if (!thrown) {
  return (asm["setTempRet0"](0), 0) | 0;
 }
 var info = EXCEPTIONS.infos[thrown];
 var throwntype = info.type;
 if (!throwntype) {
  return (asm["setTempRet0"](0), thrown) | 0;
 }
 var typeArray = Array.prototype.slice.call(arguments);
 var pointer = Module["___cxa_is_pointer_type"](throwntype);
 if (!___cxa_find_matching_catch.buffer) ___cxa_find_matching_catch.buffer = _malloc(4);
 HEAP32[___cxa_find_matching_catch.buffer >> 2] = thrown;
 thrown = ___cxa_find_matching_catch.buffer;
 for (var i = 0; i < typeArray.length; i++) {
  if (typeArray[i] && Module["___cxa_can_catch"](typeArray[i], throwntype, thrown)) {
   thrown = HEAP32[thrown >> 2];
   info.adjusted = thrown;
   return (asm["setTempRet0"](typeArray[i]), thrown) | 0;
  }
 }
 thrown = HEAP32[thrown >> 2];
 return (asm["setTempRet0"](throwntype), thrown) | 0;
}
function ___cxa_throw(ptr, type, destructor) {
 EXCEPTIONS.infos[ptr] = {
  ptr: ptr,
  adjusted: ptr,
  type: type,
  destructor: destructor,
  refcount: 0
 };
 EXCEPTIONS.last = ptr;
 if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
  __ZSt18uncaught_exceptionv.uncaught_exception = 1;
 } else {
  __ZSt18uncaught_exceptionv.uncaught_exception++;
 }
 throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";
}
Module["_memset"] = _memset;
Module["_pthread_mutex_lock"] = _pthread_mutex_lock;
function _pthread_cond_signal() {
 return 0;
}
function _abort() {
 Module["abort"]();
}
function _pthread_cond_destroy() {
 return 0;
}
function _pthread_mutex_destroy() {}
function _pthread_create() {
 return 11;
}
function _pthread_once(ptr, func) {
 if (!_pthread_once.seen) _pthread_once.seen = {};
 if (ptr in _pthread_once.seen) return;
 Runtime.dynCall("v", func);
 _pthread_once.seen[ptr] = 1;
}
Module["_i64Add"] = _i64Add;
var cttz_i8 = allocate([ 8, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 5, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 6, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 5, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 7, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 5, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 6, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 5, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0 ], "i8", ALLOC_STATIC);
Module["_llvm_cttz_i32"] = _llvm_cttz_i32;
Module["___udivmoddi4"] = ___udivmoddi4;
Module["___divdi3"] = ___divdi3;
function ___lock() {}
function ___unlock() {}
var PTHREAD_SPECIFIC = {};
function _pthread_getspecific(key) {
 return PTHREAD_SPECIFIC[key] || 0;
}
var _llvm_fabs_f64 = Math_abs;
function _sysconf(name) {
 switch (name) {
 case 30:
  return PAGE_SIZE;
 case 85:
  return totalMemory / PAGE_SIZE;
 case 132:
 case 133:
 case 12:
 case 137:
 case 138:
 case 15:
 case 235:
 case 16:
 case 17:
 case 18:
 case 19:
 case 20:
 case 149:
 case 13:
 case 10:
 case 236:
 case 153:
 case 9:
 case 21:
 case 22:
 case 159:
 case 154:
 case 14:
 case 77:
 case 78:
 case 139:
 case 80:
 case 81:
 case 82:
 case 68:
 case 67:
 case 164:
 case 11:
 case 29:
 case 47:
 case 48:
 case 95:
 case 52:
 case 51:
 case 46:
  return 200809;
 case 79:
  return 0;
 case 27:
 case 246:
 case 127:
 case 128:
 case 23:
 case 24:
 case 160:
 case 161:
 case 181:
 case 182:
 case 242:
 case 183:
 case 184:
 case 243:
 case 244:
 case 245:
 case 165:
 case 178:
 case 179:
 case 49:
 case 50:
 case 168:
 case 169:
 case 175:
 case 170:
 case 171:
 case 172:
 case 97:
 case 76:
 case 32:
 case 173:
 case 35:
  return -1;
 case 176:
 case 177:
 case 7:
 case 155:
 case 8:
 case 157:
 case 125:
 case 126:
 case 92:
 case 93:
 case 129:
 case 130:
 case 131:
 case 94:
 case 91:
  return 1;
 case 74:
 case 60:
 case 69:
 case 70:
 case 4:
  return 1024;
 case 31:
 case 42:
 case 72:
  return 32;
 case 87:
 case 26:
 case 33:
  return 2147483647;
 case 34:
 case 1:
  return 47839;
 case 38:
 case 36:
  return 99;
 case 43:
 case 37:
  return 2048;
 case 0:
  return 2097152;
 case 3:
  return 65536;
 case 28:
  return 32768;
 case 44:
  return 32767;
 case 75:
  return 16384;
 case 39:
  return 1e3;
 case 89:
  return 700;
 case 71:
  return 256;
 case 40:
  return 255;
 case 2:
  return 100;
 case 180:
  return 64;
 case 25:
  return 20;
 case 5:
  return 16;
 case 6:
  return 6;
 case 73:
  return 4;
 case 84:
  {
   if (typeof navigator === "object") return navigator["hardwareConcurrency"] || 1;
   return 1;
  }
 }
 ___setErrNo(ERRNO_CODES.EINVAL);
 return -1;
}
var PTHREAD_SPECIFIC_NEXT_KEY = 1;
function _pthread_key_create(key, destructor) {
 if (key == 0) {
  return ERRNO_CODES.EINVAL;
 }
 HEAP32[key >> 2] = PTHREAD_SPECIFIC_NEXT_KEY;
 PTHREAD_SPECIFIC[PTHREAD_SPECIFIC_NEXT_KEY] = 0;
 PTHREAD_SPECIFIC_NEXT_KEY++;
 return 0;
}
function _emscripten_memcpy_big(dest, src, num) {
 HEAPU8.set(HEAPU8.subarray(src, src + num), dest);
 return dest;
}
Module["_memcpy"] = _memcpy;
Module["_memmove"] = _memmove;
function __exit(status) {
 Module["exit"](status);
}
function _exit(status) {
 __exit(status);
}
function _pthread_setspecific(key, value) {
 if (!(key in PTHREAD_SPECIFIC)) {
  return ERRNO_CODES.EINVAL;
 }
 PTHREAD_SPECIFIC[key] = value;
 return 0;
}
function _malloc(bytes) {
 var ptr = Runtime.dynamicAlloc(bytes + 8);
 return ptr + 8 & 4294967288;
}
Module["_malloc"] = _malloc;
function ___cxa_allocate_exception(size) {
 return _malloc(size);
}
var ERRNO_MESSAGES = {
 0: "Success",
 1: "Not super-user",
 2: "No such file or directory",
 3: "No such process",
 4: "Interrupted system call",
 5: "I/O error",
 6: "No such device or address",
 7: "Arg list too long",
 8: "Exec format error",
 9: "Bad file number",
 10: "No children",
 11: "No more processes",
 12: "Not enough core",
 13: "Permission denied",
 14: "Bad address",
 15: "Block device required",
 16: "Mount device busy",
 17: "File exists",
 18: "Cross-device link",
 19: "No such device",
 20: "Not a directory",
 21: "Is a directory",
 22: "Invalid argument",
 23: "Too many open files in system",
 24: "Too many open files",
 25: "Not a typewriter",
 26: "Text file busy",
 27: "File too large",
 28: "No space left on device",
 29: "Illegal seek",
 30: "Read only file system",
 31: "Too many links",
 32: "Broken pipe",
 33: "Math arg out of domain of func",
 34: "Math result not representable",
 35: "File locking deadlock error",
 36: "File or path name too long",
 37: "No record locks available",
 38: "Function not implemented",
 39: "Directory not empty",
 40: "Too many symbolic links",
 42: "No message of desired type",
 43: "Identifier removed",
 44: "Channel number out of range",
 45: "Level 2 not synchronized",
 46: "Level 3 halted",
 47: "Level 3 reset",
 48: "Link number out of range",
 49: "Protocol driver not attached",
 50: "No CSI structure available",
 51: "Level 2 halted",
 52: "Invalid exchange",
 53: "Invalid request descriptor",
 54: "Exchange full",
 55: "No anode",
 56: "Invalid request code",
 57: "Invalid slot",
 59: "Bad font file fmt",
 60: "Device not a stream",
 61: "No data (for no delay io)",
 62: "Timer expired",
 63: "Out of streams resources",
 64: "Machine is not on the network",
 65: "Package not installed",
 66: "The object is remote",
 67: "The link has been severed",
 68: "Advertise error",
 69: "Srmount error",
 70: "Communication error on send",
 71: "Protocol error",
 72: "Multihop attempted",
 73: "Cross mount point (not really error)",
 74: "Trying to read unreadable message",
 75: "Value too large for defined data type",
 76: "Given log. name not unique",
 77: "f.d. invalid for this operation",
 78: "Remote address changed",
 79: "Can   access a needed shared lib",
 80: "Accessing a corrupted shared lib",
 81: ".lib section in a.out corrupted",
 82: "Attempting to link in too many libs",
 83: "Attempting to exec a shared library",
 84: "Illegal byte sequence",
 86: "Streams pipe error",
 87: "Too many users",
 88: "Socket operation on non-socket",
 89: "Destination address required",
 90: "Message too long",
 91: "Protocol wrong type for socket",
 92: "Protocol not available",
 93: "Unknown protocol",
 94: "Socket type not supported",
 95: "Not supported",
 96: "Protocol family not supported",
 97: "Address family not supported by protocol family",
 98: "Address already in use",
 99: "Address not available",
 100: "Network interface is not configured",
 101: "Network is unreachable",
 102: "Connection reset by network",
 103: "Connection aborted",
 104: "Connection reset by peer",
 105: "No buffer space available",
 106: "Socket is already connected",
 107: "Socket is not connected",
 108: "Can't send after socket shutdown",
 109: "Too many references",
 110: "Connection timed out",
 111: "Connection refused",
 112: "Host is down",
 113: "Host is unreachable",
 114: "Socket already connected",
 115: "Connection already in progress",
 116: "Stale file handle",
 122: "Quota exceeded",
 123: "No medium (in tape drive)",
 125: "Operation canceled",
 130: "Previous owner died",
 131: "State not recoverable"
};
var PATH = {
 splitPath: (function(filename) {
  var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
  return splitPathRe.exec(filename).slice(1);
 }),
 normalizeArray: (function(parts, allowAboveRoot) {
  var up = 0;
  for (var i = parts.length - 1; i >= 0; i--) {
   var last = parts[i];
   if (last === ".") {
    parts.splice(i, 1);
   } else if (last === "..") {
    parts.splice(i, 1);
    up++;
   } else if (up) {
    parts.splice(i, 1);
    up--;
   }
  }
  if (allowAboveRoot) {
   for (; up--; up) {
    parts.unshift("..");
   }
  }
  return parts;
 }),
 normalize: (function(path) {
  var isAbsolute = path.charAt(0) === "/", trailingSlash = path.substr(-1) === "/";
  path = PATH.normalizeArray(path.split("/").filter((function(p) {
   return !!p;
  })), !isAbsolute).join("/");
  if (!path && !isAbsolute) {
   path = ".";
  }
  if (path && trailingSlash) {
   path += "/";
  }
  return (isAbsolute ? "/" : "") + path;
 }),
 dirname: (function(path) {
  var result = PATH.splitPath(path), root = result[0], dir = result[1];
  if (!root && !dir) {
   return ".";
  }
  if (dir) {
   dir = dir.substr(0, dir.length - 1);
  }
  return root + dir;
 }),
 basename: (function(path) {
  if (path === "/") return "/";
  var lastSlash = path.lastIndexOf("/");
  if (lastSlash === -1) return path;
  return path.substr(lastSlash + 1);
 }),
 extname: (function(path) {
  return PATH.splitPath(path)[3];
 }),
 join: (function() {
  var paths = Array.prototype.slice.call(arguments, 0);
  return PATH.normalize(paths.join("/"));
 }),
 join2: (function(l, r) {
  return PATH.normalize(l + "/" + r);
 }),
 resolve: (function() {
  var resolvedPath = "", resolvedAbsolute = false;
  for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
   var path = i >= 0 ? arguments[i] : FS.cwd();
   if (typeof path !== "string") {
    throw new TypeError("Arguments to path.resolve must be strings");
   } else if (!path) {
    return "";
   }
   resolvedPath = path + "/" + resolvedPath;
   resolvedAbsolute = path.charAt(0) === "/";
  }
  resolvedPath = PATH.normalizeArray(resolvedPath.split("/").filter((function(p) {
   return !!p;
  })), !resolvedAbsolute).join("/");
  return (resolvedAbsolute ? "/" : "") + resolvedPath || ".";
 }),
 relative: (function(from, to) {
  from = PATH.resolve(from).substr(1);
  to = PATH.resolve(to).substr(1);
  function trim(arr) {
   var start = 0;
   for (; start < arr.length; start++) {
    if (arr[start] !== "") break;
   }
   var end = arr.length - 1;
   for (; end >= 0; end--) {
    if (arr[end] !== "") break;
   }
   if (start > end) return [];
   return arr.slice(start, end - start + 1);
  }
  var fromParts = trim(from.split("/"));
  var toParts = trim(to.split("/"));
  var length = Math.min(fromParts.length, toParts.length);
  var samePartsLength = length;
  for (var i = 0; i < length; i++) {
   if (fromParts[i] !== toParts[i]) {
    samePartsLength = i;
    break;
   }
  }
  var outputParts = [];
  for (var i = samePartsLength; i < fromParts.length; i++) {
   outputParts.push("..");
  }
  outputParts = outputParts.concat(toParts.slice(samePartsLength));
  return outputParts.join("/");
 })
};
var TTY = {
 ttys: [],
 init: (function() {}),
 shutdown: (function() {}),
 register: (function(dev, ops) {
  TTY.ttys[dev] = {
   input: [],
   output: [],
   ops: ops
  };
  FS.registerDevice(dev, TTY.stream_ops);
 }),
 stream_ops: {
  open: (function(stream) {
   var tty = TTY.ttys[stream.node.rdev];
   if (!tty) {
    throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
   }
   stream.tty = tty;
   stream.seekable = false;
  }),
  close: (function(stream) {
   stream.tty.ops.flush(stream.tty);
  }),
  flush: (function(stream) {
   stream.tty.ops.flush(stream.tty);
  }),
  read: (function(stream, buffer, offset, length, pos) {
   if (!stream.tty || !stream.tty.ops.get_char) {
    throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
   }
   var bytesRead = 0;
   for (var i = 0; i < length; i++) {
    var result;
    try {
     result = stream.tty.ops.get_char(stream.tty);
    } catch (e) {
     throw new FS.ErrnoError(ERRNO_CODES.EIO);
    }
    if (result === undefined && bytesRead === 0) {
     throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
    }
    if (result === null || result === undefined) break;
    bytesRead++;
    buffer[offset + i] = result;
   }
   if (bytesRead) {
    stream.node.timestamp = Date.now();
   }
   return bytesRead;
  }),
  write: (function(stream, buffer, offset, length, pos) {
   if (!stream.tty || !stream.tty.ops.put_char) {
    throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
   }
   for (var i = 0; i < length; i++) {
    try {
     stream.tty.ops.put_char(stream.tty, buffer[offset + i]);
    } catch (e) {
     throw new FS.ErrnoError(ERRNO_CODES.EIO);
    }
   }
   if (length) {
    stream.node.timestamp = Date.now();
   }
   return i;
  })
 },
 default_tty_ops: {
  get_char: (function(tty) {
   if (!tty.input.length) {
    var result = null;
    if (ENVIRONMENT_IS_NODE) {
     var BUFSIZE = 256;
     var buf = new Buffer(BUFSIZE);
     var bytesRead = 0;
     var fd = process.stdin.fd;
     var usingDevice = false;
     try {
      fd = fs.openSync("/dev/stdin", "r");
      usingDevice = true;
     } catch (e) {}
     bytesRead = fs.readSync(fd, buf, 0, BUFSIZE, null);
     if (usingDevice) {
      fs.closeSync(fd);
     }
     if (bytesRead > 0) {
      result = buf.slice(0, bytesRead).toString("utf-8");
     } else {
      result = null;
     }
    } else if (typeof window != "undefined" && typeof window.prompt == "function") {
     result = window.prompt("Input: ");
     if (result !== null) {
      result += "\n";
     }
    } else if (typeof readline == "function") {
     result = readline();
     if (result !== null) {
      result += "\n";
     }
    }
    if (!result) {
     return null;
    }
    tty.input = intArrayFromString(result, true);
   }
   return tty.input.shift();
  }),
  put_char: (function(tty, val) {
   if (val === null || val === 10) {
    Module["print"](UTF8ArrayToString(tty.output, 0));
    tty.output = [];
   } else {
    if (val != 0) tty.output.push(val);
   }
  }),
  flush: (function(tty) {
   if (tty.output && tty.output.length > 0) {
    Module["print"](UTF8ArrayToString(tty.output, 0));
    tty.output = [];
   }
  })
 },
 default_tty1_ops: {
  put_char: (function(tty, val) {
   if (val === null || val === 10) {
    Module["printErr"](UTF8ArrayToString(tty.output, 0));
    tty.output = [];
   } else {
    if (val != 0) tty.output.push(val);
   }
  }),
  flush: (function(tty) {
   if (tty.output && tty.output.length > 0) {
    Module["printErr"](UTF8ArrayToString(tty.output, 0));
    tty.output = [];
   }
  })
 }
};
var MEMFS = {
 ops_table: null,
 mount: (function(mount) {
  return MEMFS.createNode(null, "/", 16384 | 511, 0);
 }),
 createNode: (function(parent, name, mode, dev) {
  if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  if (!MEMFS.ops_table) {
   MEMFS.ops_table = {
    dir: {
     node: {
      getattr: MEMFS.node_ops.getattr,
      setattr: MEMFS.node_ops.setattr,
      lookup: MEMFS.node_ops.lookup,
      mknod: MEMFS.node_ops.mknod,
      rename: MEMFS.node_ops.rename,
      unlink: MEMFS.node_ops.unlink,
      rmdir: MEMFS.node_ops.rmdir,
      readdir: MEMFS.node_ops.readdir,
      symlink: MEMFS.node_ops.symlink
     },
     stream: {
      llseek: MEMFS.stream_ops.llseek
     }
    },
    file: {
     node: {
      getattr: MEMFS.node_ops.getattr,
      setattr: MEMFS.node_ops.setattr
     },
     stream: {
      llseek: MEMFS.stream_ops.llseek,
      read: MEMFS.stream_ops.read,
      write: MEMFS.stream_ops.write,
      allocate: MEMFS.stream_ops.allocate,
      mmap: MEMFS.stream_ops.mmap,
      msync: MEMFS.stream_ops.msync
     }
    },
    link: {
     node: {
      getattr: MEMFS.node_ops.getattr,
      setattr: MEMFS.node_ops.setattr,
      readlink: MEMFS.node_ops.readlink
     },
     stream: {}
    },
    chrdev: {
     node: {
      getattr: MEMFS.node_ops.getattr,
      setattr: MEMFS.node_ops.setattr
     },
     stream: FS.chrdev_stream_ops
    }
   };
  }
  var node = FS.createNode(parent, name, mode, dev);
  if (FS.isDir(node.mode)) {
   node.node_ops = MEMFS.ops_table.dir.node;
   node.stream_ops = MEMFS.ops_table.dir.stream;
   node.contents = {};
  } else if (FS.isFile(node.mode)) {
   node.node_ops = MEMFS.ops_table.file.node;
   node.stream_ops = MEMFS.ops_table.file.stream;
   node.usedBytes = 0;
   node.contents = null;
  } else if (FS.isLink(node.mode)) {
   node.node_ops = MEMFS.ops_table.link.node;
   node.stream_ops = MEMFS.ops_table.link.stream;
  } else if (FS.isChrdev(node.mode)) {
   node.node_ops = MEMFS.ops_table.chrdev.node;
   node.stream_ops = MEMFS.ops_table.chrdev.stream;
  }
  node.timestamp = Date.now();
  if (parent) {
   parent.contents[name] = node;
  }
  return node;
 }),
 getFileDataAsRegularArray: (function(node) {
  if (node.contents && node.contents.subarray) {
   var arr = [];
   for (var i = 0; i < node.usedBytes; ++i) arr.push(node.contents[i]);
   return arr;
  }
  return node.contents;
 }),
 getFileDataAsTypedArray: (function(node) {
  if (!node.contents) return new Uint8Array;
  if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes);
  return new Uint8Array(node.contents);
 }),
 expandFileStorage: (function(node, newCapacity) {
  if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
   node.contents = MEMFS.getFileDataAsRegularArray(node);
   node.usedBytes = node.contents.length;
  }
  if (!node.contents || node.contents.subarray) {
   var prevCapacity = node.contents ? node.contents.buffer.byteLength : 0;
   if (prevCapacity >= newCapacity) return;
   var CAPACITY_DOUBLING_MAX = 1024 * 1024;
   newCapacity = Math.max(newCapacity, prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2 : 1.125) | 0);
   if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256);
   var oldContents = node.contents;
   node.contents = new Uint8Array(newCapacity);
   if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0);
   return;
  }
  if (!node.contents && newCapacity > 0) node.contents = [];
  while (node.contents.length < newCapacity) node.contents.push(0);
 }),
 resizeFileStorage: (function(node, newSize) {
  if (node.usedBytes == newSize) return;
  if (newSize == 0) {
   node.contents = null;
   node.usedBytes = 0;
   return;
  }
  if (!node.contents || node.contents.subarray) {
   var oldContents = node.contents;
   node.contents = new Uint8Array(new ArrayBuffer(newSize));
   if (oldContents) {
    node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes)));
   }
   node.usedBytes = newSize;
   return;
  }
  if (!node.contents) node.contents = [];
  if (node.contents.length > newSize) node.contents.length = newSize; else while (node.contents.length < newSize) node.contents.push(0);
  node.usedBytes = newSize;
 }),
 node_ops: {
  getattr: (function(node) {
   var attr = {};
   attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
   attr.ino = node.id;
   attr.mode = node.mode;
   attr.nlink = 1;
   attr.uid = 0;
   attr.gid = 0;
   attr.rdev = node.rdev;
   if (FS.isDir(node.mode)) {
    attr.size = 4096;
   } else if (FS.isFile(node.mode)) {
    attr.size = node.usedBytes;
   } else if (FS.isLink(node.mode)) {
    attr.size = node.link.length;
   } else {
    attr.size = 0;
   }
   attr.atime = new Date(node.timestamp);
   attr.mtime = new Date(node.timestamp);
   attr.ctime = new Date(node.timestamp);
   attr.blksize = 4096;
   attr.blocks = Math.ceil(attr.size / attr.blksize);
   return attr;
  }),
  setattr: (function(node, attr) {
   if (attr.mode !== undefined) {
    node.mode = attr.mode;
   }
   if (attr.timestamp !== undefined) {
    node.timestamp = attr.timestamp;
   }
   if (attr.size !== undefined) {
    MEMFS.resizeFileStorage(node, attr.size);
   }
  }),
  lookup: (function(parent, name) {
   throw FS.genericErrors[ERRNO_CODES.ENOENT];
  }),
  mknod: (function(parent, name, mode, dev) {
   return MEMFS.createNode(parent, name, mode, dev);
  }),
  rename: (function(old_node, new_dir, new_name) {
   if (FS.isDir(old_node.mode)) {
    var new_node;
    try {
     new_node = FS.lookupNode(new_dir, new_name);
    } catch (e) {}
    if (new_node) {
     for (var i in new_node.contents) {
      throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
     }
    }
   }
   delete old_node.parent.contents[old_node.name];
   old_node.name = new_name;
   new_dir.contents[new_name] = old_node;
   old_node.parent = new_dir;
  }),
  unlink: (function(parent, name) {
   delete parent.contents[name];
  }),
  rmdir: (function(parent, name) {
   var node = FS.lookupNode(parent, name);
   for (var i in node.contents) {
    throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
   }
   delete parent.contents[name];
  }),
  readdir: (function(node) {
   var entries = [ ".", ".." ];
   for (var key in node.contents) {
    if (!node.contents.hasOwnProperty(key)) {
     continue;
    }
    entries.push(key);
   }
   return entries;
  }),
  symlink: (function(parent, newname, oldpath) {
   var node = MEMFS.createNode(parent, newname, 511 | 40960, 0);
   node.link = oldpath;
   return node;
  }),
  readlink: (function(node) {
   if (!FS.isLink(node.mode)) {
    throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
   }
   return node.link;
  })
 },
 stream_ops: {
  read: (function(stream, buffer, offset, length, position) {
   var contents = stream.node.contents;
   if (position >= stream.node.usedBytes) return 0;
   var size = Math.min(stream.node.usedBytes - position, length);
   assert(size >= 0);
   if (size > 8 && contents.subarray) {
    buffer.set(contents.subarray(position, position + size), offset);
   } else {
    for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
   }
   return size;
  }),
  write: (function(stream, buffer, offset, length, position, canOwn) {
   if (!length) return 0;
   var node = stream.node;
   node.timestamp = Date.now();
   if (buffer.subarray && (!node.contents || node.contents.subarray)) {
    if (canOwn) {
     node.contents = buffer.subarray(offset, offset + length);
     node.usedBytes = length;
     return length;
    } else if (node.usedBytes === 0 && position === 0) {
     node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
     node.usedBytes = length;
     return length;
    } else if (position + length <= node.usedBytes) {
     node.contents.set(buffer.subarray(offset, offset + length), position);
     return length;
    }
   }
   MEMFS.expandFileStorage(node, position + length);
   if (node.contents.subarray && buffer.subarray) node.contents.set(buffer.subarray(offset, offset + length), position); else {
    for (var i = 0; i < length; i++) {
     node.contents[position + i] = buffer[offset + i];
    }
   }
   node.usedBytes = Math.max(node.usedBytes, position + length);
   return length;
  }),
  llseek: (function(stream, offset, whence) {
   var position = offset;
   if (whence === 1) {
    position += stream.position;
   } else if (whence === 2) {
    if (FS.isFile(stream.node.mode)) {
     position += stream.node.usedBytes;
    }
   }
   if (position < 0) {
    throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
   }
   return position;
  }),
  allocate: (function(stream, offset, length) {
   MEMFS.expandFileStorage(stream.node, offset + length);
   stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
  }),
  mmap: (function(stream, buffer, offset, length, position, prot, flags) {
   if (!FS.isFile(stream.node.mode)) {
    throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
   }
   var ptr;
   var allocated;
   var contents = stream.node.contents;
   if (!(flags & 2) && (contents.buffer === buffer || contents.buffer === buffer.buffer)) {
    allocated = false;
    ptr = contents.byteOffset;
   } else {
    if (position > 0 || position + length < stream.node.usedBytes) {
     if (contents.subarray) {
      contents = contents.subarray(position, position + length);
     } else {
      contents = Array.prototype.slice.call(contents, position, position + length);
     }
    }
    allocated = true;
    ptr = _malloc(length);
    if (!ptr) {
     throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
    }
    buffer.set(contents, ptr);
   }
   return {
    ptr: ptr,
    allocated: allocated
   };
  }),
  msync: (function(stream, buffer, offset, length, mmapFlags) {
   if (!FS.isFile(stream.node.mode)) {
    throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
   }
   if (mmapFlags & 2) {
    return 0;
   }
   var bytesWritten = MEMFS.stream_ops.write(stream, buffer, 0, length, offset, false);
   return 0;
  })
 }
};
var IDBFS = {
 dbs: {},
 indexedDB: (function() {
  if (typeof indexedDB !== "undefined") return indexedDB;
  var ret = null;
  if (typeof window === "object") ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
  assert(ret, "IDBFS used, but indexedDB not supported");
  return ret;
 }),
 DB_VERSION: 21,
 DB_STORE_NAME: "FILE_DATA",
 mount: (function(mount) {
  return MEMFS.mount.apply(null, arguments);
 }),
 syncfs: (function(mount, populate, callback) {
  IDBFS.getLocalSet(mount, (function(err, local) {
   if (err) return callback(err);
   IDBFS.getRemoteSet(mount, (function(err, remote) {
    if (err) return callback(err);
    var src = populate ? remote : local;
    var dst = populate ? local : remote;
    IDBFS.reconcile(src, dst, callback);
   }));
  }));
 }),
 getDB: (function(name, callback) {
  var db = IDBFS.dbs[name];
  if (db) {
   return callback(null, db);
  }
  var req;
  try {
   req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
  } catch (e) {
   return callback(e);
  }
  req.onupgradeneeded = (function(e) {
   var db = e.target.result;
   var transaction = e.target.transaction;
   var fileStore;
   if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
    fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
   } else {
    fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
   }
   if (!fileStore.indexNames.contains("timestamp")) {
    fileStore.createIndex("timestamp", "timestamp", {
     unique: false
    });
   }
  });
  req.onsuccess = (function() {
   db = req.result;
   IDBFS.dbs[name] = db;
   callback(null, db);
  });
  req.onerror = (function(e) {
   callback(this.error);
   e.preventDefault();
  });
 }),
 getLocalSet: (function(mount, callback) {
  var entries = {};
  function isRealDir(p) {
   return p !== "." && p !== "..";
  }
  function toAbsolute(root) {
   return (function(p) {
    return PATH.join2(root, p);
   });
  }
  var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  while (check.length) {
   var path = check.pop();
   var stat;
   try {
    stat = FS.stat(path);
   } catch (e) {
    return callback(e);
   }
   if (FS.isDir(stat.mode)) {
    check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
   }
   entries[path] = {
    timestamp: stat.mtime
   };
  }
  return callback(null, {
   type: "local",
   entries: entries
  });
 }),
 getRemoteSet: (function(mount, callback) {
  var entries = {};
  IDBFS.getDB(mount.mountpoint, (function(err, db) {
   if (err) return callback(err);
   var transaction = db.transaction([ IDBFS.DB_STORE_NAME ], "readonly");
   transaction.onerror = (function(e) {
    callback(this.error);
    e.preventDefault();
   });
   var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
   var index = store.index("timestamp");
   index.openKeyCursor().onsuccess = (function(event) {
    var cursor = event.target.result;
    if (!cursor) {
     return callback(null, {
      type: "remote",
      db: db,
      entries: entries
     });
    }
    entries[cursor.primaryKey] = {
     timestamp: cursor.key
    };
    cursor.continue();
   });
  }));
 }),
 loadLocalEntry: (function(path, callback) {
  var stat, node;
  try {
   var lookup = FS.lookupPath(path);
   node = lookup.node;
   stat = FS.stat(path);
  } catch (e) {
   return callback(e);
  }
  if (FS.isDir(stat.mode)) {
   return callback(null, {
    timestamp: stat.mtime,
    mode: stat.mode
   });
  } else if (FS.isFile(stat.mode)) {
   node.contents = MEMFS.getFileDataAsTypedArray(node);
   return callback(null, {
    timestamp: stat.mtime,
    mode: stat.mode,
    contents: node.contents
   });
  } else {
   return callback(new Error("node type not supported"));
  }
 }),
 storeLocalEntry: (function(path, entry, callback) {
  try {
   if (FS.isDir(entry.mode)) {
    FS.mkdir(path, entry.mode);
   } else if (FS.isFile(entry.mode)) {
    FS.writeFile(path, entry.contents, {
     encoding: "binary",
     canOwn: true
    });
   } else {
    return callback(new Error("node type not supported"));
   }
   FS.chmod(path, entry.mode);
   FS.utime(path, entry.timestamp, entry.timestamp);
  } catch (e) {
   return callback(e);
  }
  callback(null);
 }),
 removeLocalEntry: (function(path, callback) {
  try {
   var lookup = FS.lookupPath(path);
   var stat = FS.stat(path);
   if (FS.isDir(stat.mode)) {
    FS.rmdir(path);
   } else if (FS.isFile(stat.mode)) {
    FS.unlink(path);
   }
  } catch (e) {
   return callback(e);
  }
  callback(null);
 }),
 loadRemoteEntry: (function(store, path, callback) {
  var req = store.get(path);
  req.onsuccess = (function(event) {
   callback(null, event.target.result);
  });
  req.onerror = (function(e) {
   callback(this.error);
   e.preventDefault();
  });
 }),
 storeRemoteEntry: (function(store, path, entry, callback) {
  var req = store.put(entry, path);
  req.onsuccess = (function() {
   callback(null);
  });
  req.onerror = (function(e) {
   callback(this.error);
   e.preventDefault();
  });
 }),
 removeRemoteEntry: (function(store, path, callback) {
  var req = store.delete(path);
  req.onsuccess = (function() {
   callback(null);
  });
  req.onerror = (function(e) {
   callback(this.error);
   e.preventDefault();
  });
 }),
 reconcile: (function(src, dst, callback) {
  var total = 0;
  var create = [];
  Object.keys(src.entries).forEach((function(key) {
   var e = src.entries[key];
   var e2 = dst.entries[key];
   if (!e2 || e.timestamp > e2.timestamp) {
    create.push(key);
    total++;
   }
  }));
  var remove = [];
  Object.keys(dst.entries).forEach((function(key) {
   var e = dst.entries[key];
   var e2 = src.entries[key];
   if (!e2) {
    remove.push(key);
    total++;
   }
  }));
  if (!total) {
   return callback(null);
  }
  var completed = 0;
  var db = src.type === "remote" ? src.db : dst.db;
  var transaction = db.transaction([ IDBFS.DB_STORE_NAME ], "readwrite");
  var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  function done(err) {
   if (err) {
    if (!done.errored) {
     done.errored = true;
     return callback(err);
    }
    return;
   }
   if (++completed >= total) {
    return callback(null);
   }
  }
  transaction.onerror = (function(e) {
   done(this.error);
   e.preventDefault();
  });
  create.sort().forEach((function(path) {
   if (dst.type === "local") {
    IDBFS.loadRemoteEntry(store, path, (function(err, entry) {
     if (err) return done(err);
     IDBFS.storeLocalEntry(path, entry, done);
    }));
   } else {
    IDBFS.loadLocalEntry(path, (function(err, entry) {
     if (err) return done(err);
     IDBFS.storeRemoteEntry(store, path, entry, done);
    }));
   }
  }));
  remove.sort().reverse().forEach((function(path) {
   if (dst.type === "local") {
    IDBFS.removeLocalEntry(path, done);
   } else {
    IDBFS.removeRemoteEntry(store, path, done);
   }
  }));
 })
};
var NODEFS = {
 isWindows: false,
 staticInit: (function() {
  NODEFS.isWindows = !!process.platform.match(/^win/);
 }),
 mount: (function(mount) {
  assert(ENVIRONMENT_IS_NODE);
  return NODEFS.createNode(null, "/", NODEFS.getMode(mount.opts.root), 0);
 }),
 createNode: (function(parent, name, mode, dev) {
  if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  var node = FS.createNode(parent, name, mode);
  node.node_ops = NODEFS.node_ops;
  node.stream_ops = NODEFS.stream_ops;
  return node;
 }),
 getMode: (function(path) {
  var stat;
  try {
   stat = fs.lstatSync(path);
   if (NODEFS.isWindows) {
    stat.mode = stat.mode | (stat.mode & 146) >> 1;
   }
  } catch (e) {
   if (!e.code) throw e;
   throw new FS.ErrnoError(ERRNO_CODES[e.code]);
  }
  return stat.mode;
 }),
 realPath: (function(node) {
  var parts = [];
  while (node.parent !== node) {
   parts.push(node.name);
   node = node.parent;
  }
  parts.push(node.mount.opts.root);
  parts.reverse();
  return PATH.join.apply(null, parts);
 }),
 flagsToPermissionStringMap: {
  0: "r",
  1: "r+",
  2: "r+",
  64: "r",
  65: "r+",
  66: "r+",
  129: "rx+",
  193: "rx+",
  514: "w+",
  577: "w",
  578: "w+",
  705: "wx",
  706: "wx+",
  1024: "a",
  1025: "a",
  1026: "a+",
  1089: "a",
  1090: "a+",
  1153: "ax",
  1154: "ax+",
  1217: "ax",
  1218: "ax+",
  4096: "rs",
  4098: "rs+"
 },
 flagsToPermissionString: (function(flags) {
  flags &= ~32768;
  flags &= ~524288;
  if (flags in NODEFS.flagsToPermissionStringMap) {
   return NODEFS.flagsToPermissionStringMap[flags];
  } else {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
 }),
 node_ops: {
  getattr: (function(node) {
   var path = NODEFS.realPath(node);
   var stat;
   try {
    stat = fs.lstatSync(path);
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
   if (NODEFS.isWindows && !stat.blksize) {
    stat.blksize = 4096;
   }
   if (NODEFS.isWindows && !stat.blocks) {
    stat.blocks = (stat.size + stat.blksize - 1) / stat.blksize | 0;
   }
   return {
    dev: stat.dev,
    ino: stat.ino,
    mode: stat.mode,
    nlink: stat.nlink,
    uid: stat.uid,
    gid: stat.gid,
    rdev: stat.rdev,
    size: stat.size,
    atime: stat.atime,
    mtime: stat.mtime,
    ctime: stat.ctime,
    blksize: stat.blksize,
    blocks: stat.blocks
   };
  }),
  setattr: (function(node, attr) {
   var path = NODEFS.realPath(node);
   try {
    if (attr.mode !== undefined) {
     fs.chmodSync(path, attr.mode);
     node.mode = attr.mode;
    }
    if (attr.timestamp !== undefined) {
     var date = new Date(attr.timestamp);
     fs.utimesSync(path, date, date);
    }
    if (attr.size !== undefined) {
     fs.truncateSync(path, attr.size);
    }
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
  }),
  lookup: (function(parent, name) {
   var path = PATH.join2(NODEFS.realPath(parent), name);
   var mode = NODEFS.getMode(path);
   return NODEFS.createNode(parent, name, mode);
  }),
  mknod: (function(parent, name, mode, dev) {
   var node = NODEFS.createNode(parent, name, mode, dev);
   var path = NODEFS.realPath(node);
   try {
    if (FS.isDir(node.mode)) {
     fs.mkdirSync(path, node.mode);
    } else {
     fs.writeFileSync(path, "", {
      mode: node.mode
     });
    }
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
   return node;
  }),
  rename: (function(oldNode, newDir, newName) {
   var oldPath = NODEFS.realPath(oldNode);
   var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
   try {
    fs.renameSync(oldPath, newPath);
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
  }),
  unlink: (function(parent, name) {
   var path = PATH.join2(NODEFS.realPath(parent), name);
   try {
    fs.unlinkSync(path);
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
  }),
  rmdir: (function(parent, name) {
   var path = PATH.join2(NODEFS.realPath(parent), name);
   try {
    fs.rmdirSync(path);
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
  }),
  readdir: (function(node) {
   var path = NODEFS.realPath(node);
   try {
    return fs.readdirSync(path);
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
  }),
  symlink: (function(parent, newName, oldPath) {
   var newPath = PATH.join2(NODEFS.realPath(parent), newName);
   try {
    fs.symlinkSync(oldPath, newPath);
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
  }),
  readlink: (function(node) {
   var path = NODEFS.realPath(node);
   try {
    path = fs.readlinkSync(path);
    path = NODEJS_PATH.relative(NODEJS_PATH.resolve(node.mount.opts.root), path);
    return path;
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
  })
 },
 stream_ops: {
  open: (function(stream) {
   var path = NODEFS.realPath(stream.node);
   try {
    if (FS.isFile(stream.node.mode)) {
     stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
    }
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
  }),
  close: (function(stream) {
   try {
    if (FS.isFile(stream.node.mode) && stream.nfd) {
     fs.closeSync(stream.nfd);
    }
   } catch (e) {
    if (!e.code) throw e;
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
  }),
  read: (function(stream, buffer, offset, length, position) {
   if (length === 0) return 0;
   var nbuffer = new Buffer(length);
   var res;
   try {
    res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
   } catch (e) {
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
   if (res > 0) {
    for (var i = 0; i < res; i++) {
     buffer[offset + i] = nbuffer[i];
    }
   }
   return res;
  }),
  write: (function(stream, buffer, offset, length, position) {
   var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
   var res;
   try {
    res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
   } catch (e) {
    throw new FS.ErrnoError(ERRNO_CODES[e.code]);
   }
   return res;
  }),
  llseek: (function(stream, offset, whence) {
   var position = offset;
   if (whence === 1) {
    position += stream.position;
   } else if (whence === 2) {
    if (FS.isFile(stream.node.mode)) {
     try {
      var stat = fs.fstatSync(stream.nfd);
      position += stat.size;
     } catch (e) {
      throw new FS.ErrnoError(ERRNO_CODES[e.code]);
     }
    }
   }
   if (position < 0) {
    throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
   }
   return position;
  })
 }
};
var WORKERFS = {
 DIR_MODE: 16895,
 FILE_MODE: 33279,
 reader: null,
 mount: (function(mount) {
  assert(ENVIRONMENT_IS_WORKER);
  if (!WORKERFS.reader) WORKERFS.reader = new FileReaderSync;
  var root = WORKERFS.createNode(null, "/", WORKERFS.DIR_MODE, 0);
  var createdParents = {};
  function ensureParent(path) {
   var parts = path.split("/");
   var parent = root;
   for (var i = 0; i < parts.length - 1; i++) {
    var curr = parts.slice(0, i + 1).join("/");
    if (!createdParents[curr]) {
     createdParents[curr] = WORKERFS.createNode(parent, parts[i], WORKERFS.DIR_MODE, 0);
    }
    parent = createdParents[curr];
   }
   return parent;
  }
  function base(path) {
   var parts = path.split("/");
   return parts[parts.length - 1];
  }
  Array.prototype.forEach.call(mount.opts["files"] || [], (function(file) {
   WORKERFS.createNode(ensureParent(file.name), base(file.name), WORKERFS.FILE_MODE, 0, file, file.lastModifiedDate);
  }));
  (mount.opts["blobs"] || []).forEach((function(obj) {
   WORKERFS.createNode(ensureParent(obj["name"]), base(obj["name"]), WORKERFS.FILE_MODE, 0, obj["data"]);
  }));
  (mount.opts["packages"] || []).forEach((function(pack) {
   pack["metadata"].files.forEach((function(file) {
    var name = file.filename.substr(1);
    WORKERFS.createNode(ensureParent(name), base(name), WORKERFS.FILE_MODE, 0, pack["blob"].slice(file.start, file.end));
   }));
  }));
  return root;
 }),
 createNode: (function(parent, name, mode, dev, contents, mtime) {
  var node = FS.createNode(parent, name, mode);
  node.mode = mode;
  node.node_ops = WORKERFS.node_ops;
  node.stream_ops = WORKERFS.stream_ops;
  node.timestamp = (mtime || new Date).getTime();
  assert(WORKERFS.FILE_MODE !== WORKERFS.DIR_MODE);
  if (mode === WORKERFS.FILE_MODE) {
   node.size = contents.size;
   node.contents = contents;
  } else {
   node.size = 4096;
   node.contents = {};
  }
  if (parent) {
   parent.contents[name] = node;
  }
  return node;
 }),
 node_ops: {
  getattr: (function(node) {
   return {
    dev: 1,
    ino: undefined,
    mode: node.mode,
    nlink: 1,
    uid: 0,
    gid: 0,
    rdev: undefined,
    size: node.size,
    atime: new Date(node.timestamp),
    mtime: new Date(node.timestamp),
    ctime: new Date(node.timestamp),
    blksize: 4096,
    blocks: Math.ceil(node.size / 4096)
   };
  }),
  setattr: (function(node, attr) {
   if (attr.mode !== undefined) {
    node.mode = attr.mode;
   }
   if (attr.timestamp !== undefined) {
    node.timestamp = attr.timestamp;
   }
  }),
  lookup: (function(parent, name) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
  }),
  mknod: (function(parent, name, mode, dev) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }),
  rename: (function(oldNode, newDir, newName) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }),
  unlink: (function(parent, name) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }),
  rmdir: (function(parent, name) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }),
  readdir: (function(node) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }),
  symlink: (function(parent, newName, oldPath) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }),
  readlink: (function(node) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  })
 },
 stream_ops: {
  read: (function(stream, buffer, offset, length, position) {
   if (position >= stream.node.size) return 0;
   var chunk = stream.node.contents.slice(position, position + length);
   var ab = WORKERFS.reader.readAsArrayBuffer(chunk);
   buffer.set(new Uint8Array(ab), offset);
   return chunk.size;
  }),
  write: (function(stream, buffer, offset, length, position) {
   throw new FS.ErrnoError(ERRNO_CODES.EIO);
  }),
  llseek: (function(stream, offset, whence) {
   var position = offset;
   if (whence === 1) {
    position += stream.position;
   } else if (whence === 2) {
    if (FS.isFile(stream.node.mode)) {
     position += stream.node.size;
    }
   }
   if (position < 0) {
    throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
   }
   return position;
  })
 }
};
STATICTOP += 16;
STATICTOP += 16;
STATICTOP += 16;
var FS = {
 root: null,
 mounts: [],
 devices: [ null ],
 streams: [],
 nextInode: 1,
 nameTable: null,
 currentPath: "/",
 initialized: false,
 ignorePermissions: true,
 trackingDelegate: {},
 tracking: {
  openFlags: {
   READ: 1,
   WRITE: 2
  }
 },
 ErrnoError: null,
 genericErrors: {},
 filesystems: null,
 syncFSRequests: 0,
 handleFSError: (function(e) {
  if (!(e instanceof FS.ErrnoError)) throw e + " : " + stackTrace();
  return ___setErrNo(e.errno);
 }),
 lookupPath: (function(path, opts) {
  path = PATH.resolve(FS.cwd(), path);
  opts = opts || {};
  if (!path) return {
   path: "",
   node: null
  };
  var defaults = {
   follow_mount: true,
   recurse_count: 0
  };
  for (var key in defaults) {
   if (opts[key] === undefined) {
    opts[key] = defaults[key];
   }
  }
  if (opts.recurse_count > 8) {
   throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
  }
  var parts = PATH.normalizeArray(path.split("/").filter((function(p) {
   return !!p;
  })), false);
  var current = FS.root;
  var current_path = "/";
  for (var i = 0; i < parts.length; i++) {
   var islast = i === parts.length - 1;
   if (islast && opts.parent) {
    break;
   }
   current = FS.lookupNode(current, parts[i]);
   current_path = PATH.join2(current_path, parts[i]);
   if (FS.isMountpoint(current)) {
    if (!islast || islast && opts.follow_mount) {
     current = current.mounted.root;
    }
   }
   if (!islast || opts.follow) {
    var count = 0;
    while (FS.isLink(current.mode)) {
     var link = FS.readlink(current_path);
     current_path = PATH.resolve(PATH.dirname(current_path), link);
     var lookup = FS.lookupPath(current_path, {
      recurse_count: opts.recurse_count
     });
     current = lookup.node;
     if (count++ > 40) {
      throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
     }
    }
   }
  }
  return {
   path: current_path,
   node: current
  };
 }),
 getPath: (function(node) {
  var path;
  while (true) {
   if (FS.isRoot(node)) {
    var mount = node.mount.mountpoint;
    if (!path) return mount;
    return mount[mount.length - 1] !== "/" ? mount + "/" + path : mount + path;
   }
   path = path ? node.name + "/" + path : node.name;
   node = node.parent;
  }
 }),
 hashName: (function(parentid, name) {
  var hash = 0;
  for (var i = 0; i < name.length; i++) {
   hash = (hash << 5) - hash + name.charCodeAt(i) | 0;
  }
  return (parentid + hash >>> 0) % FS.nameTable.length;
 }),
 hashAddNode: (function(node) {
  var hash = FS.hashName(node.parent.id, node.name);
  node.name_next = FS.nameTable[hash];
  FS.nameTable[hash] = node;
 }),
 hashRemoveNode: (function(node) {
  var hash = FS.hashName(node.parent.id, node.name);
  if (FS.nameTable[hash] === node) {
   FS.nameTable[hash] = node.name_next;
  } else {
   var current = FS.nameTable[hash];
   while (current) {
    if (current.name_next === node) {
     current.name_next = node.name_next;
     break;
    }
    current = current.name_next;
   }
  }
 }),
 lookupNode: (function(parent, name) {
  var err = FS.mayLookup(parent);
  if (err) {
   throw new FS.ErrnoError(err, parent);
  }
  var hash = FS.hashName(parent.id, name);
  for (var node = FS.nameTable[hash]; node; node = node.name_next) {
   var nodeName = node.name;
   if (node.parent.id === parent.id && nodeName === name) {
    return node;
   }
  }
  return FS.lookup(parent, name);
 }),
 createNode: (function(parent, name, mode, rdev) {
  if (!FS.FSNode) {
   FS.FSNode = (function(parent, name, mode, rdev) {
    if (!parent) {
     parent = this;
    }
    this.parent = parent;
    this.mount = parent.mount;
    this.mounted = null;
    this.id = FS.nextInode++;
    this.name = name;
    this.mode = mode;
    this.node_ops = {};
    this.stream_ops = {};
    this.rdev = rdev;
   });
   FS.FSNode.prototype = {};
   var readMode = 292 | 73;
   var writeMode = 146;
   Object.defineProperties(FS.FSNode.prototype, {
    read: {
     get: (function() {
      return (this.mode & readMode) === readMode;
     }),
     set: (function(val) {
      val ? this.mode |= readMode : this.mode &= ~readMode;
     })
    },
    write: {
     get: (function() {
      return (this.mode & writeMode) === writeMode;
     }),
     set: (function(val) {
      val ? this.mode |= writeMode : this.mode &= ~writeMode;
     })
    },
    isFolder: {
     get: (function() {
      return FS.isDir(this.mode);
     })
    },
    isDevice: {
     get: (function() {
      return FS.isChrdev(this.mode);
     })
    }
   });
  }
  var node = new FS.FSNode(parent, name, mode, rdev);
  FS.hashAddNode(node);
  return node;
 }),
 destroyNode: (function(node) {
  FS.hashRemoveNode(node);
 }),
 isRoot: (function(node) {
  return node === node.parent;
 }),
 isMountpoint: (function(node) {
  return !!node.mounted;
 }),
 isFile: (function(mode) {
  return (mode & 61440) === 32768;
 }),
 isDir: (function(mode) {
  return (mode & 61440) === 16384;
 }),
 isLink: (function(mode) {
  return (mode & 61440) === 40960;
 }),
 isChrdev: (function(mode) {
  return (mode & 61440) === 8192;
 }),
 isBlkdev: (function(mode) {
  return (mode & 61440) === 24576;
 }),
 isFIFO: (function(mode) {
  return (mode & 61440) === 4096;
 }),
 isSocket: (function(mode) {
  return (mode & 49152) === 49152;
 }),
 flagModes: {
  "r": 0,
  "rs": 1052672,
  "r+": 2,
  "w": 577,
  "wx": 705,
  "xw": 705,
  "w+": 578,
  "wx+": 706,
  "xw+": 706,
  "a": 1089,
  "ax": 1217,
  "xa": 1217,
  "a+": 1090,
  "ax+": 1218,
  "xa+": 1218
 },
 modeStringToFlags: (function(str) {
  var flags = FS.flagModes[str];
  if (typeof flags === "undefined") {
   throw new Error("Unknown file open mode: " + str);
  }
  return flags;
 }),
 flagsToPermissionString: (function(flag) {
  var perms = [ "r", "w", "rw" ][flag & 3];
  if (flag & 512) {
   perms += "w";
  }
  return perms;
 }),
 nodePermissions: (function(node, perms) {
  if (FS.ignorePermissions) {
   return 0;
  }
  if (perms.indexOf("r") !== -1 && !(node.mode & 292)) {
   return ERRNO_CODES.EACCES;
  } else if (perms.indexOf("w") !== -1 && !(node.mode & 146)) {
   return ERRNO_CODES.EACCES;
  } else if (perms.indexOf("x") !== -1 && !(node.mode & 73)) {
   return ERRNO_CODES.EACCES;
  }
  return 0;
 }),
 mayLookup: (function(dir) {
  var err = FS.nodePermissions(dir, "x");
  if (err) return err;
  if (!dir.node_ops.lookup) return ERRNO_CODES.EACCES;
  return 0;
 }),
 mayCreate: (function(dir, name) {
  try {
   var node = FS.lookupNode(dir, name);
   return ERRNO_CODES.EEXIST;
  } catch (e) {}
  return FS.nodePermissions(dir, "wx");
 }),
 mayDelete: (function(dir, name, isdir) {
  var node;
  try {
   node = FS.lookupNode(dir, name);
  } catch (e) {
   return e.errno;
  }
  var err = FS.nodePermissions(dir, "wx");
  if (err) {
   return err;
  }
  if (isdir) {
   if (!FS.isDir(node.mode)) {
    return ERRNO_CODES.ENOTDIR;
   }
   if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
    return ERRNO_CODES.EBUSY;
   }
  } else {
   if (FS.isDir(node.mode)) {
    return ERRNO_CODES.EISDIR;
   }
  }
  return 0;
 }),
 mayOpen: (function(node, flags) {
  if (!node) {
   return ERRNO_CODES.ENOENT;
  }
  if (FS.isLink(node.mode)) {
   return ERRNO_CODES.ELOOP;
  } else if (FS.isDir(node.mode)) {
   if (FS.flagsToPermissionString(flags) !== "r" || flags & 512) {
    return ERRNO_CODES.EISDIR;
   }
  }
  return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
 }),
 MAX_OPEN_FDS: 4096,
 nextfd: (function(fd_start, fd_end) {
  fd_start = fd_start || 0;
  fd_end = fd_end || FS.MAX_OPEN_FDS;
  for (var fd = fd_start; fd <= fd_end; fd++) {
   if (!FS.streams[fd]) {
    return fd;
   }
  }
  throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
 }),
 getStream: (function(fd) {
  return FS.streams[fd];
 }),
 createStream: (function(stream, fd_start, fd_end) {
  if (!FS.FSStream) {
   FS.FSStream = (function() {});
   FS.FSStream.prototype = {};
   Object.defineProperties(FS.FSStream.prototype, {
    object: {
     get: (function() {
      return this.node;
     }),
     set: (function(val) {
      this.node = val;
     })
    },
    isRead: {
     get: (function() {
      return (this.flags & 2097155) !== 1;
     })
    },
    isWrite: {
     get: (function() {
      return (this.flags & 2097155) !== 0;
     })
    },
    isAppend: {
     get: (function() {
      return this.flags & 1024;
     })
    }
   });
  }
  var newStream = new FS.FSStream;
  for (var p in stream) {
   newStream[p] = stream[p];
  }
  stream = newStream;
  var fd = FS.nextfd(fd_start, fd_end);
  stream.fd = fd;
  FS.streams[fd] = stream;
  return stream;
 }),
 closeStream: (function(fd) {
  FS.streams[fd] = null;
 }),
 chrdev_stream_ops: {
  open: (function(stream) {
   var device = FS.getDevice(stream.node.rdev);
   stream.stream_ops = device.stream_ops;
   if (stream.stream_ops.open) {
    stream.stream_ops.open(stream);
   }
  }),
  llseek: (function() {
   throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
  })
 },
 major: (function(dev) {
  return dev >> 8;
 }),
 minor: (function(dev) {
  return dev & 255;
 }),
 makedev: (function(ma, mi) {
  return ma << 8 | mi;
 }),
 registerDevice: (function(dev, ops) {
  FS.devices[dev] = {
   stream_ops: ops
  };
 }),
 getDevice: (function(dev) {
  return FS.devices[dev];
 }),
 getMounts: (function(mount) {
  var mounts = [];
  var check = [ mount ];
  while (check.length) {
   var m = check.pop();
   mounts.push(m);
   check.push.apply(check, m.mounts);
  }
  return mounts;
 }),
 syncfs: (function(populate, callback) {
  if (typeof populate === "function") {
   callback = populate;
   populate = false;
  }
  FS.syncFSRequests++;
  if (FS.syncFSRequests > 1) {
   console.log("warning: " + FS.syncFSRequests + " FS.syncfs operations in flight at once, probably just doing extra work");
  }
  var mounts = FS.getMounts(FS.root.mount);
  var completed = 0;
  function doCallback(err) {
   assert(FS.syncFSRequests > 0);
   FS.syncFSRequests--;
   return callback(err);
  }
  function done(err) {
   if (err) {
    if (!done.errored) {
     done.errored = true;
     return doCallback(err);
    }
    return;
   }
   if (++completed >= mounts.length) {
    doCallback(null);
   }
  }
  mounts.forEach((function(mount) {
   if (!mount.type.syncfs) {
    return done(null);
   }
   mount.type.syncfs(mount, populate, done);
  }));
 }),
 mount: (function(type, opts, mountpoint) {
  var root = mountpoint === "/";
  var pseudo = !mountpoint;
  var node;
  if (root && FS.root) {
   throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
  } else if (!root && !pseudo) {
   var lookup = FS.lookupPath(mountpoint, {
    follow_mount: false
   });
   mountpoint = lookup.path;
   node = lookup.node;
   if (FS.isMountpoint(node)) {
    throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
   }
   if (!FS.isDir(node.mode)) {
    throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
   }
  }
  var mount = {
   type: type,
   opts: opts,
   mountpoint: mountpoint,
   mounts: []
  };
  var mountRoot = type.mount(mount);
  mountRoot.mount = mount;
  mount.root = mountRoot;
  if (root) {
   FS.root = mountRoot;
  } else if (node) {
   node.mounted = mount;
   if (node.mount) {
    node.mount.mounts.push(mount);
   }
  }
  return mountRoot;
 }),
 unmount: (function(mountpoint) {
  var lookup = FS.lookupPath(mountpoint, {
   follow_mount: false
  });
  if (!FS.isMountpoint(lookup.node)) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  var node = lookup.node;
  var mount = node.mounted;
  var mounts = FS.getMounts(mount);
  Object.keys(FS.nameTable).forEach((function(hash) {
   var current = FS.nameTable[hash];
   while (current) {
    var next = current.name_next;
    if (mounts.indexOf(current.mount) !== -1) {
     FS.destroyNode(current);
    }
    current = next;
   }
  }));
  node.mounted = null;
  var idx = node.mount.mounts.indexOf(mount);
  assert(idx !== -1);
  node.mount.mounts.splice(idx, 1);
 }),
 lookup: (function(parent, name) {
  return parent.node_ops.lookup(parent, name);
 }),
 mknod: (function(path, mode, dev) {
  var lookup = FS.lookupPath(path, {
   parent: true
  });
  var parent = lookup.node;
  var name = PATH.basename(path);
  if (!name || name === "." || name === "..") {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  var err = FS.mayCreate(parent, name);
  if (err) {
   throw new FS.ErrnoError(err);
  }
  if (!parent.node_ops.mknod) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  return parent.node_ops.mknod(parent, name, mode, dev);
 }),
 create: (function(path, mode) {
  mode = mode !== undefined ? mode : 438;
  mode &= 4095;
  mode |= 32768;
  return FS.mknod(path, mode, 0);
 }),
 mkdir: (function(path, mode) {
  mode = mode !== undefined ? mode : 511;
  mode &= 511 | 512;
  mode |= 16384;
  return FS.mknod(path, mode, 0);
 }),
 mkdev: (function(path, mode, dev) {
  if (typeof dev === "undefined") {
   dev = mode;
   mode = 438;
  }
  mode |= 8192;
  return FS.mknod(path, mode, dev);
 }),
 symlink: (function(oldpath, newpath) {
  if (!PATH.resolve(oldpath)) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
  }
  var lookup = FS.lookupPath(newpath, {
   parent: true
  });
  var parent = lookup.node;
  if (!parent) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
  }
  var newname = PATH.basename(newpath);
  var err = FS.mayCreate(parent, newname);
  if (err) {
   throw new FS.ErrnoError(err);
  }
  if (!parent.node_ops.symlink) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  return parent.node_ops.symlink(parent, newname, oldpath);
 }),
 rename: (function(old_path, new_path) {
  var old_dirname = PATH.dirname(old_path);
  var new_dirname = PATH.dirname(new_path);
  var old_name = PATH.basename(old_path);
  var new_name = PATH.basename(new_path);
  var lookup, old_dir, new_dir;
  try {
   lookup = FS.lookupPath(old_path, {
    parent: true
   });
   old_dir = lookup.node;
   lookup = FS.lookupPath(new_path, {
    parent: true
   });
   new_dir = lookup.node;
  } catch (e) {
   throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
  }
  if (!old_dir || !new_dir) throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
  if (old_dir.mount !== new_dir.mount) {
   throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
  }
  var old_node = FS.lookupNode(old_dir, old_name);
  var relative = PATH.relative(old_path, new_dirname);
  if (relative.charAt(0) !== ".") {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  relative = PATH.relative(new_path, old_dirname);
  if (relative.charAt(0) !== ".") {
   throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
  }
  var new_node;
  try {
   new_node = FS.lookupNode(new_dir, new_name);
  } catch (e) {}
  if (old_node === new_node) {
   return;
  }
  var isdir = FS.isDir(old_node.mode);
  var err = FS.mayDelete(old_dir, old_name, isdir);
  if (err) {
   throw new FS.ErrnoError(err);
  }
  err = new_node ? FS.mayDelete(new_dir, new_name, isdir) : FS.mayCreate(new_dir, new_name);
  if (err) {
   throw new FS.ErrnoError(err);
  }
  if (!old_dir.node_ops.rename) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  if (FS.isMountpoint(old_node) || new_node && FS.isMountpoint(new_node)) {
   throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
  }
  if (new_dir !== old_dir) {
   err = FS.nodePermissions(old_dir, "w");
   if (err) {
    throw new FS.ErrnoError(err);
   }
  }
  try {
   if (FS.trackingDelegate["willMovePath"]) {
    FS.trackingDelegate["willMovePath"](old_path, new_path);
   }
  } catch (e) {
   console.log("FS.trackingDelegate['willMovePath']('" + old_path + "', '" + new_path + "') threw an exception: " + e.message);
  }
  FS.hashRemoveNode(old_node);
  try {
   old_dir.node_ops.rename(old_node, new_dir, new_name);
  } catch (e) {
   throw e;
  } finally {
   FS.hashAddNode(old_node);
  }
  try {
   if (FS.trackingDelegate["onMovePath"]) FS.trackingDelegate["onMovePath"](old_path, new_path);
  } catch (e) {
   console.log("FS.trackingDelegate['onMovePath']('" + old_path + "', '" + new_path + "') threw an exception: " + e.message);
  }
 }),
 rmdir: (function(path) {
  var lookup = FS.lookupPath(path, {
   parent: true
  });
  var parent = lookup.node;
  var name = PATH.basename(path);
  var node = FS.lookupNode(parent, name);
  var err = FS.mayDelete(parent, name, true);
  if (err) {
   throw new FS.ErrnoError(err);
  }
  if (!parent.node_ops.rmdir) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  if (FS.isMountpoint(node)) {
   throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
  }
  try {
   if (FS.trackingDelegate["willDeletePath"]) {
    FS.trackingDelegate["willDeletePath"](path);
   }
  } catch (e) {
   console.log("FS.trackingDelegate['willDeletePath']('" + path + "') threw an exception: " + e.message);
  }
  parent.node_ops.rmdir(parent, name);
  FS.destroyNode(node);
  try {
   if (FS.trackingDelegate["onDeletePath"]) FS.trackingDelegate["onDeletePath"](path);
  } catch (e) {
   console.log("FS.trackingDelegate['onDeletePath']('" + path + "') threw an exception: " + e.message);
  }
 }),
 readdir: (function(path) {
  var lookup = FS.lookupPath(path, {
   follow: true
  });
  var node = lookup.node;
  if (!node.node_ops.readdir) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
  }
  return node.node_ops.readdir(node);
 }),
 unlink: (function(path) {
  var lookup = FS.lookupPath(path, {
   parent: true
  });
  var parent = lookup.node;
  var name = PATH.basename(path);
  var node = FS.lookupNode(parent, name);
  var err = FS.mayDelete(parent, name, false);
  if (err) {
   if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
   throw new FS.ErrnoError(err);
  }
  if (!parent.node_ops.unlink) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  if (FS.isMountpoint(node)) {
   throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
  }
  try {
   if (FS.trackingDelegate["willDeletePath"]) {
    FS.trackingDelegate["willDeletePath"](path);
   }
  } catch (e) {
   console.log("FS.trackingDelegate['willDeletePath']('" + path + "') threw an exception: " + e.message);
  }
  parent.node_ops.unlink(parent, name);
  FS.destroyNode(node);
  try {
   if (FS.trackingDelegate["onDeletePath"]) FS.trackingDelegate["onDeletePath"](path);
  } catch (e) {
   console.log("FS.trackingDelegate['onDeletePath']('" + path + "') threw an exception: " + e.message);
  }
 }),
 readlink: (function(path) {
  var lookup = FS.lookupPath(path);
  var link = lookup.node;
  if (!link) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
  }
  if (!link.node_ops.readlink) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  return PATH.resolve(FS.getPath(link.parent), link.node_ops.readlink(link));
 }),
 stat: (function(path, dontFollow) {
  var lookup = FS.lookupPath(path, {
   follow: !dontFollow
  });
  var node = lookup.node;
  if (!node) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
  }
  if (!node.node_ops.getattr) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  return node.node_ops.getattr(node);
 }),
 lstat: (function(path) {
  return FS.stat(path, true);
 }),
 chmod: (function(path, mode, dontFollow) {
  var node;
  if (typeof path === "string") {
   var lookup = FS.lookupPath(path, {
    follow: !dontFollow
   });
   node = lookup.node;
  } else {
   node = path;
  }
  if (!node.node_ops.setattr) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  node.node_ops.setattr(node, {
   mode: mode & 4095 | node.mode & ~4095,
   timestamp: Date.now()
  });
 }),
 lchmod: (function(path, mode) {
  FS.chmod(path, mode, true);
 }),
 fchmod: (function(fd, mode) {
  var stream = FS.getStream(fd);
  if (!stream) {
   throw new FS.ErrnoError(ERRNO_CODES.EBADF);
  }
  FS.chmod(stream.node, mode);
 }),
 chown: (function(path, uid, gid, dontFollow) {
  var node;
  if (typeof path === "string") {
   var lookup = FS.lookupPath(path, {
    follow: !dontFollow
   });
   node = lookup.node;
  } else {
   node = path;
  }
  if (!node.node_ops.setattr) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  node.node_ops.setattr(node, {
   timestamp: Date.now()
  });
 }),
 lchown: (function(path, uid, gid) {
  FS.chown(path, uid, gid, true);
 }),
 fchown: (function(fd, uid, gid) {
  var stream = FS.getStream(fd);
  if (!stream) {
   throw new FS.ErrnoError(ERRNO_CODES.EBADF);
  }
  FS.chown(stream.node, uid, gid);
 }),
 truncate: (function(path, len) {
  if (len < 0) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  var node;
  if (typeof path === "string") {
   var lookup = FS.lookupPath(path, {
    follow: true
   });
   node = lookup.node;
  } else {
   node = path;
  }
  if (!node.node_ops.setattr) {
   throw new FS.ErrnoError(ERRNO_CODES.EPERM);
  }
  if (FS.isDir(node.mode)) {
   throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
  }
  if (!FS.isFile(node.mode)) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  var err = FS.nodePermissions(node, "w");
  if (err) {
   throw new FS.ErrnoError(err);
  }
  node.node_ops.setattr(node, {
   size: len,
   timestamp: Date.now()
  });
 }),
 ftruncate: (function(fd, len) {
  var stream = FS.getStream(fd);
  if (!stream) {
   throw new FS.ErrnoError(ERRNO_CODES.EBADF);
  }
  if ((stream.flags & 2097155) === 0) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  FS.truncate(stream.node, len);
 }),
 utime: (function(path, atime, mtime) {
  var lookup = FS.lookupPath(path, {
   follow: true
  });
  var node = lookup.node;
  node.node_ops.setattr(node, {
   timestamp: Math.max(atime, mtime)
  });
 }),
 open: (function(path, flags, mode, fd_start, fd_end) {
  if (path === "") {
   throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
  }
  flags = typeof flags === "string" ? FS.modeStringToFlags(flags) : flags;
  mode = typeof mode === "undefined" ? 438 : mode;
  if (flags & 64) {
   mode = mode & 4095 | 32768;
  } else {
   mode = 0;
  }
  var node;
  if (typeof path === "object") {
   node = path;
  } else {
   path = PATH.normalize(path);
   try {
    var lookup = FS.lookupPath(path, {
     follow: !(flags & 131072)
    });
    node = lookup.node;
   } catch (e) {}
  }
  var created = false;
  if (flags & 64) {
   if (node) {
    if (flags & 128) {
     throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
    }
   } else {
    node = FS.mknod(path, mode, 0);
    created = true;
   }
  }
  if (!node) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
  }
  if (FS.isChrdev(node.mode)) {
   flags &= ~512;
  }
  if (flags & 65536 && !FS.isDir(node.mode)) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
  }
  if (!created) {
   var err = FS.mayOpen(node, flags);
   if (err) {
    throw new FS.ErrnoError(err);
   }
  }
  if (flags & 512) {
   FS.truncate(node, 0);
  }
  flags &= ~(128 | 512);
  var stream = FS.createStream({
   node: node,
   path: FS.getPath(node),
   flags: flags,
   seekable: true,
   position: 0,
   stream_ops: node.stream_ops,
   ungotten: [],
   error: false
  }, fd_start, fd_end);
  if (stream.stream_ops.open) {
   stream.stream_ops.open(stream);
  }
  if (Module["logReadFiles"] && !(flags & 1)) {
   if (!FS.readFiles) FS.readFiles = {};
   if (!(path in FS.readFiles)) {
    FS.readFiles[path] = 1;
    Module["printErr"]("read file: " + path);
   }
  }
  try {
   if (FS.trackingDelegate["onOpenFile"]) {
    var trackingFlags = 0;
    if ((flags & 2097155) !== 1) {
     trackingFlags |= FS.tracking.openFlags.READ;
    }
    if ((flags & 2097155) !== 0) {
     trackingFlags |= FS.tracking.openFlags.WRITE;
    }
    FS.trackingDelegate["onOpenFile"](path, trackingFlags);
   }
  } catch (e) {
   console.log("FS.trackingDelegate['onOpenFile']('" + path + "', flags) threw an exception: " + e.message);
  }
  return stream;
 }),
 close: (function(stream) {
  if (stream.getdents) stream.getdents = null;
  try {
   if (stream.stream_ops.close) {
    stream.stream_ops.close(stream);
   }
  } catch (e) {
   throw e;
  } finally {
   FS.closeStream(stream.fd);
  }
 }),
 llseek: (function(stream, offset, whence) {
  if (!stream.seekable || !stream.stream_ops.llseek) {
   throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
  }
  stream.position = stream.stream_ops.llseek(stream, offset, whence);
  stream.ungotten = [];
  return stream.position;
 }),
 read: (function(stream, buffer, offset, length, position) {
  if (length < 0 || position < 0) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  if ((stream.flags & 2097155) === 1) {
   throw new FS.ErrnoError(ERRNO_CODES.EBADF);
  }
  if (FS.isDir(stream.node.mode)) {
   throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
  }
  if (!stream.stream_ops.read) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  var seeking = true;
  if (typeof position === "undefined") {
   position = stream.position;
   seeking = false;
  } else if (!stream.seekable) {
   throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
  }
  var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
  if (!seeking) stream.position += bytesRead;
  return bytesRead;
 }),
 write: (function(stream, buffer, offset, length, position, canOwn) {
  if (length < 0 || position < 0) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  if ((stream.flags & 2097155) === 0) {
   throw new FS.ErrnoError(ERRNO_CODES.EBADF);
  }
  if (FS.isDir(stream.node.mode)) {
   throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
  }
  if (!stream.stream_ops.write) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  if (stream.flags & 1024) {
   FS.llseek(stream, 0, 2);
  }
  var seeking = true;
  if (typeof position === "undefined") {
   position = stream.position;
   seeking = false;
  } else if (!stream.seekable) {
   throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
  }
  var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
  if (!seeking) stream.position += bytesWritten;
  try {
   if (stream.path && FS.trackingDelegate["onWriteToFile"]) FS.trackingDelegate["onWriteToFile"](stream.path);
  } catch (e) {
   console.log("FS.trackingDelegate['onWriteToFile']('" + path + "') threw an exception: " + e.message);
  }
  return bytesWritten;
 }),
 allocate: (function(stream, offset, length) {
  if (offset < 0 || length <= 0) {
   throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
  }
  if ((stream.flags & 2097155) === 0) {
   throw new FS.ErrnoError(ERRNO_CODES.EBADF);
  }
  if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
   throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
  }
  if (!stream.stream_ops.allocate) {
   throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
  }
  stream.stream_ops.allocate(stream, offset, length);
 }),
 mmap: (function(stream, buffer, offset, length, position, prot, flags) {
  if ((stream.flags & 2097155) === 1) {
   throw new FS.ErrnoError(ERRNO_CODES.EACCES);
  }
  if (!stream.stream_ops.mmap) {
   throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
  }
  return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
 }),
 msync: (function(stream, buffer, offset, length, mmapFlags) {
  if (!stream || !stream.stream_ops.msync) {
   return 0;
  }
  return stream.stream_ops.msync(stream, buffer, offset, length, mmapFlags);
 }),
 munmap: (function(stream) {
  return 0;
 }),
 ioctl: (function(stream, cmd, arg) {
  if (!stream.stream_ops.ioctl) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
  }
  return stream.stream_ops.ioctl(stream, cmd, arg);
 }),
 readFile: (function(path, opts) {
  opts = opts || {};
  opts.flags = opts.flags || "r";
  opts.encoding = opts.encoding || "binary";
  if (opts.encoding !== "utf8" && opts.encoding !== "binary") {
   throw new Error('Invalid encoding type "' + opts.encoding + '"');
  }
  var ret;
  var stream = FS.open(path, opts.flags);
  var stat = FS.stat(path);
  var length = stat.size;
  var buf = new Uint8Array(length);
  FS.read(stream, buf, 0, length, 0);
  if (opts.encoding === "utf8") {
   ret = UTF8ArrayToString(buf, 0);
  } else if (opts.encoding === "binary") {
   ret = buf;
  }
  FS.close(stream);
  return ret;
 }),
 writeFile: (function(path, data, opts) {
  opts = opts || {};
  opts.flags = opts.flags || "w";
  opts.encoding = opts.encoding || "utf8";
  if (opts.encoding !== "utf8" && opts.encoding !== "binary") {
   throw new Error('Invalid encoding type "' + opts.encoding + '"');
  }
  var stream = FS.open(path, opts.flags, opts.mode);
  if (opts.encoding === "utf8") {
   var buf = new Uint8Array(lengthBytesUTF8(data) + 1);
   var actualNumBytes = stringToUTF8Array(data, buf, 0, buf.length);
   FS.write(stream, buf, 0, actualNumBytes, 0, opts.canOwn);
  } else if (opts.encoding === "binary") {
   FS.write(stream, data, 0, data.length, 0, opts.canOwn);
  }
  FS.close(stream);
 }),
 cwd: (function() {
  return FS.currentPath;
 }),
 chdir: (function(path) {
  var lookup = FS.lookupPath(path, {
   follow: true
  });
  if (!FS.isDir(lookup.node.mode)) {
   throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
  }
  var err = FS.nodePermissions(lookup.node, "x");
  if (err) {
   throw new FS.ErrnoError(err);
  }
  FS.currentPath = lookup.path;
 }),
 createDefaultDirectories: (function() {
  FS.mkdir("/tmp");
  FS.mkdir("/home");
  FS.mkdir("/home/web_user");
 }),
 createDefaultDevices: (function() {
  FS.mkdir("/dev");
  FS.registerDevice(FS.makedev(1, 3), {
   read: (function() {
    return 0;
   }),
   write: (function(stream, buffer, offset, length, pos) {
    return length;
   })
  });
  FS.mkdev("/dev/null", FS.makedev(1, 3));
  TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
  TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
  FS.mkdev("/dev/tty", FS.makedev(5, 0));
  FS.mkdev("/dev/tty1", FS.makedev(6, 0));
  var random_device;
  if (typeof crypto !== "undefined") {
   var randomBuffer = new Uint8Array(1);
   random_device = (function() {
    crypto.getRandomValues(randomBuffer);
    return randomBuffer[0];
   });
  } else if (ENVIRONMENT_IS_NODE) {
   random_device = (function() {
    return require("crypto").randomBytes(1)[0];
   });
  } else {
   random_device = (function() {
    return Math.random() * 256 | 0;
   });
  }
  FS.createDevice("/dev", "random", random_device);
  FS.createDevice("/dev", "urandom", random_device);
  FS.mkdir("/dev/shm");
  FS.mkdir("/dev/shm/tmp");
 }),
 createSpecialDirectories: (function() {
  FS.mkdir("/proc");
  FS.mkdir("/proc/self");
  FS.mkdir("/proc/self/fd");
  FS.mount({
   mount: (function() {
    var node = FS.createNode("/proc/self", "fd", 16384 | 511, 73);
    node.node_ops = {
     lookup: (function(parent, name) {
      var fd = +name;
      var stream = FS.getStream(fd);
      if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
      var ret = {
       parent: null,
       mount: {
        mountpoint: "fake"
       },
       node_ops: {
        readlink: (function() {
         return stream.path;
        })
       }
      };
      ret.parent = ret;
      return ret;
     })
    };
    return node;
   })
  }, {}, "/proc/self/fd");
 }),
 createStandardStreams: (function() {
  if (Module["stdin"]) {
   FS.createDevice("/dev", "stdin", Module["stdin"]);
  } else {
   FS.symlink("/dev/tty", "/dev/stdin");
  }
  if (Module["stdout"]) {
   FS.createDevice("/dev", "stdout", null, Module["stdout"]);
  } else {
   FS.symlink("/dev/tty", "/dev/stdout");
  }
  if (Module["stderr"]) {
   FS.createDevice("/dev", "stderr", null, Module["stderr"]);
  } else {
   FS.symlink("/dev/tty1", "/dev/stderr");
  }
  var stdin = FS.open("/dev/stdin", "r");
  assert(stdin.fd === 0, "invalid handle for stdin (" + stdin.fd + ")");
  var stdout = FS.open("/dev/stdout", "w");
  assert(stdout.fd === 1, "invalid handle for stdout (" + stdout.fd + ")");
  var stderr = FS.open("/dev/stderr", "w");
  assert(stderr.fd === 2, "invalid handle for stderr (" + stderr.fd + ")");
 }),
 ensureErrnoError: (function() {
  if (FS.ErrnoError) return;
  FS.ErrnoError = function ErrnoError(errno, node) {
   this.node = node;
   this.setErrno = (function(errno) {
    this.errno = errno;
    for (var key in ERRNO_CODES) {
     if (ERRNO_CODES[key] === errno) {
      this.code = key;
      break;
     }
    }
   });
   this.setErrno(errno);
   this.message = ERRNO_MESSAGES[errno];
  };
  FS.ErrnoError.prototype = new Error;
  FS.ErrnoError.prototype.constructor = FS.ErrnoError;
  [ ERRNO_CODES.ENOENT ].forEach((function(code) {
   FS.genericErrors[code] = new FS.ErrnoError(code);
   FS.genericErrors[code].stack = "<generic error, no stack>";
  }));
 }),
 staticInit: (function() {
  FS.ensureErrnoError();
  FS.nameTable = new Array(4096);
  FS.mount(MEMFS, {}, "/");
  FS.createDefaultDirectories();
  FS.createDefaultDevices();
  FS.createSpecialDirectories();
  FS.filesystems = {
   "MEMFS": MEMFS,
   "IDBFS": IDBFS,
   "NODEFS": NODEFS,
   "WORKERFS": WORKERFS
  };
 }),
 init: (function(input, output, error) {
  assert(!FS.init.initialized, "FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)");
  FS.init.initialized = true;
  FS.ensureErrnoError();
  Module["stdin"] = input || Module["stdin"];
  Module["stdout"] = output || Module["stdout"];
  Module["stderr"] = error || Module["stderr"];
  FS.createStandardStreams();
 }),
 quit: (function() {
  FS.init.initialized = false;
  var fflush = Module["_fflush"];
  if (fflush) fflush(0);
  for (var i = 0; i < FS.streams.length; i++) {
   var stream = FS.streams[i];
   if (!stream) {
    continue;
   }
   FS.close(stream);
  }
 }),
 getMode: (function(canRead, canWrite) {
  var mode = 0;
  if (canRead) mode |= 292 | 73;
  if (canWrite) mode |= 146;
  return mode;
 }),
 joinPath: (function(parts, forceRelative) {
  var path = PATH.join.apply(null, parts);
  if (forceRelative && path[0] == "/") path = path.substr(1);
  return path;
 }),
 absolutePath: (function(relative, base) {
  return PATH.resolve(base, relative);
 }),
 standardizePath: (function(path) {
  return PATH.normalize(path);
 }),
 findObject: (function(path, dontResolveLastLink) {
  var ret = FS.analyzePath(path, dontResolveLastLink);
  if (ret.exists) {
   return ret.object;
  } else {
   ___setErrNo(ret.error);
   return null;
  }
 }),
 analyzePath: (function(path, dontResolveLastLink) {
  try {
   var lookup = FS.lookupPath(path, {
    follow: !dontResolveLastLink
   });
   path = lookup.path;
  } catch (e) {}
  var ret = {
   isRoot: false,
   exists: false,
   error: 0,
   name: null,
   path: null,
   object: null,
   parentExists: false,
   parentPath: null,
   parentObject: null
  };
  try {
   var lookup = FS.lookupPath(path, {
    parent: true
   });
   ret.parentExists = true;
   ret.parentPath = lookup.path;
   ret.parentObject = lookup.node;
   ret.name = PATH.basename(path);
   lookup = FS.lookupPath(path, {
    follow: !dontResolveLastLink
   });
   ret.exists = true;
   ret.path = lookup.path;
   ret.object = lookup.node;
   ret.name = lookup.node.name;
   ret.isRoot = lookup.path === "/";
  } catch (e) {
   ret.error = e.errno;
  }
  return ret;
 }),
 createFolder: (function(parent, name, canRead, canWrite) {
  var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
  var mode = FS.getMode(canRead, canWrite);
  return FS.mkdir(path, mode);
 }),
 createPath: (function(parent, path, canRead, canWrite) {
  parent = typeof parent === "string" ? parent : FS.getPath(parent);
  var parts = path.split("/").reverse();
  while (parts.length) {
   var part = parts.pop();
   if (!part) continue;
   var current = PATH.join2(parent, part);
   try {
    FS.mkdir(current);
   } catch (e) {}
   parent = current;
  }
  return current;
 }),
 createFile: (function(parent, name, properties, canRead, canWrite) {
  var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
  var mode = FS.getMode(canRead, canWrite);
  return FS.create(path, mode);
 }),
 createDataFile: (function(parent, name, data, canRead, canWrite, canOwn) {
  var path = name ? PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name) : parent;
  var mode = FS.getMode(canRead, canWrite);
  var node = FS.create(path, mode);
  if (data) {
   if (typeof data === "string") {
    var arr = new Array(data.length);
    for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
    data = arr;
   }
   FS.chmod(node, mode | 146);
   var stream = FS.open(node, "w");
   FS.write(stream, data, 0, data.length, 0, canOwn);
   FS.close(stream);
   FS.chmod(node, mode);
  }
  return node;
 }),
 createDevice: (function(parent, name, input, output) {
  var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
  var mode = FS.getMode(!!input, !!output);
  if (!FS.createDevice.major) FS.createDevice.major = 64;
  var dev = FS.makedev(FS.createDevice.major++, 0);
  FS.registerDevice(dev, {
   open: (function(stream) {
    stream.seekable = false;
   }),
   close: (function(stream) {
    if (output && output.buffer && output.buffer.length) {
     output(10);
    }
   }),
   read: (function(stream, buffer, offset, length, pos) {
    var bytesRead = 0;
    for (var i = 0; i < length; i++) {
     var result;
     try {
      result = input();
     } catch (e) {
      throw new FS.ErrnoError(ERRNO_CODES.EIO);
     }
     if (result === undefined && bytesRead === 0) {
      throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
     }
     if (result === null || result === undefined) break;
     bytesRead++;
     buffer[offset + i] = result;
    }
    if (bytesRead) {
     stream.node.timestamp = Date.now();
    }
    return bytesRead;
   }),
   write: (function(stream, buffer, offset, length, pos) {
    for (var i = 0; i < length; i++) {
     try {
      output(buffer[offset + i]);
     } catch (e) {
      throw new FS.ErrnoError(ERRNO_CODES.EIO);
     }
    }
    if (length) {
     stream.node.timestamp = Date.now();
    }
    return i;
   })
  });
  return FS.mkdev(path, mode, dev);
 }),
 createLink: (function(parent, name, target, canRead, canWrite) {
  var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
  return FS.symlink(target, path);
 }),
 forceLoadFile: (function(obj) {
  if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
  var success = true;
  if (typeof XMLHttpRequest !== "undefined") {
   throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
  } else if (Module["read"]) {
   try {
    obj.contents = intArrayFromString(Module["read"](obj.url), true);
    obj.usedBytes = obj.contents.length;
   } catch (e) {
    success = false;
   }
  } else {
   throw new Error("Cannot load without read() or XMLHttpRequest.");
  }
  if (!success) ___setErrNo(ERRNO_CODES.EIO);
  return success;
 }),
 createLazyFile: (function(parent, name, url, canRead, canWrite) {
  function LazyUint8Array() {
   this.lengthKnown = false;
   this.chunks = [];
  }
  LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
   if (idx > this.length - 1 || idx < 0) {
    return undefined;
   }
   var chunkOffset = idx % this.chunkSize;
   var chunkNum = idx / this.chunkSize | 0;
   return this.getter(chunkNum)[chunkOffset];
  };
  LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
   this.getter = getter;
  };
  LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
   var xhr = new XMLHttpRequest;
   xhr.open("HEAD", url, false);
   xhr.send(null);
   if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
   var datalength = Number(xhr.getResponseHeader("Content-length"));
   var header;
   var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
   var usesGzip = (header = xhr.getResponseHeader("Content-Encoding")) && header === "gzip";
   var chunkSize = 1024 * 1024;
   if (!hasByteServing) chunkSize = datalength;
   var doXHR = (function(from, to) {
    if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
    if (to > datalength - 1) throw new Error("only " + datalength + " bytes available! programmer error!");
    var xhr = new XMLHttpRequest;
    xhr.open("GET", url, false);
    if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
    if (typeof Uint8Array != "undefined") xhr.responseType = "arraybuffer";
    if (xhr.overrideMimeType) {
     xhr.overrideMimeType("text/plain; charset=x-user-defined");
    }
    xhr.send(null);
    if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
    if (xhr.response !== undefined) {
     return new Uint8Array(xhr.response || []);
    } else {
     return intArrayFromString(xhr.responseText || "", true);
    }
   });
   var lazyArray = this;
   lazyArray.setDataGetter((function(chunkNum) {
    var start = chunkNum * chunkSize;
    var end = (chunkNum + 1) * chunkSize - 1;
    end = Math.min(end, datalength - 1);
    if (typeof lazyArray.chunks[chunkNum] === "undefined") {
     lazyArray.chunks[chunkNum] = doXHR(start, end);
    }
    if (typeof lazyArray.chunks[chunkNum] === "undefined") throw new Error("doXHR failed!");
    return lazyArray.chunks[chunkNum];
   }));
   if (usesGzip || !datalength) {
    chunkSize = datalength = 1;
    datalength = this.getter(0).length;
    chunkSize = datalength;
    console.log("LazyFiles on gzip forces download of the whole file when length is accessed");
   }
   this._length = datalength;
   this._chunkSize = chunkSize;
   this.lengthKnown = true;
  };
  if (typeof XMLHttpRequest !== "undefined") {
   if (!ENVIRONMENT_IS_WORKER) throw "Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc";
   var lazyArray = new LazyUint8Array;
   Object.defineProperties(lazyArray, {
    length: {
     get: (function() {
      if (!this.lengthKnown) {
       this.cacheLength();
      }
      return this._length;
     })
    },
    chunkSize: {
     get: (function() {
      if (!this.lengthKnown) {
       this.cacheLength();
      }
      return this._chunkSize;
     })
    }
   });
   var properties = {
    isDevice: false,
    contents: lazyArray
   };
  } else {
   var properties = {
    isDevice: false,
    url: url
   };
  }
  var node = FS.createFile(parent, name, properties, canRead, canWrite);
  if (properties.contents) {
   node.contents = properties.contents;
  } else if (properties.url) {
   node.contents = null;
   node.url = properties.url;
  }
  Object.defineProperties(node, {
   usedBytes: {
    get: (function() {
     return this.contents.length;
    })
   }
  });
  var stream_ops = {};
  var keys = Object.keys(node.stream_ops);
  keys.forEach((function(key) {
   var fn = node.stream_ops[key];
   stream_ops[key] = function forceLoadLazyFile() {
    if (!FS.forceLoadFile(node)) {
     throw new FS.ErrnoError(ERRNO_CODES.EIO);
    }
    return fn.apply(null, arguments);
   };
  }));
  stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
   if (!FS.forceLoadFile(node)) {
    throw new FS.ErrnoError(ERRNO_CODES.EIO);
   }
   var contents = stream.node.contents;
   if (position >= contents.length) return 0;
   var size = Math.min(contents.length - position, length);
   assert(size >= 0);
   if (contents.slice) {
    for (var i = 0; i < size; i++) {
     buffer[offset + i] = contents[position + i];
    }
   } else {
    for (var i = 0; i < size; i++) {
     buffer[offset + i] = contents.get(position + i);
    }
   }
   return size;
  };
  node.stream_ops = stream_ops;
  return node;
 }),
 createPreloadedFile: (function(parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn, preFinish) {
  Browser.init();
  var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
  var dep = getUniqueRunDependency("cp " + fullname);
  function processData(byteArray) {
   function finish(byteArray) {
    if (preFinish) preFinish();
    if (!dontCreateFile) {
     FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
    }
    if (onload) onload();
    removeRunDependency(dep);
   }
   var handled = false;
   Module["preloadPlugins"].forEach((function(plugin) {
    if (handled) return;
    if (plugin["canHandle"](fullname)) {
     plugin["handle"](byteArray, fullname, finish, (function() {
      if (onerror) onerror();
      removeRunDependency(dep);
     }));
     handled = true;
    }
   }));
   if (!handled) finish(byteArray);
  }
  addRunDependency(dep);
  if (typeof url == "string") {
   Browser.asyncLoad(url, (function(byteArray) {
    processData(byteArray);
   }), onerror);
  } else {
   processData(url);
  }
 }),
 indexedDB: (function() {
  return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
 }),
 DB_NAME: (function() {
  return "EM_FS_" + window.location.pathname;
 }),
 DB_VERSION: 20,
 DB_STORE_NAME: "FILE_DATA",
 saveFilesToDB: (function(paths, onload, onerror) {
  onload = onload || (function() {});
  onerror = onerror || (function() {});
  var indexedDB = FS.indexedDB();
  try {
   var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
  } catch (e) {
   return onerror(e);
  }
  openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
   console.log("creating db");
   var db = openRequest.result;
   db.createObjectStore(FS.DB_STORE_NAME);
  };
  openRequest.onsuccess = function openRequest_onsuccess() {
   var db = openRequest.result;
   var transaction = db.transaction([ FS.DB_STORE_NAME ], "readwrite");
   var files = transaction.objectStore(FS.DB_STORE_NAME);
   var ok = 0, fail = 0, total = paths.length;
   function finish() {
    if (fail == 0) onload(); else onerror();
   }
   paths.forEach((function(path) {
    var putRequest = files.put(FS.analyzePath(path).object.contents, path);
    putRequest.onsuccess = function putRequest_onsuccess() {
     ok++;
     if (ok + fail == total) finish();
    };
    putRequest.onerror = function putRequest_onerror() {
     fail++;
     if (ok + fail == total) finish();
    };
   }));
   transaction.onerror = onerror;
  };
  openRequest.onerror = onerror;
 }),
 loadFilesFromDB: (function(paths, onload, onerror) {
  onload = onload || (function() {});
  onerror = onerror || (function() {});
  var indexedDB = FS.indexedDB();
  try {
   var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
  } catch (e) {
   return onerror(e);
  }
  openRequest.onupgradeneeded = onerror;
  openRequest.onsuccess = function openRequest_onsuccess() {
   var db = openRequest.result;
   try {
    var transaction = db.transaction([ FS.DB_STORE_NAME ], "readonly");
   } catch (e) {
    onerror(e);
    return;
   }
   var files = transaction.objectStore(FS.DB_STORE_NAME);
   var ok = 0, fail = 0, total = paths.length;
   function finish() {
    if (fail == 0) onload(); else onerror();
   }
   paths.forEach((function(path) {
    var getRequest = files.get(path);
    getRequest.onsuccess = function getRequest_onsuccess() {
     if (FS.analyzePath(path).exists) {
      FS.unlink(path);
     }
     FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
     ok++;
     if (ok + fail == total) finish();
    };
    getRequest.onerror = function getRequest_onerror() {
     fail++;
     if (ok + fail == total) finish();
    };
   }));
   transaction.onerror = onerror;
  };
  openRequest.onerror = onerror;
 })
};
var SYSCALLS = {
 DEFAULT_POLLMASK: 5,
 mappings: {},
 umask: 511,
 calculateAt: (function(dirfd, path) {
  if (path[0] !== "/") {
   var dir;
   if (dirfd === -100) {
    dir = FS.cwd();
   } else {
    var dirstream = FS.getStream(dirfd);
    if (!dirstream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
    dir = dirstream.path;
   }
   path = PATH.join2(dir, path);
  }
  return path;
 }),
 doStat: (function(func, path, buf) {
  try {
   var stat = func(path);
  } catch (e) {
   if (e && e.node && PATH.normalize(path) !== PATH.normalize(FS.getPath(e.node))) {
    return -ERRNO_CODES.ENOTDIR;
   }
   throw e;
  }
  HEAP32[buf >> 2] = stat.dev;
  HEAP32[buf + 4 >> 2] = 0;
  HEAP32[buf + 8 >> 2] = stat.ino;
  HEAP32[buf + 12 >> 2] = stat.mode;
  HEAP32[buf + 16 >> 2] = stat.nlink;
  HEAP32[buf + 20 >> 2] = stat.uid;
  HEAP32[buf + 24 >> 2] = stat.gid;
  HEAP32[buf + 28 >> 2] = stat.rdev;
  HEAP32[buf + 32 >> 2] = 0;
  HEAP32[buf + 36 >> 2] = stat.size;
  HEAP32[buf + 40 >> 2] = 4096;
  HEAP32[buf + 44 >> 2] = stat.blocks;
  HEAP32[buf + 48 >> 2] = stat.atime.getTime() / 1e3 | 0;
  HEAP32[buf + 52 >> 2] = 0;
  HEAP32[buf + 56 >> 2] = stat.mtime.getTime() / 1e3 | 0;
  HEAP32[buf + 60 >> 2] = 0;
  HEAP32[buf + 64 >> 2] = stat.ctime.getTime() / 1e3 | 0;
  HEAP32[buf + 68 >> 2] = 0;
  HEAP32[buf + 72 >> 2] = stat.ino;
  return 0;
 }),
 doMsync: (function(addr, stream, len, flags) {
  var buffer = new Uint8Array(HEAPU8.subarray(addr, addr + len));
  FS.msync(stream, buffer, 0, len, flags);
 }),
 doMkdir: (function(path, mode) {
  path = PATH.normalize(path);
  if (path[path.length - 1] === "/") path = path.substr(0, path.length - 1);
  FS.mkdir(path, mode, 0);
  return 0;
 }),
 doMknod: (function(path, mode, dev) {
  switch (mode & 61440) {
  case 32768:
  case 8192:
  case 24576:
  case 4096:
  case 49152:
   break;
  default:
   return -ERRNO_CODES.EINVAL;
  }
  FS.mknod(path, mode, dev);
  return 0;
 }),
 doReadlink: (function(path, buf, bufsize) {
  if (bufsize <= 0) return -ERRNO_CODES.EINVAL;
  var ret = FS.readlink(path);
  ret = ret.slice(0, Math.max(0, bufsize));
  writeStringToMemory(ret, buf, true);
  return ret.length;
 }),
 doAccess: (function(path, amode) {
  if (amode & ~7) {
   return -ERRNO_CODES.EINVAL;
  }
  var node;
  var lookup = FS.lookupPath(path, {
   follow: true
  });
  node = lookup.node;
  var perms = "";
  if (amode & 4) perms += "r";
  if (amode & 2) perms += "w";
  if (amode & 1) perms += "x";
  if (perms && FS.nodePermissions(node, perms)) {
   return -ERRNO_CODES.EACCES;
  }
  return 0;
 }),
 doDup: (function(path, flags, suggestFD) {
  var suggest = FS.getStream(suggestFD);
  if (suggest) FS.close(suggest);
  return FS.open(path, flags, 0, suggestFD, suggestFD).fd;
 }),
 doReadv: (function(stream, iov, iovcnt, offset) {
  var ret = 0;
  for (var i = 0; i < iovcnt; i++) {
   var ptr = HEAP32[iov + i * 8 >> 2];
   var len = HEAP32[iov + (i * 8 + 4) >> 2];
   var curr = FS.read(stream, HEAP8, ptr, len, offset);
   if (curr < 0) return -1;
   ret += curr;
   if (curr < len) break;
  }
  return ret;
 }),
 doWritev: (function(stream, iov, iovcnt, offset) {
  var ret = 0;
  for (var i = 0; i < iovcnt; i++) {
   var ptr = HEAP32[iov + i * 8 >> 2];
   var len = HEAP32[iov + (i * 8 + 4) >> 2];
   var curr = FS.write(stream, HEAP8, ptr, len, offset);
   if (curr < 0) return -1;
   ret += curr;
  }
  return ret;
 }),
 varargs: 0,
 get: (function(varargs) {
  SYSCALLS.varargs += 4;
  var ret = HEAP32[SYSCALLS.varargs - 4 >> 2];
  return ret;
 }),
 getStr: (function() {
  var ret = Pointer_stringify(SYSCALLS.get());
  return ret;
 }),
 getStreamFromFD: (function() {
  var stream = FS.getStream(SYSCALLS.get());
  if (!stream) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
  return stream;
 }),
 getSocketFromFD: (function() {
  var socket = SOCKFS.getSocket(SYSCALLS.get());
  if (!socket) throw new FS.ErrnoError(ERRNO_CODES.EBADF);
  return socket;
 }),
 getSocketAddress: (function(allowNull) {
  var addrp = SYSCALLS.get(), addrlen = SYSCALLS.get();
  if (allowNull && addrp === 0) return null;
  var info = __read_sockaddr(addrp, addrlen);
  if (info.errno) throw new FS.ErrnoError(info.errno);
  info.addr = DNS.lookup_addr(info.addr) || info.addr;
  return info;
 }),
 get64: (function() {
  var low = SYSCALLS.get(), high = SYSCALLS.get();
  if (low >= 0) assert(high === 0); else assert(high === -1);
  return low;
 }),
 getZero: (function() {
  assert(SYSCALLS.get() === 0);
 })
};
function ___syscall54(which, varargs) {
 SYSCALLS.varargs = varargs;
 try {
  var stream = SYSCALLS.getStreamFromFD(), op = SYSCALLS.get();
  switch (op) {
  case 21505:
   {
    if (!stream.tty) return -ERRNO_CODES.ENOTTY;
    return 0;
   }
  case 21506:
   {
    if (!stream.tty) return -ERRNO_CODES.ENOTTY;
    return 0;
   }
  case 21519:
   {
    if (!stream.tty) return -ERRNO_CODES.ENOTTY;
    var argp = SYSCALLS.get();
    HEAP32[argp >> 2] = 0;
    return 0;
   }
  case 21520:
   {
    if (!stream.tty) return -ERRNO_CODES.ENOTTY;
    return -ERRNO_CODES.EINVAL;
   }
  case 21531:
   {
    var argp = SYSCALLS.get();
    return FS.ioctl(stream, op, argp);
   }
  default:
   abort("bad ioctl syscall " + op);
  }
 } catch (e) {
  if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
  return -e.errno;
 }
}
Module["_bitshift64Ashr"] = _bitshift64Ashr;
Module["_bitshift64Lshr"] = _bitshift64Lshr;
function ___cxa_pure_virtual() {
 ABORT = true;
 throw "Pure virtual function called!";
}
function _pthread_cleanup_push(routine, arg) {
 __ATEXIT__.push((function() {
  Runtime.dynCall("vi", routine, [ arg ]);
 }));
 _pthread_cleanup_push.level = __ATEXIT__.length;
}
Module["_pthread_cond_broadcast"] = _pthread_cond_broadcast;
var _environ = STATICTOP;
STATICTOP += 16;
function ___buildEnvironment(env) {
 var MAX_ENV_VALUES = 64;
 var TOTAL_ENV_SIZE = 1024;
 var poolPtr;
 var envPtr;
 if (!___buildEnvironment.called) {
  ___buildEnvironment.called = true;
  ENV["USER"] = ENV["LOGNAME"] = "web_user";
  ENV["PATH"] = "/";
  ENV["PWD"] = "/";
  ENV["HOME"] = "/home/web_user";
  ENV["LANG"] = "C";
  ENV["_"] = Module["thisProgram"];
  poolPtr = allocate(TOTAL_ENV_SIZE, "i8", ALLOC_STATIC);
  envPtr = allocate(MAX_ENV_VALUES * 4, "i8*", ALLOC_STATIC);
  HEAP32[envPtr >> 2] = poolPtr;
  HEAP32[_environ >> 2] = envPtr;
 } else {
  envPtr = HEAP32[_environ >> 2];
  poolPtr = HEAP32[envPtr >> 2];
 }
 var strings = [];
 var totalSize = 0;
 for (var key in env) {
  if (typeof env[key] === "string") {
   var line = key + "=" + env[key];
   strings.push(line);
   totalSize += line.length;
  }
 }
 if (totalSize > TOTAL_ENV_SIZE) {
  throw new Error("Environment size exceeded TOTAL_ENV_SIZE!");
 }
 var ptrSize = 4;
 for (var i = 0; i < strings.length; i++) {
  var line = strings[i];
  writeAsciiToMemory(line, poolPtr);
  HEAP32[envPtr + i * ptrSize >> 2] = poolPtr;
  poolPtr += line.length + 1;
 }
 HEAP32[envPtr + strings.length * ptrSize >> 2] = 0;
}
var ENV = {};
function _getenv(name) {
 if (name === 0) return 0;
 name = Pointer_stringify(name);
 if (!ENV.hasOwnProperty(name)) return 0;
 if (_getenv.ret) _free(_getenv.ret);
 _getenv.ret = allocate(intArrayFromString(ENV[name]), "i8", ALLOC_NORMAL);
 return _getenv.ret;
}
function __isLeapYear(year) {
 return year % 4 === 0 && (year % 100 !== 0 || year % 400 === 0);
}
function __arraySum(array, index) {
 var sum = 0;
 for (var i = 0; i <= index; sum += array[i++]) ;
 return sum;
}
var __MONTH_DAYS_LEAP = [ 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 ];
var __MONTH_DAYS_REGULAR = [ 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 ];
function __addDays(date, days) {
 var newDate = new Date(date.getTime());
 while (days > 0) {
  var leap = __isLeapYear(newDate.getFullYear());
  var currentMonth = newDate.getMonth();
  var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
  if (days > daysInCurrentMonth - newDate.getDate()) {
   days -= daysInCurrentMonth - newDate.getDate() + 1;
   newDate.setDate(1);
   if (currentMonth < 11) {
    newDate.setMonth(currentMonth + 1);
   } else {
    newDate.setMonth(0);
    newDate.setFullYear(newDate.getFullYear() + 1);
   }
  } else {
   newDate.setDate(newDate.getDate() + days);
   return newDate;
  }
 }
 return newDate;
}
function _strftime(s, maxsize, format, tm) {
 var tm_zone = HEAP32[tm + 40 >> 2];
 var date = {
  tm_sec: HEAP32[tm >> 2],
  tm_min: HEAP32[tm + 4 >> 2],
  tm_hour: HEAP32[tm + 8 >> 2],
  tm_mday: HEAP32[tm + 12 >> 2],
  tm_mon: HEAP32[tm + 16 >> 2],
  tm_year: HEAP32[tm + 20 >> 2],
  tm_wday: HEAP32[tm + 24 >> 2],
  tm_yday: HEAP32[tm + 28 >> 2],
  tm_isdst: HEAP32[tm + 32 >> 2],
  tm_gmtoff: HEAP32[tm + 36 >> 2],
  tm_zone: tm_zone ? Pointer_stringify(tm_zone) : ""
 };
 var pattern = Pointer_stringify(format);
 var EXPANSION_RULES_1 = {
  "%c": "%a %b %d %H:%M:%S %Y",
  "%D": "%m/%d/%y",
  "%F": "%Y-%m-%d",
  "%h": "%b",
  "%r": "%I:%M:%S %p",
  "%R": "%H:%M",
  "%T": "%H:%M:%S",
  "%x": "%m/%d/%y",
  "%X": "%H:%M:%S"
 };
 for (var rule in EXPANSION_RULES_1) {
  pattern = pattern.replace(new RegExp(rule, "g"), EXPANSION_RULES_1[rule]);
 }
 var WEEKDAYS = [ "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" ];
 var MONTHS = [ "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December" ];
 function leadingSomething(value, digits, character) {
  var str = typeof value === "number" ? value.toString() : value || "";
  while (str.length < digits) {
   str = character[0] + str;
  }
  return str;
 }
 function leadingNulls(value, digits) {
  return leadingSomething(value, digits, "0");
 }
 function compareByDay(date1, date2) {
  function sgn(value) {
   return value < 0 ? -1 : value > 0 ? 1 : 0;
  }
  var compare;
  if ((compare = sgn(date1.getFullYear() - date2.getFullYear())) === 0) {
   if ((compare = sgn(date1.getMonth() - date2.getMonth())) === 0) {
    compare = sgn(date1.getDate() - date2.getDate());
   }
  }
  return compare;
 }
 function getFirstWeekStartDate(janFourth) {
  switch (janFourth.getDay()) {
  case 0:
   return new Date(janFourth.getFullYear() - 1, 11, 29);
  case 1:
   return janFourth;
  case 2:
   return new Date(janFourth.getFullYear(), 0, 3);
  case 3:
   return new Date(janFourth.getFullYear(), 0, 2);
  case 4:
   return new Date(janFourth.getFullYear(), 0, 1);
  case 5:
   return new Date(janFourth.getFullYear() - 1, 11, 31);
  case 6:
   return new Date(janFourth.getFullYear() - 1, 11, 30);
  }
 }
 function getWeekBasedYear(date) {
  var thisDate = __addDays(new Date(date.tm_year + 1900, 0, 1), date.tm_yday);
  var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
  var janFourthNextYear = new Date(thisDate.getFullYear() + 1, 0, 4);
  var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
  var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
   if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
    return thisDate.getFullYear() + 1;
   } else {
    return thisDate.getFullYear();
   }
  } else {
   return thisDate.getFullYear() - 1;
  }
 }
 var EXPANSION_RULES_2 = {
  "%a": (function(date) {
   return WEEKDAYS[date.tm_wday].substring(0, 3);
  }),
  "%A": (function(date) {
   return WEEKDAYS[date.tm_wday];
  }),
  "%b": (function(date) {
   return MONTHS[date.tm_mon].substring(0, 3);
  }),
  "%B": (function(date) {
   return MONTHS[date.tm_mon];
  }),
  "%C": (function(date) {
   var year = date.tm_year + 1900;
   return leadingNulls(year / 100 | 0, 2);
  }),
  "%d": (function(date) {
   return leadingNulls(date.tm_mday, 2);
  }),
  "%e": (function(date) {
   return leadingSomething(date.tm_mday, 2, " ");
  }),
  "%g": (function(date) {
   return getWeekBasedYear(date).toString().substring(2);
  }),
  "%G": (function(date) {
   return getWeekBasedYear(date);
  }),
  "%H": (function(date) {
   return leadingNulls(date.tm_hour, 2);
  }),
  "%I": (function(date) {
   var twelveHour = date.tm_hour;
   if (twelveHour == 0) twelveHour = 12; else if (twelveHour > 12) twelveHour -= 12;
   return leadingNulls(twelveHour, 2);
  }),
  "%j": (function(date) {
   return leadingNulls(date.tm_mday + __arraySum(__isLeapYear(date.tm_year + 1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon - 1), 3);
  }),
  "%m": (function(date) {
   return leadingNulls(date.tm_mon + 1, 2);
  }),
  "%M": (function(date) {
   return leadingNulls(date.tm_min, 2);
  }),
  "%n": (function() {
   return "\n";
  }),
  "%p": (function(date) {
   if (date.tm_hour >= 0 && date.tm_hour < 12) {
    return "AM";
   } else {
    return "PM";
   }
  }),
  "%S": (function(date) {
   return leadingNulls(date.tm_sec, 2);
  }),
  "%t": (function() {
   return "\t";
  }),
  "%u": (function(date) {
   var day = new Date(date.tm_year + 1900, date.tm_mon + 1, date.tm_mday, 0, 0, 0, 0);
   return day.getDay() || 7;
  }),
  "%U": (function(date) {
   var janFirst = new Date(date.tm_year + 1900, 0, 1);
   var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7 - janFirst.getDay());
   var endDate = new Date(date.tm_year + 1900, date.tm_mon, date.tm_mday);
   if (compareByDay(firstSunday, endDate) < 0) {
    var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth() - 1) - 31;
    var firstSundayUntilEndJanuary = 31 - firstSunday.getDate();
    var days = firstSundayUntilEndJanuary + februaryFirstUntilEndMonth + endDate.getDate();
    return leadingNulls(Math.ceil(days / 7), 2);
   }
   return compareByDay(firstSunday, janFirst) === 0 ? "01" : "00";
  }),
  "%V": (function(date) {
   var janFourthThisYear = new Date(date.tm_year + 1900, 0, 4);
   var janFourthNextYear = new Date(date.tm_year + 1901, 0, 4);
   var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
   var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
   var endDate = __addDays(new Date(date.tm_year + 1900, 0, 1), date.tm_yday);
   if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
    return "53";
   }
   if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
    return "01";
   }
   var daysDifference;
   if (firstWeekStartThisYear.getFullYear() < date.tm_year + 1900) {
    daysDifference = date.tm_yday + 32 - firstWeekStartThisYear.getDate();
   } else {
    daysDifference = date.tm_yday + 1 - firstWeekStartThisYear.getDate();
   }
   return leadingNulls(Math.ceil(daysDifference / 7), 2);
  }),
  "%w": (function(date) {
   var day = new Date(date.tm_year + 1900, date.tm_mon + 1, date.tm_mday, 0, 0, 0, 0);
   return day.getDay();
  }),
  "%W": (function(date) {
   var janFirst = new Date(date.tm_year, 0, 1);
   var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7 - janFirst.getDay() + 1);
   var endDate = new Date(date.tm_year + 1900, date.tm_mon, date.tm_mday);
   if (compareByDay(firstMonday, endDate) < 0) {
    var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth() - 1) - 31;
    var firstMondayUntilEndJanuary = 31 - firstMonday.getDate();
    var days = firstMondayUntilEndJanuary + februaryFirstUntilEndMonth + endDate.getDate();
    return leadingNulls(Math.ceil(days / 7), 2);
   }
   return compareByDay(firstMonday, janFirst) === 0 ? "01" : "00";
  }),
  "%y": (function(date) {
   return (date.tm_year + 1900).toString().substring(2);
  }),
  "%Y": (function(date) {
   return date.tm_year + 1900;
  }),
  "%z": (function(date) {
   var off = date.tm_gmtoff;
   var ahead = off >= 0;
   off = Math.abs(off) / 60;
   off = off / 60 * 100 + off % 60;
   return (ahead ? "+" : "-") + String("0000" + off).slice(-4);
  }),
  "%Z": (function(date) {
   return date.tm_zone;
  }),
  "%%": (function() {
   return "%";
  })
 };
 for (var rule in EXPANSION_RULES_2) {
  if (pattern.indexOf(rule) >= 0) {
   pattern = pattern.replace(new RegExp(rule, "g"), EXPANSION_RULES_2[rule](date));
  }
 }
 var bytes = intArrayFromString(pattern, false);
 if (bytes.length > maxsize) {
  return 0;
 }
 writeArrayToMemory(bytes, s);
 return bytes.length - 1;
}
function _strftime_l(s, maxsize, format, tm) {
 return _strftime(s, maxsize, format, tm);
}
function _pthread_cleanup_pop() {
 assert(_pthread_cleanup_push.level == __ATEXIT__.length, "cannot pop if something else added meanwhile!");
 __ATEXIT__.pop();
 _pthread_cleanup_push.level = __ATEXIT__.length;
}
function _pthread_join() {}
Module["___remdi3"] = ___remdi3;
function ___syscall6(which, varargs) {
 SYSCALLS.varargs = varargs;
 try {
  var stream = SYSCALLS.getStreamFromFD();
  FS.close(stream);
  return 0;
 } catch (e) {
  if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
  return -e.errno;
 }
}
Module["___udivdi3"] = ___udivdi3;
Module["___muldsi3"] = ___muldsi3;
Module["___muldi3"] = ___muldi3;
function _sbrk(bytes) {
 var self = _sbrk;
 if (!self.called) {
  DYNAMICTOP = alignMemoryPage(DYNAMICTOP);
  self.called = true;
  assert(Runtime.dynamicAlloc);
  self.alloc = Runtime.dynamicAlloc;
  Runtime.dynamicAlloc = (function() {
   abort("cannot dynamically allocate, sbrk now has control");
  });
 }
 var ret = DYNAMICTOP;
 if (bytes != 0) {
  var success = self.alloc(bytes);
  if (!success) return -1 >>> 0;
 }
 return ret;
}
Module["_bitshift64Shl"] = _bitshift64Shl;
function ___cxa_begin_catch(ptr) {
 __ZSt18uncaught_exceptionv.uncaught_exception--;
 EXCEPTIONS.caught.push(ptr);
 EXCEPTIONS.addRef(EXCEPTIONS.deAdjust(ptr));
 return ptr;
}
function ___gxx_personality_v0() {}
Module["___uremdi3"] = ___uremdi3;
function _pthread_cond_wait() {
 return 0;
}
var _llvm_fabs_f32 = Math_abs;
Module["_pthread_mutex_unlock"] = _pthread_mutex_unlock;
Module["_pthread_self"] = _pthread_self;
function ___syscall140(which, varargs) {
 SYSCALLS.varargs = varargs;
 try {
  var stream = SYSCALLS.getStreamFromFD(), offset_high = SYSCALLS.get(), offset_low = SYSCALLS.get(), result = SYSCALLS.get(), whence = SYSCALLS.get();
  var offset = offset_low;
  assert(offset_high === 0);
  FS.llseek(stream, offset, whence);
  HEAP32[result >> 2] = stream.position;
  if (stream.getdents && offset === 0 && whence === 0) stream.getdents = null;
  return 0;
 } catch (e) {
  if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
  return -e.errno;
 }
}
function ___syscall146(which, varargs) {
 SYSCALLS.varargs = varargs;
 try {
  var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get();
  return SYSCALLS.doWritev(stream, iov, iovcnt);
 } catch (e) {
  if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
  return -e.errno;
 }
}
function ___syscall145(which, varargs) {
 SYSCALLS.varargs = varargs;
 try {
  var stream = SYSCALLS.getStreamFromFD(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get();
  return SYSCALLS.doReadv(stream, iov, iovcnt);
 } catch (e) {
  if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
  return -e.errno;
 }
}
var ___dso_handle = STATICTOP;
STATICTOP += 16;
if (ENVIRONMENT_IS_NODE) {
 _emscripten_get_now = function _emscripten_get_now_actual() {
  var t = process["hrtime"]();
  return t[0] * 1e3 + t[1] / 1e6;
 };
} else if (typeof dateNow !== "undefined") {
 _emscripten_get_now = dateNow;
} else if (typeof self === "object" && self["performance"] && typeof self["performance"]["now"] === "function") {
 _emscripten_get_now = (function() {
  return self["performance"]["now"]();
 });
} else if (typeof performance === "object" && typeof performance["now"] === "function") {
 _emscripten_get_now = (function() {
  return performance["now"]();
 });
} else {
 _emscripten_get_now = Date.now;
}
FS.staticInit();
__ATINIT__.unshift((function() {
 if (!Module["noFSInit"] && !FS.init.initialized) FS.init();
}));
__ATMAIN__.push((function() {
 FS.ignorePermissions = false;
}));
__ATEXIT__.push((function() {
 FS.quit();
}));
Module["FS_createFolder"] = FS.createFolder;
Module["FS_createPath"] = FS.createPath;
Module["FS_createDataFile"] = FS.createDataFile;
Module["FS_createPreloadedFile"] = FS.createPreloadedFile;
Module["FS_createLazyFile"] = FS.createLazyFile;
Module["FS_createLink"] = FS.createLink;
Module["FS_createDevice"] = FS.createDevice;
Module["FS_unlink"] = FS.unlink;
__ATINIT__.unshift((function() {
 TTY.init();
}));
__ATEXIT__.push((function() {
 TTY.shutdown();
}));
if (ENVIRONMENT_IS_NODE) {
 var fs = require("fs");
 var NODEJS_PATH = require("path");
 NODEFS.staticInit();
}
___buildEnvironment(ENV);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true;
STACK_MAX = STACK_BASE + TOTAL_STACK;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
function invoke_iiiiiiii(index, a1, a2, a3, a4, a5, a6, a7) {
 try {
  return Module["dynCall_iiiiiiii"](index, a1, a2, a3, a4, a5, a6, a7);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_iiii(index, a1, a2, a3) {
 try {
  return Module["dynCall_iiii"](index, a1, a2, a3);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_viiiii(index, a1, a2, a3, a4, a5) {
 try {
  Module["dynCall_viiiii"](index, a1, a2, a3, a4, a5);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_iiiiiid(index, a1, a2, a3, a4, a5, a6) {
 try {
  return Module["dynCall_iiiiiid"](index, a1, a2, a3, a4, a5, a6);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_vi(index, a1) {
 try {
  Module["dynCall_vi"](index, a1);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_vii(index, a1, a2) {
 try {
  Module["dynCall_vii"](index, a1, a2);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_iiiiiii(index, a1, a2, a3, a4, a5, a6) {
 try {
  return Module["dynCall_iiiiiii"](index, a1, a2, a3, a4, a5, a6);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_iiiiid(index, a1, a2, a3, a4, a5) {
 try {
  return Module["dynCall_iiiiid"](index, a1, a2, a3, a4, a5);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_ii(index, a1) {
 try {
  return Module["dynCall_ii"](index, a1);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_viii(index, a1, a2, a3) {
 try {
  Module["dynCall_viii"](index, a1, a2, a3);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_v(index) {
 try {
  Module["dynCall_v"](index);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_iiiiiiiii(index, a1, a2, a3, a4, a5, a6, a7, a8) {
 try {
  return Module["dynCall_iiiiiiiii"](index, a1, a2, a3, a4, a5, a6, a7, a8);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_iiiii(index, a1, a2, a3, a4) {
 try {
  return Module["dynCall_iiiii"](index, a1, a2, a3, a4);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_viiiiii(index, a1, a2, a3, a4, a5, a6) {
 try {
  Module["dynCall_viiiiii"](index, a1, a2, a3, a4, a5, a6);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_iii(index, a1, a2) {
 try {
  return Module["dynCall_iii"](index, a1, a2);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_iiiiii(index, a1, a2, a3, a4, a5) {
 try {
  return Module["dynCall_iiiiii"](index, a1, a2, a3, a4, a5);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
function invoke_viiii(index, a1, a2, a3, a4) {
 try {
  Module["dynCall_viiii"](index, a1, a2, a3, a4);
 } catch (e) {
  if (typeof e !== "number" && e !== "longjmp") throw e;
  asm["setThrew"](1, 0);
 }
}
Module.asmGlobalArg = {
 "Math": Math,
 "Int8Array": Int8Array,
 "Int16Array": Int16Array,
 "Int32Array": Int32Array,
 "Uint8Array": Uint8Array,
 "Uint16Array": Uint16Array,
 "Uint32Array": Uint32Array,
 "Float32Array": Float32Array,
 "Float64Array": Float64Array,
 "NaN": NaN,
 "Infinity": Infinity,
 "byteLength": byteLength
};
Module.asmLibraryArg = {
 "abort": abort,
 "assert": assert,
 "invoke_iiiiiiii": invoke_iiiiiiii,
 "invoke_iiii": invoke_iiii,
 "invoke_viiiii": invoke_viiiii,
 "invoke_iiiiiid": invoke_iiiiiid,
 "invoke_vi": invoke_vi,
 "invoke_vii": invoke_vii,
 "invoke_iiiiiii": invoke_iiiiiii,
 "invoke_iiiiid": invoke_iiiiid,
 "invoke_ii": invoke_ii,
 "invoke_viii": invoke_viii,
 "invoke_v": invoke_v,
 "invoke_iiiiiiiii": invoke_iiiiiiiii,
 "invoke_iiiii": invoke_iiiii,
 "invoke_viiiiii": invoke_viiiiii,
 "invoke_iii": invoke_iii,
 "invoke_iiiiii": invoke_iiiiii,
 "invoke_viiii": invoke_viiii,
 "_pthread_cleanup_pop": _pthread_cleanup_pop,
 "_pthread_getspecific": _pthread_getspecific,
 "_pthread_cond_wait": _pthread_cond_wait,
 "___lock": ___lock,
 "_pthread_join": _pthread_join,
 "___resumeException": ___resumeException,
 "_pthread_key_create": _pthread_key_create,
 "_abort": _abort,
 "_llvm_fabs_f64": _llvm_fabs_f64,
 "___gxx_personality_v0": ___gxx_personality_v0,
 "___assert_fail": ___assert_fail,
 "___cxa_allocate_exception": ___cxa_allocate_exception,
 "_emscripten_get_now_is_monotonic": _emscripten_get_now_is_monotonic,
 "___buildEnvironment": ___buildEnvironment,
 "_emscripten_asm_const_ii": _emscripten_asm_const_ii,
 "_pthread_create": _pthread_create,
 "_emscripten_asm_const_i": _emscripten_asm_const_i,
 "_clock_gettime": _clock_gettime,
 "_emscripten_asm_const_did": _emscripten_asm_const_did,
 "_strftime_l": _strftime_l,
 "___setErrNo": ___setErrNo,
 "_emscripten_asm_const_id": _emscripten_asm_const_id,
 "_sbrk": _sbrk,
 "___cxa_begin_catch": ___cxa_begin_catch,
 "_emscripten_memcpy_big": _emscripten_memcpy_big,
 "_emscripten_asm_const_v": _emscripten_asm_const_v,
 "__ZSt18uncaught_exceptionv": __ZSt18uncaught_exceptionv,
 "__exit": __exit,
 "_strftime": _strftime,
 "__arraySum": __arraySum,
 "_emscripten_asm_const_di": _emscripten_asm_const_di,
 "_emscripten_asm_const_diiid": _emscripten_asm_const_diiid,
 "_pthread_cond_signal": _pthread_cond_signal,
 "_llvm_fabs_f32": _llvm_fabs_f32,
 "_pthread_mutex_destroy": _pthread_mutex_destroy,
 "_pthread_once": _pthread_once,
 "_getenv": _getenv,
 "_emscripten_asm_const_iid": _emscripten_asm_const_iid,
 "___syscall54": ___syscall54,
 "___unlock": ___unlock,
 "__isLeapYear": __isLeapYear,
 "_emscripten_asm_const_iii": _emscripten_asm_const_iii,
 "_pthread_setspecific": _pthread_setspecific,
 "___cxa_atexit": ___cxa_atexit,
 "_emscripten_asm_const_iiii": _emscripten_asm_const_iiii,
 "___cxa_throw": ___cxa_throw,
 "_sysconf": _sysconf,
 "__addDays": __addDays,
 "___syscall6": ___syscall6,
 "_pthread_cleanup_push": _pthread_cleanup_push,
 "___cxa_pure_virtual": ___cxa_pure_virtual,
 "_emscripten_get_now": _emscripten_get_now,
 "_emscripten_asm_const_dii": _emscripten_asm_const_dii,
 "_pthread_cond_destroy": _pthread_cond_destroy,
 "_emscripten_asm_const_diiiii": _emscripten_asm_const_diiiii,
 "_atexit": _atexit,
 "___syscall140": ___syscall140,
 "_exit": _exit,
 "___cxa_find_matching_catch": ___cxa_find_matching_catch,
 "___syscall145": ___syscall145,
 "___syscall146": ___syscall146,
 "STACKTOP": STACKTOP,
 "STACK_MAX": STACK_MAX,
 "tempDoublePtr": tempDoublePtr,
 "ABORT": ABORT,
 "cttz_i8": cttz_i8,
 "___dso_handle": ___dso_handle
};
// emscripten_START_ASM

var asm = (function(global,env,buffer) {

  'almost asm';
  
  
  var Int8View = global.Int8Array;
  var Int16View = global.Int16Array;
  var Int32View = global.Int32Array;
  var Uint8View = global.Uint8Array;
  var Uint16View = global.Uint16Array;
  var Uint32View = global.Uint32Array;
  var Float32View = global.Float32Array;
  var Float64View = global.Float64Array;
  var HEAP8 = new Int8View(buffer);
  var HEAP16 = new Int16View(buffer);
  var HEAP32 = new Int32View(buffer);
  var HEAPU8 = new Uint8View(buffer);
  var HEAPU16 = new Uint16View(buffer);
  var HEAPU32 = new Uint32View(buffer);
  var HEAPF32 = new Float32View(buffer);
  var HEAPF64 = new Float64View(buffer);
  var byteLength = global.byteLength;


  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var cttz_i8=env.cttz_i8|0;
  var ___dso_handle=env.___dso_handle|0;

  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var nan = global.NaN, inf = global.Infinity;
  var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;
  var tempRet0 = 0;

  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var Math_min=global.Math.min;
  var Math_clz32=global.Math.clz32;
  var abort=env.abort;
  var assert=env.assert;
  var invoke_iiiiiiii=env.invoke_iiiiiiii;
  var invoke_iiii=env.invoke_iiii;
  var invoke_viiiii=env.invoke_viiiii;
  var invoke_iiiiiid=env.invoke_iiiiiid;
  var invoke_vi=env.invoke_vi;
  var invoke_vii=env.invoke_vii;
  var invoke_iiiiiii=env.invoke_iiiiiii;
  var invoke_iiiiid=env.invoke_iiiiid;
  var invoke_ii=env.invoke_ii;
  var invoke_viii=env.invoke_viii;
  var invoke_v=env.invoke_v;
  var invoke_iiiiiiiii=env.invoke_iiiiiiiii;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_viiiiii=env.invoke_viiiiii;
  var invoke_iii=env.invoke_iii;
  var invoke_iiiiii=env.invoke_iiiiii;
  var invoke_viiii=env.invoke_viiii;
  var _pthread_cleanup_pop=env._pthread_cleanup_pop;
  var _pthread_getspecific=env._pthread_getspecific;
  var _pthread_cond_wait=env._pthread_cond_wait;
  var ___lock=env.___lock;
  var _pthread_join=env._pthread_join;
  var ___resumeException=env.___resumeException;
  var _pthread_key_create=env._pthread_key_create;
  var _abort=env._abort;
  var _llvm_fabs_f64=env._llvm_fabs_f64;
  var ___gxx_personality_v0=env.___gxx_personality_v0;
  var ___assert_fail=env.___assert_fail;
  var ___cxa_allocate_exception=env.___cxa_allocate_exception;
  var _emscripten_get_now_is_monotonic=env._emscripten_get_now_is_monotonic;
  var ___buildEnvironment=env.___buildEnvironment;
  var _emscripten_asm_const_ii=env._emscripten_asm_const_ii;
  var _pthread_create=env._pthread_create;
  var _emscripten_asm_const_i=env._emscripten_asm_const_i;
  var _clock_gettime=env._clock_gettime;
  var _emscripten_asm_const_did=env._emscripten_asm_const_did;
  var _strftime_l=env._strftime_l;
  var ___setErrNo=env.___setErrNo;
  var _emscripten_asm_const_id=env._emscripten_asm_const_id;
  var _sbrk=env._sbrk;
  var ___cxa_begin_catch=env.___cxa_begin_catch;
  var _emscripten_memcpy_big=env._emscripten_memcpy_big;
  var _emscripten_asm_const_v=env._emscripten_asm_const_v;
  var __ZSt18uncaught_exceptionv=env.__ZSt18uncaught_exceptionv;
  var __exit=env.__exit;
  var _strftime=env._strftime;
  var __arraySum=env.__arraySum;
  var _emscripten_asm_const_di=env._emscripten_asm_const_di;
  var _emscripten_asm_const_diiid=env._emscripten_asm_const_diiid;
  var _pthread_cond_signal=env._pthread_cond_signal;
  var _llvm_fabs_f32=env._llvm_fabs_f32;
  var _pthread_mutex_destroy=env._pthread_mutex_destroy;
  var _pthread_once=env._pthread_once;
  var _getenv=env._getenv;
  var _emscripten_asm_const_iid=env._emscripten_asm_const_iid;
  var ___syscall54=env.___syscall54;
  var ___unlock=env.___unlock;
  var __isLeapYear=env.__isLeapYear;
  var _emscripten_asm_const_iii=env._emscripten_asm_const_iii;
  var _pthread_setspecific=env._pthread_setspecific;
  var ___cxa_atexit=env.___cxa_atexit;
  var _emscripten_asm_const_iiii=env._emscripten_asm_const_iiii;
  var ___cxa_throw=env.___cxa_throw;
  var _sysconf=env._sysconf;
  var __addDays=env.__addDays;
  var ___syscall6=env.___syscall6;
  var _pthread_cleanup_push=env._pthread_cleanup_push;
  var ___cxa_pure_virtual=env.___cxa_pure_virtual;
  var _emscripten_get_now=env._emscripten_get_now;
  var _emscripten_asm_const_dii=env._emscripten_asm_const_dii;
  var _pthread_cond_destroy=env._pthread_cond_destroy;
  var _emscripten_asm_const_diiiii=env._emscripten_asm_const_diiiii;
  var _atexit=env._atexit;
  var ___syscall140=env.___syscall140;
  var _exit=env._exit;
  var ___cxa_find_matching_catch=env.___cxa_find_matching_catch;
  var ___syscall145=env.___syscall145;
  var ___syscall146=env.___syscall146;
  var tempFloat = 0.0;

function _emscripten_replace_memory(newBuffer) {
  if ((byteLength(newBuffer) & 0xffffff || byteLength(newBuffer) <= 0xffffff) || byteLength(newBuffer) > 0x80000000) return false;
  HEAP8 = new Int8View(newBuffer);
  HEAP16 = new Int16View(newBuffer);
  HEAP32 = new Int32View(newBuffer);
  HEAPU8 = new Uint8View(newBuffer);
  HEAPU16 = new Uint16View(newBuffer);
  HEAPU32 = new Uint32View(newBuffer);
  HEAPF32 = new Float32View(newBuffer);
  HEAPF64 = new Float64View(newBuffer);
  buffer = newBuffer;
  return true;
}

// emscripten_START_FUNCS

function __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i135, i127, i133) {
 i135 = i135 | 0;
 i127 = i127 | 0;
 i133 = i133 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i52 = 0, i53 = 0, i54 = 0, i55 = 0, i56 = 0, i57 = 0, i58 = 0, i59 = 0, i60 = 0, i61 = 0, i62 = 0, i63 = 0, i64 = 0, i65 = 0, i66 = 0, i67 = 0, i68 = 0, i69 = 0, i70 = 0, i71 = 0, i72 = 0, i73 = 0, i74 = 0, i75 = 0, i76 = 0, i77 = 0, i78 = 0, i79 = 0, i80 = 0, i81 = 0, i82 = 0, i83 = 0, i84 = 0, i85 = 0, i86 = 0, i87 = 0, i88 = 0, i89 = 0, i90 = 0, i91 = 0, i92 = 0, i93 = 0, i94 = 0, i95 = 0, i96 = 0, i97 = 0, i98 = 0, i99 = 0, i100 = 0, i101 = 0, i102 = 0, i103 = 0, i104 = 0, i105 = 0, i106 = 0, i107 = 0, i108 = 0, i109 = 0, i110 = 0, i111 = 0, i112 = 0, i113 = 0, i114 = 0, i115 = 0, i116 = 0, i117 = 0, i118 = 0, i119 = 0, i120 = 0, i121 = 0, i122 = 0, i123 = 0, i124 = 0, i125 = 0, i126 = 0, i128 = 0, i129 = 0, i130 = 0, i131 = 0, i132 = 0, i134 = 0, i136 = 0, i137 = 0, i138 = 0, i139 = 0, i140 = 0;
 i140 = STACKTOP;
 STACKTOP = STACKTOP + 1104 | 0;
 i139 = i140 + 1072 | 0;
 i138 = i140 + 1048 | 0;
 i137 = i140 + 1032 | 0;
 i136 = i140 + 1020 | 0;
 i132 = i140 + 1008 | 0;
 i131 = i140 + 984 | 0;
 i134 = i140 + 972 | 0;
 i123 = i140 + 596 | 0;
 i124 = i140 + 572 | 0;
 i126 = i140 + 548 | 0;
 i125 = i140 + 524 | 0;
 i128 = i140 + 488 | 0;
 i129 = i140 + 460 | 0;
 i10 = i140 + 960 | 0;
 i13 = i140 + 948 | 0;
 i16 = i140 + 936 | 0;
 i17 = i140 + 924 | 0;
 i18 = i140 + 912 | 0;
 i19 = i140 + 900 | 0;
 i20 = i140 + 888 | 0;
 i99 = i140 + 876 | 0;
 i100 = i140 + 864 | 0;
 i101 = i140 + 852 | 0;
 i102 = i140 + 840 | 0;
 i23 = i140 + 828 | 0;
 i103 = i140 + 816 | 0;
 i104 = i140 + 804 | 0;
 i105 = i140 + 792 | 0;
 i106 = i140 + 780 | 0;
 i25 = i140 + 768 | 0;
 i26 = i140 + 756 | 0;
 i27 = i140 + 744 | 0;
 i28 = i140 + 732 | 0;
 i29 = i140 + 720 | 0;
 i30 = i140 + 708 | 0;
 i31 = i140 + 696 | 0;
 i107 = i140 + 672 | 0;
 i108 = i140 + 656 | 0;
 i109 = i140 + 644 | 0;
 i110 = i140 + 632 | 0;
 i111 = i140 + 620 | 0;
 i32 = i140 + 608 | 0;
 i33 = i140 + 584 | 0;
 i34 = i140 + 560 | 0;
 i35 = i140 + 536 | 0;
 i36 = i140 + 512 | 0;
 i37 = i140 + 472 | 0;
 i38 = i140 + 448 | 0;
 i39 = i140 + 436 | 0;
 i64 = i140 + 424 | 0;
 i80 = i140 + 400 | 0;
 i81 = i140 + 384 | 0;
 i82 = i140 + 372 | 0;
 i83 = i140 + 360 | 0;
 i42 = i140 + 348 | 0;
 i43 = i140 + 336 | 0;
 i44 = i140 + 324 | 0;
 i45 = i140 + 312 | 0;
 i46 = i140 + 300 | 0;
 i47 = i140 + 288 | 0;
 i50 = i140 + 276 | 0;
 i51 = i140 + 264 | 0;
 i52 = i140 + 252 | 0;
 i65 = i140 + 240 | 0;
 i84 = i140 + 216 | 0;
 i85 = i140 + 204 | 0;
 i86 = i140 + 192 | 0;
 i87 = i140 + 180 | 0;
 i55 = i140 + 168 | 0;
 i116 = i140 + 144 | 0;
 i117 = i140 + 132 | 0;
 i118 = i140 + 120 | 0;
 i119 = i140 + 108 | 0;
 i120 = i140 + 96 | 0;
 i121 = i140 + 84 | 0;
 i122 = i140 + 72 | 0;
 i56 = i140 + 60 | 0;
 i57 = i140 + 48 | 0;
 i58 = i140 + 36 | 0;
 i59 = i140 + 24 | 0;
 i88 = i140;
 i113 = i127;
 i60 = i113 - i135 | 0;
 L1 : do if ((i60 | 0) > 1) {
  i61 = (i60 | 0) > 3;
  if (i61 ? (HEAP8[i135 >> 0] | 0) == 103 : 0) {
   i62 = (HEAP8[i135 + 1 >> 0] | 0) == 115;
   i89 = i62;
   i62 = i62 ? i135 + 2 | 0 : i135;
  } else {
   i89 = 0;
   i62 = i135;
  }
  do switch (HEAP8[i62 >> 0] | 0) {
  case 76:
   {
    i1 = __ZN10__cxxabiv112_GLOBAL__N_118parse_expr_primaryINS0_2DbEEEPKcS4_S4_RT_(i135, i127, i133) | 0;
    break L1;
   }
  case 84:
   {
    i1 = __ZN10__cxxabiv112_GLOBAL__N_120parse_template_paramINS0_2DbEEEPKcS4_S4_RT_(i135, i127, i133) | 0;
    break L1;
   }
  case 102:
   {
    i1 = __ZN10__cxxabiv112_GLOBAL__N_120parse_function_paramINS0_2DbEEEPKcS4_S4_RT_(i135, i127, i133) | 0;
    break L1;
   }
  case 97:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 97:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i10 >> 2] = 0;
     HEAP32[i10 + 4 >> 2] = 0;
     HEAP32[i10 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i10, 57008, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i10, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i10);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 100:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i13 >> 2] = 0;
     HEAP32[i13 + 4 >> 2] = 0;
     HEAP32[i13 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i13, 57019, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_prefix_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i13, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i13);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 110:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i16 >> 2] = 0;
     HEAP32[i16 + 4 >> 2] = 0;
     HEAP32[i16 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i16, 57019, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i16, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i16);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 78:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i17 >> 2] = 0;
     HEAP32[i17 + 4 >> 2] = 0;
     HEAP32[i17 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i17, 57021, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i17, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i17);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 83:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i18 >> 2] = 0;
     HEAP32[i18 + 4 >> 2] = 0;
     HEAP32[i18 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i18, 57024, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i18, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i18);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 116:
    {
     if (((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 97 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 116 : 0) ? (i136 = i135 + 2 | 0, i92 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i136, i127, i133) | 0, (i92 | 0) != (i136 | 0)) : 0) ? (i90 = HEAP32[i133 + 4 >> 2] | 0, (HEAP32[i133 >> 2] | 0) != (i90 | 0)) : 0) {
      i4 = i90 + -24 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i137, i4);
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i137, 0, 57026) | 0;
      HEAP32[i138 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i138 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i138 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i138, 56966) | 0;
      HEAP32[i139 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i139 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i139 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = i4 + 11 | 0;
      do if ((HEAP8[i1 >> 0] | 0) < 0) {
       HEAP8[HEAP32[i4 >> 2] >> 0] = 0;
       i3 = i90 + -20 | 0;
       HEAP32[i3 >> 2] = 0;
       i2 = HEAP8[i1 >> 0] | 0;
       if (i2 << 24 >> 24 < 0) {
        if ((HEAP32[i90 + -16 >> 2] & 2147483647 | 0) == 11) break;
        i136 = HEAP32[i4 >> 2] | 0;
        HEAP8[i4 >> 0] = HEAP8[i136 >> 0] | 0;
        _free(i136);
        HEAP8[i1 >> 0] = 0;
        break;
       } else {
        i1 = i2 & 255;
        if ((i2 & 255) < 11) break;
        i135 = i1 + 16 & 496;
        i136 = _malloc(i135) | 0;
        _memcpy(i136 | 0, i4 | 0, i1 + 1 | 0) | 0;
        HEAP32[i90 + -16 >> 2] = i135 | -2147483648;
        HEAP32[i3 >> 2] = i1;
        HEAP32[i4 >> 2] = i136;
        break;
       }
      } else {
       HEAP8[i4 >> 0] = 0;
       HEAP8[i1 >> 0] = 0;
      } while (0);
      HEAP32[i4 >> 2] = HEAP32[i139 >> 2];
      HEAP32[i4 + 4 >> 2] = HEAP32[i139 + 4 >> 2];
      HEAP32[i4 + 8 >> 2] = HEAP32[i139 + 8 >> 2];
      i1 = 0;
      while (1) {
       if ((i1 | 0) == 3) break;
       HEAP32[i139 + (i1 << 2) >> 2] = 0;
       i1 = i1 + 1 | 0;
      }
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
      i1 = i92;
     } else i1 = i135;
     break L1;
    }
   case 122:
    {
     if (((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 97 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 122 : 0) ? (i136 = i135 + 2 | 0, i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i136, i127, i133) | 0, (i1 | 0) != (i136 | 0)) : 0) ? (i91 = HEAP32[i133 + 4 >> 2] | 0, (HEAP32[i133 >> 2] | 0) != (i91 | 0)) : 0) {
      i5 = i91 + -24 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i137, i5);
      i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i137, 0, 57026) | 0;
      HEAP32[i138 >> 2] = HEAP32[i2 >> 2];
      HEAP32[i138 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
      HEAP32[i138 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
      i3 = 0;
      while (1) {
       if ((i3 | 0) == 3) break;
       HEAP32[i2 + (i3 << 2) >> 2] = 0;
       i3 = i3 + 1 | 0;
      }
      i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i138, 56966) | 0;
      HEAP32[i139 >> 2] = HEAP32[i2 >> 2];
      HEAP32[i139 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
      HEAP32[i139 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
      i3 = 0;
      while (1) {
       if ((i3 | 0) == 3) break;
       HEAP32[i2 + (i3 << 2) >> 2] = 0;
       i3 = i3 + 1 | 0;
      }
      i2 = i5 + 11 | 0;
      do if ((HEAP8[i2 >> 0] | 0) < 0) {
       HEAP8[HEAP32[i5 >> 2] >> 0] = 0;
       i4 = i91 + -20 | 0;
       HEAP32[i4 >> 2] = 0;
       i3 = HEAP8[i2 >> 0] | 0;
       if (i3 << 24 >> 24 < 0) {
        if ((HEAP32[i91 + -16 >> 2] & 2147483647 | 0) == 11) break;
        i136 = HEAP32[i5 >> 2] | 0;
        HEAP8[i5 >> 0] = HEAP8[i136 >> 0] | 0;
        _free(i136);
        HEAP8[i2 >> 0] = 0;
        break;
       } else {
        i2 = i3 & 255;
        if ((i3 & 255) < 11) break;
        i135 = i2 + 16 & 496;
        i136 = _malloc(i135) | 0;
        _memcpy(i136 | 0, i5 | 0, i2 + 1 | 0) | 0;
        HEAP32[i91 + -16 >> 2] = i135 | -2147483648;
        HEAP32[i4 >> 2] = i2;
        HEAP32[i5 >> 2] = i136;
        break;
       }
      } else {
       HEAP8[i5 >> 0] = 0;
       HEAP8[i2 >> 0] = 0;
      } while (0);
      HEAP32[i5 >> 2] = HEAP32[i139 >> 2];
      HEAP32[i5 + 4 >> 2] = HEAP32[i139 + 4 >> 2];
      HEAP32[i5 + 8 >> 2] = HEAP32[i139 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i139 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
     } else i1 = i135;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 99:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 99:
    {
     if ((((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 99 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 99 : 0) ? (i130 = i135 + 2 | 0, i21 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i130, i127, i133) | 0, (i21 | 0) != (i130 | 0)) : 0) ? (i97 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i21, i127, i133) | 0, (i97 | 0) != (i21 | 0)) : 0) ? (i71 = i133 + 4 | 0, i22 = HEAP32[i71 >> 2] | 0, ((i22 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) : 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i22 + -24 | 0);
      i1 = HEAP32[i71 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i135 = i3 + -24 | 0;
       HEAP32[i71 >> 2] = i135;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i135);
       i3 = HEAP32[i71 >> 2] | 0;
      }
      i3 = i1 + -48 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i134, i3);
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i134, 0, 57036) | 0;
      HEAP32[i131 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i131 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i131 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i131, 57048) | 0;
      HEAP32[i132 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i132 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i132 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = HEAP8[i139 + 11 >> 0] | 0;
      i2 = i1 << 24 >> 24 < 0;
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i132, i2 ? HEAP32[i139 >> 2] | 0 : i139, i2 ? HEAP32[i139 + 4 >> 2] | 0 : i1 & 255) | 0;
      HEAP32[i136 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i136 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i136 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i136, 56966) | 0;
      HEAP32[i137 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i137 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i137 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i138, i137);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i3, i138);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i132);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i131);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i134);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      i1 = i97;
     } else i1 = i135;
     break L1;
    }
   case 108:
    {
     L108 : do if ((((i61 ? (HEAP8[i135 >> 0] | 0) == 99 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 108 : 0) ? (i137 = i135 + 2 | 0, i2 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i137, i127, i133) | 0, !((i2 | 0) == (i137 | 0) | (i2 | 0) == (i127 | 0))) : 0) ? (i114 = i133 + 4 | 0, i24 = HEAP32[i114 >> 2] | 0, (HEAP32[i133 >> 2] | 0) != (i24 | 0)) : 0) {
      i137 = i24 + -12 | 0;
      i6 = HEAP8[i137 + 11 >> 0] | 0;
      i1 = i6 << 24 >> 24 < 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i24 + -24 | 0, i1 ? HEAP32[i137 >> 2] | 0 : i137, i1 ? HEAP32[i24 + -8 >> 2] | 0 : i6 & 255) | 0;
      i6 = HEAP32[i114 >> 2] | 0;
      HEAP32[i139 >> 2] = 0;
      HEAP32[i139 + 4 >> 2] = 0;
      HEAP32[i139 + 8 >> 2] = 0;
      i1 = 0;
      while (1) {
       if ((i1 | 0) == 3) break;
       HEAP32[i139 + (i1 << 2) >> 2] = 0;
       i1 = i1 + 1 | 0;
      }
      i4 = i6 + -12 | 0;
      i1 = i4 + 11 | 0;
      do if ((HEAP8[i1 >> 0] | 0) < 0) {
       HEAP8[HEAP32[i4 >> 2] >> 0] = 0;
       i5 = i6 + -8 | 0;
       HEAP32[i5 >> 2] = 0;
       i3 = HEAP8[i1 >> 0] | 0;
       if (i3 << 24 >> 24 < 0) {
        if ((HEAP32[i6 + -4 >> 2] & 2147483647 | 0) == 11) break;
        i137 = HEAP32[i4 >> 2] | 0;
        HEAP8[i4 >> 0] = HEAP8[i137 >> 0] | 0;
        _free(i137);
        HEAP8[i1 >> 0] = 0;
        break;
       } else {
        i1 = i3 & 255;
        if ((i3 & 255) < 11) break;
        i136 = i1 + 16 & 496;
        i137 = _malloc(i136) | 0;
        _memcpy(i137 | 0, i4 | 0, i1 + 1 | 0) | 0;
        HEAP32[i6 + -4 >> 2] = i136 | -2147483648;
        HEAP32[i5 >> 2] = i1;
        HEAP32[i4 >> 2] = i137;
        break;
       }
      } else {
       HEAP8[i4 >> 0] = 0;
       HEAP8[i1 >> 0] = 0;
      } while (0);
      HEAP32[i4 >> 2] = HEAP32[i139 >> 2];
      HEAP32[i4 + 4 >> 2] = HEAP32[i139 + 4 >> 2];
      HEAP32[i4 + 8 >> 2] = HEAP32[i139 + 8 >> 2];
      i1 = 0;
      while (1) {
       if ((i1 | 0) == 3) break;
       HEAP32[i139 + (i1 << 2) >> 2] = 0;
       i1 = i1 + 1 | 0;
      }
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i114 >> 2] | 0) + -24 | 0, 56964) | 0;
      i6 = i138 + 11 | 0;
      i7 = i138 + 4 | 0;
      while (1) {
       if ((HEAP8[i2 >> 0] | 0) == 69) break;
       i5 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i2, i127, i133) | 0;
       if ((i5 | 0) == (i2 | 0) | (i5 | 0) == (i127 | 0)) {
        i1 = i135;
        break L108;
       }
       i1 = HEAP32[i114 >> 2] | 0;
       if ((HEAP32[i133 >> 2] | 0) == (i1 | 0)) {
        i1 = i135;
        break L108;
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i138, i1 + -24 | 0);
       i3 = HEAP32[i114 >> 2] | 0;
       i4 = i3 + -24 | 0;
       i1 = i3;
       while (1) {
        if ((i1 | 0) == (i4 | 0)) break;
        i139 = i1 + -24 | 0;
        HEAP32[i114 >> 2] = i139;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
        i1 = HEAP32[i114 >> 2] | 0;
       }
       i2 = HEAP8[i6 >> 0] | 0;
       i1 = i2 << 24 >> 24 < 0;
       i2 = i1 ? HEAP32[i7 >> 2] | 0 : i2 & 255;
       if (i2 | 0) {
        if ((HEAP32[i133 >> 2] | 0) == (i4 | 0)) {
         i130 = 114;
         break;
        }
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i3 + -48 | 0, i1 ? HEAP32[i138 >> 2] | 0 : i138, i2) | 0;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
       i2 = i5;
      }
      if ((i130 | 0) == 114) {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
       i1 = i135;
       break;
      }
      i1 = HEAP32[i114 >> 2] | 0;
      if ((HEAP32[i133 >> 2] | 0) != (i1 | 0)) {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i1 + -24 | 0, 56966) | 0;
       i1 = i2 + 1 | 0;
      } else i1 = i135;
     } else i1 = i135; while (0);
     break L1;
    }
   case 109:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i19 >> 2] = 0;
     HEAP32[i19 + 4 >> 2] = 0;
     HEAP32[i19 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i19, 57051, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i19, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i19);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 111:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i20 >> 2] = 0;
     HEAP32[i20 + 4 >> 2] = 0;
     HEAP32[i20 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i20, 57053, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_prefix_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i20, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i20);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 118:
    {
     L152 : do if ((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 99 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 118 : 0) ? (i129 = i133 + 63 | 0, i128 = HEAP8[i129 >> 0] | 0, HEAP8[i129 >> 0] = 0, i130 = i135 + 2 | 0, i63 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i130, i127, i133) | 0, HEAP8[i129 >> 0] = i128, !((i63 | 0) == (i130 | 0) | (i63 | 0) == (i127 | 0))) : 0) {
      if ((HEAP8[i63 >> 0] | 0) != 95) {
       i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i63, i127, i133) | 0;
       if ((i1 | 0) == (i63 | 0)) {
        i1 = i135;
        break;
       }
      } else {
       i1 = i63 + 1 | 0;
       if ((i1 | 0) == (i127 | 0)) {
        i1 = i135;
        break;
       }
       i2 = HEAP8[i1 >> 0] | 0;
       L160 : do if (i2 << 24 >> 24 == 69) {
        i4 = i133 + 4 | 0;
        i3 = HEAP32[i4 >> 2] | 0;
        i130 = HEAP32[i133 + 8 >> 2] | 0;
        i5 = i130;
        if (i3 >>> 0 < i130 >>> 0) {
         HEAP32[i3 >> 2] = 0;
         HEAP32[i3 + 4 >> 2] = 0;
         HEAP32[i3 + 8 >> 2] = 0;
         HEAP32[i3 + 12 >> 2] = 0;
         HEAP32[i3 + 16 >> 2] = 0;
         HEAP32[i3 + 20 >> 2] = 0;
         i2 = 0;
         while (1) {
          if ((i2 | 0) == 3) break;
          HEAP32[i3 + (i2 << 2) >> 2] = 0;
          i2 = i2 + 1 | 0;
         }
         i2 = i3 + 12 | 0;
         HEAP32[i2 >> 2] = 0;
         HEAP32[i2 + 4 >> 2] = 0;
         HEAP32[i2 + 8 >> 2] = 0;
         i3 = 0;
         while (1) {
          if ((i3 | 0) == 3) break;
          HEAP32[i2 + (i3 << 2) >> 2] = 0;
          i3 = i3 + 1 | 0;
         }
         HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 24;
         break;
        }
        i2 = HEAP32[i133 >> 2] | 0;
        i4 = (i3 - i2 | 0) / 24 | 0;
        i3 = i4 + 1 | 0;
        if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i133);
        i2 = (i5 - i2 | 0) / 24 | 0;
        if (i2 >>> 0 < 89478485) {
         i2 = i2 << 1;
         i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
        } else i2 = 178956970;
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i139, i2, i4, i133 + 12 | 0);
        i4 = i139 + 8 | 0;
        i5 = HEAP32[i4 >> 2] | 0;
        HEAP32[i5 >> 2] = 0;
        HEAP32[i5 + 4 >> 2] = 0;
        HEAP32[i5 + 8 >> 2] = 0;
        HEAP32[i5 + 12 >> 2] = 0;
        HEAP32[i5 + 16 >> 2] = 0;
        HEAP32[i5 + 20 >> 2] = 0;
        i2 = 0;
        while (1) {
         if ((i2 | 0) == 3) break;
         HEAP32[i5 + (i2 << 2) >> 2] = 0;
         i2 = i2 + 1 | 0;
        }
        i2 = i5 + 12 | 0;
        HEAP32[i2 >> 2] = 0;
        HEAP32[i2 + 4 >> 2] = 0;
        HEAP32[i2 + 8 >> 2] = 0;
        i3 = 0;
        while (1) {
         if ((i3 | 0) == 3) break;
         HEAP32[i2 + (i3 << 2) >> 2] = 0;
         i3 = i3 + 1 | 0;
        }
        HEAP32[i4 >> 2] = i5 + 24;
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i133, i139);
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i139);
       } else while (1) {
        if (i2 << 24 >> 24 == 69) break L160;
        i3 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i1, i127, i133) | 0;
        i2 = (i3 | 0) == (i1 | 0) | (i3 | 0) == (i127 | 0);
        if (i2) {
         i1 = i135;
         break L152;
        }
        i2 = HEAP8[(i2 ? i1 : i3) >> 0] | 0;
        i1 = i3;
       } while (0);
       i1 = i1 + 1 | 0;
      }
      i5 = i133 + 4 | 0;
      i2 = HEAP32[i5 >> 2] | 0;
      if (((i2 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) {
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i2 + -24 | 0);
       i2 = HEAP32[i5 >> 2] | 0;
       i3 = i2 + -24 | 0;
       i4 = i2;
       while (1) {
        if ((i4 | 0) == (i3 | 0)) break;
        i135 = i4 + -24 | 0;
        HEAP32[i5 >> 2] = i135;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i135);
        i4 = HEAP32[i5 >> 2] | 0;
       }
       i4 = i2 + -48 | 0;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i134, i4);
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i134, 0, 56964) | 0;
       HEAP32[i131 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i131 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i131 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i131, 57055) | 0;
       HEAP32[i132 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i132 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i132 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i2 = HEAP8[i139 + 11 >> 0] | 0;
       i3 = i2 << 24 >> 24 < 0;
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i132, i3 ? HEAP32[i139 >> 2] | 0 : i139, i3 ? HEAP32[i139 + 4 >> 2] | 0 : i2 & 255) | 0;
       HEAP32[i136 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i136 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i136 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i136, 56966) | 0;
       HEAP32[i137 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i137 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i137 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i138, i137);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i4, i138);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i138);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i132);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i131);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i134);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      } else i1 = i135;
     } else i1 = i135; while (0);
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 100:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 97:
    {
     i139 = i62 + 2 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i139, i127, i133) | 0;
     if ((i1 | 0) == (i139 | 0)) {
      i1 = i135;
      break L1;
     }
     i4 = i133 + 4 | 0;
     i6 = HEAP32[i4 >> 2] | 0;
     if ((HEAP32[i133 >> 2] | 0) == (i6 | 0)) {
      i1 = i135;
      break L1;
     }
     i5 = i6 + -24 | 0;
     HEAP32[i101 >> 2] = 0;
     HEAP32[i101 + 4 >> 2] = 0;
     HEAP32[i101 + 8 >> 2] = 0;
     L221 : do if (i89) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i101, 57058, 2); else {
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break L221;
       HEAP32[i101 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
     } while (0);
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i101, 57061) | 0;
     HEAP32[i100 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i100 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i100 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i102, (HEAP32[i4 >> 2] | 0) + -24 | 0);
     i2 = HEAP8[i102 + 11 >> 0] | 0;
     i3 = i2 << 24 >> 24 < 0;
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i100, i3 ? HEAP32[i102 >> 2] | 0 : i102, i3 ? HEAP32[i102 + 4 >> 2] | 0 : i2 & 255) | 0;
     HEAP32[i99 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i99 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i99 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     i2 = i5 + 11 | 0;
     do if ((HEAP8[i2 >> 0] | 0) < 0) {
      HEAP8[HEAP32[i5 >> 2] >> 0] = 0;
      i4 = i6 + -20 | 0;
      HEAP32[i4 >> 2] = 0;
      i3 = HEAP8[i2 >> 0] | 0;
      if (i3 << 24 >> 24 < 0) {
       if ((HEAP32[i6 + -16 >> 2] & 2147483647 | 0) == 11) break;
       i139 = HEAP32[i5 >> 2] | 0;
       HEAP8[i5 >> 0] = HEAP8[i139 >> 0] | 0;
       _free(i139);
       HEAP8[i2 >> 0] = 0;
       break;
      } else {
       i2 = i3 & 255;
       if ((i3 & 255) < 11) break;
       i138 = i2 + 16 & 496;
       i139 = _malloc(i138) | 0;
       _memcpy(i139 | 0, i5 | 0, i2 + 1 | 0) | 0;
       HEAP32[i6 + -16 >> 2] = i138 | -2147483648;
       HEAP32[i4 >> 2] = i2;
       HEAP32[i5 >> 2] = i139;
       break;
      }
     } else {
      HEAP8[i5 >> 0] = 0;
      HEAP8[i2 >> 0] = 0;
     } while (0);
     HEAP32[i5 >> 2] = HEAP32[i99 >> 2];
     HEAP32[i5 + 4 >> 2] = HEAP32[i99 + 4 >> 2];
     HEAP32[i5 + 8 >> 2] = HEAP32[i99 + 8 >> 2];
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i99 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i99);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i102);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i100);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i101);
     break L1;
    }
   case 99:
    {
     if ((((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 100 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 99 : 0) ? (i130 = i135 + 2 | 0, i40 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i130, i127, i133) | 0, (i40 | 0) != (i130 | 0)) : 0) ? (i98 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i40, i127, i133) | 0, (i98 | 0) != (i40 | 0)) : 0) ? (i72 = i133 + 4 | 0, i41 = HEAP32[i72 >> 2] | 0, ((i41 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) : 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i41 + -24 | 0);
      i1 = HEAP32[i72 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i135 = i3 + -24 | 0;
       HEAP32[i72 >> 2] = i135;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i135);
       i3 = HEAP32[i72 >> 2] | 0;
      }
      i3 = i1 + -48 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i134, i3);
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i134, 0, 57071) | 0;
      HEAP32[i131 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i131 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i131 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i131, 57048) | 0;
      HEAP32[i132 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i132 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i132 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = HEAP8[i139 + 11 >> 0] | 0;
      i2 = i1 << 24 >> 24 < 0;
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i132, i2 ? HEAP32[i139 >> 2] | 0 : i139, i2 ? HEAP32[i139 + 4 >> 2] | 0 : i1 & 255) | 0;
      HEAP32[i136 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i136 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i136 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i136, 56966) | 0;
      HEAP32[i137 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i137 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i137 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i138, i137);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i3, i138);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i132);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i131);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i134);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      i1 = i98;
     } else i1 = i135;
     break L1;
    }
   case 101:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i23 >> 2] = 0;
     HEAP32[i23 + 4 >> 2] = 0;
     HEAP32[i23 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i23, 57085, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_prefix_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i23, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i23);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 108:
    {
     i139 = i62 + 2 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i139, i127, i133) | 0;
     if ((i1 | 0) == (i139 | 0)) {
      i1 = i135;
      break L1;
     }
     i4 = i133 + 4 | 0;
     i6 = HEAP32[i4 >> 2] | 0;
     if ((HEAP32[i133 >> 2] | 0) == (i6 | 0)) {
      i1 = i135;
      break L1;
     }
     i5 = i6 + -24 | 0;
     HEAP32[i105 >> 2] = 0;
     HEAP32[i105 + 4 >> 2] = 0;
     HEAP32[i105 + 8 >> 2] = 0;
     L282 : do if (i89) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i105, 57058, 2); else {
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break L282;
       HEAP32[i105 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
     } while (0);
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i105, 57087) | 0;
     HEAP32[i104 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i104 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i104 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i106, (HEAP32[i4 >> 2] | 0) + -24 | 0);
     i2 = HEAP8[i106 + 11 >> 0] | 0;
     i3 = i2 << 24 >> 24 < 0;
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i104, i3 ? HEAP32[i106 >> 2] | 0 : i106, i3 ? HEAP32[i106 + 4 >> 2] | 0 : i2 & 255) | 0;
     HEAP32[i103 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i103 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i103 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     i2 = i5 + 11 | 0;
     do if ((HEAP8[i2 >> 0] | 0) < 0) {
      HEAP8[HEAP32[i5 >> 2] >> 0] = 0;
      i4 = i6 + -20 | 0;
      HEAP32[i4 >> 2] = 0;
      i3 = HEAP8[i2 >> 0] | 0;
      if (i3 << 24 >> 24 < 0) {
       if ((HEAP32[i6 + -16 >> 2] & 2147483647 | 0) == 11) break;
       i139 = HEAP32[i5 >> 2] | 0;
       HEAP8[i5 >> 0] = HEAP8[i139 >> 0] | 0;
       _free(i139);
       HEAP8[i2 >> 0] = 0;
       break;
      } else {
       i2 = i3 & 255;
       if ((i3 & 255) < 11) break;
       i138 = i2 + 16 & 496;
       i139 = _malloc(i138) | 0;
       _memcpy(i139 | 0, i5 | 0, i2 + 1 | 0) | 0;
       HEAP32[i6 + -16 >> 2] = i138 | -2147483648;
       HEAP32[i4 >> 2] = i2;
       HEAP32[i5 >> 2] = i139;
       break;
      }
     } else {
      HEAP8[i5 >> 0] = 0;
      HEAP8[i2 >> 0] = 0;
     } while (0);
     HEAP32[i5 >> 2] = HEAP32[i103 >> 2];
     HEAP32[i5 + 4 >> 2] = HEAP32[i103 + 4 >> 2];
     HEAP32[i5 + 8 >> 2] = HEAP32[i103 + 8 >> 2];
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i103 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i103);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i106);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i104);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i105);
     break L1;
    }
   case 110:
    {
     i1 = __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i135, i127, i133) | 0;
     break L1;
    }
   case 115:
    {
     if ((((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 100 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 115 : 0) ? (i137 = i135 + 2 | 0, i48 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i137, i127, i133) | 0, (i48 | 0) != (i137 | 0)) : 0) ? (i73 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i48, i127, i133) | 0, (i73 | 0) != (i48 | 0)) : 0) ? (i74 = i133 + 4 | 0, i49 = HEAP32[i74 >> 2] | 0, ((i49 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) : 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i49 + -24 | 0);
      i1 = HEAP32[i74 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i137 = i3 + -24 | 0;
       HEAP32[i74 >> 2] = i137;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i137);
       i3 = HEAP32[i74 >> 2] | 0;
      }
      __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i138, 58002, i139);
      i137 = HEAP8[i138 + 11 >> 0] | 0;
      i136 = i137 << 24 >> 24 < 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i136 ? HEAP32[i138 >> 2] | 0 : i138, i136 ? HEAP32[i138 + 4 >> 2] | 0 : i137 & 255) | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      i1 = i73;
     } else i1 = i135;
     break L1;
    }
   case 116:
    {
     if ((((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 100 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 116 : 0) ? (i137 = i135 + 2 | 0, i53 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i137, i127, i133) | 0, (i53 | 0) != (i137 | 0)) : 0) ? (i75 = __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i53, i127, i133) | 0, (i75 | 0) != (i53 | 0)) : 0) ? (i76 = i133 + 4 | 0, i54 = HEAP32[i76 >> 2] | 0, ((i54 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) : 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i54 + -24 | 0);
      i1 = HEAP32[i76 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i137 = i3 + -24 | 0;
       HEAP32[i76 >> 2] = i137;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i137);
       i3 = HEAP32[i76 >> 2] | 0;
      }
      __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i138, 58005, i139);
      i137 = HEAP8[i138 + 11 >> 0] | 0;
      i136 = i137 << 24 >> 24 < 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i136 ? HEAP32[i138 >> 2] | 0 : i138, i136 ? HEAP32[i138 + 4 >> 2] | 0 : i137 & 255) | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      i1 = i75;
     } else i1 = i135;
     break L1;
    }
   case 118:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i25 >> 2] = 0;
     HEAP32[i25 + 4 >> 2] = 0;
     HEAP32[i25 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i25, 58007, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i25, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i25);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 86:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i26 >> 2] = 0;
     HEAP32[i26 + 4 >> 2] = 0;
     HEAP32[i26 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i26, 58009, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i26, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i26);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 101:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 111:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i27 >> 2] = 0;
     HEAP32[i27 + 4 >> 2] = 0;
     HEAP32[i27 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i27, 58012, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i27, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i27);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 79:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i28 >> 2] = 0;
     HEAP32[i28 + 4 >> 2] = 0;
     HEAP32[i28 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i28, 58014, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i28, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i28);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 113:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i29 >> 2] = 0;
     HEAP32[i29 + 4 >> 2] = 0;
     HEAP32[i29 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i29, 58017, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i29, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i29);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 103:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 101:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i30 >> 2] = 0;
     HEAP32[i30 + 4 >> 2] = 0;
     HEAP32[i30 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i30, 58020, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i30, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i30);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 116:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i31 >> 2] = 0;
     HEAP32[i31 + 4 >> 2] = 0;
     HEAP32[i31 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i31, 57011, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i31, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i31);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 105:
   {
    if ((HEAP8[i62 + 1 >> 0] | 0) != 120) {
     i1 = i135;
     break L1;
    }
    i137 = i135 + 2 | 0;
    i2 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i137, i127, i133) | 0;
    if ((i2 | 0) == (i137 | 0)) {
     i1 = i135;
     break L1;
    }
    i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i2, i127, i133) | 0;
    i5 = i133 + 4 | 0;
    if ((i1 | 0) == (i2 | 0)) {
     i2 = HEAP32[i5 >> 2] | 0;
     i1 = i2 + -24 | 0;
     while (1) {
      if ((i2 | 0) == (i1 | 0)) {
       i1 = i135;
       break L1;
      }
      i139 = i2 + -24 | 0;
      HEAP32[i5 >> 2] = i139;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
      i2 = HEAP32[i5 >> 2] | 0;
     }
    }
    i2 = HEAP32[i5 >> 2] | 0;
    if (((i2 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
     i1 = i135;
     break L1;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i2 + -24 | 0);
    i2 = HEAP32[i5 >> 2] | 0;
    i3 = i2 + -24 | 0;
    i4 = i2;
    while (1) {
     if ((i4 | 0) == (i3 | 0)) break;
     i137 = i4 + -24 | 0;
     HEAP32[i5 >> 2] = i137;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i137);
     i4 = HEAP32[i5 >> 2] | 0;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i138, i2 + -48 | 0);
    i4 = (HEAP32[i5 >> 2] | 0) + -24 | 0;
    __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i111, 56964, i138);
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i111, 58023) | 0;
    HEAP32[i110 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i110 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i110 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    i2 = HEAP8[i139 + 11 >> 0] | 0;
    i3 = i2 << 24 >> 24 < 0;
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i110, i3 ? HEAP32[i139 >> 2] | 0 : i139, i3 ? HEAP32[i139 + 4 >> 2] | 0 : i2 & 255) | 0;
    HEAP32[i109 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i109 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i109 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i109, 56962) | 0;
    HEAP32[i108 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i108 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i108 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i107, i108);
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i4, i107);
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i107);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i108);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i109);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i110);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i111);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
    break L1;
   }
  case 108:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 101:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i32 >> 2] = 0;
     HEAP32[i32 + 4 >> 2] = 0;
     HEAP32[i32 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i32, 58026, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i32, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i32);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 115:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i33 >> 2] = 0;
     HEAP32[i33 + 4 >> 2] = 0;
     HEAP32[i33 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i33, 58029, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i33, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i33);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 83:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i34 >> 2] = 0;
     HEAP32[i34 + 4 >> 2] = 0;
     HEAP32[i34 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i34, 58032, 3);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i34, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i34);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 116:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i35 >> 2] = 0;
     HEAP32[i35 + 4 >> 2] = 0;
     HEAP32[i35 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i35, 57596, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i35, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i35);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 109:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 105:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i36 >> 2] = 0;
     HEAP32[i36 + 4 >> 2] = 0;
     HEAP32[i36 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i36, 58036, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i36, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i36);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 73:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i37 >> 2] = 0;
     HEAP32[i37 + 4 >> 2] = 0;
     HEAP32[i37 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i37, 58038, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i37, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i37);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 108:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i38 >> 2] = 0;
     HEAP32[i38 + 4 >> 2] = 0;
     HEAP32[i38 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i38, 57085, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i38, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i38);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 76:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i39 >> 2] = 0;
     HEAP32[i39 + 4 >> 2] = 0;
     HEAP32[i39 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i39, 58041, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i39, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i39);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 109:
    {
     i2 = i135 + 2 | 0;
     if ((i2 | 0) != (i127 | 0) ? (HEAP8[i2 >> 0] | 0) == 95 : 0) {
      i139 = i135 + 3 | 0;
      HEAP32[i64 >> 2] = 0;
      HEAP32[i64 + 4 >> 2] = 0;
      HEAP32[i64 + 8 >> 2] = 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i64, 58044, 2);
      i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_prefix_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i64, i133) | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i64);
      i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
      break L1;
     }
     i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i2, i127, i133) | 0;
     if ((i1 | 0) == (i2 | 0)) {
      i1 = i135;
      break L1;
     }
     i2 = HEAP32[i133 + 4 >> 2] | 0;
     if ((HEAP32[i133 >> 2] | 0) == (i2 | 0)) {
      i1 = i135;
      break L1;
     }
     i4 = i2 + -24 | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i83, i4);
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i83, 0, 56964) | 0;
     HEAP32[i82 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i82 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i82 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i82, 58047) | 0;
     HEAP32[i81 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i81 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i81 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i80, i81);
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i4, i80);
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i80);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i81);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i82);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i83);
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 110:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 119:
   case 97:
    {
     L404 : do if (i61) {
      i1 = HEAP8[i135 >> 0] | 0;
      if (i1 << 24 >> 24 == 103) {
       i10 = (HEAP8[i135 + 1 >> 0] | 0) == 115;
       i2 = i10 ? i135 + 2 | 0 : i135;
       i1 = HEAP8[i2 >> 0] | 0;
      } else {
       i10 = 0;
       i2 = i135;
      }
      if (i1 << 24 >> 24 == 110) {
       i1 = HEAP8[i2 + 1 >> 0] | 0;
       switch (i1 << 24 >> 24) {
       case 97:
       case 119:
        break;
       default:
        {
         i1 = i135;
         break L404;
        }
       }
       i8 = i1 << 24 >> 24 == 97;
       i1 = i2 + 2 | 0;
       L411 : do if ((i1 | 0) != (i127 | 0)) {
        i4 = 0;
        while (1) {
         if ((HEAP8[i1 >> 0] | 0) == 95) break;
         i2 = i1;
         i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i1, i127, i133) | 0;
         i2 = (i1 | 0) == (i2 | 0);
         i3 = (i1 | 0) == (i127 | 0);
         if (i2 | i3) break L411; else i4 = i4 | (i2 | i3) ^ 1;
        }
        i122 = i1 + 1 | 0;
        i2 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i122, i127, i133) | 0;
        if (!((i2 | 0) == (i122 | 0) | (i2 | 0) == (i127 | 0))) {
         i1 = HEAP8[i2 >> 0] | 0;
         L417 : do if (!((i113 - i2 | 0) > 2 & i1 << 24 >> 24 == 112)) if (i1 << 24 >> 24 == 69) {
          i7 = 0;
          i9 = i2;
         } else break L411; else {
          if ((HEAP8[i2 + 1 >> 0] | 0) != 105) break L411;
          i1 = i2 + 2 | 0;
          while (1) {
           if ((HEAP8[i1 >> 0] | 0) == 69) {
            i7 = 1;
            i9 = i1;
            break L417;
           }
           i122 = i1;
           i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i1, i127, i133) | 0;
           if ((i1 | 0) == (i122 | 0) | (i1 | 0) == (i127 | 0)) break L411;
          }
         } while (0);
         HEAP32[i138 >> 2] = 0;
         HEAP32[i138 + 4 >> 2] = 0;
         HEAP32[i138 + 8 >> 2] = 0;
         i1 = 0;
         while (1) {
          if ((i1 | 0) == 3) break;
          HEAP32[i138 + (i1 << 2) >> 2] = 0;
          i1 = i1 + 1 | 0;
         }
         L429 : do if (i7) {
          i3 = i133 + 4 | 0;
          i1 = HEAP32[i3 >> 2] | 0;
          if ((HEAP32[i133 >> 2] | 0) == (i1 | 0)) {
           i1 = i135;
           i2 = 1;
          } else {
           __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i137, i1 + -24 | 0);
           i1 = i138 + 11 | 0;
           if ((HEAP8[i1 >> 0] | 0) < 0) {
            i2 = HEAP32[i138 >> 2] | 0;
            HEAP8[i2 >> 0] = 0;
            HEAP32[i138 + 4 >> 2] = 0;
            if ((HEAP32[i138 + 8 >> 2] & 2147483647 | 0) != 11) {
             HEAP8[i138 >> 0] = 0;
             _free(i2);
             HEAP8[i1 >> 0] = 0;
            }
           } else {
            HEAP8[i138 >> 0] = 0;
            HEAP8[i1 >> 0] = 0;
           };
           HEAP32[i138 >> 2] = HEAP32[i137 >> 2];
           HEAP32[i138 + 4 >> 2] = HEAP32[i137 + 4 >> 2];
           HEAP32[i138 + 8 >> 2] = HEAP32[i137 + 8 >> 2];
           i1 = 0;
           while (1) {
            if ((i1 | 0) == 3) break;
            HEAP32[i137 + (i1 << 2) >> 2] = 0;
            i1 = i1 + 1 | 0;
           }
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
           i1 = HEAP32[i3 >> 2] | 0;
           i2 = i1 + -24 | 0;
           while (1) {
            if ((i1 | 0) == (i2 | 0)) {
             i6 = i3;
             i5 = i133;
             i1 = i2;
             i130 = 348;
             break L429;
            }
            i137 = i1 + -24 | 0;
            HEAP32[i3 >> 2] = i137;
            __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i137);
            i1 = HEAP32[i3 >> 2] | 0;
           }
          }
         } else {
          i1 = i133 + 4 | 0;
          i6 = i1;
          i5 = i133;
          i1 = HEAP32[i1 >> 2] | 0;
          i130 = 348;
         } while (0);
         if ((i130 | 0) == 348) if ((HEAP32[i5 >> 2] | 0) == (i1 | 0)) {
          i1 = i135;
          i2 = 1;
         } else {
          __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i136, i1 + -24 | 0);
          i2 = HEAP32[i6 >> 2] | 0;
          i3 = i2 + -24 | 0;
          i1 = i2;
          while (1) {
           if ((i1 | 0) == (i3 | 0)) break;
           i137 = i1 + -24 | 0;
           HEAP32[i6 >> 2] = i137;
           __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i137);
           i1 = HEAP32[i6 >> 2] | 0;
          }
          HEAP32[i132 >> 2] = 0;
          HEAP32[i132 + 4 >> 2] = 0;
          HEAP32[i132 + 8 >> 2] = 0;
          i1 = 0;
          while (1) {
           if ((i1 | 0) == 3) break;
           HEAP32[i132 + (i1 << 2) >> 2] = 0;
           i1 = i1 + 1 | 0;
          }
          L456 : do if (i4) if ((HEAP32[i5 >> 2] | 0) == (i3 | 0)) {
           i1 = i135;
           i2 = 1;
          } else {
           __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i131, i2 + -48 | 0);
           i1 = i132 + 11 | 0;
           do if ((HEAP8[i1 >> 0] | 0) < 0) {
            i2 = HEAP32[i132 >> 2] | 0;
            HEAP8[i2 >> 0] = 0;
            HEAP32[i132 + 4 >> 2] = 0;
            if ((HEAP32[i132 + 8 >> 2] & 2147483647 | 0) == 11) break;
            HEAP8[i132 >> 0] = 0;
            _free(i2);
            HEAP8[i1 >> 0] = 0;
           } else {
            HEAP8[i132 >> 0] = 0;
            HEAP8[i1 >> 0] = 0;
           } while (0);
           HEAP32[i132 >> 2] = HEAP32[i131 >> 2];
           HEAP32[i132 + 4 >> 2] = HEAP32[i131 + 4 >> 2];
           HEAP32[i132 + 8 >> 2] = HEAP32[i131 + 8 >> 2];
           i1 = 0;
           while (1) {
            if ((i1 | 0) == 3) break;
            HEAP32[i131 + (i1 << 2) >> 2] = 0;
            i1 = i1 + 1 | 0;
           }
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i131);
           i2 = HEAP32[i6 >> 2] | 0;
           i1 = i2 + -24 | 0;
           while (1) {
            if ((i2 | 0) == (i1 | 0)) {
             i130 = 367;
             break L456;
            }
            i137 = i2 + -24 | 0;
            HEAP32[i6 >> 2] = i137;
            __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i137);
            i2 = HEAP32[i6 >> 2] | 0;
           }
          } else i130 = 367; while (0);
          if ((i130 | 0) == 367) {
           HEAP32[i134 >> 2] = 0;
           HEAP32[i134 + 4 >> 2] = 0;
           HEAP32[i134 + 8 >> 2] = 0;
           i1 = 0;
           while (1) {
            if ((i1 | 0) == 3) break;
            HEAP32[i134 + (i1 << 2) >> 2] = 0;
            i1 = i1 + 1 | 0;
           }
           if (i10) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6assignEPKcj(i134, 57058, 2);
           if (i8) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i134, 58051) | 0; else __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i134, 58055) | 0;
           if (i4) {
            __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i124, 56964, i132);
            i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i124, 57013) | 0;
            HEAP32[i123 >> 2] = HEAP32[i1 >> 2];
            HEAP32[i123 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
            HEAP32[i123 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
            i2 = 0;
            while (1) {
             if ((i2 | 0) == 3) break;
             HEAP32[i1 + (i2 << 2) >> 2] = 0;
             i2 = i2 + 1 | 0;
            }
            i137 = HEAP8[i123 + 11 >> 0] | 0;
            i131 = i137 << 24 >> 24 < 0;
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i134, i131 ? HEAP32[i123 >> 2] | 0 : i123, i131 ? HEAP32[i123 + 4 >> 2] | 0 : i137 & 255) | 0;
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i123);
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i124);
           }
           i137 = HEAP8[i136 + 11 >> 0] | 0;
           i131 = i137 << 24 >> 24 < 0;
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i134, i131 ? HEAP32[i136 >> 2] | 0 : i136, i131 ? HEAP32[i136 + 4 >> 2] | 0 : i137 & 255) | 0;
           if (i7) {
            __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i125, 57016, i138);
            i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i125, 56966) | 0;
            HEAP32[i126 >> 2] = HEAP32[i1 >> 2];
            HEAP32[i126 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
            HEAP32[i126 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
            i2 = 0;
            while (1) {
             if ((i2 | 0) == 3) break;
             HEAP32[i1 + (i2 << 2) >> 2] = 0;
             i2 = i2 + 1 | 0;
            }
            i137 = HEAP8[i126 + 11 >> 0] | 0;
            i131 = i137 << 24 >> 24 < 0;
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i134, i131 ? HEAP32[i126 >> 2] | 0 : i126, i131 ? HEAP32[i126 + 4 >> 2] | 0 : i137 & 255) | 0;
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i126);
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i125);
           };
           HEAP32[i129 >> 2] = HEAP32[i134 >> 2];
           HEAP32[i129 + 4 >> 2] = HEAP32[i134 + 4 >> 2];
           HEAP32[i129 + 8 >> 2] = HEAP32[i134 + 8 >> 2];
           i1 = 0;
           while (1) {
            if ((i1 | 0) == 3) break;
            HEAP32[i134 + (i1 << 2) >> 2] = 0;
            i1 = i1 + 1 | 0;
           }
           __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i128, i129);
           i1 = HEAP32[i6 >> 2] | 0;
           i137 = HEAP32[i133 + 8 >> 2] | 0;
           i4 = i137;
           if (i1 >>> 0 < i137 >>> 0) {
            __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i1, i128);
            HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + 24;
           } else {
            i2 = HEAP32[i133 >> 2] | 0;
            i5 = (i1 - i2 | 0) / 24 | 0;
            i3 = i5 + 1 | 0;
            if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i133);
            i1 = (i4 - i2 | 0) / 24 | 0;
            if (i1 >>> 0 < 89478485) {
             i1 = i1 << 1;
             i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
            } else i1 = 178956970;
            __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i139, i1, i5, i133 + 12 | 0);
            i137 = i139 + 8 | 0;
            i131 = HEAP32[i137 >> 2] | 0;
            __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i131, i128);
            HEAP32[i137 >> 2] = i131 + 24;
            __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i133, i139);
            __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i139);
           }
           __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i128);
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i129);
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i134);
           i1 = i9 + 1 | 0;
           i2 = 0;
          }
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i132);
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
         }
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
         if (!i2) break L404;
        }
       } while (0);
       i1 = i135;
      } else i1 = i135;
     } else i1 = i135; while (0);
     break L1;
    }
   case 101:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i42 >> 2] = 0;
     HEAP32[i42 + 4 >> 2] = 0;
     HEAP32[i42 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i42, 58057, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i42, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i42);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 103:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i43 >> 2] = 0;
     HEAP32[i43 + 4 >> 2] = 0;
     HEAP32[i43 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i43, 58036, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_prefix_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i43, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i43);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 116:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i44 >> 2] = 0;
     HEAP32[i44 + 4 >> 2] = 0;
     HEAP32[i44 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i44, 58060, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_prefix_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i44, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i44);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 120:
    {
     i6 = i135 + 2 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i6, i127, i133) | 0;
     if ((i1 | 0) != (i6 | 0) ? (i93 = HEAP32[i133 + 4 >> 2] | 0, (HEAP32[i133 >> 2] | 0) != (i93 | 0)) : 0) {
      i5 = i93 + -24 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i137, i5);
      i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i137, 0, 58062) | 0;
      HEAP32[i138 >> 2] = HEAP32[i2 >> 2];
      HEAP32[i138 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
      HEAP32[i138 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
      i3 = 0;
      while (1) {
       if ((i3 | 0) == 3) break;
       HEAP32[i2 + (i3 << 2) >> 2] = 0;
       i3 = i3 + 1 | 0;
      }
      i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i138, 56966) | 0;
      HEAP32[i139 >> 2] = HEAP32[i2 >> 2];
      HEAP32[i139 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
      HEAP32[i139 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
      i3 = 0;
      while (1) {
       if ((i3 | 0) == 3) break;
       HEAP32[i2 + (i3 << 2) >> 2] = 0;
       i3 = i3 + 1 | 0;
      }
      i2 = i5 + 11 | 0;
      do if ((HEAP8[i2 >> 0] | 0) < 0) {
       HEAP8[HEAP32[i5 >> 2] >> 0] = 0;
       i4 = i93 + -20 | 0;
       HEAP32[i4 >> 2] = 0;
       i3 = HEAP8[i2 >> 0] | 0;
       if (i3 << 24 >> 24 < 0) {
        if ((HEAP32[i93 + -16 >> 2] & 2147483647 | 0) == 11) break;
        i136 = HEAP32[i5 >> 2] | 0;
        HEAP8[i5 >> 0] = HEAP8[i136 >> 0] | 0;
        _free(i136);
        HEAP8[i2 >> 0] = 0;
        break;
       } else {
        i2 = i3 & 255;
        if ((i3 & 255) < 11) break;
        i134 = i2 + 16 & 496;
        i136 = _malloc(i134) | 0;
        _memcpy(i136 | 0, i5 | 0, i2 + 1 | 0) | 0;
        HEAP32[i93 + -16 >> 2] = i134 | -2147483648;
        HEAP32[i4 >> 2] = i2;
        HEAP32[i5 >> 2] = i136;
        break;
       }
      } else {
       HEAP8[i5 >> 0] = 0;
       HEAP8[i2 >> 0] = 0;
      } while (0);
      HEAP32[i5 >> 2] = HEAP32[i139 >> 2];
      HEAP32[i5 + 4 >> 2] = HEAP32[i139 + 4 >> 2];
      HEAP32[i5 + 8 >> 2] = HEAP32[i139 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i139 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
     } else i1 = i6;
     i1 = (i1 | 0) == (i6 | 0) ? i135 : i1;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 111:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 110:
    {
     i1 = __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i135, i127, i133) | 0;
     break L1;
    }
   case 111:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i45 >> 2] = 0;
     HEAP32[i45 + 4 >> 2] = 0;
     HEAP32[i45 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i45, 58073, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i45, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i45);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 114:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i46 >> 2] = 0;
     HEAP32[i46 + 4 >> 2] = 0;
     HEAP32[i46 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i46, 58076, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i46, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i46);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 82:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i47 >> 2] = 0;
     HEAP32[i47 + 4 >> 2] = 0;
     HEAP32[i47 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i47, 58078, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i47, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i47);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 112:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 109:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i50 >> 2] = 0;
     HEAP32[i50 + 4 >> 2] = 0;
     HEAP32[i50 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i50, 58081, 3);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i50, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i50);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 108:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i51 >> 2] = 0;
     HEAP32[i51 + 4 >> 2] = 0;
     HEAP32[i51 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i51, 58085, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i51, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i51);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 76:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i52 >> 2] = 0;
     HEAP32[i52 + 4 >> 2] = 0;
     HEAP32[i52 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i52, 58087, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i52, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i52);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 112:
    {
     i2 = i135 + 2 | 0;
     if ((i2 | 0) != (i127 | 0) ? (HEAP8[i2 >> 0] | 0) == 95 : 0) {
      i139 = i135 + 3 | 0;
      HEAP32[i65 >> 2] = 0;
      HEAP32[i65 + 4 >> 2] = 0;
      HEAP32[i65 + 8 >> 2] = 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i65, 58090, 2);
      i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_prefix_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i65, i133) | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i65);
      i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
      break L1;
     }
     i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i2, i127, i133) | 0;
     if ((i1 | 0) == (i2 | 0)) {
      i1 = i135;
      break L1;
     }
     i2 = HEAP32[i133 + 4 >> 2] | 0;
     if ((HEAP32[i133 >> 2] | 0) == (i2 | 0)) {
      i1 = i135;
      break L1;
     }
     i4 = i2 + -24 | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i87, i4);
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i87, 0, 56964) | 0;
     HEAP32[i86 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i86 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i86 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i86, 58093) | 0;
     HEAP32[i85 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i85 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i85 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i84, i85);
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i4, i84);
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i84);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i85);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i86);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i87);
     break L1;
    }
   case 115:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i55 >> 2] = 0;
     HEAP32[i55 + 4 >> 2] = 0;
     HEAP32[i55 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i55, 58085, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_prefix_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i55, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i55);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 116:
    {
     if ((i60 | 0) <= 2) {
      i1 = i135;
      break L1;
     }
     if ((HEAP8[i135 >> 0] | 0) != 112) {
      i1 = i135;
      break L1;
     }
     if ((HEAP8[i135 + 1 >> 0] | 0) != 116) {
      i1 = i135;
      break L1;
     }
     i138 = i135 + 2 | 0;
     i2 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i138, i127, i133) | 0;
     if ((i2 | 0) == (i138 | 0)) {
      i1 = i135;
      break L1;
     }
     i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i2, i127, i133) | 0;
     if ((i1 | 0) == (i2 | 0)) {
      i1 = i135;
      break L1;
     }
     i5 = i133 + 4 | 0;
     i2 = HEAP32[i5 >> 2] | 0;
     if (((i2 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
      i1 = i135;
      break L1;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i2 + -24 | 0);
     i2 = HEAP32[i5 >> 2] | 0;
     i3 = i2 + -24 | 0;
     i4 = i2;
     while (1) {
      if ((i4 | 0) == (i3 | 0)) break;
      i138 = i4 + -24 | 0;
      HEAP32[i5 >> 2] = i138;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i138);
      i4 = HEAP32[i5 >> 2] | 0;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + -48 | 0, 58097) | 0;
     i138 = HEAP8[i139 + 11 >> 0] | 0;
     i137 = i138 << 24 >> 24 < 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj((HEAP32[i5 >> 2] | 0) + -24 | 0, i137 ? HEAP32[i139 >> 2] | 0 : i139, i137 ? HEAP32[i139 + 4 >> 2] | 0 : i138 & 255) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 113:
   {
    if ((HEAP8[i62 + 1 >> 0] | 0) != 117) {
     i1 = i135;
     break L1;
    }
    i136 = i135 + 2 | 0;
    i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i136, i127, i133) | 0;
    if ((i1 | 0) == (i136 | 0)) {
     i1 = i135;
     break L1;
    }
    i2 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i1, i127, i133) | 0;
    if ((i2 | 0) == (i1 | 0)) {
     i1 = i133 + 4 | 0;
     i3 = HEAP32[i1 >> 2] | 0;
     i2 = i3 + -24 | 0;
     while (1) {
      if ((i3 | 0) == (i2 | 0)) {
       i1 = i135;
       break L1;
      }
      i139 = i3 + -24 | 0;
      HEAP32[i1 >> 2] = i139;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
      i3 = HEAP32[i1 >> 2] | 0;
     }
    }
    i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i2, i127, i133) | 0;
    i5 = i133 + 4 | 0;
    if ((i1 | 0) == (i2 | 0)) {
     i2 = HEAP32[i5 >> 2] | 0;
     i1 = i2 + -24 | 0;
     i3 = i2;
     while (1) {
      if ((i3 | 0) == (i1 | 0)) break;
      i139 = i3 + -24 | 0;
      HEAP32[i5 >> 2] = i139;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
      i3 = HEAP32[i5 >> 2] | 0;
     }
     i2 = i2 + -48 | 0;
     while (1) {
      if ((i1 | 0) == (i2 | 0)) {
       i1 = i135;
       break L1;
      }
      i139 = i1 + -24 | 0;
      HEAP32[i5 >> 2] = i139;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
      i1 = HEAP32[i5 >> 2] | 0;
     }
    }
    i2 = HEAP32[i5 >> 2] | 0;
    if (((i2 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 3) {
     i1 = i135;
     break L1;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i2 + -24 | 0);
    i2 = HEAP32[i5 >> 2] | 0;
    i3 = i2 + -24 | 0;
    i4 = i2;
    while (1) {
     if ((i4 | 0) == (i3 | 0)) break;
     i136 = i4 + -24 | 0;
     HEAP32[i5 >> 2] = i136;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i136);
     i4 = HEAP32[i5 >> 2] | 0;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i138, i2 + -48 | 0);
    i2 = HEAP32[i5 >> 2] | 0;
    i3 = i2 + -24 | 0;
    i4 = i2;
    while (1) {
     if ((i4 | 0) == (i3 | 0)) break;
     i136 = i4 + -24 | 0;
     HEAP32[i5 >> 2] = i136;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i136);
     i4 = HEAP32[i5 >> 2] | 0;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i137, i2 + -48 | 0);
    i4 = (HEAP32[i5 >> 2] | 0) + -24 | 0;
    __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i122, 56964, i137);
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i122, 58100) | 0;
    HEAP32[i121 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i121 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i121 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    i2 = HEAP8[i138 + 11 >> 0] | 0;
    i3 = i2 << 24 >> 24 < 0;
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i121, i3 ? HEAP32[i138 >> 2] | 0 : i138, i3 ? HEAP32[i138 + 4 >> 2] | 0 : i2 & 255) | 0;
    HEAP32[i120 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i120 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i120 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i120, 58106) | 0;
    HEAP32[i119 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i119 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i119 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    i2 = HEAP8[i139 + 11 >> 0] | 0;
    i3 = i2 << 24 >> 24 < 0;
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i119, i3 ? HEAP32[i139 >> 2] | 0 : i139, i3 ? HEAP32[i139 + 4 >> 2] | 0 : i2 & 255) | 0;
    HEAP32[i118 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i118 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i118 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i118, 56966) | 0;
    HEAP32[i117 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i117 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i117 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i116, i117);
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i4, i116);
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i116);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i117);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i118);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i119);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i120);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i121);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i122);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
    break L1;
   }
  case 114:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 99:
    {
     if ((((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 114 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 99 : 0) ? (i130 = i135 + 2 | 0, i4 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i130, i127, i133) | 0, (i4 | 0) != (i130 | 0)) : 0) ? (i94 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i4, i127, i133) | 0, (i94 | 0) != (i4 | 0)) : 0) ? (i66 = i133 + 4 | 0, i5 = HEAP32[i66 >> 2] | 0, ((i5 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) : 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i5 + -24 | 0);
      i1 = HEAP32[i66 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i135 = i3 + -24 | 0;
       HEAP32[i66 >> 2] = i135;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i135);
       i3 = HEAP32[i66 >> 2] | 0;
      }
      i3 = i1 + -48 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i134, i3);
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i134, 0, 58112) | 0;
      HEAP32[i131 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i131 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i131 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i131, 57048) | 0;
      HEAP32[i132 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i132 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i132 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = HEAP8[i139 + 11 >> 0] | 0;
      i2 = i1 << 24 >> 24 < 0;
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i132, i2 ? HEAP32[i139 >> 2] | 0 : i139, i2 ? HEAP32[i139 + 4 >> 2] | 0 : i1 & 255) | 0;
      HEAP32[i136 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i136 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i136 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i136, 56966) | 0;
      HEAP32[i137 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i137 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i137 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i138, i137);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i3, i138);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i132);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i131);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i134);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      i1 = i94;
     } else i1 = i135;
     break L1;
    }
   case 109:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i56 >> 2] = 0;
     HEAP32[i56 + 4 >> 2] = 0;
     HEAP32[i56 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i56, 58130, 1);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i56, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i56);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 77:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i57 >> 2] = 0;
     HEAP32[i57 + 4 >> 2] = 0;
     HEAP32[i57 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i57, 58132, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i57, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i57);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 115:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i58 >> 2] = 0;
     HEAP32[i58 + 4 >> 2] = 0;
     HEAP32[i58 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i58, 58135, 2);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i58, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i58);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 83:
    {
     i139 = i135 + 2 | 0;
     HEAP32[i59 >> 2] = 0;
     HEAP32[i59 + 4 >> 2] = 0;
     HEAP32[i59 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i59, 58138, 3);
     i1 = __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i139, i127, i59, i133) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i59);
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 115:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 99:
    {
     if ((((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 115 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 99 : 0) ? (i130 = i135 + 2 | 0, i6 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i130, i127, i133) | 0, (i6 | 0) != (i130 | 0)) : 0) ? (i95 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i6, i127, i133) | 0, (i95 | 0) != (i6 | 0)) : 0) ? (i67 = i133 + 4 | 0, i7 = HEAP32[i67 >> 2] | 0, ((i7 - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) : 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i139, i7 + -24 | 0);
      i1 = HEAP32[i67 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i135 = i3 + -24 | 0;
       HEAP32[i67 >> 2] = i135;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i135);
       i3 = HEAP32[i67 >> 2] | 0;
      }
      i3 = i1 + -48 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i134, i3);
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i134, 0, 58142) | 0;
      HEAP32[i131 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i131 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i131 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i131, 57048) | 0;
      HEAP32[i132 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i132 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i132 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = HEAP8[i139 + 11 >> 0] | 0;
      i2 = i1 << 24 >> 24 < 0;
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i132, i2 ? HEAP32[i139 >> 2] | 0 : i139, i2 ? HEAP32[i139 + 4 >> 2] | 0 : i1 & 255) | 0;
      HEAP32[i136 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i136 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i136 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i136, 56966) | 0;
      HEAP32[i137 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i137 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i137 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i138, i137);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i3, i138);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i132);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i131);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i134);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i139);
      i1 = i95;
     } else i1 = i135;
     break L1;
    }
   case 112:
    {
     if ((i60 | 0) <= 2) {
      i1 = i135;
      break L1;
     }
     if ((HEAP8[i135 >> 0] | 0) != 115) {
      i1 = i135;
      break L1;
     }
     if ((HEAP8[i135 + 1 >> 0] | 0) != 112) {
      i1 = i135;
      break L1;
     }
     i139 = i135 + 2 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i139, i127, i133) | 0;
     i1 = (i1 | 0) == (i139 | 0) ? i135 : i1;
     break L1;
    }
   case 114:
    {
     i1 = __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i135, i127, i133) | 0;
     break L1;
    }
   case 116:
    {
     if (((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 115 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 116 : 0) ? (i134 = i135 + 2 | 0, i77 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i134, i127, i133) | 0, (i77 | 0) != (i134 | 0)) : 0) ? (i8 = HEAP32[i133 + 4 >> 2] | 0, (HEAP32[i133 >> 2] | 0) != (i8 | 0)) : 0) {
      i3 = i8 + -24 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i136, i3);
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i136, 0, 58155) | 0;
      HEAP32[i137 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i137 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i137 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i137, 56966) | 0;
      HEAP32[i138 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i138 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i138 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i139, i138);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i3, i139);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
      i1 = i77;
     } else i1 = i135;
     break L1;
    }
   case 122:
    {
     if (((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 115 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 122 : 0) ? (i134 = i135 + 2 | 0, i78 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i134, i127, i133) | 0, (i78 | 0) != (i134 | 0)) : 0) ? (i9 = HEAP32[i133 + 4 >> 2] | 0, (HEAP32[i133 >> 2] | 0) != (i9 | 0)) : 0) {
      i3 = i9 + -24 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i136, i3);
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i136, 0, 58155) | 0;
      HEAP32[i137 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i137 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i137 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i137, 56966) | 0;
      HEAP32[i138 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i138 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
      HEAP32[i138 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
      i2 = 0;
      while (1) {
       if ((i2 | 0) == 3) break;
       HEAP32[i1 + (i2 << 2) >> 2] = 0;
       i2 = i2 + 1 | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i139, i138);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i3, i139);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
      i1 = i78;
     } else i1 = i135;
     break L1;
    }
   case 90:
    {
     if ((i113 - i62 | 0) <= 2) {
      i1 = i135;
      break L1;
     }
     switch (HEAP8[i62 + 2 >> 0] | 0) {
     case 84:
      break;
     case 102:
      {
       if ((((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 115 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 90 : 0) ? (i12 = i135 + 2 | 0, (HEAP8[i12 >> 0] | 0) == 102) : 0) ? (i79 = __ZN10__cxxabiv112_GLOBAL__N_120parse_function_paramINS0_2DbEEEPKcS4_S4_RT_(i12, i127, i133) | 0, (i79 | 0) != (i12 | 0)) : 0) ? (i14 = HEAP32[i133 + 4 >> 2] | 0, (HEAP32[i133 >> 2] | 0) != (i14 | 0)) : 0) {
        i3 = i14 + -24 | 0;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i136, i3);
        i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i136, 0, 58164) | 0;
        HEAP32[i137 >> 2] = HEAP32[i1 >> 2];
        HEAP32[i137 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
        HEAP32[i137 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
        i2 = 0;
        while (1) {
         if ((i2 | 0) == 3) break;
         HEAP32[i1 + (i2 << 2) >> 2] = 0;
         i2 = i2 + 1 | 0;
        }
        i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i137, 56966) | 0;
        HEAP32[i138 >> 2] = HEAP32[i1 >> 2];
        HEAP32[i138 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
        HEAP32[i138 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
        i2 = 0;
        while (1) {
         if ((i2 | 0) == 3) break;
         HEAP32[i1 + (i2 << 2) >> 2] = 0;
         i2 = i2 + 1 | 0;
        }
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i139, i138);
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i3, i139);
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
        i1 = i79;
       } else i1 = i135;
       break L1;
      }
     default:
      {
       i1 = i135;
       break L1;
      }
     }
     if (((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 115 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 90 : 0) ? (i11 = i135 + 2 | 0, (HEAP8[i11 >> 0] | 0) == 84) : 0) ? (i112 = i133 + 4 | 0, i96 = ((HEAP32[i112 >> 2] | 0) - (HEAP32[i133 >> 2] | 0) | 0) / 24 | 0, i115 = __ZN10__cxxabiv112_GLOBAL__N_120parse_template_paramINS0_2DbEEEPKcS4_S4_RT_(i11, i127, i133) | 0, i68 = HEAP32[i133 >> 2] | 0, i3 = ((HEAP32[i112 >> 2] | 0) - i68 | 0) / 24 | 0, i68, (i115 | 0) != (i11 | 0)) : 0) {
      HEAP32[i138 >> 2] = 0;
      HEAP32[i138 + 4 >> 2] = 0;
      HEAP32[i138 + 8 >> 2] = 0;
      HEAP8[i138 + 11 >> 0] = 10;
      i1 = i138;
      i2 = 58164;
      i4 = i1 + 10 | 0;
      do {
       HEAP8[i1 >> 0] = HEAP8[i2 >> 0] | 0;
       i1 = i1 + 1 | 0;
       i2 = i2 + 1 | 0;
      } while ((i1 | 0) < (i4 | 0));
      HEAP8[i138 + 10 >> 0] = 0;
      L761 : do if ((i96 | 0) != (i3 | 0)) {
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i137, i68 + (i96 * 24 | 0) | 0);
       i5 = HEAP8[i137 + 11 >> 0] | 0;
       i6 = i5 << 24 >> 24 < 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i138, i6 ? HEAP32[i137 >> 2] | 0 : i137, i6 ? HEAP32[i137 + 4 >> 2] | 0 : i5 & 255) | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
       i5 = i136 + 11 | 0;
       i6 = i136 + 4 | 0;
       i1 = i96;
       while (1) {
        i1 = i1 + 1 | 0;
        if ((i1 | 0) == (i3 | 0)) break L761;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i132, (HEAP32[i133 >> 2] | 0) + (i1 * 24 | 0) | 0);
        i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i132, 0, 57598) | 0;
        HEAP32[i136 >> 2] = HEAP32[i2 >> 2];
        HEAP32[i136 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
        HEAP32[i136 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
        i4 = 0;
        while (1) {
         if ((i4 | 0) == 3) break;
         HEAP32[i2 + (i4 << 2) >> 2] = 0;
         i4 = i4 + 1 | 0;
        }
        i137 = HEAP8[i5 >> 0] | 0;
        i135 = i137 << 24 >> 24 < 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i138, i135 ? HEAP32[i136 >> 2] | 0 : i136, i135 ? HEAP32[i6 >> 2] | 0 : i137 & 255) | 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i132);
       }
      } while (0);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i138, 56966) | 0;
      while (1) {
       if ((i3 | 0) == (i96 | 0)) break;
       i2 = HEAP32[i112 >> 2] | 0;
       i1 = i2 + -24 | 0;
       while (1) {
        if ((i2 | 0) == (i1 | 0)) break;
        i137 = i2 + -24 | 0;
        HEAP32[i112 >> 2] = i137;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i137);
        i2 = HEAP32[i112 >> 2] | 0;
       }
       i3 = i3 + -1 | 0;
      }
      HEAP32[i134 >> 2] = HEAP32[i138 >> 2];
      HEAP32[i134 + 4 >> 2] = HEAP32[i138 + 4 >> 2];
      HEAP32[i134 + 8 >> 2] = HEAP32[i138 + 8 >> 2];
      i1 = 0;
      while (1) {
       if ((i1 | 0) == 3) break;
       HEAP32[i138 + (i1 << 2) >> 2] = 0;
       i1 = i1 + 1 | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i131, i134);
      i1 = HEAP32[i112 >> 2] | 0;
      i137 = HEAP32[i133 + 8 >> 2] | 0;
      i4 = i137;
      if (i1 >>> 0 < i137 >>> 0) {
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i1, i131);
       HEAP32[i112 >> 2] = (HEAP32[i112 >> 2] | 0) + 24;
      } else {
       i2 = HEAP32[i133 >> 2] | 0;
       i5 = (i1 - i2 | 0) / 24 | 0;
       i3 = i5 + 1 | 0;
       if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i133);
       i1 = (i4 - i2 | 0) / 24 | 0;
       if (i1 >>> 0 < 89478485) {
        i1 = i1 << 1;
        i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
       } else i1 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i139, i1, i5, i133 + 12 | 0);
       i137 = i139 + 8 | 0;
       i136 = HEAP32[i137 >> 2] | 0;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i136, i131);
       HEAP32[i137 >> 2] = i136 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i133, i139);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i139);
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i131);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i134);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
      i1 = i115;
     } else i1 = i135;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 116:
   switch (HEAP8[i62 + 1 >> 0] | 0) {
   case 105:
   case 101:
    {
     L797 : do if ((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 116 : 0) {
      i1 = HEAP8[i135 + 1 >> 0] | 0;
      switch (i1 << 24 >> 24) {
      case 105:
      case 101:
       break;
      default:
       {
        i1 = i135;
        break L797;
       }
      }
      i2 = i135 + 2 | 0;
      if (i1 << 24 >> 24 == 101) i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i2, i127, i133) | 0; else i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i2, i127, i133) | 0;
      if ((i1 | 0) != (i2 | 0) ? (i69 = HEAP32[i133 + 4 >> 2] | 0, (HEAP32[i133 >> 2] | 0) != (i69 | 0)) : 0) {
       i4 = i69 + -24 | 0;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i136, i4);
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i136, 0, 58175) | 0;
       HEAP32[i137 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i137 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i137 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i137, 56966) | 0;
       HEAP32[i138 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i138 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i138 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i139, i138);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i4, i139);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i136);
      } else i1 = i135;
     } else i1 = i135; while (0);
     break L1;
    }
   case 114:
    {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj6EEERAT__Kc(i88, 58183);
     i1 = i133 + 4 | 0;
     i2 = HEAP32[i1 >> 2] | 0;
     i138 = HEAP32[i133 + 8 >> 2] | 0;
     i3 = i138;
     if (i2 >>> 0 < i138 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i88);
      HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
     } else {
      i1 = HEAP32[i133 >> 2] | 0;
      i4 = (i2 - i1 | 0) / 24 | 0;
      i2 = i4 + 1 | 0;
      if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i133);
      i1 = (i3 - i1 | 0) / 24 | 0;
      if (i1 >>> 0 < 89478485) {
       i1 = i1 << 1;
       i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
      } else i1 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i139, i1, i4, i133 + 12 | 0);
      i138 = i139 + 8 | 0;
      i137 = HEAP32[i138 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i137, i88);
      HEAP32[i138 >> 2] = i137 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i133, i139);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i139);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i88);
     i1 = i135 + 2 | 0;
     break L1;
    }
   case 119:
    {
     if (((((i60 | 0) > 2 ? (HEAP8[i135 >> 0] | 0) == 116 : 0) ? (HEAP8[i135 + 1 >> 0] | 0) == 119 : 0) ? (i136 = i135 + 2 | 0, i70 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i136, i127, i133) | 0, (i70 | 0) != (i136 | 0)) : 0) ? (i15 = HEAP32[i133 + 4 >> 2] | 0, (HEAP32[i133 >> 2] | 0) != (i15 | 0)) : 0) {
      i1 = i15 + -24 | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i137, i1);
      i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i137, 0, 58189) | 0;
      HEAP32[i138 >> 2] = HEAP32[i2 >> 2];
      HEAP32[i138 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
      HEAP32[i138 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
      i3 = 0;
      while (1) {
       if ((i3 | 0) == 3) break;
       HEAP32[i2 + (i3 << 2) >> 2] = 0;
       i3 = i3 + 1 | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i139, i138);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i1, i139);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i139);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i138);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i137);
      i1 = i70;
     } else i1 = i135;
     break L1;
    }
   default:
    {
     i1 = i135;
     break L1;
    }
   }
  case 57:
  case 56:
  case 55:
  case 54:
  case 53:
  case 52:
  case 51:
  case 50:
  case 49:
   {
    i1 = __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i135, i127, i133) | 0;
    break L1;
   }
  default:
   {
    i1 = i135;
    break L1;
   }
  } while (0);
 } else i1 = i135; while (0);
 STACKTOP = i140;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i73, i72, i74) {
 i73 = i73 | 0;
 i72 = i72 | 0;
 i74 = i74 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i52 = 0, i53 = 0, i54 = 0, i55 = 0, i56 = 0, i57 = 0, i58 = 0, i59 = 0, i60 = 0, i61 = 0, i62 = 0, i63 = 0, i64 = 0, i65 = 0, i66 = 0, i67 = 0, i68 = 0, i69 = 0, i70 = 0, i71 = 0, i75 = 0, i76 = 0;
 i76 = STACKTOP;
 STACKTOP = STACKTOP + 736 | 0;
 i75 = i76 + 704 | 0;
 i67 = i76 + 680 | 0;
 i65 = i76 + 668 | 0;
 i51 = i76 + 656 | 0;
 i54 = i76 + 632 | 0;
 i64 = i76 + 608 | 0;
 i66 = i76 + 584 | 0;
 i56 = i76 + 572 | 0;
 i58 = i76 + 560 | 0;
 i62 = i76 + 548 | 0;
 i63 = i76 + 536 | 0;
 i38 = i76 + 384 | 0;
 i59 = i76 + 520 | 0;
 i53 = i76 + 512 | 0;
 i16 = i76 + 496 | 0;
 i8 = i76 + 488 | 0;
 i43 = i76 + 472 | 0;
 i36 = i76 + 464 | 0;
 i17 = i76 + 448 | 0;
 i9 = i76 + 440 | 0;
 i57 = i76 + 424 | 0;
 i52 = i76 + 420 | 0;
 i41 = i76 + 408 | 0;
 i60 = i76 + 396 | 0;
 i61 = i76 + 372 | 0;
 i42 = i76 + 360 | 0;
 i46 = i76 + 344 | 0;
 i44 = i76 + 340 | 0;
 i13 = i76 + 328 | 0;
 i19 = i76 + 304 | 0;
 i20 = i76 + 288 | 0;
 i21 = i76 + 276 | 0;
 i22 = i76 + 264 | 0;
 i28 = i76 + 240 | 0;
 i29 = i76 + 228 | 0;
 i30 = i76 + 216 | 0;
 i31 = i76 + 204 | 0;
 i32 = i76 + 192 | 0;
 i33 = i76 + 168 | 0;
 i34 = i76 + 156 | 0;
 i35 = i76 + 144 | 0;
 i45 = i76 + 128 | 0;
 i40 = i76 + 120 | 0;
 i15 = i76 + 104 | 0;
 i7 = i76 + 96 | 0;
 i26 = i76 + 80 | 0;
 i12 = i76 + 72 | 0;
 i24 = i76 + 56 | 0;
 i11 = i76 + 48 | 0;
 i55 = i76 + 32 | 0;
 i49 = i76 + 24 | 0;
 i70 = i76 + 8 | 0;
 i69 = i76;
 L1 : do if ((i73 | 0) != (i72 | 0)) {
  switch (HEAP8[i73 >> 0] | 0) {
  case 75:
  case 86:
  case 114:
   {
    HEAP32[i67 >> 2] = 0;
    i2 = __ZN10__cxxabiv112_GLOBAL__N_119parse_cv_qualifiersEPKcS2_Rj(i73, i72, i67) | 0;
    L5 : do if ((i2 | 0) != (i73 | 0) ? (i3 = HEAP8[i2 >> 0] | 0, i48 = i74 + 4 | 0, i10 = ((HEAP32[i48 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0, i47 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i2, i72, i74) | 0, i48 = ((HEAP32[i48 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0, (i47 | 0) != (i2 | 0)) : 0) {
     i15 = i3 << 24 >> 24 == 70;
     i16 = i74 + 20 | 0;
     i2 = HEAP32[i16 >> 2] | 0;
     L8 : do if (i15) {
      i3 = i2 + -16 | 0;
      while (1) {
       if ((i2 | 0) == (i3 | 0)) {
        i2 = i3;
        break L8;
       }
       i73 = i2 + -16 | 0;
       HEAP32[i16 >> 2] = i73;
       __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i73);
       i2 = HEAP32[i16 >> 2] | 0;
      }
     } while (0);
     i7 = i74 + 16 | 0;
     i8 = HEAP32[i74 + 12 >> 2] | 0;
     i73 = HEAP32[i74 + 24 >> 2] | 0;
     i3 = i73;
     if (i2 >>> 0 < i73 >>> 0) {
      HEAP32[i2 >> 2] = 0;
      HEAP32[i2 + 4 >> 2] = 0;
      HEAP32[i2 + 8 >> 2] = 0;
      HEAP32[i2 + 12 >> 2] = i8;
      HEAP32[i16 >> 2] = (HEAP32[i16 >> 2] | 0) + 16;
     } else {
      i4 = HEAP32[i7 >> 2] | 0;
      i6 = i2 - i4 >> 4;
      i5 = i6 + 1 | 0;
      if (i5 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
      i2 = i3 - i4 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i6, i74 + 28 | 0);
      i73 = i75 + 8 | 0;
      i72 = HEAP32[i73 >> 2] | 0;
      HEAP32[i72 >> 2] = 0;
      HEAP32[i72 + 4 >> 2] = 0;
      HEAP32[i72 + 8 >> 2] = 0;
      HEAP32[i72 + 12 >> 2] = i8;
      HEAP32[i73 >> 2] = i72 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i7, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     i13 = HEAP32[i67 >> 2] | 0;
     i11 = (i13 & 1 | 0) == 0;
     i12 = (i13 & 2 | 0) == 0;
     i13 = (i13 & 4 | 0) == 0;
     i14 = i75 + 8 | 0;
     while (1) {
      if (i10 >>> 0 >= i48 >>> 0) {
       i1 = i47;
       break L5;
      }
      if (i15) {
       i4 = HEAP32[i74 >> 2] | 0;
       i8 = i4 + (i10 * 24 | 0) + 12 | 0;
       i5 = HEAP8[i8 + 11 >> 0] | 0;
       i2 = i5 << 24 >> 24 < 0;
       if (i2) {
        i6 = HEAP32[i4 + (i10 * 24 | 0) + 16 >> 2] | 0;
        i3 = HEAP32[i8 >> 2] | 0;
       } else {
        i6 = i5 & 255;
        i3 = i8;
       }
       i7 = i6 + -2 | 0;
       if ((HEAP8[i3 + i7 >> 0] | 0) == 38) i2 = i6 + -3 | 0; else {
        if (i2) {
         i3 = HEAP32[i8 >> 2] | 0;
         i2 = HEAP32[i4 + (i10 * 24 | 0) + 16 >> 2] | 0;
        } else {
         i3 = i8;
         i2 = i5 & 255;
        }
        i2 = (HEAP8[i3 + i2 + -1 >> 0] | 0) == 38 ? i7 : i6;
       }
       if (!i11) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i8, i2, 56614) | 0;
        i2 = i2 + 6 | 0;
       }
       if (!i12) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc((HEAP32[i74 >> 2] | 0) + (i10 * 24 | 0) + 12 | 0, i2, 56621) | 0;
        i2 = i2 + 9 | 0;
       }
       if (!i13) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc((HEAP32[i74 >> 2] | 0) + (i10 * 24 | 0) + 12 | 0, i2, 56631) | 0;
      } else {
       if (!i11) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i74 >> 2] | 0) + (i10 * 24 | 0) | 0, 56614) | 0;
       if (!i12) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i74 >> 2] | 0) + (i10 * 24 | 0) | 0, 56621) | 0;
       if (!i13) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i74 >> 2] | 0) + (i10 * 24 | 0) | 0, 56631) | 0;
      }
      i7 = HEAP32[i16 >> 2] | 0;
      i2 = i7 + -16 | 0;
      i8 = HEAP32[i74 >> 2] | 0;
      i9 = i8 + (i10 * 24 | 0) | 0;
      i3 = i7 + -12 | 0;
      i4 = HEAP32[i3 >> 2] | 0;
      i73 = HEAP32[i7 + -8 >> 2] | 0;
      i5 = i73;
      if ((i4 | 0) == (i73 | 0)) {
       i3 = HEAP32[i2 >> 2] | 0;
       i6 = (i4 - i3 | 0) / 24 | 0;
       i4 = i6 + 1 | 0;
       if (i4 >>> 0 > 178956970) break;
       i3 = (i5 - i3 | 0) / 24 | 0;
       if (i3 >>> 0 < 89478485) {
        i3 = i3 << 1;
        i3 = i3 >>> 0 < i4 >>> 0 ? i4 : i3;
       } else i3 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i75, i3, i6, i7 + -4 | 0);
       i73 = HEAP32[i14 >> 2] | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i73, i9);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i73 + 12 | 0, i8 + (i10 * 24 | 0) + 12 | 0);
       HEAP32[i14 >> 2] = i73 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i2, i75);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i75);
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i4, i9);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i4 + 12 | 0, i8 + (i10 * 24 | 0) + 12 | 0);
       HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 24;
      }
      i10 = i10 + 1 | 0;
     }
     __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2);
    } else i1 = i73; while (0);
    break L1;
   }
  default:
   {}
  }
  i1 = __ZN10__cxxabiv112_GLOBAL__N_118parse_builtin_typeINS0_2DbEEEPKcS4_S4_RT_(i73, i72, i74) | 0;
  if ((i1 | 0) == (i73 | 0)) {
   i2 = HEAP8[i73 >> 0] | 0;
   L69 : do switch (i2 << 24 >> 24 | 0) {
   case 65:
    {
     do if (i2 << 24 >> 24 == 65 ? (i14 = i73 + 1 | 0, (i14 | 0) != (i72 | 0)) : 0) {
      i1 = HEAP8[i14 >> 0] | 0;
      if (i1 << 24 >> 24 == 95) {
       i71 = i73 + 2 | 0;
       i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i71, i72, i74) | 0;
       if ((i1 | 0) == (i71 | 0)) {
        i1 = i73;
        break;
       }
       i3 = i74 + 4 | 0;
       i2 = HEAP32[i3 >> 2] | 0;
       if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
        i1 = i73;
        break;
       }
       i71 = i2 + -12 | 0;
       HEAP32[i75 >> 2] = 0;
       HEAP32[i75 + 4 >> 2] = 0;
       HEAP32[i75 + 8 >> 2] = 0;
       i72 = HEAP8[i71 + 11 >> 0] | 0;
       i70 = i72 << 24 >> 24 < 0;
       i72 = i70 ? HEAP32[i2 + -8 >> 2] | 0 : i72 & 255;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i75, i70 ? HEAP32[i71 >> 2] | 0 : i71, i72 >>> 0 < 2 ? i72 : 2);
       i72 = HEAP8[i75 + 11 >> 0] | 0;
       i2 = i72 << 24 >> 24 < 0;
       if (((i2 ? HEAP32[i75 + 4 >> 2] | 0 : i72 & 255) | 0) == 2) {
        i72 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2 ? HEAP32[i75 >> 2] | 0 : i75, 56955, 2) | 0) == 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i75);
        if (i72) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE5eraseEjj((HEAP32[i3 >> 2] | 0) + -12 | 0);
       } else __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i75);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc((HEAP32[i3 >> 2] | 0) + -12 | 0, 0, 56958) | 0;
       break;
      }
      if ((i1 + -49 & 255) < 9) {
       i7 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i14, i72) | 0;
       if ((i7 | 0) == (i72 | 0)) {
        i1 = i73;
        break;
       }
       if ((HEAP8[i7 >> 0] | 0) != 95) {
        i1 = i73;
        break;
       }
       i71 = i7 + 1 | 0;
       i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i71, i72, i74) | 0;
       if ((i1 | 0) == (i71 | 0)) {
        i1 = i73;
        break;
       }
       i3 = i74 + 4 | 0;
       i2 = HEAP32[i3 >> 2] | 0;
       if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
        i1 = i73;
        break;
       }
       i71 = i2 + -12 | 0;
       HEAP32[i67 >> 2] = 0;
       HEAP32[i67 + 4 >> 2] = 0;
       HEAP32[i67 + 8 >> 2] = 0;
       i72 = HEAP8[i71 + 11 >> 0] | 0;
       i70 = i72 << 24 >> 24 < 0;
       i72 = i70 ? HEAP32[i2 + -8 >> 2] | 0 : i72 & 255;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i67, i70 ? HEAP32[i71 >> 2] | 0 : i71, i72 >>> 0 < 2 ? i72 : 2);
       i72 = HEAP8[i67 + 11 >> 0] | 0;
       i2 = i72 << 24 >> 24 < 0;
       if (((i2 ? HEAP32[i67 + 4 >> 2] | 0 : i72 & 255) | 0) == 2) {
        i72 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2 ? HEAP32[i67 >> 2] | 0 : i67, 56955, 2) | 0) == 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i67);
        if (i72) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE5eraseEjj((HEAP32[i3 >> 2] | 0) + -12 | 0);
       } else __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i67);
       i6 = (HEAP32[i3 >> 2] | 0) + -12 | 0;
       HEAP32[i54 >> 2] = 0;
       HEAP32[i54 + 4 >> 2] = 0;
       HEAP32[i54 + 8 >> 2] = 0;
       i4 = i7 - i14 | 0;
       if (i4 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i54);
       if (i4 >>> 0 < 11) {
        HEAP8[i54 + 11 >> 0] = i4;
        i5 = i54;
       } else {
        i72 = i4 + 16 & -16;
        i5 = _malloc(i72) | 0;
        HEAP32[i54 >> 2] = i5;
        HEAP32[i54 + 8 >> 2] = i72 | -2147483648;
        HEAP32[i54 + 4 >> 2] = i4;
       }
       i2 = i14;
       i3 = i5;
       while (1) {
        if ((i2 | 0) == (i7 | 0)) break;
        HEAP8[i3 >> 0] = HEAP8[i2 >> 0] | 0;
        i2 = i2 + 1 | 0;
        i3 = i3 + 1 | 0;
       }
       HEAP8[i5 + i4 >> 0] = 0;
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i54, 0, 56955) | 0;
       HEAP32[i51 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i51 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i51 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i51, 56962) | 0;
       HEAP32[i65 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i65 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i65 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i72 = HEAP8[i65 + 11 >> 0] | 0;
       i71 = i72 << 24 >> 24 < 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKcj(i6, 0, i71 ? HEAP32[i65 >> 2] | 0 : i65, i71 ? HEAP32[i65 + 4 >> 2] | 0 : i72 & 255) | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i65);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i51);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i54);
       break;
      }
      i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i14, i72, i74) | 0;
      if (((!((i1 | 0) == (i14 | 0) | (i1 | 0) == (i72 | 0)) ? (HEAP8[i1 >> 0] | 0) == 95 : 0) ? (i71 = i1 + 1 | 0, i39 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i71, i72, i74) | 0, (i39 | 0) != (i71 | 0)) : 0) ? (i25 = i74 + 4 | 0, i6 = HEAP32[i25 >> 2] | 0, ((i6 - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) : 0) {
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i64, i6 + -24 | 0);
       i1 = HEAP32[i25 >> 2] | 0;
       i2 = i1 + -24 | 0;
       i3 = i1;
       while (1) {
        if ((i3 | 0) == (i2 | 0)) break;
        i72 = i3 + -24 | 0;
        HEAP32[i25 >> 2] = i72;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i72);
        i3 = HEAP32[i25 >> 2] | 0;
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i66, i1 + -48 | 0);
       i3 = HEAP32[i25 >> 2] | 0;
       i4 = i3 + -24 | 0;
       i1 = i4 + 11 | 0;
       do if ((HEAP8[i1 >> 0] | 0) < 0) {
        HEAP8[HEAP32[i4 >> 2] >> 0] = 0;
        i5 = i3 + -20 | 0;
        HEAP32[i5 >> 2] = 0;
        i2 = HEAP8[i1 >> 0] | 0;
        if (i2 << 24 >> 24 < 0) {
         if ((HEAP32[i3 + -16 >> 2] & 2147483647 | 0) == 11) break;
         i72 = HEAP32[i4 >> 2] | 0;
         HEAP8[i4 >> 0] = HEAP8[i72 >> 0] | 0;
         _free(i72);
         HEAP8[i1 >> 0] = 0;
         break;
        } else {
         i1 = i2 & 255;
         if ((i2 & 255) < 11) break;
         i71 = i1 + 16 & 496;
         i72 = _malloc(i71) | 0;
         _memcpy(i72 | 0, i4 | 0, i1 + 1 | 0) | 0;
         HEAP32[i3 + -16 >> 2] = i71 | -2147483648;
         HEAP32[i5 >> 2] = i1;
         HEAP32[i4 >> 2] = i72;
         break;
        }
       } else {
        HEAP8[i4 >> 0] = 0;
        HEAP8[i1 >> 0] = 0;
       } while (0);
       HEAP32[i4 >> 2] = HEAP32[i64 >> 2];
       HEAP32[i4 + 4 >> 2] = HEAP32[i64 + 4 >> 2];
       HEAP32[i4 + 8 >> 2] = HEAP32[i64 + 8 >> 2];
       i1 = 0;
       while (1) {
        if ((i1 | 0) == 3) break;
        HEAP32[i64 + (i1 << 2) >> 2] = 0;
        i1 = i1 + 1 | 0;
       }
       i3 = i64 + 12 | 0;
       HEAP32[i56 >> 2] = 0;
       HEAP32[i56 + 4 >> 2] = 0;
       HEAP32[i56 + 8 >> 2] = 0;
       i4 = i3 + 11 | 0;
       i72 = HEAP8[i4 >> 0] | 0;
       i1 = i72 << 24 >> 24 < 0;
       i5 = i64 + 16 | 0;
       i72 = i1 ? HEAP32[i5 >> 2] | 0 : i72 & 255;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i56, i1 ? HEAP32[i3 >> 2] | 0 : i3, i72 >>> 0 < 2 ? i72 : 2);
       i72 = HEAP8[i56 + 11 >> 0] | 0;
       i1 = i72 << 24 >> 24 < 0;
       if (((i1 ? HEAP32[i56 + 4 >> 2] | 0 : i72 & 255) | 0) == 2) {
        i72 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i1 ? HEAP32[i56 >> 2] | 0 : i56, 56955, 2) | 0) == 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i56);
        if (i72) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE5eraseEjj(i3);
       } else __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i56);
       i6 = HEAP32[i25 >> 2] | 0;
       i7 = i6 + -12 | 0;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i38, i66);
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i38, 0, 56955) | 0;
       HEAP32[i63 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i63 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i63 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i63, 56962) | 0;
       HEAP32[i62 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i62 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i62 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i1 = HEAP8[i4 >> 0] | 0;
       i2 = i1 << 24 >> 24 < 0;
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i62, i2 ? HEAP32[i3 >> 2] | 0 : i3, i2 ? HEAP32[i5 >> 2] | 0 : i1 & 255) | 0;
       HEAP32[i58 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i58 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i58 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i1 = i7 + 11 | 0;
       do if ((HEAP8[i1 >> 0] | 0) < 0) {
        HEAP8[HEAP32[i7 >> 2] >> 0] = 0;
        i3 = i6 + -8 | 0;
        HEAP32[i3 >> 2] = 0;
        i2 = HEAP8[i1 >> 0] | 0;
        if (i2 << 24 >> 24 < 0) {
         if ((HEAP32[i6 + -4 >> 2] & 2147483647 | 0) == 11) break;
         i72 = HEAP32[i7 >> 2] | 0;
         HEAP8[i7 >> 0] = HEAP8[i72 >> 0] | 0;
         _free(i72);
         HEAP8[i1 >> 0] = 0;
         break;
        } else {
         i1 = i2 & 255;
         if ((i2 & 255) < 11) break;
         i71 = i1 + 16 & 496;
         i72 = _malloc(i71) | 0;
         _memcpy(i72 | 0, i7 | 0, i1 + 1 | 0) | 0;
         HEAP32[i6 + -4 >> 2] = i71 | -2147483648;
         HEAP32[i3 >> 2] = i1;
         HEAP32[i7 >> 2] = i72;
         break;
        }
       } else {
        HEAP8[i7 >> 0] = 0;
        HEAP8[i1 >> 0] = 0;
       } while (0);
       HEAP32[i7 >> 2] = HEAP32[i58 >> 2];
       HEAP32[i7 + 4 >> 2] = HEAP32[i58 + 4 >> 2];
       HEAP32[i7 + 8 >> 2] = HEAP32[i58 + 8 >> 2];
       i1 = 0;
       while (1) {
        if ((i1 | 0) == 3) break;
        HEAP32[i58 + (i1 << 2) >> 2] = 0;
        i1 = i1 + 1 | 0;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i58);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i62);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i63);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i38);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i66);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i64);
       i1 = i39;
      } else i1 = i73;
     } else i1 = i73; while (0);
     if ((i1 | 0) == (i73 | 0)) {
      i1 = i73;
      break L1;
     }
     i2 = HEAP32[i74 + 4 >> 2] | 0;
     if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
      i1 = i73;
      break L1;
     }
     i6 = i74 + 16 | 0;
     HEAP32[i53 >> 2] = HEAP32[i74 + 12 >> 2];
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i59, i2 + -24 | 0, i53);
     i2 = i74 + 20 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i73 = HEAP32[i74 + 24 >> 2] | 0;
     i4 = i73;
     if (i3 >>> 0 < i73 >>> 0) {
      HEAP32[i3 + 12 >> 2] = HEAP32[i59 + 12 >> 2];
      HEAP32[i3 >> 2] = HEAP32[i59 >> 2];
      i75 = i59 + 4 | 0;
      HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
      i74 = i59 + 8 | 0;
      HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
      HEAP32[i74 >> 2] = 0;
      HEAP32[i75 >> 2] = 0;
      HEAP32[i59 >> 2] = 0;
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
     } else {
      i2 = HEAP32[i6 >> 2] | 0;
      i5 = i3 - i2 >> 4;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
      i2 = i4 - i2 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
      i74 = i75 + 8 | 0;
      i73 = HEAP32[i74 >> 2] | 0;
      HEAP32[i73 + 12 >> 2] = HEAP32[i59 + 12 >> 2];
      HEAP32[i73 >> 2] = HEAP32[i59 >> 2];
      i72 = i59 + 4 | 0;
      HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
      i71 = i59 + 8 | 0;
      HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
      HEAP32[i71 >> 2] = 0;
      HEAP32[i72 >> 2] = 0;
      HEAP32[i59 >> 2] = 0;
      HEAP32[i74 >> 2] = i73 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i59);
     break L1;
    }
   case 67:
    {
     i71 = i73 + 1 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i71, i72, i74) | 0;
     if ((i1 | 0) == (i71 | 0)) {
      i1 = i73;
      break L1;
     }
     i3 = i74 + 4 | 0;
     i2 = HEAP32[i3 >> 2] | 0;
     if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
      i1 = i73;
      break L1;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + -24 | 0, 58196) | 0;
     i6 = i74 + 16 | 0;
     i2 = (HEAP32[i3 >> 2] | 0) + -24 | 0;
     HEAP32[i8 >> 2] = HEAP32[i74 + 12 >> 2];
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i16, i2, i8);
     i2 = i74 + 20 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i73 = HEAP32[i74 + 24 >> 2] | 0;
     i4 = i73;
     if (i3 >>> 0 < i73 >>> 0) {
      HEAP32[i3 + 12 >> 2] = HEAP32[i16 + 12 >> 2];
      HEAP32[i3 >> 2] = HEAP32[i16 >> 2];
      i75 = i16 + 4 | 0;
      HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
      i74 = i16 + 8 | 0;
      HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
      HEAP32[i74 >> 2] = 0;
      HEAP32[i75 >> 2] = 0;
      HEAP32[i16 >> 2] = 0;
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
     } else {
      i2 = HEAP32[i6 >> 2] | 0;
      i5 = i3 - i2 >> 4;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
      i2 = i4 - i2 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
      i74 = i75 + 8 | 0;
      i73 = HEAP32[i74 >> 2] | 0;
      HEAP32[i73 + 12 >> 2] = HEAP32[i16 + 12 >> 2];
      HEAP32[i73 >> 2] = HEAP32[i16 >> 2];
      i72 = i16 + 4 | 0;
      HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
      i71 = i16 + 8 | 0;
      HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
      HEAP32[i71 >> 2] = 0;
      HEAP32[i72 >> 2] = 0;
      HEAP32[i16 >> 2] = 0;
      HEAP32[i74 >> 2] = i73 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i16);
     break L1;
    }
   case 70:
    {
     do if (i2 << 24 >> 24 == 70) {
      i1 = i73 + 1 | 0;
      if ((i1 | 0) != (i72 | 0)) {
       if ((HEAP8[i1 >> 0] | 0) == 89) {
        i1 = i73 + 2 | 0;
        if ((i1 | 0) == (i72 | 0)) break;
       }
       i3 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i1, i72, i74) | 0;
       if ((i3 | 0) != (i1 | 0)) {
        HEAP32[i75 >> 2] = 0;
        HEAP32[i75 + 4 >> 2] = 0;
        HEAP32[i75 + 8 >> 2] = 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i75, 56964, 1);
        i11 = i74 + 4 | 0;
        i9 = i75 + 11 | 0;
        i10 = i75 + 4 | 0;
        i7 = i67 + 11 | 0;
        i8 = i67 + 4 | 0;
        i2 = 0;
        i1 = i3;
        L201 : while (1) L203 : while (1) {
         if ((i1 | 0) == (i72 | 0)) {
          i71 = 154;
          break L201;
         }
         switch (HEAP8[i1 >> 0] | 0) {
         case 69:
          {
           i71 = 158;
           break L201;
          }
         case 118:
          {
           i1 = i1 + 1 | 0;
           continue L203;
          }
         case 82:
          {
           i3 = i1 + 1 | 0;
           if ((i3 | 0) != (i72 | 0) ? (HEAP8[i3 >> 0] | 0) == 69 : 0) {
            i2 = 1;
            i1 = i3;
            continue L201;
           }
           break;
          }
         case 79:
          {
           i3 = i1 + 1 | 0;
           if ((i3 | 0) != (i72 | 0) ? (HEAP8[i3 >> 0] | 0) == 69 : 0) {
            i2 = 2;
            i1 = i3;
            continue L201;
           }
           break;
          }
         default:
          {}
         }
         i3 = ((HEAP32[i11 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
         i5 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i1, i72, i74) | 0;
         i6 = ((HEAP32[i11 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
         if ((i5 | 0) == (i1 | 0) | (i5 | 0) == (i72 | 0)) break L201; else i1 = i3;
         while (1) {
          if (i1 >>> 0 >= i6 >>> 0) break;
          i70 = HEAP8[i9 >> 0] | 0;
          if ((i70 << 24 >> 24 < 0 ? HEAP32[i10 >> 2] | 0 : i70 & 255) >>> 0 > 1) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i75, 57598) | 0;
          __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i67, (HEAP32[i74 >> 2] | 0) + (i1 * 24 | 0) | 0);
          i70 = HEAP8[i7 >> 0] | 0;
          i69 = i70 << 24 >> 24 < 0;
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i75, i69 ? HEAP32[i67 >> 2] | 0 : i67, i69 ? HEAP32[i8 >> 2] | 0 : i70 & 255) | 0;
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i67);
          i1 = i1 + 1 | 0;
         }
         while (1) {
          if (i3 >>> 0 >= i6 >>> 0) {
           i1 = i5;
           continue L203;
          }
          i4 = HEAP32[i11 >> 2] | 0;
          i1 = i4 + -24 | 0;
          while (1) {
           if ((i4 | 0) == (i1 | 0)) break;
           i70 = i4 + -24 | 0;
           HEAP32[i11 >> 2] = i70;
           __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i70);
           i4 = HEAP32[i11 >> 2] | 0;
          }
          i3 = i3 + 1 | 0;
         }
        }
        L226 : do if ((i71 | 0) == 154) {
         i2 = HEAP32[i11 >> 2] | 0;
         i1 = i2 + -24 | 0;
         while (1) {
          if ((i2 | 0) == (i1 | 0)) break L226;
          i74 = i2 + -24 | 0;
          HEAP32[i11 >> 2] = i74;
          __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i74);
          i2 = HEAP32[i11 >> 2] | 0;
         }
        } else if ((i71 | 0) == 158) {
         i1 = i1 + 1 | 0;
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i75, 56966) | 0;
         switch (i2 | 0) {
         case 1:
          {
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i75, 58205) | 0;
           break;
          }
         case 2:
          {
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i75, 58208) | 0;
           break;
          }
         default:
          {}
         }
         i2 = HEAP32[i11 >> 2] | 0;
         if ((HEAP32[i74 >> 2] | 0) != (i2 | 0)) {
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + -24 | 0, 58055) | 0;
          i72 = HEAP8[i9 >> 0] | 0;
          i71 = i72 << 24 >> 24 < 0;
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKcj((HEAP32[i11 >> 2] | 0) + -12 | 0, 0, i71 ? HEAP32[i75 >> 2] | 0 : i75, i71 ? HEAP32[i10 >> 2] | 0 : i72 & 255) | 0;
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i75);
          if ((i1 | 0) == (i73 | 0)) {
           i1 = i73;
           break L1;
          }
          i2 = HEAP32[i11 >> 2] | 0;
          if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
           i1 = i73;
           break L1;
          }
          i6 = i74 + 16 | 0;
          HEAP32[i36 >> 2] = HEAP32[i74 + 12 >> 2];
          __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i43, i2 + -24 | 0, i36);
          i2 = i74 + 20 | 0;
          i3 = HEAP32[i2 >> 2] | 0;
          i73 = HEAP32[i74 + 24 >> 2] | 0;
          i4 = i73;
          if (i3 >>> 0 < i73 >>> 0) {
           HEAP32[i3 + 12 >> 2] = HEAP32[i43 + 12 >> 2];
           HEAP32[i3 >> 2] = HEAP32[i43 >> 2];
           i75 = i43 + 4 | 0;
           HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
           i74 = i43 + 8 | 0;
           HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
           HEAP32[i74 >> 2] = 0;
           HEAP32[i75 >> 2] = 0;
           HEAP32[i43 >> 2] = 0;
           HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
          } else {
           i2 = HEAP32[i6 >> 2] | 0;
           i5 = i3 - i2 >> 4;
           i3 = i5 + 1 | 0;
           if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
           i2 = i4 - i2 | 0;
           if (i2 >> 4 >>> 0 < 134217727) {
            i2 = i2 >> 3;
            i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
           } else i2 = 268435455;
           __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
           i74 = i75 + 8 | 0;
           i73 = HEAP32[i74 >> 2] | 0;
           HEAP32[i73 + 12 >> 2] = HEAP32[i43 + 12 >> 2];
           HEAP32[i73 >> 2] = HEAP32[i43 >> 2];
           i72 = i43 + 4 | 0;
           HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
           i71 = i43 + 8 | 0;
           HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
           HEAP32[i71 >> 2] = 0;
           HEAP32[i72 >> 2] = 0;
           HEAP32[i43 >> 2] = 0;
           HEAP32[i74 >> 2] = i73 + 16;
           __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
           __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
          }
          __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i43);
          break L1;
         }
        } while (0);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i75);
        break;
       }
      }
      i1 = i73;
      break L1;
     } while (0);
     i1 = i73;
     break L1;
    }
   case 71:
    {
     i71 = i73 + 1 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i71, i72, i74) | 0;
     if ((i1 | 0) == (i71 | 0)) {
      i1 = i73;
      break L1;
     }
     i3 = i74 + 4 | 0;
     i2 = HEAP32[i3 >> 2] | 0;
     if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
      i1 = i73;
      break L1;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + -24 | 0, 58212) | 0;
     i6 = i74 + 16 | 0;
     i2 = (HEAP32[i3 >> 2] | 0) + -24 | 0;
     HEAP32[i9 >> 2] = HEAP32[i74 + 12 >> 2];
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i17, i2, i9);
     i2 = i74 + 20 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i73 = HEAP32[i74 + 24 >> 2] | 0;
     i4 = i73;
     if (i3 >>> 0 < i73 >>> 0) {
      HEAP32[i3 + 12 >> 2] = HEAP32[i17 + 12 >> 2];
      HEAP32[i3 >> 2] = HEAP32[i17 >> 2];
      i75 = i17 + 4 | 0;
      HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
      i74 = i17 + 8 | 0;
      HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
      HEAP32[i74 >> 2] = 0;
      HEAP32[i75 >> 2] = 0;
      HEAP32[i17 >> 2] = 0;
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
     } else {
      i2 = HEAP32[i6 >> 2] | 0;
      i5 = i3 - i2 >> 4;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
      i2 = i4 - i2 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
      i74 = i75 + 8 | 0;
      i73 = HEAP32[i74 >> 2] | 0;
      HEAP32[i73 + 12 >> 2] = HEAP32[i17 + 12 >> 2];
      HEAP32[i73 >> 2] = HEAP32[i17 >> 2];
      i72 = i17 + 4 | 0;
      HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
      i71 = i17 + 8 | 0;
      HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
      HEAP32[i71 >> 2] = 0;
      HEAP32[i72 >> 2] = 0;
      HEAP32[i17 >> 2] = 0;
      HEAP32[i74 >> 2] = i73 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i17);
     break L1;
    }
   case 77:
    {
     if (((i2 << 24 >> 24 == 77 ? (i71 = i73 + 1 | 0, i4 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i71, i72, i74) | 0, (i4 | 0) != (i71 | 0)) : 0) ? (i50 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i4, i72, i74) | 0, (i50 | 0) != (i4 | 0)) : 0) ? (i37 = i74 + 4 | 0, i5 = HEAP32[i37 >> 2] | 0, ((i5 - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) : 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i75, i5 + -24 | 0);
      i1 = HEAP32[i37 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i72 = i3 + -24 | 0;
       HEAP32[i37 >> 2] = i72;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i72);
       i3 = HEAP32[i37 >> 2] | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i67, i1 + -48 | 0);
      i6 = i75 + 12 | 0;
      i4 = HEAP32[i37 >> 2] | 0;
      i5 = i4 + -24 | 0;
      L275 : do if ((HEAP8[((HEAP8[i6 + 11 >> 0] | 0) < 0 ? HEAP32[i6 >> 2] | 0 : i6) >> 0] | 0) == 40) {
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i75, 56964) | 0;
       HEAP32[i54 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i54 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i54 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i64, i67);
       i1 = HEAP8[i64 + 11 >> 0] | 0;
       i2 = i1 << 24 >> 24 < 0;
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i54, i2 ? HEAP32[i64 >> 2] | 0 : i64, i2 ? HEAP32[i64 + 4 >> 2] | 0 : i1 & 255) | 0;
       HEAP32[i51 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i51 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i51 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i51, 58223) | 0;
       HEAP32[i65 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i65 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i65 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i1 = i5 + 11 | 0;
       do if ((HEAP8[i1 >> 0] | 0) < 0) {
        HEAP8[HEAP32[i5 >> 2] >> 0] = 0;
        i3 = i4 + -20 | 0;
        HEAP32[i3 >> 2] = 0;
        i2 = HEAP8[i1 >> 0] | 0;
        if (i2 << 24 >> 24 < 0) {
         if ((HEAP32[i4 + -16 >> 2] & 2147483647 | 0) == 11) break;
         i72 = HEAP32[i5 >> 2] | 0;
         HEAP8[i5 >> 0] = HEAP8[i72 >> 0] | 0;
         _free(i72);
         HEAP8[i1 >> 0] = 0;
         break;
        } else {
         i1 = i2 & 255;
         if ((i2 & 255) < 11) break;
         i71 = i1 + 16 & 496;
         i72 = _malloc(i71) | 0;
         _memcpy(i72 | 0, i5 | 0, i1 + 1 | 0) | 0;
         HEAP32[i4 + -16 >> 2] = i71 | -2147483648;
         HEAP32[i3 >> 2] = i1;
         HEAP32[i5 >> 2] = i72;
         break;
        }
       } else {
        HEAP8[i5 >> 0] = 0;
        HEAP8[i1 >> 0] = 0;
       } while (0);
       HEAP32[i5 >> 2] = HEAP32[i65 >> 2];
       HEAP32[i5 + 4 >> 2] = HEAP32[i65 + 4 >> 2];
       HEAP32[i5 + 8 >> 2] = HEAP32[i65 + 8 >> 2];
       i1 = 0;
       while (1) {
        if ((i1 | 0) == 3) break;
        HEAP32[i65 + (i1 << 2) >> 2] = 0;
        i1 = i1 + 1 | 0;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i65);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i51);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i64);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i54);
       i5 = HEAP32[i37 >> 2] | 0;
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i6, 0, 56966) | 0;
       HEAP32[i66 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i66 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i66 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i3 = i5 + -12 | 0;
       i1 = i3 + 11 | 0;
       do if ((HEAP8[i1 >> 0] | 0) < 0) {
        HEAP8[HEAP32[i3 >> 2] >> 0] = 0;
        i4 = i5 + -8 | 0;
        HEAP32[i4 >> 2] = 0;
        i2 = HEAP8[i1 >> 0] | 0;
        if (i2 << 24 >> 24 < 0) {
         if ((HEAP32[i5 + -4 >> 2] & 2147483647 | 0) == 11) break;
         i72 = HEAP32[i3 >> 2] | 0;
         HEAP8[i3 >> 0] = HEAP8[i72 >> 0] | 0;
         _free(i72);
         HEAP8[i1 >> 0] = 0;
         break;
        } else {
         i1 = i2 & 255;
         if ((i2 & 255) < 11) break;
         i71 = i1 + 16 & 496;
         i72 = _malloc(i71) | 0;
         _memcpy(i72 | 0, i3 | 0, i1 + 1 | 0) | 0;
         HEAP32[i5 + -4 >> 2] = i71 | -2147483648;
         HEAP32[i4 >> 2] = i1;
         HEAP32[i3 >> 2] = i72;
         break;
        }
       } else {
        HEAP8[i3 >> 0] = 0;
        HEAP8[i1 >> 0] = 0;
       } while (0);
       HEAP32[i3 >> 2] = HEAP32[i66 >> 2];
       HEAP32[i3 + 4 >> 2] = HEAP32[i66 + 4 >> 2];
       HEAP32[i3 + 8 >> 2] = HEAP32[i66 + 8 >> 2];
       i1 = 0;
       while (1) {
        if ((i1 | 0) == 3) break;
        HEAP32[i66 + (i1 << 2) >> 2] = 0;
        i1 = i1 + 1 | 0;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i66);
      } else {
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i75, 58055) | 0;
       HEAP32[i62 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i62 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i62 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i63, i67);
       i1 = HEAP8[i63 + 11 >> 0] | 0;
       i2 = i1 << 24 >> 24 < 0;
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i62, i2 ? HEAP32[i63 >> 2] | 0 : i63, i2 ? HEAP32[i63 + 4 >> 2] | 0 : i1 & 255) | 0;
       HEAP32[i58 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i58 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i58 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i58, 58223) | 0;
       HEAP32[i56 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i56 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i56 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i1 = i5 + 11 | 0;
       do if ((HEAP8[i1 >> 0] | 0) < 0) {
        HEAP8[HEAP32[i5 >> 2] >> 0] = 0;
        i3 = i4 + -20 | 0;
        HEAP32[i3 >> 2] = 0;
        i2 = HEAP8[i1 >> 0] | 0;
        if (i2 << 24 >> 24 < 0) {
         if ((HEAP32[i4 + -16 >> 2] & 2147483647 | 0) == 11) break;
         i72 = HEAP32[i5 >> 2] | 0;
         HEAP8[i5 >> 0] = HEAP8[i72 >> 0] | 0;
         _free(i72);
         HEAP8[i1 >> 0] = 0;
         break;
        } else {
         i1 = i2 & 255;
         if ((i2 & 255) < 11) break;
         i71 = i1 + 16 & 496;
         i72 = _malloc(i71) | 0;
         _memcpy(i72 | 0, i5 | 0, i1 + 1 | 0) | 0;
         HEAP32[i4 + -16 >> 2] = i71 | -2147483648;
         HEAP32[i3 >> 2] = i1;
         HEAP32[i5 >> 2] = i72;
         break;
        }
       } else {
        HEAP8[i5 >> 0] = 0;
        HEAP8[i1 >> 0] = 0;
       } while (0);
       HEAP32[i5 >> 2] = HEAP32[i56 >> 2];
       HEAP32[i5 + 4 >> 2] = HEAP32[i56 + 4 >> 2];
       HEAP32[i5 + 8 >> 2] = HEAP32[i56 + 8 >> 2];
       i1 = 0;
       while (1) {
        if ((i1 | 0) == 3) break;
        HEAP32[i56 + (i1 << 2) >> 2] = 0;
        i1 = i1 + 1 | 0;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i56);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i58);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i63);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i62);
       i3 = HEAP32[i37 >> 2] | 0;
       i4 = i3 + -12 | 0;
       i1 = i4 + 11 | 0;
       do if ((HEAP8[i1 >> 0] | 0) < 0) {
        HEAP8[HEAP32[i4 >> 2] >> 0] = 0;
        i5 = i3 + -8 | 0;
        HEAP32[i5 >> 2] = 0;
        i2 = HEAP8[i1 >> 0] | 0;
        if (i2 << 24 >> 24 < 0) {
         if ((HEAP32[i3 + -4 >> 2] & 2147483647 | 0) == 11) break;
         i72 = HEAP32[i4 >> 2] | 0;
         HEAP8[i4 >> 0] = HEAP8[i72 >> 0] | 0;
         _free(i72);
         HEAP8[i1 >> 0] = 0;
         break;
        } else {
         i1 = i2 & 255;
         if ((i2 & 255) < 11) break;
         i71 = i1 + 16 & 496;
         i72 = _malloc(i71) | 0;
         _memcpy(i72 | 0, i4 | 0, i1 + 1 | 0) | 0;
         HEAP32[i3 + -4 >> 2] = i71 | -2147483648;
         HEAP32[i5 >> 2] = i1;
         HEAP32[i4 >> 2] = i72;
         break;
        }
       } else {
        HEAP8[i4 >> 0] = 0;
        HEAP8[i1 >> 0] = 0;
       } while (0);
       HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
       HEAP32[i4 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
       HEAP32[i4 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
       i1 = 0;
       while (1) {
        if ((i1 | 0) == 3) break L275;
        HEAP32[i6 + (i1 << 2) >> 2] = 0;
        i1 = i1 + 1 | 0;
       }
      } while (0);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i67);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i75);
      i1 = i50;
     } else i1 = i73;
     if ((i1 | 0) == (i73 | 0)) {
      i1 = i73;
      break L1;
     }
     i2 = HEAP32[i74 + 4 >> 2] | 0;
     if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
      i1 = i73;
      break L1;
     }
     i6 = i74 + 16 | 0;
     HEAP32[i52 >> 2] = HEAP32[i74 + 12 >> 2];
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i57, i2 + -24 | 0, i52);
     i2 = i74 + 20 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i73 = HEAP32[i74 + 24 >> 2] | 0;
     i4 = i73;
     if (i3 >>> 0 < i73 >>> 0) {
      HEAP32[i3 + 12 >> 2] = HEAP32[i57 + 12 >> 2];
      HEAP32[i3 >> 2] = HEAP32[i57 >> 2];
      i75 = i57 + 4 | 0;
      HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
      i74 = i57 + 8 | 0;
      HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
      HEAP32[i74 >> 2] = 0;
      HEAP32[i75 >> 2] = 0;
      HEAP32[i57 >> 2] = 0;
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
     } else {
      i2 = HEAP32[i6 >> 2] | 0;
      i5 = i3 - i2 >> 4;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
      i2 = i4 - i2 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
      i74 = i75 + 8 | 0;
      i73 = HEAP32[i74 >> 2] | 0;
      HEAP32[i73 + 12 >> 2] = HEAP32[i57 + 12 >> 2];
      HEAP32[i73 >> 2] = HEAP32[i57 >> 2];
      i72 = i57 + 4 | 0;
      HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
      i71 = i57 + 8 | 0;
      HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
      HEAP32[i71 >> 2] = 0;
      HEAP32[i72 >> 2] = 0;
      HEAP32[i57 >> 2] = 0;
      HEAP32[i74 >> 2] = i73 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i57);
     break L1;
    }
   case 79:
    {
     i14 = i74 + 4 | 0;
     i9 = ((HEAP32[i14 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
     i67 = i73 + 1 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i67, i72, i74) | 0;
     i14 = ((HEAP32[i14 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
     if ((i1 | 0) == (i67 | 0)) {
      i1 = i73;
      break L1;
     }
     i7 = i74 + 16 | 0;
     i8 = HEAP32[i74 + 12 >> 2] | 0;
     i15 = i74 + 20 | 0;
     i2 = HEAP32[i15 >> 2] | 0;
     i67 = HEAP32[i74 + 24 >> 2] | 0;
     i3 = i67;
     if (i2 >>> 0 < i67 >>> 0) {
      HEAP32[i2 >> 2] = 0;
      HEAP32[i2 + 4 >> 2] = 0;
      HEAP32[i2 + 8 >> 2] = 0;
      HEAP32[i2 + 12 >> 2] = i8;
      HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + 16;
     } else {
      i4 = HEAP32[i7 >> 2] | 0;
      i6 = i2 - i4 >> 4;
      i5 = i6 + 1 | 0;
      if (i5 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
      i2 = i3 - i4 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i6, i74 + 28 | 0);
      i67 = i75 + 8 | 0;
      i66 = HEAP32[i67 >> 2] | 0;
      HEAP32[i66 >> 2] = 0;
      HEAP32[i66 + 4 >> 2] = 0;
      HEAP32[i66 + 8 >> 2] = 0;
      HEAP32[i66 + 12 >> 2] = i8;
      HEAP32[i67 >> 2] = i66 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i7, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     i11 = i41 + 11 | 0;
     i12 = i41 + 4 | 0;
     i13 = i75 + 8 | 0;
     while (1) {
      if (i9 >>> 0 >= i14 >>> 0) break L1;
      i65 = HEAP32[i74 >> 2] | 0;
      i2 = i65 + (i9 * 24 | 0) + 12 | 0;
      HEAP32[i41 >> 2] = 0;
      HEAP32[i41 + 4 >> 2] = 0;
      HEAP32[i41 + 8 >> 2] = 0;
      i67 = HEAP8[i2 + 11 >> 0] | 0;
      i66 = i67 << 24 >> 24 < 0;
      i67 = i66 ? HEAP32[i65 + (i9 * 24 | 0) + 16 >> 2] | 0 : i67 & 255;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i41, i66 ? HEAP32[i2 >> 2] | 0 : i2, i67 >>> 0 < 2 ? i67 : 2);
      i67 = HEAP8[i11 >> 0] | 0;
      i2 = i67 << 24 >> 24 < 0;
      if (((i2 ? HEAP32[i12 >> 2] | 0 : i67 & 255) | 0) == 2) {
       i67 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2 ? HEAP32[i41 >> 2] | 0 : i41, 56955, 2) | 0) == 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i41);
       i2 = HEAP32[i74 >> 2] | 0;
       if (i67) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + (i9 * 24 | 0) | 0, 57016) | 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc((HEAP32[i74 >> 2] | 0) + (i9 * 24 | 0) + 12 | 0, 0, 56966) | 0;
       } else i71 = 295;
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i41);
       i2 = HEAP32[i74 >> 2] | 0;
       i71 = 295;
      }
      if ((i71 | 0) == 295) {
       i71 = 0;
       i3 = i2 + (i9 * 24 | 0) + 12 | 0;
       if ((HEAP8[i3 + 11 >> 0] | 0) < 0) i3 = HEAP32[i3 >> 2] | 0;
       if ((HEAP8[i3 >> 0] | 0) == 40) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + (i9 * 24 | 0) | 0, 56964) | 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc((HEAP32[i74 >> 2] | 0) + (i9 * 24 | 0) + 12 | 0, 0, 56966) | 0;
       }
      }
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i74 >> 2] | 0) + (i9 * 24 | 0) | 0, 57008) | 0;
      i6 = HEAP32[i15 >> 2] | 0;
      i7 = i6 + -16 | 0;
      i8 = HEAP32[i74 >> 2] | 0;
      i10 = i8 + (i9 * 24 | 0) | 0;
      i2 = i6 + -12 | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      i67 = HEAP32[i6 + -8 >> 2] | 0;
      i4 = i67;
      if ((i3 | 0) == (i67 | 0)) {
       i2 = HEAP32[i7 >> 2] | 0;
       i5 = (i3 - i2 | 0) / 24 | 0;
       i3 = i5 + 1 | 0;
       if (i3 >>> 0 > 178956970) {
        i1 = i7;
        break;
       }
       i2 = (i4 - i2 | 0) / 24 | 0;
       if (i2 >>> 0 < 89478485) {
        i2 = i2 << 1;
        i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
       } else i2 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i75, i2, i5, i6 + -4 | 0);
       i67 = HEAP32[i13 >> 2] | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i67, i10);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i67 + 12 | 0, i8 + (i9 * 24 | 0) + 12 | 0);
       HEAP32[i13 >> 2] = i67 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i75);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i75);
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i3, i10);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i3 + 12 | 0, i8 + (i9 * 24 | 0) + 12 | 0);
       HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
      }
      i9 = i9 + 1 | 0;
     }
     __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i1);
     break;
    }
   case 80:
    {
     i17 = i74 + 4 | 0;
     i9 = ((HEAP32[i17 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
     i16 = i73 + 1 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i16, i72, i74) | 0;
     i17 = ((HEAP32[i17 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
     if ((i1 | 0) == (i16 | 0)) {
      i1 = i73;
      break L1;
     }
     i7 = i74 + 16 | 0;
     i8 = HEAP32[i74 + 12 >> 2] | 0;
     i18 = i74 + 20 | 0;
     i2 = HEAP32[i18 >> 2] | 0;
     i67 = HEAP32[i74 + 24 >> 2] | 0;
     i3 = i67;
     if (i2 >>> 0 < i67 >>> 0) {
      HEAP32[i2 >> 2] = 0;
      HEAP32[i2 + 4 >> 2] = 0;
      HEAP32[i2 + 8 >> 2] = 0;
      HEAP32[i2 + 12 >> 2] = i8;
      HEAP32[i18 >> 2] = (HEAP32[i18 >> 2] | 0) + 16;
     } else {
      i4 = HEAP32[i7 >> 2] | 0;
      i6 = i2 - i4 >> 4;
      i5 = i6 + 1 | 0;
      if (i5 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
      i2 = i3 - i4 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i6, i74 + 28 | 0);
      i67 = i75 + 8 | 0;
      i66 = HEAP32[i67 >> 2] | 0;
      HEAP32[i66 >> 2] = 0;
      HEAP32[i66 + 4 >> 2] = 0;
      HEAP32[i66 + 8 >> 2] = 0;
      HEAP32[i66 + 12 >> 2] = i8;
      HEAP32[i67 >> 2] = i66 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i7, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     i11 = i60 + 11 | 0;
     i12 = i60 + 4 | 0;
     i13 = i61 + 11 | 0;
     i14 = i61 + 4 | 0;
     i15 = i75 + 8 | 0;
     while (1) {
      if (i9 >>> 0 >= i17 >>> 0) break L1;
      i65 = HEAP32[i74 >> 2] | 0;
      i2 = i65 + (i9 * 24 | 0) + 12 | 0;
      HEAP32[i60 >> 2] = 0;
      HEAP32[i60 + 4 >> 2] = 0;
      HEAP32[i60 + 8 >> 2] = 0;
      i67 = HEAP8[i2 + 11 >> 0] | 0;
      i66 = i67 << 24 >> 24 < 0;
      i67 = i66 ? HEAP32[i65 + (i9 * 24 | 0) + 16 >> 2] | 0 : i67 & 255;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i60, i66 ? HEAP32[i2 >> 2] | 0 : i2, i67 >>> 0 < 2 ? i67 : 2);
      i67 = HEAP8[i11 >> 0] | 0;
      i2 = i67 << 24 >> 24 < 0;
      if (((i2 ? HEAP32[i12 >> 2] | 0 : i67 & 255) | 0) == 2) {
       i67 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2 ? HEAP32[i60 >> 2] | 0 : i60, 56955, 2) | 0) == 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i60);
       i2 = HEAP32[i74 >> 2] | 0;
       if (i67) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + (i9 * 24 | 0) | 0, 57016) | 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc((HEAP32[i74 >> 2] | 0) + (i9 * 24 | 0) + 12 | 0, 0, 56966) | 0;
       } else i71 = 322;
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i60);
       i2 = HEAP32[i74 >> 2] | 0;
       i71 = 322;
      }
      if ((i71 | 0) == 322) {
       i71 = 0;
       i3 = i2 + (i9 * 24 | 0) + 12 | 0;
       if ((HEAP8[i3 + 11 >> 0] | 0) < 0) i3 = HEAP32[i3 >> 2] | 0;
       if ((HEAP8[i3 >> 0] | 0) == 40) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + (i9 * 24 | 0) | 0, 56964) | 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc((HEAP32[i74 >> 2] | 0) + (i9 * 24 | 0) + 12 | 0, 0, 56966) | 0;
       }
      }
      i3 = HEAP32[i74 >> 2] | 0;
      i2 = i3 + (i9 * 24 | 0) | 0;
      do if ((HEAP8[i16 >> 0] | 0) == 85) {
       HEAP32[i61 >> 2] = 0;
       HEAP32[i61 + 4 >> 2] = 0;
       HEAP32[i61 + 8 >> 2] = 0;
       i67 = HEAP8[i2 + 11 >> 0] | 0;
       i66 = i67 << 24 >> 24 < 0;
       i67 = i66 ? HEAP32[i3 + (i9 * 24 | 0) + 4 >> 2] | 0 : i67 & 255;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i61, i66 ? HEAP32[i2 >> 2] | 0 : i2, i67 >>> 0 < 12 ? i67 : 12);
       i67 = HEAP8[i13 >> 0] | 0;
       i2 = i67 << 24 >> 24 < 0;
       if (((i2 ? HEAP32[i14 >> 2] | 0 : i67 & 255) | 0) != 12) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i61);
        i2 = (HEAP32[i74 >> 2] | 0) + (i9 * 24 | 0) | 0;
        i71 = 331;
        break;
       }
       i67 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2 ? HEAP32[i61 >> 2] | 0 : i61, 58227, 12) | 0) == 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i61);
       i8 = HEAP32[i74 >> 2] | 0;
       i2 = i8 + (i9 * 24 | 0) | 0;
       if (i67) {
        i10 = i2 + 11 | 0;
        i3 = HEAP8[i10 >> 0] | 0;
        i4 = i3 << 24 >> 24 < 0;
        if (i4) {
         i6 = HEAP32[i8 + (i9 * 24 | 0) + 4 >> 2] | 0;
         i7 = i6;
         i6 = i6 >>> 0 < 11 ? i6 : 11;
         i3 = (HEAP32[i8 + (i9 * 24 | 0) + 8 >> 2] & 2147483647) + -1 | 0;
        } else {
         i6 = i3 & 255;
         i7 = i6;
         i6 = i6 >>> 0 < 11 ? i6 : 11;
         i3 = 10;
        }
        if ((i6 - i7 + i3 | 0) >>> 0 < 2) {
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE21__grow_by_and_replaceEjjjjjjPKc(i2, i3, 2 - i6 + i7 - i3 | 0, i7, 0, i6, 2, 58240);
         break;
        }
        if (i4) i2 = HEAP32[i2 >> 2] | 0;
        L451 : do if ((i6 | 0) != 2) {
         i4 = i7 - i6 | 0;
         if ((i7 | 0) == (i6 | 0)) {
          i4 = i6;
          i6 = 0;
          i5 = 58240;
          i3 = 2;
          i71 = 350;
         } else {
          if (i6 >>> 0 > 2) {
           HEAP8[i2 >> 0] = 105;
           HEAP8[i2 + 1 >> 0] = 100;
           _memmove(i2 + 2 | 0, i2 + i6 | 0, i4 | 0) | 0;
           i4 = i6;
           i3 = 2;
           break;
          }
          i5 = i2 + i6 | 0;
          do if (i2 >>> 0 < 58240 >>> 0 & (i2 + i7 | 0) >>> 0 > 58240 >>> 0) {
           if (i5 >>> 0 <= 58240 >>> 0) {
            i3 = 58240 + (2 - i6) | 0;
            break;
           }
           if (i6 | 0) _memcpy(i2 | 0, 58240, i6 | 0) | 0;
           i3 = 2 - i6 | 0;
           _memmove(i5 + i3 | 0, i5 | 0, i4 | 0) | 0;
           if (!i3) {
            i4 = 0;
            i3 = 0;
            break L451;
           } else {
            i4 = 0;
            i5 = 58242;
            i71 = 350;
            break L451;
           }
          } else i3 = 58240; while (0);
          _memmove(i2 + 2 | 0, i5 | 0, i4 | 0) | 0;
          i4 = i6;
          i6 = 0;
          i5 = i3;
          i3 = 2;
          i71 = 350;
         }
        } else {
         i4 = 2;
         i6 = 0;
         i5 = 58240;
         i3 = 2;
         i71 = 350;
        } while (0);
        if ((i71 | 0) == 350) {
         i71 = 0;
         _memmove(i2 + i6 | 0, i5 | 0, i3 | 0) | 0;
        }
        i3 = i3 - i4 + i7 | 0;
        if ((HEAP8[i10 >> 0] | 0) < 0) HEAP32[i8 + (i9 * 24 | 0) + 4 >> 2] = i3; else HEAP8[i10 >> 0] = i3;
        HEAP8[i2 + i3 >> 0] = 0;
       } else i71 = 331;
      } else i71 = 331; while (0);
      if ((i71 | 0) == 331) {
       i71 = 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2, 57085) | 0;
      }
      i6 = HEAP32[i18 >> 2] | 0;
      i7 = i6 + -16 | 0;
      i8 = HEAP32[i74 >> 2] | 0;
      i10 = i8 + (i9 * 24 | 0) | 0;
      i2 = i6 + -12 | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      i67 = HEAP32[i6 + -8 >> 2] | 0;
      i4 = i67;
      if ((i3 | 0) == (i67 | 0)) {
       i2 = HEAP32[i7 >> 2] | 0;
       i5 = (i3 - i2 | 0) / 24 | 0;
       i3 = i5 + 1 | 0;
       if (i3 >>> 0 > 178956970) {
        i1 = i7;
        break;
       }
       i2 = (i4 - i2 | 0) / 24 | 0;
       if (i2 >>> 0 < 89478485) {
        i2 = i2 << 1;
        i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
       } else i2 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i75, i2, i5, i6 + -4 | 0);
       i67 = HEAP32[i15 >> 2] | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i67, i10);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i67 + 12 | 0, i8 + (i9 * 24 | 0) + 12 | 0);
       HEAP32[i15 >> 2] = i67 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i75);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i75);
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i3, i10);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i3 + 12 | 0, i8 + (i9 * 24 | 0) + 12 | 0);
       HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
      }
      i9 = i9 + 1 | 0;
     }
     __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i1);
     break;
    }
   case 82:
    {
     i14 = i74 + 4 | 0;
     i9 = ((HEAP32[i14 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
     i67 = i73 + 1 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i67, i72, i74) | 0;
     i14 = ((HEAP32[i14 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
     if ((i1 | 0) == (i67 | 0)) {
      i1 = i73;
      break L1;
     }
     i7 = i74 + 16 | 0;
     i8 = HEAP32[i74 + 12 >> 2] | 0;
     i15 = i74 + 20 | 0;
     i2 = HEAP32[i15 >> 2] | 0;
     i67 = HEAP32[i74 + 24 >> 2] | 0;
     i3 = i67;
     if (i2 >>> 0 < i67 >>> 0) {
      HEAP32[i2 >> 2] = 0;
      HEAP32[i2 + 4 >> 2] = 0;
      HEAP32[i2 + 8 >> 2] = 0;
      HEAP32[i2 + 12 >> 2] = i8;
      HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + 16;
     } else {
      i4 = HEAP32[i7 >> 2] | 0;
      i6 = i2 - i4 >> 4;
      i5 = i6 + 1 | 0;
      if (i5 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
      i2 = i3 - i4 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i6, i74 + 28 | 0);
      i67 = i75 + 8 | 0;
      i66 = HEAP32[i67 >> 2] | 0;
      HEAP32[i66 >> 2] = 0;
      HEAP32[i66 + 4 >> 2] = 0;
      HEAP32[i66 + 8 >> 2] = 0;
      HEAP32[i66 + 12 >> 2] = i8;
      HEAP32[i67 >> 2] = i66 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i7, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     i11 = i42 + 11 | 0;
     i12 = i42 + 4 | 0;
     i13 = i75 + 8 | 0;
     while (1) {
      if (i9 >>> 0 >= i14 >>> 0) break L1;
      i65 = HEAP32[i74 >> 2] | 0;
      i2 = i65 + (i9 * 24 | 0) + 12 | 0;
      HEAP32[i42 >> 2] = 0;
      HEAP32[i42 + 4 >> 2] = 0;
      HEAP32[i42 + 8 >> 2] = 0;
      i67 = HEAP8[i2 + 11 >> 0] | 0;
      i66 = i67 << 24 >> 24 < 0;
      i67 = i66 ? HEAP32[i65 + (i9 * 24 | 0) + 16 >> 2] | 0 : i67 & 255;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i42, i66 ? HEAP32[i2 >> 2] | 0 : i2, i67 >>> 0 < 2 ? i67 : 2);
      i67 = HEAP8[i11 >> 0] | 0;
      i2 = i67 << 24 >> 24 < 0;
      if (((i2 ? HEAP32[i12 >> 2] | 0 : i67 & 255) | 0) == 2) {
       i67 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2 ? HEAP32[i42 >> 2] | 0 : i42, 56955, 2) | 0) == 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i42);
       i2 = HEAP32[i74 >> 2] | 0;
       if (i67) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + (i9 * 24 | 0) | 0, 57016) | 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc((HEAP32[i74 >> 2] | 0) + (i9 * 24 | 0) + 12 | 0, 0, 56966) | 0;
       } else i71 = 378;
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i42);
       i2 = HEAP32[i74 >> 2] | 0;
       i71 = 378;
      }
      if ((i71 | 0) == 378) {
       i71 = 0;
       i3 = i2 + (i9 * 24 | 0) + 12 | 0;
       if ((HEAP8[i3 + 11 >> 0] | 0) < 0) i3 = HEAP32[i3 >> 2] | 0;
       if ((HEAP8[i3 >> 0] | 0) == 40) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + (i9 * 24 | 0) | 0, 56964) | 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc((HEAP32[i74 >> 2] | 0) + (i9 * 24 | 0) + 12 | 0, 0, 56966) | 0;
       }
      }
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i74 >> 2] | 0) + (i9 * 24 | 0) | 0, 57019) | 0;
      i6 = HEAP32[i15 >> 2] | 0;
      i7 = i6 + -16 | 0;
      i8 = HEAP32[i74 >> 2] | 0;
      i10 = i8 + (i9 * 24 | 0) | 0;
      i2 = i6 + -12 | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      i67 = HEAP32[i6 + -8 >> 2] | 0;
      i4 = i67;
      if ((i3 | 0) == (i67 | 0)) {
       i2 = HEAP32[i7 >> 2] | 0;
       i5 = (i3 - i2 | 0) / 24 | 0;
       i3 = i5 + 1 | 0;
       if (i3 >>> 0 > 178956970) {
        i1 = i7;
        break;
       }
       i2 = (i4 - i2 | 0) / 24 | 0;
       if (i2 >>> 0 < 89478485) {
        i2 = i2 << 1;
        i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
       } else i2 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i75, i2, i5, i6 + -4 | 0);
       i67 = HEAP32[i13 >> 2] | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i67, i10);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i67 + 12 | 0, i8 + (i9 * 24 | 0) + 12 | 0);
       HEAP32[i13 >> 2] = i67 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i75);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i75);
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i3, i10);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i3 + 12 | 0, i8 + (i9 * 24 | 0) + 12 | 0);
       HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
      }
      i9 = i9 + 1 | 0;
     }
     __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i1);
     break;
    }
   case 84:
    {
     i15 = i74 + 4 | 0;
     i12 = ((HEAP32[i15 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_120parse_template_paramINS0_2DbEEEPKcS4_S4_RT_(i73, i72, i74) | 0;
     i13 = ((HEAP32[i15 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
     if ((i1 | 0) == (i73 | 0)) {
      i1 = i73;
      break L1;
     }
     i18 = i74 + 16 | 0;
     i14 = i74 + 12 | 0;
     i7 = HEAP32[i14 >> 2] | 0;
     i17 = i74 + 20 | 0;
     i2 = HEAP32[i17 >> 2] | 0;
     i16 = i74 + 24 | 0;
     i73 = HEAP32[i16 >> 2] | 0;
     i3 = i73;
     if (i2 >>> 0 < i73 >>> 0) {
      HEAP32[i2 >> 2] = 0;
      HEAP32[i2 + 4 >> 2] = 0;
      HEAP32[i2 + 8 >> 2] = 0;
      HEAP32[i2 + 12 >> 2] = i7;
      HEAP32[i17 >> 2] = (HEAP32[i17 >> 2] | 0) + 16;
     } else {
      i4 = HEAP32[i18 >> 2] | 0;
      i6 = i2 - i4 >> 4;
      i5 = i6 + 1 | 0;
      if (i5 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i18);
      i2 = i3 - i4 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i6, i74 + 28 | 0);
      i73 = i75 + 8 | 0;
      i70 = HEAP32[i73 >> 2] | 0;
      HEAP32[i70 >> 2] = 0;
      HEAP32[i70 + 4 >> 2] = 0;
      HEAP32[i70 + 8 >> 2] = 0;
      HEAP32[i70 + 12 >> 2] = i7;
      HEAP32[i73 >> 2] = i70 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i18, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     i7 = i75 + 8 | 0;
     i11 = i12;
     while (1) {
      if (i11 >>> 0 >= i13 >>> 0) break;
      i8 = HEAP32[i17 >> 2] | 0;
      i2 = i8 + -16 | 0;
      i9 = HEAP32[i74 >> 2] | 0;
      i10 = i9 + (i11 * 24 | 0) | 0;
      i3 = i8 + -12 | 0;
      i4 = HEAP32[i3 >> 2] | 0;
      i73 = HEAP32[i8 + -8 >> 2] | 0;
      i5 = i73;
      if ((i4 | 0) == (i73 | 0)) {
       i3 = HEAP32[i2 >> 2] | 0;
       i6 = (i4 - i3 | 0) / 24 | 0;
       i4 = i6 + 1 | 0;
       if (i4 >>> 0 > 178956970) {
        i71 = 405;
        break;
       }
       i3 = (i5 - i3 | 0) / 24 | 0;
       if (i3 >>> 0 < 89478485) {
        i3 = i3 << 1;
        i3 = i3 >>> 0 < i4 >>> 0 ? i4 : i3;
       } else i3 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i75, i3, i6, i8 + -4 | 0);
       i73 = HEAP32[i7 >> 2] | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i73, i10);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i73 + 12 | 0, i9 + (i11 * 24 | 0) + 12 | 0);
       HEAP32[i7 >> 2] = i73 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i2, i75);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i75);
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i4, i10);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i4 + 12 | 0, i9 + (i11 * 24 | 0) + 12 | 0);
       HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 24;
      }
      i11 = i11 + 1 | 0;
     }
     if ((i71 | 0) == 405) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2);
     if (!((i13 | 0) == (i12 + 1 | 0) & (HEAP8[i74 + 63 >> 0] | 0) != 0)) break L1;
     i6 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i1, i72, i74) | 0;
     if ((i6 | 0) == (i1 | 0)) break L1;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i67, (HEAP32[i15 >> 2] | 0) + -24 | 0);
     i1 = HEAP32[i15 >> 2] | 0;
     i2 = i1 + -24 | 0;
     i3 = i1;
     while (1) {
      if ((i3 | 0) == (i2 | 0)) break;
      i73 = i3 + -24 | 0;
      HEAP32[i15 >> 2] = i73;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i73);
      i3 = HEAP32[i15 >> 2] | 0;
     }
     i73 = HEAP8[i67 + 11 >> 0] | 0;
     i4 = i73 << 24 >> 24 < 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i4 ? HEAP32[i67 >> 2] | 0 : i67, i4 ? HEAP32[i67 + 4 >> 2] | 0 : i73 & 255) | 0;
     i1 = (HEAP32[i15 >> 2] | 0) + -24 | 0;
     HEAP32[i44 >> 2] = HEAP32[i14 >> 2];
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i46, i1, i44);
     i1 = HEAP32[i17 >> 2] | 0;
     i73 = HEAP32[i16 >> 2] | 0;
     i4 = i73;
     if (i1 >>> 0 < i73 >>> 0) {
      HEAP32[i1 + 12 >> 2] = HEAP32[i46 + 12 >> 2];
      HEAP32[i1 >> 2] = HEAP32[i46 >> 2];
      i75 = i46 + 4 | 0;
      HEAP32[i1 + 4 >> 2] = HEAP32[i75 >> 2];
      i74 = i46 + 8 | 0;
      HEAP32[i1 + 8 >> 2] = HEAP32[i74 >> 2];
      HEAP32[i74 >> 2] = 0;
      HEAP32[i75 >> 2] = 0;
      HEAP32[i46 >> 2] = 0;
      HEAP32[i17 >> 2] = (HEAP32[i17 >> 2] | 0) + 16;
     } else {
      i2 = HEAP32[i18 >> 2] | 0;
      i5 = i1 - i2 >> 4;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i18);
      i1 = i4 - i2 | 0;
      if (i1 >> 4 >>> 0 < 134217727) {
       i1 = i1 >> 3;
       i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
      } else i1 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i1, i5, i74 + 28 | 0);
      i74 = i75 + 8 | 0;
      i73 = HEAP32[i74 >> 2] | 0;
      HEAP32[i73 + 12 >> 2] = HEAP32[i46 + 12 >> 2];
      HEAP32[i73 >> 2] = HEAP32[i46 >> 2];
      i72 = i46 + 4 | 0;
      HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
      i71 = i46 + 8 | 0;
      HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
      HEAP32[i71 >> 2] = 0;
      HEAP32[i72 >> 2] = 0;
      HEAP32[i46 >> 2] = 0;
      HEAP32[i74 >> 2] = i73 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i18, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i46);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i67);
     i1 = i6;
     break L1;
    }
   case 85:
    {
     i1 = i73 + 1 | 0;
     if ((i1 | 0) == (i72 | 0)) {
      i1 = i73;
      break L1;
     }
     i2 = __ZN10__cxxabiv112_GLOBAL__N_117parse_source_nameINS0_2DbEEEPKcS4_S4_RT_(i1, i72, i74) | 0;
     if ((i2 | 0) == (i1 | 0)) {
      i1 = i73;
      break L1;
     }
     i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i2, i72, i74) | 0;
     if ((i1 | 0) == (i2 | 0)) {
      i1 = i73;
      break L1;
     }
     i7 = i74 + 4 | 0;
     i2 = HEAP32[i7 >> 2] | 0;
     if (((i2 - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
      i1 = i73;
      break L1;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i67, i2 + -24 | 0);
     i2 = HEAP32[i7 >> 2] | 0;
     i3 = i2 + -24 | 0;
     i4 = i2;
     while (1) {
      if ((i4 | 0) == (i3 | 0)) break;
      i73 = i4 + -24 | 0;
      HEAP32[i7 >> 2] = i73;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i73);
      i4 = HEAP32[i7 >> 2] | 0;
     }
     i72 = i2 + -48 | 0;
     HEAP32[i13 >> 2] = 0;
     HEAP32[i13 + 4 >> 2] = 0;
     HEAP32[i13 + 8 >> 2] = 0;
     i73 = HEAP8[i72 + 11 >> 0] | 0;
     i70 = i73 << 24 >> 24 < 0;
     i73 = i70 ? HEAP32[i2 + -44 >> 2] | 0 : i73 & 255;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i13, i70 ? HEAP32[i72 >> 2] | 0 : i72, i73 >>> 0 < 9 ? i73 : 9);
     i73 = HEAP8[i13 + 11 >> 0] | 0;
     i2 = i73 << 24 >> 24 < 0;
     if (((i2 ? HEAP32[i13 + 4 >> 2] | 0 : i73 & 255) | 0) == 9) {
      i73 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2 ? HEAP32[i13 >> 2] | 0 : i13, 58243, 9) | 0) == 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i13);
      if (i73) {
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i65, (HEAP32[i7 >> 2] | 0) + -24 | 0);
       i3 = HEAP32[i7 >> 2] | 0;
       i2 = i3 + -24 | 0;
       while (1) {
        if ((i3 | 0) == (i2 | 0)) break;
        i73 = i3 + -24 | 0;
        HEAP32[i7 >> 2] = i73;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i73);
        i3 = HEAP32[i7 >> 2] | 0;
       }
       i2 = i65 + 11 | 0;
       i73 = HEAP8[i2 >> 0] | 0;
       i72 = i73 << 24 >> 24 < 0;
       i70 = HEAP32[i65 >> 2] | 0;
       i73 = __ZN10__cxxabiv112_GLOBAL__N_117parse_source_nameINS0_2DbEEEPKcS4_S4_RT_(i72 ? i70 + 9 | 0 : i65 + 9 | 0, (i72 ? i70 : i65) + (i72 ? HEAP32[i65 + 4 >> 2] | 0 : i73 & 255) | 0, i74) | 0;
       if ((i73 | 0) == (((HEAP8[i2 >> 0] | 0) < 0 ? HEAP32[i65 >> 2] | 0 : i65) + 9 | 0)) {
        __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EERKSB_PKS8_(i35, i67, 58055);
        i2 = HEAP8[i2 >> 0] | 0;
        i3 = i2 << 24 >> 24 < 0;
        i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i35, i3 ? HEAP32[i65 >> 2] | 0 : i65, i3 ? HEAP32[i65 + 4 >> 2] | 0 : i2 & 255) | 0;
        HEAP32[i34 >> 2] = HEAP32[i2 >> 2];
        HEAP32[i34 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
        HEAP32[i34 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
        i3 = 0;
        while (1) {
         if ((i3 | 0) == 3) break;
         HEAP32[i2 + (i3 << 2) >> 2] = 0;
         i3 = i3 + 1 | 0;
        }
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i33, i34);
        i2 = HEAP32[i7 >> 2] | 0;
        i73 = HEAP32[i74 + 8 >> 2] | 0;
        i3 = i73;
        if (i2 >>> 0 < i73 >>> 0) {
         __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i33);
         HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
        } else {
         i4 = HEAP32[i74 >> 2] | 0;
         i6 = (i2 - i4 | 0) / 24 | 0;
         i5 = i6 + 1 | 0;
         if (i5 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i74);
         i2 = (i3 - i4 | 0) / 24 | 0;
         if (i2 >>> 0 < 89478485) {
          i2 = i2 << 1;
          i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
         } else i2 = 178956970;
         __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i75, i2, i6, i74 + 12 | 0);
         i73 = i75 + 8 | 0;
         i72 = HEAP32[i73 >> 2] | 0;
         __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i72, i33);
         HEAP32[i73 >> 2] = i72 + 24;
         __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i74, i75);
         __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i75);
        }
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i33);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i34);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i35);
       } else {
        i4 = (HEAP32[i7 >> 2] | 0) + -24 | 0;
        __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EERKSB_PKS8_(i31, i67, 57596);
        __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i32, (HEAP32[i7 >> 2] | 0) + -24 | 0);
        i2 = HEAP8[i32 + 11 >> 0] | 0;
        i3 = i2 << 24 >> 24 < 0;
        i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i31, i3 ? HEAP32[i32 >> 2] | 0 : i32, i3 ? HEAP32[i32 + 4 >> 2] | 0 : i2 & 255) | 0;
        HEAP32[i30 >> 2] = HEAP32[i2 >> 2];
        HEAP32[i30 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
        HEAP32[i30 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
        i3 = 0;
        while (1) {
         if ((i3 | 0) == 3) break;
         HEAP32[i2 + (i3 << 2) >> 2] = 0;
         i3 = i3 + 1 | 0;
        }
        i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i30, 57011) | 0;
        HEAP32[i29 >> 2] = HEAP32[i2 >> 2];
        HEAP32[i29 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
        HEAP32[i29 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
        i3 = 0;
        while (1) {
         if ((i3 | 0) == 3) break;
         HEAP32[i2 + (i3 << 2) >> 2] = 0;
         i3 = i3 + 1 | 0;
        }
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i28, i29);
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i4, i28);
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i28);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i29);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i30);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i32);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i31);
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i65);
      } else i71 = 432;
     } else {
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i13);
      i71 = 432;
     }
     if ((i71 | 0) == 432) {
      i2 = (HEAP32[i7 >> 2] | 0) + -24 | 0;
      __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EERKSB_PKS8_(i21, i67, 58055);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i22, (HEAP32[i7 >> 2] | 0) + -24 | 0);
      i3 = HEAP8[i22 + 11 >> 0] | 0;
      i4 = i3 << 24 >> 24 < 0;
      i3 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i21, i4 ? HEAP32[i22 >> 2] | 0 : i22, i4 ? HEAP32[i22 + 4 >> 2] | 0 : i3 & 255) | 0;
      HEAP32[i20 >> 2] = HEAP32[i3 >> 2];
      HEAP32[i20 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
      HEAP32[i20 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
      i4 = 0;
      while (1) {
       if ((i4 | 0) == 3) break;
       HEAP32[i3 + (i4 << 2) >> 2] = 0;
       i4 = i4 + 1 | 0;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i19, i20);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i2, i19);
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i19);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i20);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i22);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i21);
     }
     i6 = (HEAP32[i7 >> 2] | 0) + -24 | 0;
     HEAP32[i40 >> 2] = HEAP32[i74 + 12 >> 2];
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i45, i6, i40);
     i6 = i74 + 16 | 0;
     i2 = i74 + 20 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i73 = HEAP32[i74 + 24 >> 2] | 0;
     i4 = i73;
     if (i3 >>> 0 < i73 >>> 0) {
      HEAP32[i3 + 12 >> 2] = HEAP32[i45 + 12 >> 2];
      HEAP32[i3 >> 2] = HEAP32[i45 >> 2];
      i75 = i45 + 4 | 0;
      HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
      i74 = i45 + 8 | 0;
      HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
      HEAP32[i74 >> 2] = 0;
      HEAP32[i75 >> 2] = 0;
      HEAP32[i45 >> 2] = 0;
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
     } else {
      i2 = HEAP32[i6 >> 2] | 0;
      i5 = i3 - i2 >> 4;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
      i2 = i4 - i2 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
      i74 = i75 + 8 | 0;
      i73 = HEAP32[i74 >> 2] | 0;
      HEAP32[i73 + 12 >> 2] = HEAP32[i45 + 12 >> 2];
      HEAP32[i73 >> 2] = HEAP32[i45 >> 2];
      i72 = i45 + 4 | 0;
      HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
      i71 = i45 + 8 | 0;
      HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
      HEAP32[i71 >> 2] = 0;
      HEAP32[i72 >> 2] = 0;
      HEAP32[i45 >> 2] = 0;
      HEAP32[i74 >> 2] = i73 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i45);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i67);
     break L1;
    }
   case 83:
    {
     i71 = i73 + 1 | 0;
     if ((i71 | 0) != (i72 | 0) ? (HEAP8[i71 >> 0] | 0) == 116 : 0) {
      i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_nameINS0_2DbEEEPKcS4_S4_RT_(i73, i72, i74) | 0;
      if ((i1 | 0) == (i73 | 0)) {
       i1 = i73;
       break L1;
      }
      i2 = HEAP32[i74 + 4 >> 2] | 0;
      if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
       i1 = i73;
       break L1;
      }
      i6 = i74 + 16 | 0;
      HEAP32[i7 >> 2] = HEAP32[i74 + 12 >> 2];
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i15, i2 + -24 | 0, i7);
      i2 = i74 + 20 | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      i73 = HEAP32[i74 + 24 >> 2] | 0;
      i4 = i73;
      if (i3 >>> 0 < i73 >>> 0) {
       HEAP32[i3 + 12 >> 2] = HEAP32[i15 + 12 >> 2];
       HEAP32[i3 >> 2] = HEAP32[i15 >> 2];
       i75 = i15 + 4 | 0;
       HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
       i74 = i15 + 8 | 0;
       HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
       HEAP32[i74 >> 2] = 0;
       HEAP32[i75 >> 2] = 0;
       HEAP32[i15 >> 2] = 0;
       HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
      } else {
       i2 = HEAP32[i6 >> 2] | 0;
       i5 = i3 - i2 >> 4;
       i3 = i5 + 1 | 0;
       if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
       i2 = i4 - i2 | 0;
       if (i2 >> 4 >>> 0 < 134217727) {
        i2 = i2 >> 3;
        i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
       } else i2 = 268435455;
       __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
       i74 = i75 + 8 | 0;
       i73 = HEAP32[i74 >> 2] | 0;
       HEAP32[i73 + 12 >> 2] = HEAP32[i15 + 12 >> 2];
       HEAP32[i73 >> 2] = HEAP32[i15 >> 2];
       i72 = i15 + 4 | 0;
       HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
       i71 = i15 + 8 | 0;
       HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
       HEAP32[i71 >> 2] = 0;
       HEAP32[i72 >> 2] = 0;
       HEAP32[i15 >> 2] = 0;
       HEAP32[i74 >> 2] = i73 + 16;
       __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
       __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
      }
      __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i15);
      break L1;
     }
     i1 = __ZN10__cxxabiv112_GLOBAL__N_118parse_substitutionINS0_2DbEEEPKcS4_S4_RT_(i73, i72, i74) | 0;
     if ((i1 | 0) == (i73 | 0)) {
      i1 = i73;
      break L1;
     }
     i6 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i1, i72, i74) | 0;
     if ((i6 | 0) == (i1 | 0)) break L1;
     i4 = i74 + 4 | 0;
     i2 = HEAP32[i4 >> 2] | 0;
     if (((i2 - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) break L1;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i67, i2 + -24 | 0);
     i1 = HEAP32[i4 >> 2] | 0;
     i2 = i1 + -24 | 0;
     i3 = i1;
     while (1) {
      if ((i3 | 0) == (i2 | 0)) break;
      i73 = i3 + -24 | 0;
      HEAP32[i4 >> 2] = i73;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i73);
      i3 = HEAP32[i4 >> 2] | 0;
     }
     i5 = HEAP8[i67 + 11 >> 0] | 0;
     i2 = i5 << 24 >> 24 < 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i2 ? HEAP32[i67 >> 2] | 0 : i67, i2 ? HEAP32[i67 + 4 >> 2] | 0 : i5 & 255) | 0;
     i5 = (HEAP32[i4 >> 2] | 0) + -24 | 0;
     HEAP32[i12 >> 2] = HEAP32[i74 + 12 >> 2];
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i26, i5, i12);
     i5 = i74 + 16 | 0;
     i1 = i74 + 20 | 0;
     i2 = HEAP32[i1 >> 2] | 0;
     i73 = HEAP32[i74 + 24 >> 2] | 0;
     i3 = i73;
     if (i2 >>> 0 < i73 >>> 0) {
      HEAP32[i2 + 12 >> 2] = HEAP32[i26 + 12 >> 2];
      HEAP32[i2 >> 2] = HEAP32[i26 >> 2];
      i75 = i26 + 4 | 0;
      HEAP32[i2 + 4 >> 2] = HEAP32[i75 >> 2];
      i74 = i26 + 8 | 0;
      HEAP32[i2 + 8 >> 2] = HEAP32[i74 >> 2];
      HEAP32[i74 >> 2] = 0;
      HEAP32[i75 >> 2] = 0;
      HEAP32[i26 >> 2] = 0;
      HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 16;
     } else {
      i1 = HEAP32[i5 >> 2] | 0;
      i4 = i2 - i1 >> 4;
      i2 = i4 + 1 | 0;
      if (i2 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i5);
      i1 = i3 - i1 | 0;
      if (i1 >> 4 >>> 0 < 134217727) {
       i1 = i1 >> 3;
       i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
      } else i1 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i1, i4, i74 + 28 | 0);
      i74 = i75 + 8 | 0;
      i73 = HEAP32[i74 >> 2] | 0;
      HEAP32[i73 + 12 >> 2] = HEAP32[i26 + 12 >> 2];
      HEAP32[i73 >> 2] = HEAP32[i26 >> 2];
      i72 = i26 + 4 | 0;
      HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
      i71 = i26 + 8 | 0;
      HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
      HEAP32[i71 >> 2] = 0;
      HEAP32[i72 >> 2] = 0;
      HEAP32[i26 >> 2] = 0;
      HEAP32[i74 >> 2] = i73 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i5, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i26);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i67);
     i1 = i6;
     break L1;
    }
   case 68:
    {
     i1 = i73 + 1 | 0;
     if ((i1 | 0) != (i72 | 0)) {
      i1 = HEAP8[i1 >> 0] | 0;
      switch (i1 << 24 >> 24 | 0) {
      case 112:
       {
        i12 = i74 + 4 | 0;
        i9 = ((HEAP32[i12 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
        i71 = i73 + 2 | 0;
        i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i71, i72, i74) | 0;
        i12 = ((HEAP32[i12 >> 2] | 0) - (HEAP32[i74 >> 2] | 0) | 0) / 24 | 0;
        if ((i1 | 0) == (i71 | 0)) break L69;
        i7 = i74 + 16 | 0;
        i8 = HEAP32[i74 + 12 >> 2] | 0;
        i13 = i74 + 20 | 0;
        i2 = HEAP32[i13 >> 2] | 0;
        i71 = HEAP32[i74 + 24 >> 2] | 0;
        i3 = i71;
        if (i2 >>> 0 < i71 >>> 0) {
         HEAP32[i2 >> 2] = 0;
         HEAP32[i2 + 4 >> 2] = 0;
         HEAP32[i2 + 8 >> 2] = 0;
         HEAP32[i2 + 12 >> 2] = i8;
         HEAP32[i13 >> 2] = (HEAP32[i13 >> 2] | 0) + 16;
        } else {
         i4 = HEAP32[i7 >> 2] | 0;
         i6 = i2 - i4 >> 4;
         i5 = i6 + 1 | 0;
         if (i5 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
         i2 = i3 - i4 | 0;
         if (i2 >> 4 >>> 0 < 134217727) {
          i2 = i2 >> 3;
          i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
         } else i2 = 268435455;
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i6, i74 + 28 | 0);
         i71 = i75 + 8 | 0;
         i67 = HEAP32[i71 >> 2] | 0;
         HEAP32[i67 >> 2] = 0;
         HEAP32[i67 + 4 >> 2] = 0;
         HEAP32[i67 + 8 >> 2] = 0;
         HEAP32[i67 + 12 >> 2] = i8;
         HEAP32[i71 >> 2] = i67 + 16;
         __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i7, i75);
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
        }
        i11 = i75 + 8 | 0;
        while (1) {
         if (i9 >>> 0 >= i12 >>> 0) break L1;
         i6 = HEAP32[i13 >> 2] | 0;
         i7 = i6 + -16 | 0;
         i8 = HEAP32[i74 >> 2] | 0;
         i10 = i8 + (i9 * 24 | 0) | 0;
         i2 = i6 + -12 | 0;
         i3 = HEAP32[i2 >> 2] | 0;
         i71 = HEAP32[i6 + -8 >> 2] | 0;
         i4 = i71;
         if ((i3 | 0) == (i71 | 0)) {
          i2 = HEAP32[i7 >> 2] | 0;
          i5 = (i3 - i2 | 0) / 24 | 0;
          i3 = i5 + 1 | 0;
          if (i3 >>> 0 > 178956970) {
           i1 = i7;
           break;
          }
          i2 = (i4 - i2 | 0) / 24 | 0;
          if (i2 >>> 0 < 89478485) {
           i2 = i2 << 1;
           i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
          } else i2 = 178956970;
          __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i75, i2, i5, i6 + -4 | 0);
          i71 = HEAP32[i11 >> 2] | 0;
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i71, i10);
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i71 + 12 | 0, i8 + (i9 * 24 | 0) + 12 | 0);
          HEAP32[i11 >> 2] = i71 + 24;
          __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i75);
          __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i75);
         } else {
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i3, i10);
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i3 + 12 | 0, i8 + (i9 * 24 | 0) + 12 | 0);
          HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
         }
         i9 = i9 + 1 | 0;
        }
        __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i1);
        break;
       }
      case 84:
      case 116:
       {
        i1 = __ZN10__cxxabiv112_GLOBAL__N_114parse_decltypeINS0_2DbEEEPKcS4_S4_RT_(i73, i72, i74) | 0;
        if ((i1 | 0) == (i73 | 0)) break L69;
        i2 = HEAP32[i74 + 4 >> 2] | 0;
        if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
         i1 = i73;
         break L1;
        }
        i6 = i74 + 16 | 0;
        HEAP32[i11 >> 2] = HEAP32[i74 + 12 >> 2];
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i24, i2 + -24 | 0, i11);
        i2 = i74 + 20 | 0;
        i3 = HEAP32[i2 >> 2] | 0;
        i73 = HEAP32[i74 + 24 >> 2] | 0;
        i4 = i73;
        if (i3 >>> 0 < i73 >>> 0) {
         HEAP32[i3 + 12 >> 2] = HEAP32[i24 + 12 >> 2];
         HEAP32[i3 >> 2] = HEAP32[i24 >> 2];
         i75 = i24 + 4 | 0;
         HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
         i74 = i24 + 8 | 0;
         HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
         HEAP32[i74 >> 2] = 0;
         HEAP32[i75 >> 2] = 0;
         HEAP32[i24 >> 2] = 0;
         HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
        } else {
         i2 = HEAP32[i6 >> 2] | 0;
         i5 = i3 - i2 >> 4;
         i3 = i5 + 1 | 0;
         if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
         i2 = i4 - i2 | 0;
         if (i2 >> 4 >>> 0 < 134217727) {
          i2 = i2 >> 3;
          i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
         } else i2 = 268435455;
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
         i74 = i75 + 8 | 0;
         i73 = HEAP32[i74 >> 2] | 0;
         HEAP32[i73 + 12 >> 2] = HEAP32[i24 + 12 >> 2];
         HEAP32[i73 >> 2] = HEAP32[i24 >> 2];
         i72 = i24 + 4 | 0;
         HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
         i71 = i24 + 8 | 0;
         HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
         HEAP32[i71 >> 2] = 0;
         HEAP32[i72 >> 2] = 0;
         HEAP32[i24 >> 2] = 0;
         HEAP32[i74 >> 2] = i73 + 16;
         __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
        }
        __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i24);
        break L1;
       }
      case 118:
       {
        L698 : do if ((i72 - i73 | 0) > 3 & i2 << 24 >> 24 == 68 & i1 << 24 >> 24 == 118) {
         i5 = i73 + 2 | 0;
         i2 = HEAP8[i5 >> 0] | 0;
         if ((i2 + -49 & 255) < 9) {
          i1 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i5, i72) | 0;
          if ((i1 | 0) == (i72 | 0)) {
           i1 = i73;
           break;
          }
          if ((HEAP8[i1 >> 0] | 0) != 95) {
           i1 = i73;
           break;
          }
          i3 = i1 - i5 | 0;
          i2 = i1 + 1 | 0;
          if ((i2 | 0) == (i72 | 0)) {
           i1 = i73;
           break;
          }
          if ((HEAP8[i2 >> 0] | 0) != 112) {
           i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i2, i72, i74) | 0;
           if ((i1 | 0) == (i2 | 0)) {
            i1 = i73;
            break;
           }
           i2 = HEAP32[i74 + 4 >> 2] | 0;
           if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
            i1 = i73;
            break;
           }
           i4 = i2 + -24 | 0;
           HEAP32[i51 >> 2] = 0;
           HEAP32[i51 + 4 >> 2] = 0;
           HEAP32[i51 + 8 >> 2] = 0;
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i51, i5, i3);
           i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i51, 0, 58274) | 0;
           HEAP32[i65 >> 2] = HEAP32[i2 >> 2];
           HEAP32[i65 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
           HEAP32[i65 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
           i3 = 0;
           while (1) {
            if ((i3 | 0) == 3) break;
            HEAP32[i2 + (i3 << 2) >> 2] = 0;
            i3 = i3 + 1 | 0;
           }
           i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i65, 56962) | 0;
           HEAP32[i67 >> 2] = HEAP32[i2 >> 2];
           HEAP32[i67 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
           HEAP32[i67 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
           i3 = 0;
           while (1) {
            if ((i3 | 0) == 3) break;
            HEAP32[i2 + (i3 << 2) >> 2] = 0;
            i3 = i3 + 1 | 0;
           }
           i71 = HEAP8[i67 + 11 >> 0] | 0;
           i66 = i71 << 24 >> 24 < 0;
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4, i66 ? HEAP32[i67 >> 2] | 0 : i67, i66 ? HEAP32[i67 + 4 >> 2] | 0 : i71 & 255) | 0;
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i67);
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i65);
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i51);
           break;
          }
          i1 = i1 + 2 | 0;
          HEAP32[i56 >> 2] = 0;
          HEAP32[i56 + 4 >> 2] = 0;
          HEAP32[i56 + 8 >> 2] = 0;
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i56, i5, i3);
          i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i56, 0, 58283) | 0;
          HEAP32[i66 >> 2] = HEAP32[i2 >> 2];
          HEAP32[i66 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
          HEAP32[i66 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
          i3 = 0;
          while (1) {
           if ((i3 | 0) == 3) break;
           HEAP32[i2 + (i3 << 2) >> 2] = 0;
           i3 = i3 + 1 | 0;
          }
          i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i66, 56962) | 0;
          HEAP32[i64 >> 2] = HEAP32[i2 >> 2];
          HEAP32[i64 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
          HEAP32[i64 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
          i3 = 0;
          while (1) {
           if ((i3 | 0) == 3) break;
           HEAP32[i2 + (i3 << 2) >> 2] = 0;
           i3 = i3 + 1 | 0;
          }
          __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i54, i64);
          i2 = i74 + 4 | 0;
          i3 = HEAP32[i2 >> 2] | 0;
          i71 = HEAP32[i74 + 8 >> 2] | 0;
          i4 = i71;
          if (i3 >>> 0 < i71 >>> 0) {
           __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i54);
           HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
          } else {
           i2 = HEAP32[i74 >> 2] | 0;
           i5 = (i3 - i2 | 0) / 24 | 0;
           i3 = i5 + 1 | 0;
           if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i74);
           i2 = (i4 - i2 | 0) / 24 | 0;
           if (i2 >>> 0 < 89478485) {
            i2 = i2 << 1;
            i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
           } else i2 = 178956970;
           __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i75, i2, i5, i74 + 12 | 0);
           i71 = i75 + 8 | 0;
           i67 = HEAP32[i71 >> 2] | 0;
           __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i67, i54);
           HEAP32[i71 >> 2] = i67 + 24;
           __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i74, i75);
           __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i75);
          }
          __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i54);
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i64);
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i66);
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i56);
          break;
         } else {
          HEAP32[i75 >> 2] = 0;
          HEAP32[i75 + 4 >> 2] = 0;
          HEAP32[i75 + 8 >> 2] = 0;
          i1 = 0;
          while (1) {
           if ((i1 | 0) == 3) break;
           HEAP32[i75 + (i1 << 2) >> 2] = 0;
           i1 = i1 + 1 | 0;
          }
          L741 : do if (i2 << 24 >> 24 != 95 ? (i18 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i5, i72, i74) | 0, (i18 | 0) != (i5 | 0)) : 0) {
           i3 = i74 + 4 | 0;
           i1 = HEAP32[i3 >> 2] | 0;
           if ((HEAP32[i74 >> 2] | 0) != (i1 | 0)) {
            __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i58, i1 + -24 | 0);
            i1 = i75 + 11 | 0;
            if ((HEAP8[i1 >> 0] | 0) < 0) {
             i2 = HEAP32[i75 >> 2] | 0;
             HEAP8[i2 >> 0] = 0;
             HEAP32[i75 + 4 >> 2] = 0;
             if ((HEAP32[i75 + 8 >> 2] & 2147483647 | 0) != 11) {
              HEAP8[i75 >> 0] = 0;
              _free(i2);
              HEAP8[i1 >> 0] = 0;
             }
            } else {
             HEAP8[i75 >> 0] = 0;
             HEAP8[i1 >> 0] = 0;
            };
            HEAP32[i75 >> 2] = HEAP32[i58 >> 2];
            HEAP32[i75 + 4 >> 2] = HEAP32[i58 + 4 >> 2];
            HEAP32[i75 + 8 >> 2] = HEAP32[i58 + 8 >> 2];
            i1 = 0;
            while (1) {
             if ((i1 | 0) == 3) break;
             HEAP32[i58 + (i1 << 2) >> 2] = 0;
             i1 = i1 + 1 | 0;
            }
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i58);
            i2 = HEAP32[i3 >> 2] | 0;
            i1 = i2 + -24 | 0;
            while (1) {
             if ((i2 | 0) == (i1 | 0)) {
              i1 = i18;
              i71 = 568;
              break L741;
             }
             i71 = i2 + -24 | 0;
             HEAP32[i3 >> 2] = i71;
             __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i71);
             i2 = HEAP32[i3 >> 2] | 0;
            }
           }
          } else {
           i1 = i5;
           i71 = 568;
          } while (0);
          do if ((i71 | 0) == 568) {
           if ((((i1 | 0) != (i72 | 0) ? (HEAP8[i1 >> 0] | 0) == 95 : 0) ? (i23 = i1 + 1 | 0, (i23 | 0) != (i72 | 0)) : 0) ? (i27 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i23, i72, i74) | 0, (i27 | 0) != (i23 | 0)) : 0) {
            i1 = HEAP32[i74 + 4 >> 2] | 0;
            if ((HEAP32[i74 >> 2] | 0) == (i1 | 0)) break;
            i1 = i1 + -24 | 0;
            __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i63, 58274, i75);
            i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i63, 56962) | 0;
            HEAP32[i62 >> 2] = HEAP32[i2 >> 2];
            HEAP32[i62 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
            HEAP32[i62 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
            i3 = 0;
            while (1) {
             if ((i3 | 0) == 3) break;
             HEAP32[i2 + (i3 << 2) >> 2] = 0;
             i3 = i3 + 1 | 0;
            }
            i71 = HEAP8[i62 + 11 >> 0] | 0;
            i67 = i71 << 24 >> 24 < 0;
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1, i67 ? HEAP32[i62 >> 2] | 0 : i62, i67 ? HEAP32[i62 + 4 >> 2] | 0 : i71 & 255) | 0;
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i62);
            __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i63);
            i1 = i27;
           } else i1 = i73;
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i75);
           break L698;
          } while (0);
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i75);
          i1 = i73;
          break;
         }
        } else i1 = i73; while (0);
        if ((i1 | 0) == (i73 | 0)) break L69;
        i2 = HEAP32[i74 + 4 >> 2] | 0;
        if ((HEAP32[i74 >> 2] | 0) == (i2 | 0)) {
         i1 = i73;
         break L1;
        }
        i6 = i74 + 16 | 0;
        HEAP32[i49 >> 2] = HEAP32[i74 + 12 >> 2];
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i55, i2 + -24 | 0, i49);
        i2 = i74 + 20 | 0;
        i3 = HEAP32[i2 >> 2] | 0;
        i73 = HEAP32[i74 + 24 >> 2] | 0;
        i4 = i73;
        if (i3 >>> 0 < i73 >>> 0) {
         HEAP32[i3 + 12 >> 2] = HEAP32[i55 + 12 >> 2];
         HEAP32[i3 >> 2] = HEAP32[i55 >> 2];
         i75 = i55 + 4 | 0;
         HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
         i74 = i55 + 8 | 0;
         HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
         HEAP32[i74 >> 2] = 0;
         HEAP32[i75 >> 2] = 0;
         HEAP32[i55 >> 2] = 0;
         HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
        } else {
         i2 = HEAP32[i6 >> 2] | 0;
         i5 = i3 - i2 >> 4;
         i3 = i5 + 1 | 0;
         if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
         i2 = i4 - i2 | 0;
         if (i2 >> 4 >>> 0 < 134217727) {
          i2 = i2 >> 3;
          i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
         } else i2 = 268435455;
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
         i74 = i75 + 8 | 0;
         i73 = HEAP32[i74 >> 2] | 0;
         HEAP32[i73 + 12 >> 2] = HEAP32[i55 + 12 >> 2];
         HEAP32[i73 >> 2] = HEAP32[i55 >> 2];
         i72 = i55 + 4 | 0;
         HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
         i71 = i55 + 8 | 0;
         HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
         HEAP32[i71 >> 2] = 0;
         HEAP32[i72 >> 2] = 0;
         HEAP32[i55 >> 2] = 0;
         HEAP32[i74 >> 2] = i73 + 16;
         __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
        }
        __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i55);
        break L1;
       }
      default:
       break L69;
      }
     }
     break;
    }
   default:
    {}
   } while (0);
   i1 = __ZN10__cxxabiv112_GLOBAL__N_118parse_builtin_typeINS0_2DbEEEPKcS4_S4_RT_(i73, i72, i74) | 0;
   if ((i1 | 0) == (i73 | 0)) {
    i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_nameINS0_2DbEEEPKcS4_S4_RT_(i73, i72, i74) | 0;
    if ((i1 | 0) != (i73 | 0) ? (i68 = HEAP32[i74 + 4 >> 2] | 0, (HEAP32[i74 >> 2] | 0) != (i68 | 0)) : 0) {
     i6 = i74 + 16 | 0;
     HEAP32[i69 >> 2] = HEAP32[i74 + 12 >> 2];
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i70, i68 + -24 | 0, i69);
     i2 = i74 + 20 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i73 = HEAP32[i74 + 24 >> 2] | 0;
     i4 = i73;
     if (i3 >>> 0 < i73 >>> 0) {
      HEAP32[i3 + 12 >> 2] = HEAP32[i70 + 12 >> 2];
      HEAP32[i3 >> 2] = HEAP32[i70 >> 2];
      i75 = i70 + 4 | 0;
      HEAP32[i3 + 4 >> 2] = HEAP32[i75 >> 2];
      i74 = i70 + 8 | 0;
      HEAP32[i3 + 8 >> 2] = HEAP32[i74 >> 2];
      HEAP32[i74 >> 2] = 0;
      HEAP32[i75 >> 2] = 0;
      HEAP32[i70 >> 2] = 0;
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
     } else {
      i2 = HEAP32[i6 >> 2] | 0;
      i5 = i3 - i2 >> 4;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
      i2 = i4 - i2 | 0;
      if (i2 >> 4 >>> 0 < 134217727) {
       i2 = i2 >> 3;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 268435455;
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i75, i2, i5, i74 + 28 | 0);
      i74 = i75 + 8 | 0;
      i73 = HEAP32[i74 >> 2] | 0;
      HEAP32[i73 + 12 >> 2] = HEAP32[i70 + 12 >> 2];
      HEAP32[i73 >> 2] = HEAP32[i70 >> 2];
      i72 = i70 + 4 | 0;
      HEAP32[i73 + 4 >> 2] = HEAP32[i72 >> 2];
      i71 = i70 + 8 | 0;
      HEAP32[i73 + 8 >> 2] = HEAP32[i71 >> 2];
      HEAP32[i71 >> 2] = 0;
      HEAP32[i72 >> 2] = 0;
      HEAP32[i70 >> 2] = 0;
      HEAP32[i74 >> 2] = i73 + 16;
      __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i75);
      __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i75);
     }
     __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i70);
    } else i1 = i73;
   }
  }
 } else i1 = i73; while (0);
 STACKTOP = i76;
 return i1 | 0;
}

function __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__1clES2_(i121, i119) {
 i121 = i121 | 0;
 i119 = i119 | 0;
 var i1 = 0, i2 = 0, d3 = 0.0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, d9 = 0.0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i52 = 0, i53 = 0, i54 = 0, i55 = 0, i56 = 0, i57 = 0, i58 = 0, i59 = 0, i60 = 0, i61 = 0, i62 = 0, i63 = 0, i64 = 0, i65 = 0, i66 = 0, i67 = 0, i68 = 0, i69 = 0, i70 = 0, i71 = 0, i72 = 0, i73 = 0, i74 = 0, i75 = 0, i76 = 0, i77 = 0, i78 = 0, i79 = 0, i80 = 0, i81 = 0, i82 = 0, i83 = 0, i84 = 0, i85 = 0, i86 = 0, i87 = 0, i88 = 0, i89 = 0, i90 = 0, i91 = 0, i92 = 0, i93 = 0, i94 = 0, i95 = 0, i96 = 0, i97 = 0, i98 = 0, i99 = 0, i100 = 0, i101 = 0, i102 = 0, i103 = 0, i104 = 0, i105 = 0, i106 = 0, i107 = 0, i108 = 0, i109 = 0, i110 = 0, i111 = 0, i112 = 0, i113 = 0, i114 = 0, i115 = 0, i116 = 0, i117 = 0, i118 = 0, i120 = 0, i122 = 0, i123 = 0, i124 = 0;
 i124 = STACKTOP;
 STACKTOP = STACKTOP + 688 | 0;
 i123 = i124 + 640 | 0;
 i118 = i124 + 32 | 0;
 i120 = i124 + 280 | 0;
 i70 = i124 + 676 | 0;
 i58 = i124 + 636 | 0;
 i2 = i124 + 632 | 0;
 i4 = i124 + 628 | 0;
 i5 = i124 + 624 | 0;
 i21 = i124 + 620 | 0;
 i32 = i124 + 616 | 0;
 i34 = i124 + 612 | 0;
 i6 = i124 + 600 | 0;
 i7 = i124 + 596 | 0;
 i8 = i124 + 592 | 0;
 i23 = i124 + 588 | 0;
 i26 = i124 + 584 | 0;
 i35 = i124 + 580 | 0;
 i36 = i124 + 576 | 0;
 i37 = i124 + 572 | 0;
 i43 = i124 + 560 | 0;
 i11 = i124 + 556 | 0;
 i24 = i124 + 544 | 0;
 i12 = i124 + 540 | 0;
 i13 = i124 + 536 | 0;
 i25 = i124 + 532 | 0;
 i38 = i124 + 528 | 0;
 i14 = i124 + 48 | 0;
 i15 = i124 + 524 | 0;
 i16 = i124 + 520 | 0;
 i27 = i124 + 516 | 0;
 i39 = i124 + 512 | 0;
 i28 = i124 + 508 | 0;
 i40 = i124 + 504 | 0;
 i48 = i124 + 492 | 0;
 i17 = i124 + 488 | 0;
 i18 = i124 + 484 | 0;
 i19 = i124 + 472 | 0;
 i20 = i124 + 468 | 0;
 i29 = i124 + 464 | 0;
 i30 = i124 + 460 | 0;
 i31 = i124 + 456 | 0;
 i41 = i124 + 452 | 0;
 i42 = i124 + 448 | 0;
 i53 = i124 + 444 | 0;
 i44 = i124 + 440 | 0;
 i49 = i124 + 436 | 0;
 i59 = i124 + 424 | 0;
 i60 = i124 + 420 | 0;
 i45 = i124 + 416 | 0;
 i115 = i124 + 412 | 0;
 i50 = i124 + 408 | 0;
 i51 = i124 + 404 | 0;
 i52 = i124 + 400 | 0;
 i54 = i124 + 396 | 0;
 i78 = i124 + 392 | 0;
 i33 = i124 + 388 | 0;
 i117 = i124 + 128 | 0;
 i46 = i124 + 384 | 0;
 i47 = i124 + 380 | 0;
 i55 = i124 + 376 | 0;
 i71 = i124 + 372 | 0;
 i65 = i124 + 368 | 0;
 i92 = i124 + 364 | 0;
 i66 = i124 + 360 | 0;
 i67 = i124 + 356 | 0;
 i79 = i124 + 352 | 0;
 i80 = i124 + 348 | 0;
 i81 = i124 + 336 | 0;
 i82 = i124 + 324 | 0;
 i97 = i124 + 320 | 0;
 i98 = i124 + 316 | 0;
 i99 = i124 + 312 | 0;
 i68 = i124 + 308 | 0;
 i69 = i124 + 296 | 0;
 i83 = i124 + 284 | 0;
 i95 = i124 + 276 | 0;
 i74 = i124 + 272 | 0;
 i75 = i124 + 268 | 0;
 i76 = i124 + 256 | 0;
 i77 = i124 + 244 | 0;
 i96 = i124 + 240 | 0;
 i105 = i124 + 236 | 0;
 i87 = i124 + 232 | 0;
 i88 = i124 + 228 | 0;
 i89 = i124 + 216 | 0;
 i90 = i124 + 204 | 0;
 i102 = i124 + 200 | 0;
 i103 = i124 + 196 | 0;
 i104 = i124 + 192 | 0;
 i106 = i124 + 188 | 0;
 i61 = i124 + 184 | 0;
 i62 = i124 + 180 | 0;
 i63 = i124 + 176 | 0;
 i64 = i124 + 172 | 0;
 i91 = i124 + 168 | 0;
 i86 = i124 + 164 | 0;
 i84 = i124 + 160 | 0;
 i85 = i124 + 156 | 0;
 i72 = i124 + 152 | 0;
 i73 = i124 + 140 | 0;
 i93 = i124 + 136 | 0;
 i112 = i124 + 64 | 0;
 i100 = i124 + 132 | 0;
 i101 = i124 + 16 | 0;
 i110 = i124 + 124 | 0;
 i111 = i124 + 112 | 0;
 i107 = i124 + 108 | 0;
 i108 = i124;
 i109 = i124 + 96 | 0;
 i114 = i124 + 84 | 0;
 i56 = i124 + 72 | 0;
 i57 = i124 + 68 | 0;
 i122 = HEAP32[i121 >> 2] | 0;
 HEAP32[i58 >> 2] = HEAP32[i119 >> 2];
 HEAP32[i123 >> 2] = HEAP32[i58 >> 2];
 __ZN4wasm14AstStackHelperC2EN6cashew3RefE(i70, i123);
 if (HEAP8[i122 + 45 >> 0] | 0) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60808, 29720) | 0;
  __ZN6cashew5Value9stringifyERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEb(HEAP32[i119 >> 2] | 0, 60808, 0);
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(60808, 10) | 0;
 }
 i58 = __ZN6cashew3RefixEj(i119, 0) | 0;
 i58 = __ZN6cashew5Value10getIStringEv(HEAP32[i58 >> 2] | 0) | 0;
 i58 = HEAP32[i58 >> 2] | 0;
 L4 : do if ((i58 | 0) != (HEAP32[14821] | 0)) {
  if ((i58 | 0) == (HEAP32[14822] | 0)) {
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0, 59292) | 0) {
    i120 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 1) | 0;
    i120 = __ZN6cashew5Value10getIStringEv(HEAP32[i120 >> 2] | 0) | 0;
    HEAP32[i118 >> 2] = HEAP32[i120 >> 2];
    do if (!(__ZNKSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE4findIS2_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS2_PvEEEERKT_(HEAP32[i121 + 8 >> 2] | 0, i118) | 0)) {
     i1 = i122 + 48 | 0;
     if ((__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i1, i118) | 0) == (i122 + 52 | 0)) ___assert_fail(29725, 16311, 964, 57137); else {
      i120 = __ZNSt3__23mapIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_(i1, i118) | 0;
      i118 = HEAP32[i120 >> 2] | 0;
      i120 = HEAP32[i120 + 4 >> 2] | 0;
      i10 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
      i117 = __ZN4wasm15getWasmTypeSizeENS_8WasmTypeE(i120) | 0;
      HEAP8[i10 + 8 >> 0] = i117;
      HEAP32[i10 + 12 >> 2] = 0;
      __ZN4wasm7AddressaSEy(i10 + 16 | 0, i117 & 255, 0) | 0;
      i122 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 8 >> 2] | 0) | 0;
      HEAP32[i122 + 8 >> 2] = 1;
      HEAP32[i122 + 16 >> 2] = i118;
      HEAP32[i122 + 4 >> 2] = 1;
      HEAP32[i10 + 20 >> 2] = i122;
      i122 = HEAP32[i121 + 4 >> 2] | 0;
      i121 = __ZN6cashew3RefixEj(i119, 3) | 0;
      HEAP32[i21 >> 2] = HEAP32[i121 >> 2];
      HEAP32[i123 >> 2] = HEAP32[i21 >> 2];
      i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
      HEAP32[i10 + 24 >> 2] = i123;
      HEAP32[i10 + 4 >> 2] = i120;
      break;
     }
    } else {
     i10 = __ZN10MixedArena5allocIN4wasm8SetLocalEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
     i122 = HEAP32[HEAP32[i121 + 12 >> 2] >> 2] | 0;
     i120 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 1) | 0;
     i120 = __ZN6cashew5Value10getIStringEv(HEAP32[i120 >> 2] | 0) | 0;
     HEAP32[i4 >> 2] = HEAP32[i120 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i4 >> 2];
     i122 = __ZN4wasm8Function13getLocalIndexENS_4NameE(i122, i123) | 0;
     HEAP32[i10 + 8 >> 2] = i122;
     i122 = HEAP32[i121 + 4 >> 2] | 0;
     i121 = __ZN6cashew3RefixEj(i119, 3) | 0;
     HEAP32[i5 >> 2] = HEAP32[i121 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i5 >> 2];
     i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
     HEAP32[i10 + 12 >> 2] = i123;
     HEAP32[i10 + 4 >> 2] = HEAP32[i123 + 4 >> 2];
    } while (0);
    i1 = i10;
    break;
   }
   if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0, 59340) | 0)) {
    HEAP32[i6 >> 2] = 0;
    HEAP32[i6 + 4 >> 2] = 0;
    HEAP32[i6 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i6, 29826, 16);
    HEAP32[i7 >> 2] = HEAP32[i119 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i7 >> 2];
    __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew3RefE(i6, i123);
   }
   i117 = __ZN6cashew3RefixEj(i119, 2) | 0;
   HEAP32[i118 >> 2] = HEAP32[i117 >> 2];
   if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i118, 1) | 0, 0) | 0, 59292) | 0)) ___assert_fail(29773, 16311, 976, 57137);
   i1 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i118, 1) | 0, 1) | 0;
   i1 = __ZN6cashew5Value10getIStringEv(HEAP32[i1 >> 2] | 0) | 0;
   HEAP32[i120 >> 2] = HEAP32[i1 >> 2];
   i1 = i122 + 60 | 0;
   if ((__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i1, i120) | 0) == (i122 + 64 | 0)) ___assert_fail(29794, 16311, 978, 57137);
   i4 = __ZNSt3__23mapIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_(i1, i120) | 0;
   i6 = i122 + 4 | 0;
   i1 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i6 >> 2] | 0) | 0;
   i2 = HEAP32[i4 >> 2] | 0;
   HEAP8[i1 + 8 >> 0] = i2;
   HEAP32[i1 + 12 >> 2] = 0;
   __ZN4wasm7AddressaSEy(i1 + 16 | 0, i2, 0) | 0;
   i2 = HEAP32[i121 + 16 >> 2] | 0;
   i5 = __ZN6cashew3RefixEj(i118, 2) | 0;
   HEAP32[i32 >> 2] = HEAP32[i5 >> 2];
   i5 = HEAP32[i4 >> 2] | 0;
   HEAP32[i123 >> 2] = HEAP32[i32 >> 2];
   i5 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEEclES5_j(i2, i123, i5) | 0;
   HEAP32[i1 + 20 >> 2] = i5;
   i5 = HEAP32[i121 + 4 >> 2] | 0;
   i2 = __ZN6cashew3RefixEj(i119, 3) | 0;
   HEAP32[i34 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i34 >> 2];
   i5 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i5, i123) | 0;
   i2 = i1 + 24 | 0;
   HEAP32[i2 >> 2] = i5;
   i4 = __ZN4wasm13asmToWasmTypeE7AsmType(HEAP32[i4 + 8 >> 2] | 0) | 0;
   HEAP32[i1 + 4 >> 2] = i4;
   i5 = HEAP32[(HEAP32[i2 >> 2] | 0) + 4 >> 2] | 0;
   do if ((i4 | 0) != (i5 | 0)) if ((i4 | 0) == 3 & (i5 | 0) == 4) {
    i123 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i6 >> 2] | 0) | 0;
    HEAP32[i123 + 8 >> 2] = 44;
    HEAP32[i123 + 12 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i123 + 4 >> 2] = 3;
    HEAP32[i2 >> 2] = i123;
    break;
   } else _abort(); while (0);
   break;
  }
  if ((i58 | 0) == (HEAP32[14827] | 0)) {
   if (!(!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i119, 1) | 0, 59436) | 0) ? !(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i119, 1) | 0, 59500) | 0) : 0)) i116 = 27;
   if (((i116 | 0) == 27 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 3) | 0, 0) | 0, 59348) | 0 : 0) ? (i117 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 3) | 0, 1) | 0, i117 = __ZN6cashew5Value9getNumberEv(HEAP32[i117 >> 2] | 0) | 0, +HEAPF64[i117 >> 3] == 0.0) : 0) {
    i1 = HEAP32[i121 + 4 >> 2] | 0;
    i122 = __ZN6cashew3RefixEj(i119, 2) | 0;
    HEAP32[i8 >> 2] = HEAP32[i122 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i8 >> 2];
    i1 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i123) | 0;
    switch (HEAP32[i1 >> 2] | 0) {
    case 6:
     {
      HEAP32[i1 + 4 >> 2] = 1;
      break L4;
     }
    case 7:
     {
      HEAP32[i1 + 4 >> 2] = 1;
      break L4;
     }
    case 8:
     {
      HEAP32[i1 + 4 >> 2] = 1;
      break L4;
     }
    default:
     break L4;
    }
   }
   i5 = i122 + 4 | 0;
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i5 >> 2] | 0) | 0;
   i121 = i121 + 4 | 0;
   i2 = HEAP32[i121 >> 2] | 0;
   i4 = __ZN6cashew3RefixEj(i119, 2) | 0;
   HEAP32[i23 >> 2] = HEAP32[i4 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i23 >> 2];
   i2 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i2, i123) | 0;
   i4 = i1 + 12 | 0;
   HEAP32[i4 >> 2] = i2;
   i121 = HEAP32[i121 >> 2] | 0;
   i2 = __ZN6cashew3RefixEj(i119, 3) | 0;
   HEAP32[i26 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i26 >> 2];
   i121 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i121, i123) | 0;
   i2 = i1 + 16 | 0;
   HEAP32[i2 >> 2] = i121;
   i121 = __ZN6cashew3RefixEj(i119, 1) | 0;
   i121 = __ZN6cashew5Value10getIStringEv(HEAP32[i121 >> 2] | 0) | 0;
   HEAP32[i35 >> 2] = HEAP32[i121 >> 2];
   i121 = __ZN6cashew3RefixEj(i119, 2) | 0;
   HEAP32[i36 >> 2] = HEAP32[i121 >> 2];
   i119 = __ZN6cashew3RefixEj(i119, 3) | 0;
   HEAP32[i37 >> 2] = HEAP32[i119 >> 2];
   i119 = HEAP32[i4 >> 2] | 0;
   i121 = HEAP32[i2 >> 2] | 0;
   HEAP32[i120 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i118 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i37 >> 2];
   i121 = __ZN4wasm15Asm2WasmBuilder16parseAsmBinaryOpEN6cashew7IStringENS1_3RefES3_PNS_10ExpressionES5_(i122, i120, i118, i123, i119, i121) | 0;
   i123 = i1 + 8 | 0;
   HEAP32[i123 >> 2] = i121;
   __ZN4wasm6Binary8finalizeEv(i1);
   if ((HEAP32[i123 >> 2] | 0) == 5 ? ((HEAP32[i1 + 4 >> 2] | 0) + -3 | 0) >>> 0 < 2 : 0) {
    i1 = __ZN10MixedArena5allocIN4wasm10CallImportEEEPT_v(HEAP32[i5 >> 2] | 0) | 0;
    HEAP32[i1 + 24 >> 2] = HEAP32[14961];
    i123 = i1 + 8 | 0;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i123, HEAP32[i4 >> 2] | 0);
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i123, HEAP32[i2 >> 2] | 0);
    HEAP32[i1 + 4 >> 2] = 4;
    if (HEAP8[65620] | 0) break;
    HEAP8[65620] = 1;
    i123 = __Znwj(16) | 0;
    HEAP32[i123 >> 2] = 0;
    HEAP32[i123 + 4 >> 2] = 0;
    HEAP32[i123 + 8 >> 2] = 0;
    HEAP32[i123 + 12 >> 2] = 0;
    i121 = HEAP32[14961] | 0;
    HEAP32[i123 >> 2] = i121;
    HEAP32[i123 + 4 >> 2] = HEAP32[14960];
    HEAP32[i123 + 8 >> 2] = i121;
    HEAP32[i43 >> 2] = 0;
    HEAP32[i43 + 4 >> 2] = 0;
    HEAP32[i43 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i43, 29843, 3);
    i121 = __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i43, HEAP32[i122 >> 2] | 0) | 0;
    HEAP32[i123 + 12 >> 2] = i121;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i43);
    __ZN4wasm6Module9addImportEPNS_6ImportE(HEAP32[i122 >> 2] | 0, i123);
    break;
   }
   break;
  }
  if ((i58 | 0) == (HEAP32[14837] | 0)) {
   i1 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
   i123 = __ZN6cashew3RefixEj(i119, 1) | 0;
   i123 = __ZN6cashew5Value9getNumberEv(HEAP32[i123 >> 2] | 0) | 0;
   d3 = +HEAPF64[i123 >> 3];
   do if (!(__ZN4wasm12isSInteger32Ed(d3) | 0)) if (__ZN4wasm12isUInteger32Ed(d3) | 0) {
    i2 = __ZN4wasm12toUInteger32Ed(d3) | 0;
    HEAP32[i1 + 8 >> 2] = 1;
    HEAP32[i1 + 16 >> 2] = i2;
    i2 = 1;
    break;
   } else {
    HEAP32[i1 + 8 >> 2] = 4;
    HEAPF64[i1 + 16 >> 3] = d3;
    i2 = 4;
    break;
   } else {
    i2 = __ZN4wasm12toSInteger32Ed(d3) | 0;
    HEAP32[i1 + 8 >> 2] = 1;
    HEAP32[i1 + 16 >> 2] = i2;
    i2 = 1;
   } while (0);
   HEAP32[i1 + 4 >> 2] = i2;
   break;
  }
  if ((i58 | 0) == (HEAP32[14823] | 0)) {
   i1 = __ZN6cashew3RefixEj(i119, 1) | 0;
   i1 = __ZN6cashew5Value10getIStringEv(HEAP32[i1 >> 2] | 0) | 0;
   i1 = HEAP32[i1 >> 2] | 0;
   HEAP32[i118 >> 2] = i1;
   do if (!(__ZNKSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE4findIS2_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS2_PvEEEERKT_(HEAP32[i121 + 8 >> 2] | 0, i118) | 0)) {
    if ((i1 | 0) == (HEAP32[14969] | 0)) {
     i1 = __ZN10MixedArena5allocIN4wasm10CallImportEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
     HEAP32[i1 + 24 >> 2] = HEAP32[14969];
     HEAP32[i1 + 4 >> 2] = 0;
     if (HEAP8[65621] | 0) {
      i22 = i1;
      break;
     }
     HEAP8[65621] = 1;
     i22 = __Znwj(16) | 0;
     HEAP32[i22 >> 2] = 0;
     HEAP32[i22 + 4 >> 2] = 0;
     HEAP32[i22 + 8 >> 2] = 0;
     HEAP32[i22 + 12 >> 2] = 0;
     i123 = HEAP32[14969] | 0;
     HEAP32[i22 >> 2] = i123;
     HEAP32[i22 + 4 >> 2] = HEAP32[14960];
     HEAP32[i22 + 8 >> 2] = i123;
     HEAP32[i24 >> 2] = 0;
     HEAP32[i24 + 4 >> 2] = 0;
     HEAP32[i24 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i24, 29847, 1);
     i123 = __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i24, HEAP32[i122 >> 2] | 0) | 0;
     HEAP32[i22 + 12 >> 2] = i123;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i24);
     __ZN4wasm6Module9addImportEPNS_6ImportE(HEAP32[i122 >> 2] | 0, i22);
     i22 = i1;
     break;
    }
    i1 = i122 + 48 | 0;
    if ((__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i1, i118) | 0) == (i122 + 52 | 0)) ___assert_fail(29725, 16311, 1071, 57137); else {
     i123 = __ZNSt3__23mapIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_(i1, i118) | 0;
     i121 = HEAP32[i123 >> 2] | 0;
     i123 = HEAP32[i123 + 4 >> 2] | 0;
     i22 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
     i120 = __ZN4wasm15getWasmTypeSizeENS_8WasmTypeE(i123) | 0;
     HEAP8[i22 + 8 >> 0] = i120;
     HEAP8[i22 + 9 >> 0] = 1;
     HEAP32[i22 + 12 >> 2] = 0;
     __ZN4wasm7AddressaSEy(i22 + 16 | 0, i120 & 255, 0) | 0;
     i122 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 8 >> 2] | 0) | 0;
     HEAP32[i122 + 8 >> 2] = 1;
     HEAP32[i122 + 16 >> 2] = i121;
     HEAP32[i122 + 4 >> 2] = 1;
     HEAP32[i22 + 20 >> 2] = i122;
     HEAP32[i22 + 4 >> 2] = i123;
     break;
    }
   } else {
    i22 = __ZN10MixedArena5allocIN4wasm8GetLocalEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
    i122 = HEAP32[HEAP32[i121 + 12 >> 2] >> 2] | 0;
    HEAP32[i11 >> 2] = HEAP32[i118 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i11 >> 2];
    i123 = __ZN4wasm8Function13getLocalIndexENS_4NameE(i122, i123) | 0;
    HEAP32[i22 + 8 >> 2] = i123;
    i123 = __ZN4wasm13asmToWasmTypeE7AsmType(__ZN7AsmData7getTypeERKN6cashew7IStringE(HEAP32[i121 + 20 >> 2] | 0, i118) | 0) | 0;
    HEAP32[i22 + 4 >> 2] = i123;
   } while (0);
   i1 = i22;
   break;
  }
  if ((i58 | 0) == (HEAP32[14835] | 0)) {
   i43 = __ZN6cashew3RefixEj(i119, 1) | 0;
   HEAP32[i118 >> 2] = HEAP32[i43 >> 2];
   if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i118, 0) | 0, 59292) | 0)) ___assert_fail(29849, 16311, 1083, 57137);
   i2 = __ZN6cashew3RefixEj(i118, 1) | 0;
   i2 = __ZN6cashew5Value10getIStringEv(HEAP32[i2 >> 2] | 0) | 0;
   HEAP32[i120 >> 2] = HEAP32[i2 >> 2];
   i2 = i122 + 60 | 0;
   if ((__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i2, i120) | 0) == (i122 + 64 | 0)) ___assert_fail(29794, 16311, 1085, 57137); else {
    i120 = __ZNSt3__23mapIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_(i2, i120) | 0;
    i1 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
    i122 = HEAP32[i120 >> 2] | 0;
    HEAP8[i1 + 8 >> 0] = i122;
    HEAP8[i1 + 9 >> 0] = HEAP8[i120 + 5 >> 0] | 0;
    HEAP32[i1 + 12 >> 2] = 0;
    __ZN4wasm7AddressaSEy(i1 + 16 | 0, i122, 0) | 0;
    i121 = HEAP32[i121 + 16 >> 2] | 0;
    i122 = __ZN6cashew3RefixEj(i119, 2) | 0;
    HEAP32[i12 >> 2] = HEAP32[i122 >> 2];
    i122 = HEAP32[i120 >> 2] | 0;
    HEAP32[i123 >> 2] = HEAP32[i12 >> 2];
    i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEEclES5_j(i121, i123, i122) | 0;
    HEAP32[i1 + 20 >> 2] = i123;
    i123 = __ZN4wasm11getWasmTypeEjb(HEAP32[i120 >> 2] | 0, (HEAP8[i120 + 4 >> 0] | 0) == 0) | 0;
    HEAP32[i1 + 4 >> 2] = i123;
    break;
   }
  }
  if ((i58 | 0) == (HEAP32[14849] | 0)) {
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i119, 1) | 0, 59428) | 0) {
    HEAP32[i13 >> 2] = HEAP32[i119 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i13 >> 2];
    __ZN4wasm15Asm2WasmBuilder12checkLiteralEN6cashew3RefE(i118, i122, i123);
    i1 = HEAP32[i118 >> 2] | 0;
    L91 : do if (!i1) {
     i1 = HEAP32[i121 + 4 >> 2] | 0;
     i2 = __ZN6cashew3RefixEj(i119, 2) | 0;
     HEAP32[i25 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i25 >> 2];
     i1 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i123) | 0;
     i2 = i1 + 4 | 0;
     switch (HEAP32[i2 >> 2] | 0) {
     case 1:
      {
       i121 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
       i120 = __ZN6cashew3RefixEj(i119, 2) | 0;
       HEAP32[i38 >> 2] = HEAP32[i120 >> 2];
       HEAP32[i123 >> 2] = HEAP32[i38 >> 2];
       i123 = __ZN4wasm15Asm2WasmBuilder18isUnsignedCoercionEN6cashew3RefE(i122, i123) | 0;
       HEAP32[i121 + 8 >> 2] = i123 ? 38 : 36;
       HEAP32[i121 + 12 >> 2] = i1;
       HEAP32[i121 + 4 >> 2] = 4;
       i1 = i121;
       break L91;
      }
     case 3:
      {
       i123 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
       HEAP32[i123 + 8 >> 2] = 43;
       HEAP32[i123 + 12 >> 2] = i1;
       HEAP32[i123 + 4 >> 2] = 4;
       i1 = i123;
       break L91;
      }
     default:
      switch (HEAP32[i1 >> 2] | 0) {
      case 6:
       {
        HEAP32[i2 >> 2] = 4;
        break L91;
       }
      case 7:
       {
        HEAP32[i2 >> 2] = 4;
        break L91;
       }
      case 8:
       {
        HEAP32[i2 >> 2] = 4;
        break L91;
       }
      default:
       break L91;
      }
     }
    } else {
     i121 = i118 + 4 | 0;
     HEAP32[i123 >> 2] = HEAP32[i121 >> 2];
     HEAP32[i123 + 4 >> 2] = HEAP32[i121 + 4 >> 2];
     HEAP32[i123 + 8 >> 2] = HEAP32[i121 + 8 >> 2];
     i122 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 8 >> 2] | 0) | 0;
     HEAP32[i122 + 8 >> 2] = i1;
     i121 = i122 + 12 | 0;
     HEAP32[i121 >> 2] = HEAP32[i123 >> 2];
     HEAP32[i121 + 4 >> 2] = HEAP32[i123 + 4 >> 2];
     HEAP32[i121 + 8 >> 2] = HEAP32[i123 + 8 >> 2];
     HEAP32[i122 + 4 >> 2] = i1;
     i1 = i122;
    } while (0);
    break;
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i119, 1) | 0, 59432) | 0) {
    do if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0, 59348) | 0)) {
     if ((__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0, 59396) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 1) | 0, 59428) | 0 : 0) ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 2) | 0, 0) | 0, 59348) | 0 : 0) break;
     i2 = __ZN6cashew3RefixEj(i119, 2) | 0;
     HEAP32[i16 >> 2] = HEAP32[i2 >> 2];
     i2 = HEAP32[i121 + 20 >> 2] | 0;
     HEAP32[i123 >> 2] = HEAP32[i16 >> 2];
     i2 = __ZN4wasm15Asm2WasmBuilder13detectAsmTypeEN6cashew3RefEP7AsmData(i122, i123, i2) | 0;
     i1 = HEAP32[i122 + 4 >> 2] | 0;
     if (!i2) {
      i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(i1) | 0;
      HEAP32[i1 + 8 >> 2] = 1;
      i122 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 8 >> 2] | 0) | 0;
      HEAP32[i122 + 8 >> 2] = 1;
      HEAP32[i122 + 16 >> 2] = 0;
      HEAP32[i122 + 4 >> 2] = 1;
      HEAP32[i1 + 12 >> 2] = i122;
      i122 = HEAP32[i121 + 4 >> 2] | 0;
      i121 = __ZN6cashew3RefixEj(i119, 2) | 0;
      HEAP32[i27 >> 2] = HEAP32[i121 >> 2];
      HEAP32[i123 >> 2] = HEAP32[i27 >> 2];
      i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
      HEAP32[i1 + 16 >> 2] = i123;
      HEAP32[i1 + 4 >> 2] = 1;
      break L4;
     }
     i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(i1) | 0;
     i122 = HEAP32[i121 + 4 >> 2] | 0;
     i121 = __ZN6cashew3RefixEj(i119, 2) | 0;
     HEAP32[i39 >> 2] = HEAP32[i121 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i39 >> 2];
     i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
     HEAP32[i1 + 12 >> 2] = i123;
     switch (i2 | 0) {
     case 1:
      {
       HEAP32[i1 + 8 >> 2] = 7;
       HEAP32[i1 + 4 >> 2] = 4;
       break;
      }
     case 2:
      {
       HEAP32[i1 + 8 >> 2] = 6;
       HEAP32[i1 + 4 >> 2] = 3;
       break;
      }
     default:
      _abort();
     }
     break L4;
    } while (0);
    i1 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
    i121 = i1 + 8 | 0;
    HEAP32[i15 >> 2] = HEAP32[i119 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i15 >> 2];
    __ZN4wasm15Asm2WasmBuilder10getLiteralEN6cashew3RefE(i14, i122, i123);
    HEAP32[i121 >> 2] = HEAP32[i14 >> 2];
    HEAP32[i121 + 4 >> 2] = HEAP32[i14 + 4 >> 2];
    HEAP32[i121 + 8 >> 2] = HEAP32[i14 + 8 >> 2];
    HEAP32[i121 + 12 >> 2] = HEAP32[i14 + 12 >> 2];
    HEAP32[i1 + 4 >> 2] = HEAP32[i121 >> 2];
    break;
   }
   if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i119, 1) | 0, 59452) | 0)) if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i119, 1) | 0, 59448) | 0) {
    i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
    HEAP32[i1 + 8 >> 2] = 20;
    i122 = HEAP32[i121 + 4 >> 2] | 0;
    i121 = __ZN6cashew3RefixEj(i119, 2) | 0;
    HEAP32[i18 >> 2] = HEAP32[i121 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i18 >> 2];
    i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
    HEAP32[i1 + 12 >> 2] = i123;
    HEAP32[i1 + 4 >> 2] = 1;
    break;
   } else {
    HEAP32[i19 >> 2] = 0;
    HEAP32[i19 + 4 >> 2] = 0;
    HEAP32[i19 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i19, 29867, 9);
    HEAP32[i20 >> 2] = HEAP32[i119 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i20 >> 2];
    __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew3RefE(i19, i123);
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0, 59396) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 1) | 0, 59452) | 0 : 0) {
    i4 = i122 + 4 | 0;
    i1 = HEAP32[i4 >> 2] | 0;
    if (HEAP8[i122 + 46 >> 0] | 0) {
     i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(i1) | 0;
     i122 = HEAP32[i121 + 4 >> 2] | 0;
     i121 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 2) | 0;
     HEAP32[i28 >> 2] = HEAP32[i121 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i28 >> 2];
     i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
     HEAP32[i1 + 12 >> 2] = i123;
     HEAP32[i1 + 8 >> 2] = (HEAP32[i123 + 4 >> 2] | 0) == 4 ? 29 : 25;
     HEAP32[i1 + 4 >> 2] = 1;
     break;
    }
    i1 = __ZN10MixedArena5allocIN4wasm10CallImportEEEPT_v(i1) | 0;
    HEAP32[i1 + 24 >> 2] = HEAP32[14962];
    i2 = HEAP32[i121 + 4 >> 2] | 0;
    i121 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 2) | 0;
    HEAP32[i40 >> 2] = HEAP32[i121 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i40 >> 2];
    i2 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i2, i123) | 0;
    if ((HEAP32[i2 + 4 >> 2] | 0) == 3) {
     i123 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 >> 2] | 0) | 0;
     HEAP32[i123 + 8 >> 2] = 43;
     HEAP32[i123 + 12 >> 2] = i2;
     HEAP32[i123 + 4 >> 2] = 4;
     i2 = i123;
    }
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i1 + 8 | 0, i2);
    HEAP32[i1 + 4 >> 2] = 1;
    if (HEAP8[65622] | 0) break;
    HEAP8[65622] = 1;
    i123 = __Znwj(16) | 0;
    HEAP32[i123 >> 2] = 0;
    HEAP32[i123 + 4 >> 2] = 0;
    HEAP32[i123 + 8 >> 2] = 0;
    HEAP32[i123 + 12 >> 2] = 0;
    i121 = HEAP32[14962] | 0;
    HEAP32[i123 >> 2] = i121;
    HEAP32[i123 + 4 >> 2] = HEAP32[14960];
    HEAP32[i123 + 8 >> 2] = i121;
    HEAP32[i48 >> 2] = 0;
    HEAP32[i48 + 4 >> 2] = 0;
    HEAP32[i48 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i48, 58240, 2);
    i121 = __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i48, HEAP32[i122 >> 2] | 0) | 0;
    HEAP32[i123 + 12 >> 2] = i121;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i48);
    __ZN4wasm6Module9addImportEPNS_6ImportE(HEAP32[i122 >> 2] | 0, i123);
    break;
   }
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 9;
   i121 = HEAP32[i121 + 4 >> 2] | 0;
   i120 = __ZN6cashew3RefixEj(i119, 2) | 0;
   HEAP32[i17 >> 2] = HEAP32[i120 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i17 >> 2];
   i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i121, i123) | 0;
   HEAP32[i1 + 12 >> 2] = i123;
   i123 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 8 >> 2] | 0) | 0;
   HEAP32[i123 + 8 >> 2] = 1;
   HEAP32[i123 + 16 >> 2] = -1;
   HEAP32[i123 + 4 >> 2] = 1;
   HEAP32[i1 + 16 >> 2] = i123;
   HEAP32[i1 + 4 >> 2] = 1;
   break;
  }
  if ((i58 | 0) == (HEAP32[14829] | 0)) {
   i1 = __ZN10MixedArena5allocIN4wasm2IfEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
   i2 = i121 + 4 | 0;
   i122 = HEAP32[i2 >> 2] | 0;
   i121 = __ZN6cashew3RefixEj(i119, 1) | 0;
   HEAP32[i29 >> 2] = HEAP32[i121 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i29 >> 2];
   i122 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
   HEAP32[i1 + 8 >> 2] = i122;
   i122 = HEAP32[i2 >> 2] | 0;
   i121 = __ZN6cashew3RefixEj(i119, 2) | 0;
   HEAP32[i30 >> 2] = HEAP32[i121 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i30 >> 2];
   i122 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
   HEAP32[i1 + 12 >> 2] = i122;
   if (__ZN6cashew3RefntEv(__ZN6cashew3RefixEj(i119, 3) | 0) | 0) i2 = 0; else {
    i2 = HEAP32[i2 >> 2] | 0;
    i122 = __ZN6cashew3RefixEj(i119, 3) | 0;
    HEAP32[i31 >> 2] = HEAP32[i122 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i31 >> 2];
    i2 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i2, i123) | 0;
   }
   HEAP32[i1 + 16 >> 2] = i2;
   break;
  }
  if ((i58 | 0) == (HEAP32[14984] | 0)) {
   if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 0) | 0, 59292) | 0)) {
    i2 = __ZN10MixedArena5allocIN4wasm12CallIndirectEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
    HEAP32[i118 >> 2] = i2;
    i48 = __ZN6cashew3RefixEj(i119, 1) | 0;
    HEAP32[i120 >> 2] = HEAP32[i48 >> 2];
    if ((((__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i120, 0) | 0, 59340) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 1) | 0, 0) | 0, 59292) | 0 : 0) ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 2) | 0, 0) | 0, 59308) | 0 : 0) ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 2) | 0, 1) | 0, 59440) | 0 : 0) ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 2) | 0, 3) | 0, 0) | 0, 59348) | 0 : 0) {
     i4 = i121 + 4 | 0;
     i1 = HEAP32[i4 >> 2] | 0;
     i121 = __ZN6cashew3RefixEj(i120, 2) | 0;
     HEAP32[i33 >> 2] = HEAP32[i121 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i33 >> 2];
     i1 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i123) | 0;
     HEAP32[i2 + 28 >> 2] = i1;
     i1 = __ZN6cashew3RefixEj(i119, 2) | 0;
     i1 = HEAP32[i1 >> 2] | 0;
     HEAP32[i117 >> 2] = i1;
     i2 = 0;
     while (1) {
      if (i2 >>> 0 >= (__ZN6cashew5Value4sizeEv(i1) | 0) >>> 0) break;
      i121 = (HEAP32[i118 >> 2] | 0) + 8 | 0;
      i1 = HEAP32[i4 >> 2] | 0;
      i119 = __ZN6cashew3RefixEj(i117, i2) | 0;
      HEAP32[i46 >> 2] = HEAP32[i119 >> 2];
      HEAP32[i123 >> 2] = HEAP32[i46 >> 2];
      __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i121, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i123) | 0);
      i1 = HEAP32[i117 >> 2] | 0;
      i2 = i2 + 1 | 0;
     }
     i1 = __ZN4wasm14AstStackHelper9getParentEv(i70) | 0;
     HEAP32[i47 >> 2] = i1;
     i1 = HEAP32[i118 >> 2] | 0;
     HEAP32[i123 >> 2] = HEAP32[i47 >> 2];
     i123 = __ZN4wasm15Asm2WasmBuilder15getFunctionTypeEN6cashew3RefER11ArenaVectorIPNS_10ExpressionEE(i122, i123, i1 + 8 | 0) | 0;
     HEAP32[i1 + 24 >> 2] = i123;
     i1 = HEAP32[i118 >> 2] | 0;
     HEAP32[i1 + 4 >> 2] = HEAP32[(HEAP32[i1 + 24 >> 2] | 0) + 4 >> 2];
     i1 = __ZNSt3__23mapIPN4wasm12CallIndirectEN6cashew7IStringENS_4lessIS3_EENS_9allocatorINS_4pairIKS3_S5_EEEEEixERSA_(i122 + 32 | 0, i118) | 0;
     i123 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 1) | 0, 1) | 0;
     i123 = __ZN6cashew5Value10getIStringEv(HEAP32[i123 >> 2] | 0) | 0;
     HEAP32[i1 >> 2] = HEAP32[i123 >> 2];
     i1 = HEAP32[i118 >> 2] | 0;
     break;
    }
    ___assert_fail(29941, 16311, 1336, 57137);
   }
   i5 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 1) | 0;
   i5 = __ZN6cashew5Value10getIStringEv(HEAP32[i5 >> 2] | 0) | 0;
   i5 = HEAP32[i5 >> 2] | 0;
   i6 = i5;
   if ((i6 | 0) == (HEAP32[i122 + 72 >> 2] | 0)) {
    i48 = __ZN6cashew3RefixEj(i119, 2) | 0;
    if ((__ZN6cashew5Value4sizeEv(HEAP32[i48 >> 2] | 0) | 0) == 2) {
     i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
     HEAP32[i1 + 8 >> 2] = 2;
     i122 = i121 + 4 | 0;
     i121 = HEAP32[i122 >> 2] | 0;
     i120 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0;
     HEAP32[i41 >> 2] = HEAP32[i120 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i41 >> 2];
     i121 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i121, i123) | 0;
     HEAP32[i1 + 12 >> 2] = i121;
     i122 = HEAP32[i122 >> 2] | 0;
     i121 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 1) | 0;
     HEAP32[i42 >> 2] = HEAP32[i121 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i42 >> 2];
     i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
     HEAP32[i1 + 16 >> 2] = i123;
     HEAP32[i1 + 4 >> 2] = 1;
     break;
    } else ___assert_fail(29877, 16311, 1208, 57137);
   }
   i4 = i122 + 76 | 0;
   if ((i6 | 0) != (HEAP32[i4 >> 2] | 0) ? (i6 | 0) != (HEAP32[i122 + 100 >> 2] | 0) : 0) {
    if ((i6 | 0) == (HEAP32[i122 + 80 >> 2] | 0)) {
     i120 = __ZN6cashew3RefixEj(i119, 2) | 0;
     if ((__ZN6cashew5Value4sizeEv(HEAP32[i120 >> 2] | 0) | 0) != 1) ___assert_fail(29897, 16311, 1225, 57137);
     i120 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0;
     HEAP32[i44 >> 2] = HEAP32[i120 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i44 >> 2];
     __ZN4wasm15Asm2WasmBuilder12checkLiteralEN6cashew3RefE(i118, i122, i123);
     L176 : do switch (HEAP32[i118 >> 2] | 0) {
     case 1:
      {
       i123 = __ZNK4wasm7Literal6geti32Ev(i118) | 0;
       i1 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 8 >> 2] | 0) | 0;
       HEAP32[i1 + 8 >> 2] = 3;
       HEAPF32[i1 + 16 >> 2] = +(i123 | 0);
       HEAP32[i1 + 4 >> 2] = 3;
       break;
      }
     case 4:
      {
       d9 = +__ZNK4wasm7Literal6getf64Ev(i118);
       i1 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 8 >> 2] | 0) | 0;
       HEAP32[i1 + 8 >> 2] = 3;
       HEAPF32[i1 + 16 >> 2] = d9;
       HEAP32[i1 + 4 >> 2] = 3;
       break;
      }
     default:
      {
       i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
       i2 = HEAP32[i121 + 4 >> 2] | 0;
       i4 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0;
       HEAP32[i49 >> 2] = HEAP32[i4 >> 2];
       HEAP32[i123 >> 2] = HEAP32[i49 >> 2];
       i2 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i2, i123) | 0;
       HEAP32[i1 + 12 >> 2] = i2;
       i4 = i2 + 4 | 0;
       switch (HEAP32[i4 >> 2] | 0) {
       case 3:
        {
         i1 = i2;
         break L176;
        }
       case 4:
        {
         HEAP32[i1 + 8 >> 2] = 44;
         break;
        }
       case 1:
        {
         HEAP32[i1 + 8 >> 2] = 35;
         break;
        }
       case 0:
        {
         HEAP32[i4 >> 2] = 3;
         i1 = i2;
         break L176;
        }
       default:
        {
         HEAP32[i59 >> 2] = 0;
         HEAP32[i59 + 4 >> 2] = 0;
         HEAP32[i59 + 8 >> 2] = 0;
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i59, 29917, 23);
         i122 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0;
         HEAP32[i60 >> 2] = HEAP32[i122 >> 2];
         HEAP32[i123 >> 2] = HEAP32[i60 >> 2];
         __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew3RefE(i59, i123);
        }
       }
       HEAP32[i1 + 4 >> 2] = 3;
      }
     } while (0);
     break;
    }
    if ((i6 | 0) != (HEAP32[i122 + 84 >> 2] | 0)) {
     i2 = i122 + 88 | 0;
     do if ((i6 | 0) != (HEAP32[i2 >> 2] | 0)) {
      if ((i6 | 0) == (HEAP32[i122 + 96 >> 2] | 0)) break;
      if ((i6 | 0) == (HEAP32[i122 + 92 >> 2] | 0)) break;
      i120 = HEAP32[i122 >> 2] | 0;
      HEAP32[i51 >> 2] = i5;
      HEAP32[i123 >> 2] = HEAP32[i51 >> 2];
      if (!(__ZN4wasm6Module11checkImportENS_4NameE(i120, i123) | 0)) {
       i1 = __ZN10MixedArena5allocIN4wasm4CallEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
       HEAP32[i1 + 24 >> 2] = i5;
       i6 = i1 + 8 | 0;
      } else {
       i120 = __ZN4wasm14AstStackHelper9getParentEv(i70) | 0;
       HEAP32[i118 >> 2] = i120;
       if (__ZN6cashew3RefntEv(i118) | 0) i1 = 0; else {
        HEAP32[i52 >> 2] = HEAP32[i118 >> 2];
        i1 = HEAP32[i121 + 20 >> 2] | 0;
        HEAP32[i123 >> 2] = HEAP32[i52 >> 2];
        i1 = __ZN4wasm15Asm2WasmBuilder14detectWasmTypeEN6cashew3RefEP7AsmData(i122, i123, i1) | 0;
       }
       i120 = __ZN10MixedArena5allocIN4wasm10CallImportEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
       HEAP32[i54 >> 2] = HEAP32[i119 >> 2];
       i6 = HEAP32[i121 + 20 >> 2] | 0;
       HEAP32[i123 >> 2] = HEAP32[i54 >> 2];
       __ZN4wasm15Asm2WasmBuilder24noteImportedFunctionCallEN6cashew3RefENS_8WasmTypeEP7AsmDataPNS_10CallImportE(i122, i123, i1, i6, i120);
       HEAP32[i120 + 24 >> 2] = i5;
       i6 = i120 + 8 | 0;
       i1 = i120;
      }
      i4 = __ZN6cashew3RefixEj(i119, 2) | 0;
      i4 = HEAP32[i4 >> 2] | 0;
      HEAP32[i118 >> 2] = i4;
      i2 = i121 + 4 | 0;
      i5 = 0;
      while (1) {
       if (i5 >>> 0 >= (__ZN6cashew5Value4sizeEv(i4) | 0) >>> 0) break;
       i4 = HEAP32[i2 >> 2] | 0;
       i122 = __ZN6cashew3RefixEj(i118, i5) | 0;
       HEAP32[i78 >> 2] = HEAP32[i122 >> 2];
       HEAP32[i123 >> 2] = HEAP32[i78 >> 2];
       __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i6, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i4, i123) | 0);
       i4 = HEAP32[i118 >> 2] | 0;
       i5 = i5 + 1 | 0;
      }
      break L4;
     } while (0);
     i1 = HEAP32[i121 + 4 >> 2] | 0;
     i121 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0;
     HEAP32[i50 >> 2] = HEAP32[i121 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i50 >> 2];
     i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i123) | 0;
     i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
     HEAP32[i1 + 12 >> 2] = i123;
     switch (HEAP32[i123 + 4 >> 2] | 0) {
     case 3:
      {
       if ((i6 | 0) == (HEAP32[i2 >> 2] | 0)) i2 = 12; else i2 = (i6 | 0) == (HEAP32[i122 + 92 >> 2] | 0) ? 10 : 18;
       HEAP32[i1 + 8 >> 2] = i2;
       HEAP32[i1 + 4 >> 2] = 3;
       break;
      }
     case 4:
      {
       if ((i6 | 0) == (HEAP32[i2 >> 2] | 0)) i2 = 13; else i2 = (i6 | 0) == (HEAP32[i122 + 92 >> 2] | 0) ? 11 : 19;
       HEAP32[i1 + 8 >> 2] = i2;
       HEAP32[i1 + 4 >> 2] = 4;
       break;
      }
     default:
      _abort();
     }
     break;
    }
    i16 = HEAP32[i121 + 4 >> 2] | 0;
    i2 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0;
    HEAP32[i45 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i45 >> 2];
    i16 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i16, i123) | 0;
    i2 = i16 + 4 | 0;
    switch (HEAP32[i2 >> 2] | 0) {
    case 1:
     {
      i15 = HEAP32[i121 + 24 >> 2] | 0;
      i1 = HEAP32[i15 >> 2] | 0;
      if (!(HEAP8[i1 >> 0] | 0)) {
       HEAP8[i1 >> 0] = 1;
       i14 = HEAP32[HEAP32[i15 + 4 >> 2] >> 2] | 0;
       HEAP32[i118 >> 2] = HEAP32[14968];
       HEAP32[i123 >> 2] = HEAP32[i118 >> 2];
       __ZN4wasm7Builder6addVarEPNS_8FunctionENS_4NameENS_8WasmTypeE(i14, i123, 1) | 0;
       i14 = HEAP32[i15 + 8 >> 2] | 0;
       i1 = HEAP32[14968] | 0;
       i13 = i1 * 33 ^ 5381;
       i11 = i14 + 4 | 0;
       i12 = HEAP32[i11 >> 2] | 0;
       i10 = (i12 | 0) == 0;
       i5 = i1;
       L223 : do if (i10) {
        i2 = 0;
        i116 = 141;
       } else {
        i6 = i12 + -1 | 0;
        i7 = (i6 & i12 | 0) == 0;
        if (i7) i8 = i6 & i13; else i8 = (i13 >>> 0) % (i12 >>> 0) | 0;
        i2 = HEAP32[(HEAP32[i14 >> 2] | 0) + (i8 << 2) >> 2] | 0;
        if (!i2) {
         i2 = i8;
         i116 = 141;
         break;
        }
        do {
         i2 = HEAP32[i2 >> 2] | 0;
         if (!i2) {
          i2 = i8;
          i116 = 141;
          break L223;
         }
         i4 = HEAP32[i2 + 4 >> 2] | 0;
         if (i7) i4 = i4 & i6; else i4 = (i4 >>> 0) % (i12 >>> 0) | 0;
         if ((i4 | 0) != (i8 | 0)) {
          i2 = i8;
          i116 = 141;
          break L223;
         }
        } while ((HEAP32[i2 + 8 >> 2] | 0) != (i5 | 0));
       } while (0);
       if ((i116 | 0) == 141) {
        i6 = __Znwj(12) | 0;
        HEAP32[i6 + 8 >> 2] = i1;
        HEAP32[i6 + 4 >> 2] = i13;
        HEAP32[i6 >> 2] = 0;
        i5 = i14 + 12 | 0;
        d3 = +(((HEAP32[i5 >> 2] | 0) + 1 | 0) >>> 0);
        d9 = +HEAPF32[i14 + 16 >> 2];
        do if (i10 | d3 > +(i12 >>> 0) * d9) {
         if (i12 >>> 0 > 2) i1 = (i12 + -1 & i12 | 0) == 0; else i1 = 0;
         i1 = (i1 & 1 | i12 << 1) ^ 1;
         i2 = ~~+Math_ceil(+(d3 / d9)) >>> 0;
         __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE6rehashEj(i14, i1 >>> 0 < i2 >>> 0 ? i2 : i1);
         i1 = HEAP32[i11 >> 2] | 0;
         i2 = i1 + -1 | 0;
         if (!(i2 & i1)) {
          i4 = i1;
          i1 = i2 & i13;
          break;
         } else {
          i4 = i1;
          i1 = (i13 >>> 0) % (i1 >>> 0) | 0;
          break;
         }
        } else {
         i4 = i12;
         i1 = i2;
        } while (0);
        i1 = (HEAP32[i14 >> 2] | 0) + (i1 << 2) | 0;
        i2 = HEAP32[i1 >> 2] | 0;
        do if (!i2) {
         i119 = i14 + 8 | 0;
         HEAP32[i6 >> 2] = HEAP32[i119 >> 2];
         HEAP32[i119 >> 2] = i6;
         HEAP32[i1 >> 2] = i119;
         i1 = HEAP32[i6 >> 2] | 0;
         if (!i1) break;
         i1 = HEAP32[i1 + 4 >> 2] | 0;
         i2 = i4 + -1 | 0;
         if (!(i2 & i4)) i1 = i1 & i2; else i1 = (i1 >>> 0) % (i4 >>> 0) | 0;
         HEAP32[(HEAP32[i14 >> 2] | 0) + (i1 << 2) >> 2] = i6;
        } else {
         HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
         HEAP32[i2 >> 2] = i6;
        } while (0);
        HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 1;
        i1 = HEAP32[14968] | 0;
       }
       i119 = HEAP32[i15 + 12 >> 2] | 0;
       HEAP32[i120 >> 2] = i1;
       HEAP32[i123 >> 2] = HEAP32[i120 >> 2];
       __ZN7AsmData6addVarEN6cashew7IStringE7AsmType(i119, i123, 0);
      }
      i118 = i122 + 4 | 0;
      i119 = __ZN10MixedArena5allocIN4wasm8SetLocalEEEPT_v(HEAP32[i118 >> 2] | 0) | 0;
      i120 = i121 + 12 | 0;
      i1 = HEAP32[HEAP32[i120 >> 2] >> 2] | 0;
      HEAP32[i115 >> 2] = HEAP32[14968];
      HEAP32[i123 >> 2] = HEAP32[i115 >> 2];
      i1 = __ZN4wasm8Function13getLocalIndexENS_4NameE(i1, i123) | 0;
      HEAP32[i119 + 8 >> 2] = i1;
      HEAP32[i119 + 12 >> 2] = i16;
      HEAP32[i119 + 4 >> 2] = 1;
      HEAP32[i123 >> 2] = i122;
      HEAP32[i123 + 4 >> 2] = HEAP32[i120 >> 2];
      i120 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i118 >> 2] | 0) | 0;
      HEAP32[i120 + 8 >> 2] = 17;
      i1 = __ZZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__1clES2_ENKUlvE_clEv(i123) | 0;
      HEAP32[i120 + 12 >> 2] = i1;
      i122 = i122 + 8 | 0;
      i1 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 >> 2] | 0) | 0;
      HEAP32[i1 + 8 >> 2] = 1;
      HEAP32[i1 + 16 >> 2] = 0;
      HEAP32[i1 + 4 >> 2] = 1;
      HEAP32[i120 + 16 >> 2] = i1;
      __ZN4wasm6Binary8finalizeEv(i120);
      i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i118 >> 2] | 0) | 0;
      i121 = i1 + 12 | 0;
      __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i121, i119);
      i119 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i118 >> 2] | 0) | 0;
      HEAP32[i119 + 8 >> 2] = 1;
      i122 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 >> 2] | 0) | 0;
      HEAP32[i122 + 8 >> 2] = 1;
      HEAP32[i122 + 16 >> 2] = 0;
      HEAP32[i122 + 4 >> 2] = 1;
      HEAP32[i119 + 12 >> 2] = i122;
      i122 = __ZZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__1clES2_ENKUlvE_clEv(i123) | 0;
      HEAP32[i119 + 16 >> 2] = i122;
      HEAP32[i119 + 4 >> 2] = 1;
      i122 = __ZN10MixedArena5allocIN4wasm6SelectEEEPT_v(HEAP32[i118 >> 2] | 0) | 0;
      HEAP32[i122 + 8 >> 2] = i119;
      i123 = __ZZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__1clES2_ENKUlvE_clEv(i123) | 0;
      HEAP32[i122 + 12 >> 2] = i123;
      HEAP32[i122 + 16 >> 2] = i120;
      HEAP32[i122 + 4 >> 2] = 1;
      __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i121, i122);
      __ZN4wasm5Block8finalizeEv(i1);
      break L4;
     }
    case 4:
    case 3:
     {
      i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
      i123 = HEAP32[i2 >> 2] | 0;
      HEAP32[i1 + 8 >> 2] = (i123 | 0) == 3 ? 8 : 9;
      HEAP32[i1 + 12 >> 2] = i16;
      HEAP32[i1 + 4 >> 2] = i123;
      break L4;
     }
    default:
     _abort();
    }
   }
   i115 = __ZN6cashew3RefixEj(i119, 2) | 0;
   if ((__ZN6cashew5Value4sizeEv(HEAP32[i115 >> 2] | 0) | 0) == 1) {
    i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
    HEAP32[i1 + 8 >> 2] = (i6 | 0) == (HEAP32[i4 >> 2] | 0) ? 0 : 2;
    i122 = HEAP32[i121 + 4 >> 2] | 0;
    i121 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0;
    HEAP32[i53 >> 2] = HEAP32[i121 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i53 >> 2];
    i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
    HEAP32[i1 + 12 >> 2] = i123;
    HEAP32[i1 + 4 >> 2] = 1;
    break;
   } else ___assert_fail(29897, 16311, 1217, 57137);
  }
  if ((i58 | 0) == (HEAP32[14828] | 0)) {
   if (__ZN6cashew3RefntEv(__ZN6cashew3RefixEj(i119, 1) | 0) | 0) i2 = 0; else {
    i2 = __ZN6cashew3RefixEj(i119, 1) | 0;
    HEAP32[i55 >> 2] = HEAP32[i2 >> 2];
    i2 = HEAP32[i121 + 20 >> 2] | 0;
    HEAP32[i123 >> 2] = HEAP32[i55 >> 2];
    i2 = __ZN4wasm15Asm2WasmBuilder14detectWasmTypeEN6cashew3RefEP7AsmData(i122, i123, i2) | 0;
   }
   i1 = (HEAP32[HEAP32[i121 + 12 >> 2] >> 2] | 0) + 4 | 0;
   if (HEAP8[HEAP32[i121 + 28 >> 2] >> 0] | 0) {
    if ((HEAP32[i1 >> 2] | 0) != (i2 | 0)) ___assert_fail(30057, 16311, 1349, 57137);
   } else HEAP32[i1 >> 2] = i2;
   i1 = __ZN10MixedArena5allocIN4wasm6ReturnEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
   if (__ZN6cashew3RefntEv(__ZN6cashew3RefixEj(i119, 1) | 0) | 0) i2 = 0; else {
    i2 = HEAP32[i121 + 4 >> 2] | 0;
    i122 = __ZN6cashew3RefixEj(i119, 1) | 0;
    HEAP32[i71 >> 2] = HEAP32[i122 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i71 >> 2];
    i2 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i2, i123) | 0;
   }
   HEAP32[i1 + 8 >> 2] = i2;
   break;
  }
  if ((i58 | 0) == (HEAP32[14987] | 0)) {
   HEAP32[i118 >> 2] = 0;
   i4 = i121 + 32 | 0;
   i1 = HEAP32[i4 >> 2] | 0;
   do if (HEAP32[i1 >> 2] | 0) {
    HEAP32[i65 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i65 >> 2];
    i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__5clENS1_7IStringE(i123) | 0;
    i6 = i2;
    HEAP32[i118 >> 2] = i6;
    HEAP32[HEAP32[i4 >> 2] >> 2] = 0;
    i1 = HEAP32[i121 + 40 >> 2] | 0;
    i4 = i1 + 4 | 0;
    i5 = HEAP32[i4 >> 2] | 0;
    if ((i5 | 0) == (HEAP32[i1 + 8 >> 2] | 0)) {
     __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i1, i118);
     break;
    } else {
     HEAP32[i5 >> 2] = i6;
     HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 4;
     break;
    }
   } else {
    i2 = 0;
    i6 = 0;
   } while (0);
   i1 = HEAP32[i121 + 44 >> 2] | 0;
   i120 = __ZN6cashew3RefixEj(i119, 1) | 0;
   HEAP32[i92 >> 2] = HEAP32[i120 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i92 >> 2];
   i1 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEEclES5_j(i1, i123, 0) | 0;
   do if (i2) {
    i2 = (HEAP32[i121 + 40 >> 2] | 0) + 4 | 0;
    i5 = HEAP32[i2 >> 2] | 0;
    i4 = i5 + -4 | 0;
    while (1) {
     if ((i5 | 0) == (i4 | 0)) break;
     i123 = i5 + -4 | 0;
     HEAP32[i2 >> 2] = i123;
     i5 = i123;
    }
    if (!((i1 | 0) == 0 | (HEAP32[i1 >> 2] | 0) != 1) ? (i94 = i1 + 8 | 0, (HEAP32[i94 >> 2] | 0) == 0) : 0) {
     HEAP32[i94 >> 2] = i6;
     break;
    }
    i123 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
    HEAP32[i123 + 8 >> 2] = i6;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i123 + 12 | 0, i1);
    __ZN4wasm5Block8finalizeEv(i123);
    i1 = i123;
   } while (0);
   break;
  }
  if ((i58 | 0) == (HEAP32[14839] | 0)) {
   i1 = __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
   i2 = i121 + 40 | 0;
   i122 = HEAP32[i2 >> 2] | 0;
   if ((HEAP32[i122 + 4 >> 2] | 0) == (HEAP32[i122 >> 2] | 0)) ___assert_fail(30082, 16311, 1381, 57137);
   if (__ZN6cashew3RefntEv(__ZN6cashew3RefixEj(i119, 1) | 0) | 0) i2 = HEAP32[(HEAP32[(HEAP32[i2 >> 2] | 0) + 4 >> 2] | 0) + -4 >> 2] | 0; else {
    i2 = __ZN6cashew3RefixEj(i119, 1) | 0;
    i2 = __ZN6cashew5Value10getIStringEv(HEAP32[i2 >> 2] | 0) | 0;
    HEAP32[i66 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i66 >> 2];
    i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__5clENS1_7IStringE(i123) | 0;
   }
   HEAP32[i1 + 8 >> 2] = i2;
   break;
  }
  if ((i58 | 0) == (HEAP32[14840] | 0)) {
   i1 = __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
   i2 = i121 + 48 | 0;
   i122 = HEAP32[i2 >> 2] | 0;
   if ((HEAP32[i122 + 4 >> 2] | 0) == (HEAP32[i122 >> 2] | 0)) ___assert_fail(30104, 16311, 1386, 57137);
   if (__ZN6cashew3RefntEv(__ZN6cashew3RefixEj(i119, 1) | 0) | 0) i2 = HEAP32[(HEAP32[(HEAP32[i2 >> 2] | 0) + 4 >> 2] | 0) + -4 >> 2] | 0; else {
    i2 = __ZN6cashew3RefixEj(i119, 1) | 0;
    i2 = __ZN6cashew5Value10getIStringEv(HEAP32[i2 >> 2] | 0) | 0;
    HEAP32[i67 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i67 >> 2];
    i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__6clENS1_7IStringE(i123) | 0;
   }
   HEAP32[i1 + 8 >> 2] = i2;
   break;
  }
  if ((i58 | 0) == (HEAP32[14831] | 0)) {
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 0) | 0, 59348) | 0) {
    i12 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 1) | 0;
    i12 = (__ZN6cashew5Value10getIntegerEv(HEAP32[i12 >> 2] | 0) | 0) == 1;
   } else i12 = 0;
   i13 = i122 + 4 | 0;
   i1 = __ZN10MixedArena5allocIN4wasm4LoopEEEPT_v(HEAP32[i13 >> 2] | 0) | 0;
   HEAP32[i118 >> 2] = 0;
   HEAP32[i120 >> 2] = 0;
   i2 = i121 + 32 | 0;
   i4 = HEAP32[i2 >> 2] | 0;
   if (!(HEAP32[i4 >> 2] | 0)) {
    i4 = i121 + 56 | 0;
    i2 = HEAP32[i4 >> 2] | 0;
    HEAP32[i81 >> 2] = 0;
    HEAP32[i81 + 4 >> 2] = 0;
    HEAP32[i81 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i81, 30129, 9);
    i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i2, i81) | 0;
    HEAP32[i118 >> 2] = i2;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i81);
    i4 = HEAP32[i4 >> 2] | 0;
    HEAP32[i82 >> 2] = 0;
    HEAP32[i82 + 4 >> 2] = 0;
    HEAP32[i82 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i82, 30139, 8);
    i4 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i4, i82) | 0;
    HEAP32[i120 >> 2] = i4;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i82);
   } else {
    HEAP32[i79 >> 2] = HEAP32[i4 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i79 >> 2];
    i117 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__5clENS1_7IStringE(i123) | 0;
    HEAP32[i118 >> 2] = i117;
    HEAP32[i80 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
    HEAP32[i123 >> 2] = HEAP32[i80 >> 2];
    i4 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__6clENS1_7IStringE(i123) | 0;
    HEAP32[i120 >> 2] = i4;
    HEAP32[HEAP32[i2 >> 2] >> 2] = 0;
    i2 = i117;
   }
   HEAP32[i1 + 8 >> 2] = i2;
   i10 = i1 + 12 | 0;
   HEAP32[i10 >> 2] = i4;
   i11 = i121 + 40 | 0;
   i5 = HEAP32[i11 >> 2] | 0;
   i6 = i5 + 4 | 0;
   i7 = HEAP32[i6 >> 2] | 0;
   if ((i7 | 0) == (HEAP32[i5 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i5, i118); else {
    HEAP32[i7 >> 2] = i2;
    HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + 4;
   }
   i8 = i121 + 48 | 0;
   i5 = HEAP32[i8 >> 2] | 0;
   i6 = i5 + 4 | 0;
   i7 = HEAP32[i6 >> 2] | 0;
   if ((i7 | 0) == (HEAP32[i5 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i5, i120); else {
    HEAP32[i7 >> 2] = i4;
    HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + 4;
   }
   if (i12) {
    i4 = HEAP32[i121 + 4 >> 2] | 0;
    i2 = __ZN6cashew3RefixEj(i119, 2) | 0;
    HEAP32[i97 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i97 >> 2];
    i4 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i4, i123) | 0;
    i2 = i1 + 16 | 0;
    HEAP32[i2 >> 2] = i4;
   } else {
    i4 = __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(HEAP32[i13 >> 2] | 0) | 0;
    HEAP32[i4 + 8 >> 2] = i2;
    i120 = __ZN10MixedArena5allocIN4wasm2IfEEEPT_v(HEAP32[i13 >> 2] | 0) | 0;
    i2 = i121 + 4 | 0;
    i121 = HEAP32[i2 >> 2] | 0;
    i118 = __ZN6cashew3RefixEj(i119, 1) | 0;
    HEAP32[i98 >> 2] = HEAP32[i118 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i98 >> 2];
    i121 = __ZN4wasm7Builder9makeUnaryENS_7UnaryOpEPNS_10ExpressionE(i122 + 8 | 0, 20, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i121, i123) | 0) | 0;
    HEAP32[i120 + 8 >> 2] = i121;
    HEAP32[i120 + 12 >> 2] = i4;
    i4 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i13 >> 2] | 0) | 0;
    i121 = i4 + 12 | 0;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i121, i120);
    i2 = HEAP32[i2 >> 2] | 0;
    i120 = __ZN6cashew3RefixEj(i119, 2) | 0;
    HEAP32[i99 >> 2] = HEAP32[i120 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i99 >> 2];
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i121, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i2, i123) | 0);
    __ZN4wasm5Block8finalizeEv(i4);
    i2 = i1 + 16 | 0;
    HEAP32[i2 >> 2] = i4;
   }
   i5 = __ZN4wasm15Asm2WasmBuilder8blockifyEPNS_10ExpressionE(i122, i4) | 0;
   i4 = __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(HEAP32[i13 >> 2] | 0) | 0;
   HEAP32[i4 + 8 >> 2] = HEAP32[i10 >> 2];
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i5 + 12 | 0, i4);
   HEAP32[i2 >> 2] = i5;
   i2 = (HEAP32[i8 >> 2] | 0) + 4 | 0;
   i5 = HEAP32[i2 >> 2] | 0;
   i4 = i5 + -4 | 0;
   while (1) {
    if ((i5 | 0) == (i4 | 0)) break;
    i123 = i5 + -4 | 0;
    HEAP32[i2 >> 2] = i123;
    i5 = i123;
   }
   i2 = (HEAP32[i11 >> 2] | 0) + 4 | 0;
   i5 = HEAP32[i2 >> 2] | 0;
   i4 = i5 + -4 | 0;
   while (1) {
    if ((i5 | 0) == (i4 | 0)) break;
    i123 = i5 + -4 | 0;
    HEAP32[i2 >> 2] = i123;
    i5 = i123;
   }
   break;
  }
  if ((i58 | 0) == (HEAP32[14832] | 0)) {
   do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 0) | 0, 59348) | 0) {
    i116 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 1) | 0;
    i116 = __ZN6cashew5Value9getNumberEv(HEAP32[i116 >> 2] | 0) | 0;
    if (!(+HEAPF64[i116 >> 3] == 0.0)) break;
    HEAP32[i118 >> 2] = 0;
    i1 = i121 + 32 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    if (!(HEAP32[i2 >> 2] | 0)) {
     i2 = i121 + 56 | 0;
     i1 = HEAP32[i2 >> 2] | 0;
     HEAP32[i69 >> 2] = 0;
     HEAP32[i69 + 4 >> 2] = 0;
     HEAP32[i69 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i69, 30148, 7);
     i1 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i1, i69) | 0;
     HEAP32[i118 >> 2] = i1;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i69);
    } else {
     HEAP32[i68 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i123 >> 2] = HEAP32[i68 >> 2];
     i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__5clENS1_7IStringE(i123) | 0;
     HEAP32[i118 >> 2] = i2;
     HEAP32[HEAP32[i1 >> 2] >> 2] = 0;
     i1 = i2;
     i2 = i121 + 56 | 0;
    }
    i8 = i1;
    i7 = HEAP32[i2 >> 2] | 0;
    HEAP32[i83 >> 2] = 0;
    HEAP32[i83 + 4 >> 2] = 0;
    HEAP32[i83 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i83, 30156, 17);
    i7 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i7, i83) | 0;
    HEAP32[i120 >> 2] = i7;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i83);
    i6 = i121 + 40 | 0;
    i1 = HEAP32[i6 >> 2] | 0;
    i2 = i1 + 4 | 0;
    i4 = HEAP32[i2 >> 2] | 0;
    if ((i4 | 0) == (HEAP32[i1 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i1, i118); else {
     HEAP32[i4 >> 2] = i8;
     HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
    }
    i1 = i121 + 48 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i4 = i2 + 4 | 0;
    i5 = HEAP32[i4 >> 2] | 0;
    if ((i5 | 0) == (HEAP32[i2 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i2, i120); else {
     HEAP32[i5 >> 2] = i7;
     HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 4;
    }
    i4 = HEAP32[i121 + 4 >> 2] | 0;
    i2 = __ZN6cashew3RefixEj(i119, 2) | 0;
    HEAP32[i95 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i95 >> 2];
    i4 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i4, i123) | 0;
    HEAP32[i117 >> 2] = i4;
    i1 = (HEAP32[i1 >> 2] | 0) + 4 | 0;
    i4 = HEAP32[i1 >> 2] | 0;
    i2 = i4 + -4 | 0;
    while (1) {
     if ((i4 | 0) == (i2 | 0)) break;
     i121 = i4 + -4 | 0;
     HEAP32[i1 >> 2] = i121;
     i4 = i121;
    }
    i1 = (HEAP32[i6 >> 2] | 0) + 4 | 0;
    i4 = HEAP32[i1 >> 2] | 0;
    i2 = i4 + -4 | 0;
    while (1) {
     if ((i4 | 0) == (i2 | 0)) break;
     i121 = i4 + -4 | 0;
     HEAP32[i1 >> 2] = i121;
     i4 = i121;
    }
    i121 = i123 + 4 | 0;
    HEAP32[i121 >> 2] = 0;
    HEAP32[i121 + 4 >> 2] = 0;
    HEAP32[i121 + 8 >> 2] = 0;
    HEAP32[i121 + 12 >> 2] = 0;
    HEAP32[i121 + 16 >> 2] = 0;
    HEAP32[i121 + 20 >> 2] = 0;
    HEAP32[i123 >> 2] = 4456;
    HEAP32[i123 + 28 >> 2] = i7;
    i121 = i123 + 32 | 0;
    HEAP32[i121 >> 2] = 0;
    __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i123, i117);
    i1 = HEAP32[i122 + 4 >> 2] | 0;
    if (!(HEAP32[i121 >> 2] | 0)) {
     i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(i1) | 0;
     __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i1 + 12 | 0, HEAP32[i117 >> 2] | 0);
     HEAP32[i1 + 8 >> 2] = i8;
     __ZN4wasm5Block8finalizeEv(i1);
    } else {
     i1 = __ZN10MixedArena5allocIN4wasm4LoopEEEPT_v(i1) | 0;
     HEAP32[i1 + 16 >> 2] = HEAP32[i117 >> 2];
     HEAP32[i1 + 8 >> 2] = i8;
     HEAP32[i1 + 12 >> 2] = i7;
    }
    HEAP32[i123 >> 2] = 4468;
    __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i123 + 8 | 0);
    break L4;
   } while (0);
   i12 = i122 + 4 | 0;
   i1 = __ZN10MixedArena5allocIN4wasm4LoopEEEPT_v(HEAP32[i12 >> 2] | 0) | 0;
   HEAP32[i118 >> 2] = 0;
   HEAP32[i120 >> 2] = 0;
   i2 = i121 + 32 | 0;
   i4 = HEAP32[i2 >> 2] | 0;
   if (!(HEAP32[i4 >> 2] | 0)) {
    i4 = i121 + 56 | 0;
    i2 = HEAP32[i4 >> 2] | 0;
    HEAP32[i76 >> 2] = 0;
    HEAP32[i76 + 4 >> 2] = 0;
    HEAP32[i76 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i76, 30174, 6);
    i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i2, i76) | 0;
    HEAP32[i118 >> 2] = i2;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i76);
    i4 = HEAP32[i4 >> 2] | 0;
    HEAP32[i77 >> 2] = 0;
    HEAP32[i77 + 4 >> 2] = 0;
    HEAP32[i77 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i77, 30181, 5);
    i4 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i4, i77) | 0;
    HEAP32[i120 >> 2] = i4;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i77);
   } else {
    HEAP32[i74 >> 2] = HEAP32[i4 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i74 >> 2];
    i117 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__5clENS1_7IStringE(i123) | 0;
    HEAP32[i118 >> 2] = i117;
    HEAP32[i75 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
    HEAP32[i123 >> 2] = HEAP32[i75 >> 2];
    i4 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__6clENS1_7IStringE(i123) | 0;
    HEAP32[i120 >> 2] = i4;
    HEAP32[HEAP32[i2 >> 2] >> 2] = 0;
    i2 = i117;
   }
   i11 = i4;
   HEAP32[i1 + 8 >> 2] = i2;
   HEAP32[i1 + 12 >> 2] = i11;
   i10 = i121 + 40 | 0;
   i4 = HEAP32[i10 >> 2] | 0;
   i5 = i4 + 4 | 0;
   i6 = HEAP32[i5 >> 2] | 0;
   if ((i6 | 0) == (HEAP32[i4 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4, i118); else {
    HEAP32[i6 >> 2] = i2;
    HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
   }
   i6 = i121 + 48 | 0;
   i2 = HEAP32[i6 >> 2] | 0;
   i4 = i2 + 4 | 0;
   i5 = HEAP32[i4 >> 2] | 0;
   if ((i5 | 0) == (HEAP32[i2 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i2, i120); else {
    HEAP32[i5 >> 2] = i11;
    HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 4;
   }
   i8 = i121 + 4 | 0;
   i2 = HEAP32[i8 >> 2] | 0;
   i7 = __ZN6cashew3RefixEj(i119, 2) | 0;
   HEAP32[i96 >> 2] = HEAP32[i7 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i96 >> 2];
   i2 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i2, i123) | 0;
   i7 = i1 + 16 | 0;
   HEAP32[i7 >> 2] = i2;
   i2 = (HEAP32[i6 >> 2] | 0) + 4 | 0;
   i5 = HEAP32[i2 >> 2] | 0;
   i4 = i5 + -4 | 0;
   while (1) {
    if ((i5 | 0) == (i4 | 0)) break;
    i121 = i5 + -4 | 0;
    HEAP32[i2 >> 2] = i121;
    i5 = i121;
   }
   i2 = (HEAP32[i10 >> 2] | 0) + 4 | 0;
   i5 = HEAP32[i2 >> 2] | 0;
   i4 = i5 + -4 | 0;
   while (1) {
    if ((i5 | 0) == (i4 | 0)) break;
    i121 = i5 + -4 | 0;
    HEAP32[i2 >> 2] = i121;
    i5 = i121;
   }
   i121 = __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(HEAP32[i12 >> 2] | 0) | 0;
   HEAP32[i121 + 8 >> 2] = i11;
   i120 = HEAP32[i8 >> 2] | 0;
   i119 = __ZN6cashew3RefixEj(i119, 1) | 0;
   HEAP32[i105 >> 2] = HEAP32[i119 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i105 >> 2];
   i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i120, i123) | 0;
   HEAP32[i121 + 16 >> 2] = i123;
   i123 = __ZN4wasm15Asm2WasmBuilder8blockifyEPNS_10ExpressionE(i122, HEAP32[i7 >> 2] | 0) | 0;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i123 + 12 | 0, i121);
   HEAP32[i7 >> 2] = i123;
   break;
  }
  if ((i58 | 0) == (HEAP32[14833] | 0)) {
   i16 = __ZN6cashew3RefixEj(i119, 1) | 0;
   i16 = HEAP32[i16 >> 2] | 0;
   i12 = __ZN6cashew3RefixEj(i119, 2) | 0;
   i12 = HEAP32[i12 >> 2] | 0;
   i13 = __ZN6cashew3RefixEj(i119, 3) | 0;
   i13 = HEAP32[i13 >> 2] | 0;
   i11 = __ZN6cashew3RefixEj(i119, 4) | 0;
   i11 = HEAP32[i11 >> 2] | 0;
   i14 = i122 + 4 | 0;
   i15 = __ZN10MixedArena5allocIN4wasm4LoopEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
   HEAP32[i118 >> 2] = 0;
   HEAP32[i120 >> 2] = 0;
   i1 = i121 + 32 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if (!(HEAP32[i2 >> 2] | 0)) {
    i2 = i121 + 56 | 0;
    i1 = HEAP32[i2 >> 2] | 0;
    HEAP32[i89 >> 2] = 0;
    HEAP32[i89 + 4 >> 2] = 0;
    HEAP32[i89 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i89, 30187, 7);
    i1 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i1, i89) | 0;
    HEAP32[i118 >> 2] = i1;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i89);
    i2 = HEAP32[i2 >> 2] | 0;
    HEAP32[i90 >> 2] = 0;
    HEAP32[i90 + 4 >> 2] = 0;
    HEAP32[i90 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i90, 30195, 6);
    i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i2, i90) | 0;
    HEAP32[i120 >> 2] = i2;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i90);
   } else {
    HEAP32[i87 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i87 >> 2];
    i119 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__5clENS1_7IStringE(i123) | 0;
    HEAP32[i118 >> 2] = i119;
    HEAP32[i88 >> 2] = HEAP32[HEAP32[i1 >> 2] >> 2];
    HEAP32[i123 >> 2] = HEAP32[i88 >> 2];
    i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__6clENS1_7IStringE(i123) | 0;
    HEAP32[i120 >> 2] = i2;
    HEAP32[HEAP32[i1 >> 2] >> 2] = 0;
    i1 = i119;
   }
   HEAP32[i15 + 8 >> 2] = i1;
   i8 = i15 + 12 | 0;
   HEAP32[i8 >> 2] = i2;
   i10 = i121 + 40 | 0;
   i4 = HEAP32[i10 >> 2] | 0;
   i5 = i4 + 4 | 0;
   i6 = HEAP32[i5 >> 2] | 0;
   if ((i6 | 0) == (HEAP32[i4 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4, i118); else {
    HEAP32[i6 >> 2] = i1;
    HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
   }
   i7 = i121 + 48 | 0;
   i4 = HEAP32[i7 >> 2] | 0;
   i5 = i4 + 4 | 0;
   i6 = HEAP32[i5 >> 2] | 0;
   if ((i6 | 0) == (HEAP32[i4 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4, i120); else {
    HEAP32[i6 >> 2] = i2;
    HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
   }
   i4 = __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
   HEAP32[i4 + 8 >> 2] = i1;
   i1 = __ZN10MixedArena5allocIN4wasm2IfEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
   i5 = i121 + 4 | 0;
   i2 = HEAP32[i5 >> 2] | 0;
   HEAP32[i102 >> 2] = i12;
   HEAP32[i123 >> 2] = HEAP32[i102 >> 2];
   i2 = __ZN4wasm7Builder9makeUnaryENS_7UnaryOpEPNS_10ExpressionE(i122 + 8 | 0, 20, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i2, i123) | 0) | 0;
   HEAP32[i1 + 8 >> 2] = i2;
   HEAP32[i1 + 12 >> 2] = i4;
   i4 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
   i2 = i4 + 12 | 0;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, i1);
   i1 = HEAP32[i5 >> 2] | 0;
   HEAP32[i103 >> 2] = i11;
   HEAP32[i123 >> 2] = HEAP32[i103 >> 2];
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i123) | 0);
   i1 = HEAP32[i5 >> 2] | 0;
   HEAP32[i104 >> 2] = i13;
   HEAP32[i123 >> 2] = HEAP32[i104 >> 2];
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i123) | 0);
   __ZN4wasm5Block8finalizeEv(i4);
   i1 = i15 + 16 | 0;
   HEAP32[i1 >> 2] = i4;
   i4 = __ZN4wasm15Asm2WasmBuilder8blockifyEPNS_10ExpressionE(i122, i4) | 0;
   i2 = __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
   HEAP32[i2 + 8 >> 2] = HEAP32[i8 >> 2];
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i4 + 12 | 0, i2);
   HEAP32[i1 >> 2] = i4;
   i1 = (HEAP32[i7 >> 2] | 0) + 4 | 0;
   i4 = HEAP32[i1 >> 2] | 0;
   i2 = i4 + -4 | 0;
   while (1) {
    if ((i4 | 0) == (i2 | 0)) break;
    i122 = i4 + -4 | 0;
    HEAP32[i1 >> 2] = i122;
    i4 = i122;
   }
   i1 = (HEAP32[i10 >> 2] | 0) + 4 | 0;
   i4 = HEAP32[i1 >> 2] | 0;
   i2 = i4 + -4 | 0;
   while (1) {
    if ((i4 | 0) == (i2 | 0)) break;
    i122 = i4 + -4 | 0;
    HEAP32[i1 >> 2] = i122;
    i4 = i122;
   }
   i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
   i122 = i1 + 12 | 0;
   i121 = HEAP32[i5 >> 2] | 0;
   HEAP32[i106 >> 2] = i16;
   HEAP32[i123 >> 2] = HEAP32[i106 >> 2];
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i122, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i121, i123) | 0);
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i122, i15);
   __ZN4wasm5Block8finalizeEv(i1);
   break;
  }
  if ((i58 | 0) == (HEAP32[14838] | 0)) {
   i2 = HEAP32[i121 + 32 >> 2] | 0;
   if (!(HEAP32[i2 >> 2] | 0)) {
    i1 = __ZN6cashew3RefixEj(i119, 1) | 0;
    i1 = __ZN6cashew5Value10getIStringEv(HEAP32[i1 >> 2] | 0) | 0;
    HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
    i1 = HEAP32[i121 + 4 >> 2] | 0;
    i122 = __ZN6cashew3RefixEj(i119, 2) | 0;
    HEAP32[i61 >> 2] = HEAP32[i122 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i61 >> 2];
    i1 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i123) | 0;
    break;
   } else ___assert_fail(17247, 16311, 1531, 57137);
  }
  if ((i58 | 0) == (HEAP32[14826] | 0)) {
   i1 = __ZN10MixedArena5allocIN4wasm2IfEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
   i121 = i121 + 4 | 0;
   i120 = HEAP32[i121 >> 2] | 0;
   i122 = __ZN6cashew3RefixEj(i119, 1) | 0;
   HEAP32[i62 >> 2] = HEAP32[i122 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i62 >> 2];
   i120 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i120, i123) | 0;
   HEAP32[i1 + 8 >> 2] = i120;
   i120 = HEAP32[i121 >> 2] | 0;
   i122 = __ZN6cashew3RefixEj(i119, 2) | 0;
   HEAP32[i63 >> 2] = HEAP32[i122 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i63 >> 2];
   i120 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i120, i123) | 0;
   i122 = i1 + 12 | 0;
   HEAP32[i122 >> 2] = i120;
   i121 = HEAP32[i121 >> 2] | 0;
   i120 = __ZN6cashew3RefixEj(i119, 3) | 0;
   HEAP32[i64 >> 2] = HEAP32[i120 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i64 >> 2];
   i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i121, i123) | 0;
   HEAP32[i1 + 16 >> 2] = i123;
   HEAP32[i1 + 4 >> 2] = HEAP32[(HEAP32[i122 >> 2] | 0) + 4 >> 2];
   break;
  }
  if ((i58 | 0) == (HEAP32[14834] | 0)) {
   do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 0) | 0, 59288) | 0) {
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 2) | 0, 0) | 0, 59340) | 0)) break;
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 2) | 0, 1) | 0, 0) | 0, 59292) | 0)) break;
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 2) | 0, 2) | 0, 0) | 0, 59308) | 0)) break;
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 2) | 0, 2) | 0, 1) | 0, 59492) | 0)) break;
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 2) | 0, 2) | 0, 2) | 0, 0) | 0, 59292) | 0)) break;
    i2 = i122 + 104 | 0;
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 2) | 0, 2) | 0, 2) | 0, 1) | 0, i2) | 0)) break;
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 2) | 0, 2) | 0, 3) | 0, 0) | 0, 59348) | 0)) break;
    i117 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 2) | 0, 2) | 0, 3) | 0, 1) | 0;
    i117 = __ZN6cashew5Value9getNumberEv(HEAP32[i117 >> 2] | 0) | 0;
    if (!(+HEAPF64[i117 >> 3] == 2.0)) break;
    i1 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 2) | 0, 1) | 0, 1) | 0;
    i1 = __ZN6cashew5Value10getIStringEv(HEAP32[i1 >> 2] | 0) | 0;
    HEAP32[i118 >> 2] = HEAP32[i1 >> 2];
    i1 = i122 + 60 | 0;
    if ((__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i1, i118) | 0) != (i122 + 64 | 0)) {
     i1 = (__ZNSt3__23mapIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_(i1, i118) | 0) + 8 | 0;
     i1 = HEAP32[i1 >> 2] | 0;
     HEAP32[i120 >> 2] = 0;
     do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0, 59308) | 0) {
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 1) | 0, 59436) | 0)) {
       i116 = 327;
       break;
      }
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 3) | 0, 0) | 0, 59348) | 0)) {
       i116 = 327;
       break;
      }
      i118 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 3) | 0, 1) | 0;
      i118 = __ZN6cashew5Value9getNumberEv(HEAP32[i118 >> 2] | 0) | 0;
      if (!(+HEAPF64[i118 >> 3] == 0.0)) {
       i116 = 327;
       break;
      }
      i5 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 2) | 0;
      HEAP32[i120 >> 2] = HEAP32[i5 >> 2];
      i5 = 0;
      i116 = 334;
     } else i116 = 327; while (0);
     L451 : do if ((i116 | 0) == 327) {
      do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0, 59396) | 0) {
       if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 1) | 0, 59428) | 0)) break;
       i5 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 2) | 0;
       HEAP32[i120 >> 2] = HEAP32[i5 >> 2];
       i5 = 1;
       i116 = 334;
       break L451;
      } while (0);
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 0) | 0, 59936) | 0)) break;
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 1) | 0, 0) | 0, 59292) | 0)) break;
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 1) | 0, 1) | 0, i122 + 80 | 0) | 0)) break;
      i5 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 2) | 0, 2) | 0, 0) | 0;
      HEAP32[i120 >> 2] = HEAP32[i5 >> 2];
      i5 = 2;
      i116 = 334;
     } while (0);
     L460 : do if ((i116 | 0) == 334) {
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i120, 0) | 0, 59340) | 0)) break;
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 1) | 0, 0) | 0, 59292) | 0)) break;
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 2) | 0, 0) | 0, 59308) | 0)) break;
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 2) | 0, 1) | 0, 59492) | 0)) break;
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 2) | 0, 2) | 0, 0) | 0, 59292) | 0)) break;
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 2) | 0, 2) | 0, 1) | 0, i2) | 0)) break;
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 2) | 0, 3) | 0, 0) | 0, 59348) | 0)) break;
      i120 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i120, 2) | 0, 3) | 0, 1) | 0;
      i120 = __ZN6cashew5Value9getNumberEv(HEAP32[i120 >> 2] | 0) | 0;
      if (!(+HEAPF64[i120 >> 3] == 2.0)) break;
      i4 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i119, 1) | 0, 3) | 0;
      i4 = HEAP32[i4 >> 2] | 0;
      do if (!i1) {
       if ((i5 + -1 | 0) >>> 0 >= 2) break L460;
       i2 = i122 + 4 | 0;
       i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i2 >> 2] | 0) | 0;
       HEAP32[i1 + 8 >> 2] = 45;
       i122 = HEAP32[i121 + 4 >> 2] | 0;
       HEAP32[i91 >> 2] = i4;
       HEAP32[i123 >> 2] = HEAP32[i91 >> 2];
       i123 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0;
       HEAP32[i1 + 12 >> 2] = i123;
       HEAP32[i1 + 4 >> 2] = 3;
       if ((i5 | 0) != 1) break;
       i123 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i2 >> 2] | 0) | 0;
       HEAP32[i123 + 8 >> 2] = 43;
       HEAP32[i123 + 12 >> 2] = i1;
       HEAP32[i123 + 4 >> 2] = 4;
       i1 = i123;
      } else {
       if (!((i1 | 0) == 2 & (i5 | 0) == 0)) break L460;
       i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
       HEAP32[i1 + 8 >> 2] = 33;
       i2 = HEAP32[i121 + 4 >> 2] | 0;
       HEAP32[i86 >> 2] = i4;
       HEAP32[i123 >> 2] = HEAP32[i86 >> 2];
       i2 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i2, i123) | 0;
       i4 = i1 + 12 | 0;
       HEAP32[i4 >> 2] = i2;
       if ((HEAP32[i2 + 4 >> 2] | 0) == 4) {
        i123 = __ZN4wasm7Builder9makeUnaryENS_7UnaryOpEPNS_10ExpressionE(i122 + 8 | 0, 44, i2) | 0;
        HEAP32[i4 >> 2] = i123;
       }
       HEAP32[i1 + 4 >> 2] = 1;
      } while (0);
      break L4;
     } while (0);
    }
   } while (0);
   i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i122 + 4 >> 2] | 0) | 0;
   i120 = i1 + 12 | 0;
   i122 = i121 + 4 | 0;
   i121 = HEAP32[i122 >> 2] | 0;
   i118 = __ZN6cashew3RefixEj(i119, 1) | 0;
   HEAP32[i84 >> 2] = HEAP32[i118 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i84 >> 2];
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i120, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i121, i123) | 0);
   i122 = HEAP32[i122 >> 2] | 0;
   i121 = __ZN6cashew3RefixEj(i119, 2) | 0;
   HEAP32[i85 >> 2] = HEAP32[i121 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i85 >> 2];
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i120, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i122, i123) | 0);
   __ZN4wasm5Block8finalizeEv(i1);
   break;
  }
  if ((i58 | 0) != (HEAP32[14841] | 0)) {
   HEAP32[i56 >> 2] = 0;
   HEAP32[i56 + 4 >> 2] = 0;
   HEAP32[i56 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i56, 30332, 20);
   HEAP32[i57 >> 2] = HEAP32[i119 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i57 >> 2];
   __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew3RefE(i56, i123);
  }
  HEAP32[i118 >> 2] = 0;
  i2 = i121 + 32 | 0;
  i4 = HEAP32[i2 >> 2] | 0;
  if (!(HEAP32[i4 >> 2] | 0)) {
   i2 = HEAP32[i121 + 56 >> 2] | 0;
   HEAP32[i73 >> 2] = 0;
   HEAP32[i73 + 4 >> 2] = 0;
   HEAP32[i73 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i73, 47699, 6);
   i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i2, i73) | 0;
   HEAP32[i118 >> 2] = i2;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i73);
  } else {
   HEAP32[i72 >> 2] = HEAP32[i4 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i72 >> 2];
   i115 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__5clENS1_7IStringE(i123) | 0;
   HEAP32[i118 >> 2] = i115;
   HEAP32[HEAP32[i2 >> 2] >> 2] = 0;
   i2 = i115;
  }
  i16 = i2;
  i15 = i121 + 40 | 0;
  i2 = HEAP32[i15 >> 2] | 0;
  i4 = i2 + 4 | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  if ((i5 | 0) == (HEAP32[i2 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i2, i118); else {
   HEAP32[i5 >> 2] = i16;
   HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 4;
  }
  i14 = i122 + 4 | 0;
  i11 = __ZN10MixedArena5allocIN4wasm6SwitchEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
  i118 = HEAP32[i121 + 4 >> 2] | 0;
  i8 = __ZN6cashew3RefixEj(i119, 1) | 0;
  HEAP32[i93 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i123 >> 2] = HEAP32[i93 >> 2];
  i118 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i118, i123) | 0;
  i8 = i11 + 28 | 0;
  HEAP32[i8 >> 2] = i118;
  if ((HEAP32[i118 + 4 >> 2] | 0) != 1) ___assert_fail(30202, 16311, 1614, 57137);
  i5 = __ZN6cashew3RefixEj(i119, 2) | 0;
  i5 = HEAP32[i5 >> 2] | 0;
  HEAP32[i120 >> 2] = i5;
  i7 = 0;
  i6 = 0;
  i4 = 0;
  L498 : while (1) {
   if (i7 >>> 0 >= (__ZN6cashew5Value4sizeEv(i5) | 0) >>> 0) {
    i113 = i6;
    break;
   }
   i119 = __ZN6cashew3RefixEj(i120, i7) | 0;
   HEAP32[i117 >> 2] = HEAP32[i119 >> 2];
   i119 = __ZN6cashew3RefixEj(i117, 0) | 0;
   i119 = HEAP32[i119 >> 2] | 0;
   HEAP32[i112 >> 2] = i119;
   do if ((HEAP32[i119 >> 2] | 0) == 3) i2 = i6; else {
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i112, 0) | 0, 59348) | 0) ? !(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i112, 0) | 0, 59396) | 0) : 0) {
     i116 = 369;
     break L498;
    }
    HEAP32[i100 >> 2] = HEAP32[i112 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i100 >> 2];
    __ZN4wasm15Asm2WasmBuilder10getLiteralEN6cashew3RefE(i101, i122, i123);
    i2 = __ZNK4wasm7Literal6geti32Ev(i101) | 0;
    if (!i4) {
     i4 = 1;
     break;
    }
    i2 = (i2 | 0) < (i6 | 0) ? i2 : i6;
    i4 = 1;
   } while (0);
   i5 = HEAP32[i120 >> 2] | 0;
   i7 = i7 + 1 | 0;
   i6 = i2;
  }
  if ((i116 | 0) == 369) ___assert_fail(30229, 16311, 1623, 57137);
  i5 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
  HEAP32[i5 + 8 >> 2] = 1;
  HEAP32[i5 + 12 >> 2] = HEAP32[i8 >> 2];
  i13 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i122 + 8 >> 2] | 0) | 0;
  HEAP32[i13 + 8 >> 2] = 1;
  HEAP32[i13 + 16 >> 2] = i113;
  HEAP32[i13 + 4 >> 2] = 1;
  HEAP32[i5 + 16 >> 2] = i13;
  HEAP32[i5 + 4 >> 2] = 1;
  HEAP32[i8 >> 2] = i5;
  i5 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i5 + 12 | 0, i11);
  __ZN4wasm5Block8finalizeEv(i5);
  i8 = i121 + 44 | 0;
  i13 = i11 + 24 | 0;
  i10 = i121 + 56 | 0;
  i12 = i11 + 8 | 0;
  i11 = i11 + 16 | 0;
  i7 = 0;
  while (1) {
   if (i7 >>> 0 >= (__ZN6cashew5Value4sizeEv(HEAP32[i120 >> 2] | 0) | 0) >>> 0) {
    i116 = 374;
    break;
   }
   i121 = __ZN6cashew3RefixEj(i120, i7) | 0;
   HEAP32[i117 >> 2] = HEAP32[i121 >> 2];
   i121 = __ZN6cashew3RefixEj(i117, 0) | 0;
   HEAP32[i112 >> 2] = HEAP32[i121 >> 2];
   i121 = __ZN6cashew3RefixEj(i117, 1) | 0;
   i6 = HEAP32[i8 >> 2] | 0;
   HEAP32[i110 >> 2] = HEAP32[i121 >> 2];
   HEAP32[i123 >> 2] = HEAP32[i110 >> 2];
   i6 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEEclES5_j(i6, i123, 0) | 0;
   if ((HEAP32[HEAP32[i112 >> 2] >> 2] | 0) == 3) {
    i2 = HEAP32[i10 >> 2] | 0;
    HEAP32[i111 >> 2] = 0;
    HEAP32[i111 + 4 >> 2] = 0;
    HEAP32[i111 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i111, 30281, 14);
    i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i2, i111) | 0;
    HEAP32[i13 >> 2] = i2;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i111);
   } else {
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i112, 0) | 0, 59348) | 0) ? !(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i112, 0) | 0, 59396) | 0) : 0) {
     i116 = 379;
     break;
    }
    HEAP32[i107 >> 2] = HEAP32[i112 >> 2];
    HEAP32[i123 >> 2] = HEAP32[i107 >> 2];
    __ZN4wasm15Asm2WasmBuilder10getLiteralEN6cashew3RefE(i108, i122, i123);
    i2 = __ZNK4wasm7Literal6geti32Ev(i108) | 0;
    if ((i2 | 0) < (i113 | 0)) {
     i116 = 381;
     break;
    }
    i4 = i2 - i113 | 0;
    if ((i4 | 0) <= -1) {
     i116 = 383;
     break;
    }
    i2 = HEAP32[i10 >> 2] | 0;
    HEAP32[i109 >> 2] = 0;
    HEAP32[i109 + 4 >> 2] = 0;
    HEAP32[i109 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i109, 30320, 11);
    i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i2, i109) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i109);
    if ((HEAP32[i11 >> 2] | 0) >>> 0 <= i4 >>> 0) __ZN11ArenaVectorIN4wasm4NameEE6resizeEj(i12, i4 + 1 | 0);
    i121 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i12, i4) | 0;
    HEAP32[i121 >> 2] = i2;
   }
   i121 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
   HEAP32[i5 + 8 >> 2] = i2;
   i119 = i121 + 12 | 0;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i119, i5);
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i119, i6);
   __ZN4wasm5Block8finalizeEv(i121);
   i7 = i7 + 1 | 0;
   i5 = i121;
  }
  if ((i116 | 0) == 374) {
   if (!(HEAP32[i13 >> 2] | 0)) {
    i1 = HEAP32[i10 >> 2] | 0;
    HEAP32[i114 >> 2] = 0;
    HEAP32[i114 + 4 >> 2] = 0;
    HEAP32[i114 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i114, 30281, 14);
    i1 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i1, i114) | 0;
    HEAP32[i13 >> 2] = i1;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i114);
    i1 = 0;
   } else i1 = 0;
   while (1) {
    if (i1 >>> 0 >= (HEAP32[i11 >> 2] | 0) >>> 0) break;
    i123 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i12, i1) | 0;
    if (!(HEAP32[i123 >> 2] | 0)) {
     i123 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i12, i1) | 0;
     HEAP32[i123 >> 2] = HEAP32[i13 >> 2];
    }
    i1 = i1 + 1 | 0;
   }
   HEAP32[i5 + 8 >> 2] = HEAP32[i13 >> 2];
   i1 = (HEAP32[i15 >> 2] | 0) + 4 | 0;
   i4 = HEAP32[i1 >> 2] | 0;
   i2 = i4 + -4 | 0;
   while (1) {
    if ((i4 | 0) == (i2 | 0)) break;
    i123 = i4 + -4 | 0;
    HEAP32[i1 >> 2] = i123;
    i4 = i123;
   }
   i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = i16;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i1 + 12 | 0, i5);
   break;
  } else if ((i116 | 0) == 379) ___assert_fail(30229, 16311, 1653, 57137); else if ((i116 | 0) == 381) ___assert_fail(30296, 16311, 1655, 57137); else if ((i116 | 0) == 383) ___assert_fail(30309, 16311, 1657, 57137);
 } else {
  i1 = HEAP32[i121 + 4 >> 2] | 0;
  i122 = __ZN6cashew3RefixEj(i119, 1) | 0;
  HEAP32[i2 >> 2] = HEAP32[i122 >> 2];
  HEAP32[i123 >> 2] = HEAP32[i2 >> 2];
  i1 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i123) | 0;
 } while (0);
 i4 = HEAP32[14805] | 0;
 i2 = i4 + -4 | 0;
 while (1) {
  if ((i4 | 0) == (i2 | 0)) break;
  i123 = i4 + -4 | 0;
  HEAP32[14805] = i123;
  i4 = i123;
 }
 STACKTOP = i124;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_119parse_operator_nameINS0_2DbEEEPKcS4_S4_RT_(i53, i1, i52) {
 i53 = i53 | 0;
 i1 = i1 | 0;
 i52 = i52 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i54 = 0;
 i54 = STACKTOP;
 STACKTOP = STACKTOP + 1136 | 0;
 i51 = i54 + 1104 | 0;
 i5 = i54 + 1080 | 0;
 i6 = i54 + 1056 | 0;
 i17 = i54 + 1032 | 0;
 i28 = i54 + 1008 | 0;
 i39 = i54 + 984 | 0;
 i46 = i54 + 960 | 0;
 i47 = i54 + 936 | 0;
 i48 = i54 + 912 | 0;
 i49 = i54 + 888 | 0;
 i50 = i54 + 864 | 0;
 i7 = i54 + 840 | 0;
 i8 = i54 + 816 | 0;
 i9 = i54 + 792 | 0;
 i10 = i54 + 768 | 0;
 i11 = i54 + 744 | 0;
 i12 = i54 + 720 | 0;
 i13 = i54 + 696 | 0;
 i14 = i54 + 672 | 0;
 i15 = i54 + 648 | 0;
 i16 = i54 + 624 | 0;
 i18 = i54 + 600 | 0;
 i19 = i54 + 576 | 0;
 i20 = i54 + 552 | 0;
 i21 = i54 + 528 | 0;
 i22 = i54 + 504 | 0;
 i23 = i54 + 480 | 0;
 i24 = i54 + 456 | 0;
 i25 = i54 + 432 | 0;
 i26 = i54 + 408 | 0;
 i27 = i54 + 384 | 0;
 i29 = i54 + 360 | 0;
 i30 = i54 + 336 | 0;
 i31 = i54 + 312 | 0;
 i32 = i54 + 288 | 0;
 i33 = i54 + 264 | 0;
 i34 = i54 + 240 | 0;
 i35 = i54 + 216 | 0;
 i36 = i54 + 192 | 0;
 i37 = i54 + 168 | 0;
 i38 = i54 + 144 | 0;
 i40 = i54 + 120 | 0;
 i41 = i54 + 96 | 0;
 i42 = i54 + 72 | 0;
 i43 = i54 + 48 | 0;
 i44 = i54 + 24 | 0;
 i45 = i54;
 L1 : do if ((i1 - i53 | 0) > 1) do switch (HEAP8[i53 >> 0] | 0) {
 case 97:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 97:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i5, 57095);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i5);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i5);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i5);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 110:
  case 100:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i6, 57106);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i6);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i6);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 78:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i17, 57116);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i17);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i17);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i17);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 83:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i28, 57127);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i28);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i28);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i28);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 99:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 108:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i39, 57137);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i39);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i39);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i39);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 109:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i46, 57148);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i46);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i46);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i46);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 111:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i47, 57158);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i47);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i47);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i47);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 118:
   {
    i50 = i52 + 63 | 0;
    i49 = HEAP8[i50 >> 0] | 0;
    HEAP8[i50 >> 0] = 0;
    i51 = i53 + 2 | 0;
    i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i51, i1, i52) | 0;
    HEAP8[i50 >> 0] = i49;
    if ((i1 | 0) == (i51 | 0)) {
     i1 = i53;
     break L1;
    }
    i2 = HEAP32[i52 + 4 >> 2] | 0;
    if ((HEAP32[i52 >> 2] | 0) == (i2 | 0)) {
     i1 = i53;
     break L1;
    }
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 57168) | 0;
    HEAP8[i52 + 60 >> 0] = 1;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 100:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 97:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj18EEERAT__Kc(i48, 57178);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i48);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i48);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i48);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 101:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i49, 57196);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i49);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i48 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i48, i49);
     HEAP32[i50 >> 2] = i48 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i49);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 108:
   {
    HEAP32[i50 >> 2] = 0;
    i1 = _malloc(16) | 0;
    HEAP32[i50 >> 2] = i1;
    HEAP32[i50 + 8 >> 2] = -2147483632;
    HEAP32[i50 + 4 >> 2] = 15;
    i2 = i1;
    i3 = 57206;
    i4 = i2 + 15 | 0;
    do {
     HEAP8[i2 >> 0] = HEAP8[i3 >> 0] | 0;
     i2 = i2 + 1 | 0;
     i3 = i3 + 1 | 0;
    } while ((i2 | 0) < (i4 | 0));
    HEAP8[i1 + 15 >> 0] = 0;
    i1 = i50 + 12 | 0;
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i49 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i49;
    if (i2 >>> 0 < i49 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i50);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i49 = i51 + 8 | 0;
     i48 = HEAP32[i49 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i48, i50);
     HEAP32[i49 >> 2] = i48 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i50);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 118:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i7, 57222);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i7);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i7);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i7);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 86:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i8, 57232);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i8);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i8);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i8);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 101:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 111:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i9, 57243);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i9);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i9);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i9);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 79:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i10, 57253);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i10);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i10);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i10);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 113:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i11, 57264);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i11);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i11);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i11);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 103:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 101:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i12, 57275);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i12);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i12);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i12);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 116:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i13, 57286);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i13);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i13);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i13);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 105:
  {
   if ((HEAP8[i53 + 1 >> 0] | 0) != 120) {
    i1 = i53;
    break L1;
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i14, 57296);
   i1 = i52 + 4 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   i50 = HEAP32[i52 + 8 >> 2] | 0;
   i3 = i50;
   if (i2 >>> 0 < i50 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i14);
    HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
   } else {
    i1 = HEAP32[i52 >> 2] | 0;
    i4 = (i2 - i1 | 0) / 24 | 0;
    i2 = i4 + 1 | 0;
    if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
    i1 = (i3 - i1 | 0) / 24 | 0;
    if (i1 >>> 0 < 89478485) {
     i1 = i1 << 1;
     i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
    } else i1 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
    i50 = i51 + 8 | 0;
    i49 = HEAP32[i50 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i14);
    HEAP32[i50 >> 2] = i49 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i14);
   i1 = i53 + 2 | 0;
   break L1;
  }
 case 108:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 101:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i15, 57307);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i15);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i15);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 105:
   {
    i51 = i53 + 2 | 0;
    i1 = __ZN10__cxxabiv112_GLOBAL__N_117parse_source_nameINS0_2DbEEEPKcS4_S4_RT_(i51, i1, i52) | 0;
    if ((i1 | 0) == (i51 | 0)) {
     i1 = i53;
     break L1;
    }
    i2 = HEAP32[i52 + 4 >> 2] | 0;
    if ((HEAP32[i52 >> 2] | 0) == (i2 | 0)) {
     i1 = i53;
     break L1;
    }
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 57318) | 0;
    break L1;
   }
  case 115:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i16, 57330);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i16);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i16);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i16);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 83:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj12EEERAT__Kc(i18, 57341);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i18);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i18);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i18);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 116:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i19, 57353);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i19);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i19);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i19);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 109:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 105:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i20, 57363);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i20);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i20);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i20);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 73:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i21, 57373);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i21);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i21);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i21);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 108:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i22, 57196);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i22);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i22);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i22);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 76:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i23, 57384);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i23);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i23);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i23);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 109:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i24, 57395);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i24);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i24);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i24);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 110:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 97:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj15EEERAT__Kc(i25, 57406);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i25);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i25);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i25);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 101:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i26, 57421);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i26);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i26);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i26);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 103:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i27, 57363);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i27);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i27);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i27);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 116:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i29, 57432);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i29);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i29);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i29);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 119:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj13EEERAT__Kc(i30, 57442);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i30);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i30);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i30);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 111:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 111:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i31, 57455);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i31);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i31);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i31);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 114:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i32, 57466);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i32);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i32);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i32);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 82:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i33, 57476);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i33);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i33);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i33);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 112:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 109:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj12EEERAT__Kc(i34, 57487);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i34);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i34);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i34);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 108:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i35, 57499);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i35);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i35);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i35);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 76:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i36, 57509);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i36);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i36);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i36);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 112:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i37, 57520);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i37);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i37);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i37);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 115:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i38, 57499);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i38);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i38);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i38);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 116:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i40, 57531);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i40);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i40);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i40);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 113:
  {
   if ((HEAP8[i53 + 1 >> 0] | 0) != 117) {
    i1 = i53;
    break L1;
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i41, 57542);
   i1 = i52 + 4 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   i50 = HEAP32[i52 + 8 >> 2] | 0;
   i3 = i50;
   if (i2 >>> 0 < i50 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i41);
    HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
   } else {
    i1 = HEAP32[i52 >> 2] | 0;
    i4 = (i2 - i1 | 0) / 24 | 0;
    i2 = i4 + 1 | 0;
    if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
    i1 = (i3 - i1 | 0) / 24 | 0;
    if (i1 >>> 0 < 89478485) {
     i1 = i1 << 1;
     i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
    } else i1 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
    i50 = i51 + 8 | 0;
    i49 = HEAP32[i50 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i41);
    HEAP32[i50 >> 2] = i49 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i41);
   i1 = i53 + 2 | 0;
   break L1;
  }
 case 114:
  switch (HEAP8[i53 + 1 >> 0] | 0) {
  case 109:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i42, 57552);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i42);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i42);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i42);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 77:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i43, 57562);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i43);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i43);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i43);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 115:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i44, 57573);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i44);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i44);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i44);
    i1 = i53 + 2 | 0;
    break L1;
   }
  case 83:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj12EEERAT__Kc(i45, 57584);
    i1 = i52 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i50 = HEAP32[i52 + 8 >> 2] | 0;
    i3 = i50;
    if (i2 >>> 0 < i50 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i45);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i52 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i52);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i51, i1, i4, i52 + 12 | 0);
     i50 = i51 + 8 | 0;
     i49 = HEAP32[i50 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i49, i45);
     HEAP32[i50 >> 2] = i49 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i52, i51);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i51);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i45);
    i1 = i53 + 2 | 0;
    break L1;
   }
  default:
   {
    i1 = i53;
    break L1;
   }
  }
 case 118:
  {
   if (((HEAP8[i53 + 1 >> 0] | 0) + -48 | 0) >>> 0 >= 10) {
    i1 = i53;
    break L1;
   }
   i51 = i53 + 2 | 0;
   i1 = __ZN10__cxxabiv112_GLOBAL__N_117parse_source_nameINS0_2DbEEEPKcS4_S4_RT_(i51, i1, i52) | 0;
   if ((i1 | 0) == (i51 | 0)) {
    i1 = i53;
    break L1;
   }
   i2 = HEAP32[i52 + 4 >> 2] | 0;
   if ((HEAP32[i52 >> 2] | 0) == (i2 | 0)) {
    i1 = i53;
    break L1;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 57168) | 0;
   break L1;
  }
 default:
  {
   i1 = i53;
   break L1;
  }
 } while (0); else i1 = i53; while (0);
 STACKTOP = i54;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_118parse_builtin_typeINS0_2DbEEEPKcS4_S4_RT_(i1, i3, i36) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i36 = i36 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i37 = 0;
 i37 = STACKTOP;
 STACKTOP = STACKTOP + 720 | 0;
 i35 = i37 + 696 | 0;
 i6 = i37 + 672 | 0;
 i32 = i37 + 648 | 0;
 i15 = i37 + 624 | 0;
 i17 = i37 + 600 | 0;
 i18 = i37 + 576 | 0;
 i19 = i37 + 552 | 0;
 i20 = i37 + 528 | 0;
 i21 = i37 + 504 | 0;
 i22 = i37 + 480 | 0;
 i23 = i37 + 456 | 0;
 i7 = i37 + 432 | 0;
 i8 = i37 + 408 | 0;
 i9 = i37 + 384 | 0;
 i34 = i37 + 360 | 0;
 i10 = i37 + 336 | 0;
 i11 = i37 + 312 | 0;
 i12 = i37 + 288 | 0;
 i33 = i37 + 264 | 0;
 i13 = i37 + 240 | 0;
 i14 = i37 + 216 | 0;
 i16 = i37 + 192 | 0;
 i24 = i37 + 168 | 0;
 i25 = i37 + 144 | 0;
 i26 = i37 + 120 | 0;
 i27 = i37 + 96 | 0;
 i28 = i37 + 72 | 0;
 i29 = i37 + 48 | 0;
 i30 = i37 + 24 | 0;
 i31 = i37;
 L1 : do if ((i1 | 0) != (i3 | 0)) do switch (HEAP8[i1 >> 0] | 0) {
 case 118:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj5EEERAT__Kc(i6, 56641);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i6);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i6);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 119:
  {
   HEAP32[i32 >> 2] = 0;
   HEAP32[i32 + 4 >> 2] = 0;
   HEAP32[i32 + 8 >> 2] = 0;
   HEAP8[i32 + 11 >> 0] = 7;
   HEAP8[i32 >> 0] = HEAP8[56646] | 0;
   HEAP8[i32 + 1 >> 0] = HEAP8[56647] | 0;
   HEAP8[i32 + 2 >> 0] = HEAP8[56648] | 0;
   HEAP8[i32 + 3 >> 0] = HEAP8[56649] | 0;
   HEAP8[i32 + 4 >> 0] = HEAP8[56650] | 0;
   HEAP8[i32 + 5 >> 0] = HEAP8[56651] | 0;
   HEAP8[i32 + 6 >> 0] = HEAP8[56652] | 0;
   HEAP8[i32 + 7 >> 0] = 0;
   i2 = i32 + 12 | 0;
   HEAP32[i2 >> 2] = 0;
   HEAP32[i2 + 4 >> 2] = 0;
   HEAP32[i2 + 8 >> 2] = 0;
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i32);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i32);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i32);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 98:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj5EEERAT__Kc(i15, 56654);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i15);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i15);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 99:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj5EEERAT__Kc(i17, 56659);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i17);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i17);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i17);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 97:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj12EEERAT__Kc(i18, 56664);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i18);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i18);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i18);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 104:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj14EEERAT__Kc(i19, 56676);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i19);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i19);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i19);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 115:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj6EEERAT__Kc(i20, 56690);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i20);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i20);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i20);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 116:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj15EEERAT__Kc(i21, 56696);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i21);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i21);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i21);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 105:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj4EEERAT__Kc(i22, 56711);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i22);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i22);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i22);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 106:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj13EEERAT__Kc(i23, 56715);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i23);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i23);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i23);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 108:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj5EEERAT__Kc(i7, 56728);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i7);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i7);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i7);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 109:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj14EEERAT__Kc(i8, 56733);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i8);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i8);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i8);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 120:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i9, 56747);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i9);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i9);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i9);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 121:
  {
   HEAP32[i34 >> 2] = 0;
   i2 = _malloc(32) | 0;
   HEAP32[i34 >> 2] = i2;
   HEAP32[i34 + 8 >> 2] = -2147483616;
   HEAP32[i34 + 4 >> 2] = 18;
   i3 = i2;
   i4 = 56757;
   i5 = i3 + 18 | 0;
   do {
    HEAP8[i3 >> 0] = HEAP8[i4 >> 0] | 0;
    i3 = i3 + 1 | 0;
    i4 = i4 + 1 | 0;
   } while ((i3 | 0) < (i5 | 0));
   HEAP8[i2 + 18 >> 0] = 0;
   i2 = i34 + 12 | 0;
   HEAP32[i2 >> 2] = 0;
   HEAP32[i2 + 4 >> 2] = 0;
   HEAP32[i2 + 8 >> 2] = 0;
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i33 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i33;
   if (i3 >>> 0 < i33 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i34);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i33 = i35 + 8 | 0;
    i32 = HEAP32[i33 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i32, i34);
    HEAP32[i33 >> 2] = i32 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i34);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 110:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj9EEERAT__Kc(i10, 56776);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i10);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i10);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i10);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 111:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj18EEERAT__Kc(i11, 56785);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i11);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i11);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i11);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 102:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj6EEERAT__Kc(i12, 56803);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i12);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i12);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i12);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 100:
  {
   HEAP32[i33 >> 2] = 0;
   HEAP32[i33 + 4 >> 2] = 0;
   HEAP32[i33 + 8 >> 2] = 0;
   HEAP8[i33 + 11 >> 0] = 6;
   HEAP8[i33 >> 0] = HEAP8[56809] | 0;
   HEAP8[i33 + 1 >> 0] = HEAP8[56810] | 0;
   HEAP8[i33 + 2 >> 0] = HEAP8[56811] | 0;
   HEAP8[i33 + 3 >> 0] = HEAP8[56812] | 0;
   HEAP8[i33 + 4 >> 0] = HEAP8[56813] | 0;
   HEAP8[i33 + 5 >> 0] = HEAP8[56814] | 0;
   HEAP8[i33 + 6 >> 0] = 0;
   i2 = i33 + 12 | 0;
   HEAP32[i2 >> 2] = 0;
   HEAP32[i2 + 4 >> 2] = 0;
   HEAP32[i2 + 8 >> 2] = 0;
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i33);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i32 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i32, i33);
    HEAP32[i34 >> 2] = i32 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i33);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 101:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj12EEERAT__Kc(i13, 56816);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i13);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i13);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i13);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 103:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i14, 56828);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i14);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i14);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i14);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 122:
  {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj4EEERAT__Kc(i16, 56839);
   i2 = i36 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i34 = HEAP32[i36 + 8 >> 2] | 0;
   i4 = i34;
   if (i3 >>> 0 < i34 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i16);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i36 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
    i34 = i35 + 8 | 0;
    i33 = HEAP32[i34 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i16);
    HEAP32[i34 >> 2] = i33 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i16);
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 117:
  {
   i35 = i1 + 1 | 0;
   i36 = __ZN10__cxxabiv112_GLOBAL__N_117parse_source_nameINS0_2DbEEEPKcS4_S4_RT_(i35, i3, i36) | 0;
   i1 = (i36 | 0) == (i35 | 0) ? i1 : i36;
   break L1;
  }
 case 68:
  {
   i2 = i1 + 1 | 0;
   if ((i2 | 0) == (i3 | 0)) break L1;
   switch (HEAP8[i2 >> 0] | 0) {
   case 100:
    {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i24, 56876);
     i2 = i36 + 4 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i34 = HEAP32[i36 + 8 >> 2] | 0;
     i4 = i34;
     if (i3 >>> 0 < i34 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i24);
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
     } else {
      i2 = HEAP32[i36 >> 2] | 0;
      i5 = (i3 - i2 | 0) / 24 | 0;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
      i2 = (i4 - i2 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
      i34 = i35 + 8 | 0;
      i33 = HEAP32[i34 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i24);
      HEAP32[i34 >> 2] = i33 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i24);
     i1 = i1 + 2 | 0;
     break L1;
    }
   case 101:
    {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i25, 56886);
     i2 = i36 + 4 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i34 = HEAP32[i36 + 8 >> 2] | 0;
     i4 = i34;
     if (i3 >>> 0 < i34 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i25);
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
     } else {
      i2 = HEAP32[i36 >> 2] | 0;
      i5 = (i3 - i2 | 0) / 24 | 0;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
      i2 = (i4 - i2 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
      i34 = i35 + 8 | 0;
      i33 = HEAP32[i34 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i25);
      HEAP32[i34 >> 2] = i33 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i25);
     i1 = i1 + 2 | 0;
     break L1;
    }
   case 102:
    {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i26, 56897);
     i2 = i36 + 4 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i34 = HEAP32[i36 + 8 >> 2] | 0;
     i4 = i34;
     if (i3 >>> 0 < i34 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i26);
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
     } else {
      i2 = HEAP32[i36 >> 2] | 0;
      i5 = (i3 - i2 | 0) / 24 | 0;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
      i2 = (i4 - i2 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
      i34 = i35 + 8 | 0;
      i33 = HEAP32[i34 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i26);
      HEAP32[i34 >> 2] = i33 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i26);
     i1 = i1 + 2 | 0;
     break L1;
    }
   case 104:
    {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i27, 56907);
     i2 = i36 + 4 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i34 = HEAP32[i36 + 8 >> 2] | 0;
     i4 = i34;
     if (i3 >>> 0 < i34 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i27);
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
     } else {
      i2 = HEAP32[i36 >> 2] | 0;
      i5 = (i3 - i2 | 0) / 24 | 0;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
      i2 = (i4 - i2 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
      i34 = i35 + 8 | 0;
      i33 = HEAP32[i34 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i27);
      HEAP32[i34 >> 2] = i33 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i27);
     i1 = i1 + 2 | 0;
     break L1;
    }
   case 105:
    {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj9EEERAT__Kc(i28, 56917);
     i2 = i36 + 4 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i34 = HEAP32[i36 + 8 >> 2] | 0;
     i4 = i34;
     if (i3 >>> 0 < i34 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i28);
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
     } else {
      i2 = HEAP32[i36 >> 2] | 0;
      i5 = (i3 - i2 | 0) / 24 | 0;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
      i2 = (i4 - i2 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
      i34 = i35 + 8 | 0;
      i33 = HEAP32[i34 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i28);
      HEAP32[i34 >> 2] = i33 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i28);
     i1 = i1 + 2 | 0;
     break L1;
    }
   case 115:
    {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj9EEERAT__Kc(i29, 56926);
     i2 = i36 + 4 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i34 = HEAP32[i36 + 8 >> 2] | 0;
     i4 = i34;
     if (i3 >>> 0 < i34 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i29);
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
     } else {
      i2 = HEAP32[i36 >> 2] | 0;
      i5 = (i3 - i2 | 0) / 24 | 0;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
      i2 = (i4 - i2 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
      i34 = i35 + 8 | 0;
      i33 = HEAP32[i34 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i29);
      HEAP32[i34 >> 2] = i33 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i29);
     i1 = i1 + 2 | 0;
     break L1;
    }
   case 97:
    {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj5EEERAT__Kc(i30, 56935);
     i2 = i36 + 4 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i34 = HEAP32[i36 + 8 >> 2] | 0;
     i4 = i34;
     if (i3 >>> 0 < i34 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i30);
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
     } else {
      i2 = HEAP32[i36 >> 2] | 0;
      i5 = (i3 - i2 | 0) / 24 | 0;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
      i2 = (i4 - i2 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
      i34 = i35 + 8 | 0;
      i33 = HEAP32[i34 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i30);
      HEAP32[i34 >> 2] = i33 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i30);
     i1 = i1 + 2 | 0;
     break L1;
    }
   case 110:
    {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj15EEERAT__Kc(i31, 56940);
     i2 = i36 + 4 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i34 = HEAP32[i36 + 8 >> 2] | 0;
     i4 = i34;
     if (i3 >>> 0 < i34 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i31);
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
     } else {
      i2 = HEAP32[i36 >> 2] | 0;
      i5 = (i3 - i2 | 0) / 24 | 0;
      i3 = i5 + 1 | 0;
      if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i36);
      i2 = (i4 - i2 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i35, i2, i5, i36 + 12 | 0);
      i34 = i35 + 8 | 0;
      i33 = HEAP32[i34 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i31);
      HEAP32[i34 >> 2] = i33 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i36, i35);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i35);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i31);
     i1 = i1 + 2 | 0;
     break L1;
    }
   default:
    break L1;
   }
  }
 default:
  break L1;
 } while (0); while (0);
 STACKTOP = i37;
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i67, i66) {
 i67 = i67 | 0;
 i66 = i66 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i52 = 0, i53 = 0, i54 = 0, i55 = 0, i56 = 0, i57 = 0, i58 = 0, i59 = 0, i60 = 0, i61 = 0, i62 = 0, i63 = 0, i64 = 0, i65 = 0, i68 = 0, i69 = 0, i70 = 0;
 i68 = STACKTOP;
 STACKTOP = STACKTOP + 768 | 0;
 i70 = i68 + 744 | 0;
 i49 = i68 + 732 | 0;
 i32 = i68 + 720 | 0;
 i55 = i68 + 708 | 0;
 i43 = i68 + 696 | 0;
 i63 = i68 + 684 | 0;
 i46 = i68 + 672 | 0;
 i64 = i68 + 660 | 0;
 i47 = i68 + 648 | 0;
 i65 = i68 + 636 | 0;
 i48 = i68 + 624 | 0;
 i50 = i68 + 612 | 0;
 i33 = i68 + 600 | 0;
 i51 = i68 + 588 | 0;
 i34 = i68 + 576 | 0;
 i52 = i68 + 564 | 0;
 i35 = i68 + 552 | 0;
 i53 = i68 + 540 | 0;
 i36 = i68 + 528 | 0;
 i54 = i68 + 516 | 0;
 i37 = i68 + 504 | 0;
 i56 = i68 + 492 | 0;
 i38 = i68 + 480 | 0;
 i57 = i68 + 468 | 0;
 i39 = i68 + 456 | 0;
 i58 = i68 + 444 | 0;
 i40 = i68 + 432 | 0;
 i59 = i68 + 420 | 0;
 i41 = i68 + 408 | 0;
 i60 = i68 + 396 | 0;
 i42 = i68 + 384 | 0;
 i61 = i68 + 372 | 0;
 i44 = i68 + 360 | 0;
 i62 = i68 + 348 | 0;
 i45 = i68 + 336 | 0;
 i16 = i68 + 324 | 0;
 i1 = i68 + 312 | 0;
 i17 = i68 + 300 | 0;
 i2 = i68 + 288 | 0;
 i18 = i68 + 276 | 0;
 i4 = i68 + 264 | 0;
 i19 = i68 + 252 | 0;
 i5 = i68 + 240 | 0;
 i20 = i68 + 228 | 0;
 i6 = i68 + 216 | 0;
 i21 = i68 + 204 | 0;
 i7 = i68 + 192 | 0;
 i22 = i68 + 180 | 0;
 i8 = i68 + 168 | 0;
 i23 = i68 + 156 | 0;
 i9 = i68 + 144 | 0;
 i24 = i68 + 132 | 0;
 i10 = i68 + 120 | 0;
 i25 = i68 + 108 | 0;
 i11 = i68 + 96 | 0;
 i26 = i68 + 84 | 0;
 i12 = i68 + 72 | 0;
 i27 = i68 + 60 | 0;
 i13 = i68 + 48 | 0;
 i28 = i68 + 36 | 0;
 i14 = i68 + 24 | 0;
 i29 = i68 + 12 | 0;
 i15 = i68;
 i69 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i66, 0) | 0) | 0;
 i30 = _strchr(i69, 46) | 0;
 L1 : do if (!i30) do switch (HEAP8[i69 >> 0] | 0) {
 case 98:
  switch (HEAP8[i69 + 1 >> 0] | 0) {
  case 108:
   {
    i1 = __ZN4wasm22SExpressionWasmBuilder9makeBlockERNS_7ElementE(i67, i66) | 0;
    break L1;
   }
  case 114:
   {
    if ((HEAP8[i69 + 2 >> 0] | 0) == 95 ? (HEAP8[i69 + 3 >> 0] | 0) == 116 : 0) {
     i1 = __ZN4wasm22SExpressionWasmBuilder14makeBreakTableERNS_7ElementE(i67, i66) | 0;
     break L1;
    }
    i1 = __ZN4wasm22SExpressionWasmBuilder9makeBreakERNS_7ElementE(i67, i66) | 0;
    break L1;
   }
  default:
   {
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i1, i69) | 0;
    HEAP32[i16 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i16 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i16 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i16);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  }
 case 99:
  {
   switch (HEAP8[i69 + 1 >> 0] | 0) {
   case 97:
    {
     i31 = 178;
     break;
    }
   case 117:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder8makeHostERNS_7ElementENS_6HostOpE(i67, i66, 1) | 0;
     break L1;
    }
   default:
    {}
   }
   if ((i31 | 0) == 178) {
    if ((i69 | 0) == (HEAP32[14984] | 0)) {
     i1 = __ZN4wasm22SExpressionWasmBuilder8makeCallERNS_7ElementE(i67, i66) | 0;
     break L1;
    }
    if ((i69 | 0) == (HEAP32[14985] | 0)) {
     i1 = __ZN4wasm22SExpressionWasmBuilder14makeCallImportERNS_7ElementE(i67, i66) | 0;
     break L1;
    }
    if ((i69 | 0) == (HEAP32[14986] | 0)) {
     i1 = __ZN4wasm22SExpressionWasmBuilder16makeCallIndirectERNS_7ElementE(i67, i66) | 0;
     break L1;
    }
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i2 >> 2] = 0;
   HEAP32[i2 + 4 >> 2] = 0;
   HEAP32[i2 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i2, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i2, i69) | 0;
   HEAP32[i17 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i17 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i17 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i17);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 101:
  {
   if ((HEAP8[i69 + 1 >> 0] | 0) == 108) {
    i1 = __ZN4wasm22SExpressionWasmBuilder14makeThenOrElseERNS_7ElementE(i67, i66) | 0;
    break L1;
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i4 >> 2] = 0;
   HEAP32[i4 + 4 >> 2] = 0;
   HEAP32[i4 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i4, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i4, i69) | 0;
   HEAP32[i18 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i18 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i18 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i18);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 103:
  switch (HEAP8[i69 + 1 >> 0] | 0) {
  case 101:
   {
    i1 = __ZN4wasm22SExpressionWasmBuilder12makeGetLocalERNS_7ElementE(i67, i66) | 0;
    break L1;
   }
  case 114:
   {
    i1 = __ZN4wasm22SExpressionWasmBuilder8makeHostERNS_7ElementENS_6HostOpE(i67, i66, 2) | 0;
    break L1;
   }
  default:
   {
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i5 >> 2] = 0;
    HEAP32[i5 + 4 >> 2] = 0;
    HEAP32[i5 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i5, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i5, i69) | 0;
    HEAP32[i19 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i19 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i19 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i19);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  }
 case 104:
  {
   if ((HEAP8[i69 + 1 >> 0] | 0) == 97) {
    i1 = __ZN4wasm22SExpressionWasmBuilder8makeHostERNS_7ElementENS_6HostOpE(i67, i66, 3) | 0;
    break L1;
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i6 >> 2] = 0;
   HEAP32[i6 + 4 >> 2] = 0;
   HEAP32[i6 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i6, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i6, i69) | 0;
   HEAP32[i20 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i20 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i20 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i20);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 105:
  {
   if ((HEAP8[i69 + 1 >> 0] | 0) == 102) {
    i1 = __ZN4wasm22SExpressionWasmBuilder6makeIfERNS_7ElementE(i67, i66) | 0;
    break L1;
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i7 >> 2] = 0;
   HEAP32[i7 + 4 >> 2] = 0;
   HEAP32[i7 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i7, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i7, i69) | 0;
   HEAP32[i21 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i21 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i21 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i21);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 108:
  {
   if ((HEAP8[i69 + 1 >> 0] | 0) == 111) {
    i1 = __ZN4wasm22SExpressionWasmBuilder8makeLoopERNS_7ElementE(i67, i66) | 0;
    break L1;
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i8 >> 2] = 0;
   HEAP32[i8 + 4 >> 2] = 0;
   HEAP32[i8 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i8, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i8, i69) | 0;
   HEAP32[i22 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i22 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i22 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i22);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 110:
  {
   if ((HEAP8[i69 + 1 >> 0] | 0) == 111) {
    i1 = __ZN10MixedArena5allocIN4wasm3NopEEEPT_v(HEAP32[i67 + 4 >> 2] | 0) | 0;
    break L1;
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i9 >> 2] = 0;
   HEAP32[i9 + 4 >> 2] = 0;
   HEAP32[i9 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i9, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i9, i69) | 0;
   HEAP32[i23 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i23 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i23 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i23);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 112:
  {
   if ((HEAP8[i69 + 1 >> 0] | 0) == 97) {
    i1 = __ZN4wasm22SExpressionWasmBuilder8makeHostERNS_7ElementENS_6HostOpE(i67, i66, 0) | 0;
    break L1;
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i10 >> 2] = 0;
   HEAP32[i10 + 4 >> 2] = 0;
   HEAP32[i10 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i10, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i10, i69) | 0;
   HEAP32[i24 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i24 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i24 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i24);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 115:
  {
   L97 : do if ((HEAP8[i69 + 1 >> 0] | 0) == 101) switch (HEAP8[i69 + 2 >> 0] | 0) {
   case 116:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder12makeSetLocalERNS_7ElementE(i67, i66) | 0;
     break L1;
    }
   case 108:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeSelectERNS_7ElementE(i67, i66) | 0;
     break L1;
    }
   default:
    break L97;
   } while (0);
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i11 >> 2] = 0;
   HEAP32[i11 + 4 >> 2] = 0;
   HEAP32[i11 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i11, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i11, i69) | 0;
   HEAP32[i25 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i25 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i25 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i25);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 114:
  {
   if ((HEAP8[i69 + 1 >> 0] | 0) == 101) {
    i1 = __ZN4wasm22SExpressionWasmBuilder10makeReturnERNS_7ElementE(i67, i66) | 0;
    break L1;
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i12 >> 2] = 0;
   HEAP32[i12 + 4 >> 2] = 0;
   HEAP32[i12 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i12, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i12, i69) | 0;
   HEAP32[i26 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i26 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i26 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i26);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 116:
  {
   if ((HEAP8[i69 + 1 >> 0] | 0) == 104) {
    i1 = __ZN4wasm22SExpressionWasmBuilder14makeThenOrElseERNS_7ElementE(i67, i66) | 0;
    break L1;
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i13 >> 2] = 0;
   HEAP32[i13 + 4 >> 2] = 0;
   HEAP32[i13 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i13, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i13, i69) | 0;
   HEAP32[i27 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i27 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i27 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i27);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 case 117:
  {
   if ((HEAP8[i69 + 1 >> 0] | 0) == 110) {
    i1 = __ZN10MixedArena5allocIN4wasm11UnreachableEEEPT_v(HEAP32[i67 + 4 >> 2] | 0) | 0;
    break L1;
   }
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i14 >> 2] = 0;
   HEAP32[i14 + 4 >> 2] = 0;
   HEAP32[i14 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i14, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i14, i69) | 0;
   HEAP32[i28 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i28 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i28 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i28);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 default:
  {
   i3 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i15 >> 2] = 0;
   HEAP32[i15 + 4 >> 2] = 0;
   HEAP32[i15 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i15, 21946, 9);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i15, i69) | 0;
   HEAP32[i29 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i29 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i29 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i29);
   ___cxa_throw(i3 | 0, 64, 279);
  }
 } while (0); else {
  i3 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i67, i69, 0, 1) | 0;
  i1 = i70;
  i2 = i1 + 16 | 0;
  do {
   HEAP8[i1 >> 0] = 0;
   i1 = i1 + 1 | 0;
  } while ((i1 | 0) < (i2 | 0));
  _strncpy(i70, i30 + 1 | 0, 15) | 0;
  L132 : do switch (HEAP8[i70 >> 0] | 0) {
  case 97:
   switch (HEAP8[i70 + 1 >> 0] | 0) {
   case 98:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 8 : 9, i3) | 0;
     break L132;
    }
   case 100:
    {
     if ((i3 | 0) != 1) if ((i3 | 0) == 2) i1 = 25; else i1 = (i3 | 0) == 3 ? 50 : 63; else i1 = 0;
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, i1, i3) | 0;
     break L132;
    }
   case 110:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 1 ? 7 : 32, i3) | 0;
     break L132;
    }
   default:
    {
     i3 = ___cxa_allocate_exception(20) | 0;
     HEAP32[i32 >> 2] = 0;
     HEAP32[i32 + 4 >> 2] = 0;
     HEAP32[i32 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i32, 21946, 9);
     i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i32, i70) | 0;
     HEAP32[i49 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i49 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
     HEAP32[i49 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i1 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i49);
     ___cxa_throw(i3 | 0, 64, 279);
    }
   }
  case 99:
   {
    L153 : do switch (HEAP8[i70 + 1 >> 0] | 0) {
    case 101:
     {
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 10 : 11, i3) | 0;
      break L132;
     }
    case 108:
     {
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) != 1 & 1, i3) | 0;
      break L132;
     }
    case 111:
     {
      switch (HEAP8[i70 + 2 >> 0] | 0) {
      case 112:
       {
        i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 54 : 67, i3) | 0;
        break L132;
       }
      case 110:
       break;
      default:
       break L153;
      }
      switch (HEAP8[i70 + 3 >> 0] | 0) {
      case 118:
       break;
      case 115:
       {
        i1 = __ZN4wasm22SExpressionWasmBuilder9makeConstERNS_7ElementENS_8WasmTypeE(i67, i66, i3) | 0;
        break L132;
       }
      default:
       break L153;
      }
      switch (HEAP8[i70 + 8 >> 0] | 0) {
      case 115:
       {
        i1 = (i3 | 0) == 3;
        i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 11 >> 0] | 0) == 51 ? (i1 ? 35 : 36) : i1 ? 39 : 40, i3) | 0;
        break L132;
       }
      case 117:
       {
        i1 = (i3 | 0) == 3;
        i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 11 >> 0] | 0) == 51 ? (i1 ? 37 : 38) : i1 ? 41 : 42, i3) | 0;
        break L132;
       }
      default:
       break L153;
      }
     }
    case 116:
     {
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 1 ? 2 : 3, i3) | 0;
      break L132;
     }
    default:
     {}
    } while (0);
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i43 >> 2] = 0;
    HEAP32[i43 + 4 >> 2] = 0;
    HEAP32[i43 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i43, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i43, i70) | 0;
    HEAP32[i55 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i55 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i55 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i55);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 100:
   {
    switch (HEAP8[i70 + 1 >> 0] | 0) {
    case 105:
     {
      i31 = 30;
      break;
     }
    case 101:
     {
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, 44, i3) | 0;
      break L132;
     }
    default:
     {}
    }
    L175 : do if ((i31 | 0) == 30) switch (HEAP8[i70 + 3 >> 0] | 0) {
    case 95:
     {
      i1 = (i3 | 0) == 1;
      i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 4 >> 0] | 0) == 117 ? (i1 ? 4 : 29) : i1 ? 3 : 28, i3) | 0;
      break L132;
     }
    case 0:
     {
      i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 53 : 66, i3) | 0;
      break L132;
     }
    default:
     break L175;
    } while (0);
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i46 >> 2] = 0;
    HEAP32[i46 + 4 >> 2] = 0;
    HEAP32[i46 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i46, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i46, i70) | 0;
    HEAP32[i63 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i63 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i63 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i63);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 101:
   {
    switch (HEAP8[i70 + 1 >> 0] | 0) {
    case 113:
     {
      i31 = 39;
      break;
     }
    case 120:
     {
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 7 >> 0] | 0) == 117 ? 23 : 22, i3) | 0;
      break L132;
     }
    default:
     {}
    }
    L188 : do if ((i31 | 0) == 39) {
     switch (HEAP8[i70 + 2 >> 0] | 0) {
     case 0:
      break;
     case 122:
      {
       i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 1 ? 20 : 21, i3) | 0;
       break L132;
      }
     default:
      break L188;
     }
     if ((i3 | 0) != 1) if ((i3 | 0) == 2) i1 = 40; else i1 = (i3 | 0) == 3 ? 57 : 70; else i1 = 15;
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, i1, i3) | 0;
     break L132;
    } while (0);
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i47 >> 2] = 0;
    HEAP32[i47 + 4 >> 2] = 0;
    HEAP32[i47 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i47, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i47, i70) | 0;
    HEAP32[i64 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i64 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i64 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i64);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 102:
   {
    if ((HEAP8[i70 + 1 >> 0] | 0) == 108) {
     i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 12 : 13, i3) | 0;
     break L132;
    }
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i48 >> 2] = 0;
    HEAP32[i48 + 4 >> 2] = 0;
    HEAP32[i48 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i48, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i48, i70) | 0;
    HEAP32[i65 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i65 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i65 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i65);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 103:
   {
    L211 : do switch (HEAP8[i70 + 1 >> 0] | 0) {
    case 116:
     switch (HEAP8[i70 + 2 >> 0] | 0) {
     case 95:
      {
       i1 = (i3 | 0) == 1;
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 3 >> 0] | 0) == 117 ? (i1 ? 22 : 47) : i1 ? 21 : 46, i3) | 0;
       break L132;
      }
     case 0:
      {
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 61 : 74, i3) | 0;
       break L132;
      }
     default:
      break L211;
     }
    case 101:
     switch (HEAP8[i70 + 2 >> 0] | 0) {
     case 95:
      {
       i1 = (i3 | 0) == 1;
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 3 >> 0] | 0) == 117 ? (i1 ? 24 : 49) : i1 ? 23 : 48, i3) | 0;
       break L132;
      }
     case 0:
      {
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 62 : 75, i3) | 0;
       break L132;
      }
     default:
      break L211;
     }
    default:
     {}
    } while (0);
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i33 >> 2] = 0;
    HEAP32[i33 + 4 >> 2] = 0;
    HEAP32[i33 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i33, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i33, i70) | 0;
    HEAP32[i50 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i50 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i50 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i50);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 108:
   {
    L226 : do switch (HEAP8[i70 + 1 >> 0] | 0) {
    case 116:
     switch (HEAP8[i70 + 2 >> 0] | 0) {
     case 95:
      {
       i1 = (i3 | 0) == 1;
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 3 >> 0] | 0) == 117 ? (i1 ? 18 : 43) : i1 ? 17 : 42, i3) | 0;
       break L132;
      }
     case 0:
      {
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 59 : 72, i3) | 0;
       break L132;
      }
     default:
      break L226;
     }
    case 101:
     switch (HEAP8[i70 + 2 >> 0] | 0) {
     case 95:
      {
       i1 = (i3 | 0) == 1;
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 3 >> 0] | 0) == 117 ? (i1 ? 20 : 45) : i1 ? 19 : 44, i3) | 0;
       break L132;
      }
     case 0:
      {
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 60 : 73, i3) | 0;
       break L132;
      }
     default:
      break L226;
     }
    case 111:
     {
      i1 = __ZN4wasm22SExpressionWasmBuilder8makeLoadERNS_7ElementENS_8WasmTypeE(i67, i66, i3) | 0;
      break L132;
     }
    default:
     {}
    } while (0);
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i34 >> 2] = 0;
    HEAP32[i34 + 4 >> 2] = 0;
    HEAP32[i34 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i34, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i34, i70) | 0;
    HEAP32[i51 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i51 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i51 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i51);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 109:
   switch (HEAP8[i70 + 1 >> 0] | 0) {
   case 105:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 55 : 68, i3) | 0;
     break L132;
    }
   case 97:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 56 : 69, i3) | 0;
     break L132;
    }
   case 117:
    {
     if ((i3 | 0) != 1) if ((i3 | 0) == 2) i1 = 27; else i1 = (i3 | 0) == 3 ? 52 : 65; else i1 = 2;
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, i1, i3) | 0;
     break L132;
    }
   default:
    {
     i3 = ___cxa_allocate_exception(20) | 0;
     HEAP32[i35 >> 2] = 0;
     HEAP32[i35 + 4 >> 2] = 0;
     HEAP32[i35 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i35, 21946, 9);
     i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i35, i70) | 0;
     HEAP32[i52 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i52 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
     HEAP32[i52 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i1 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i52);
     ___cxa_throw(i3 | 0, 64, 279);
    }
   }
  case 110:
   {
    L256 : do if ((HEAP8[i70 + 1 >> 0] | 0) == 101) switch (HEAP8[i70 + 2 >> 0] | 0) {
    case 0:
     {
      if ((i3 | 0) != 1) if ((i3 | 0) == 2) i1 = 41; else i1 = (i3 | 0) == 3 ? 58 : 71; else i1 = 16;
      i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, i1, i3) | 0;
      break L132;
     }
    case 97:
     {
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 16 : 17, i3) | 0;
      break L132;
     }
    case 103:
     {
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 6 : 7, i3) | 0;
      break L132;
     }
    default:
     break L256;
    } while (0);
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i36 >> 2] = 0;
    HEAP32[i36 + 4 >> 2] = 0;
    HEAP32[i36 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i36, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i36, i70) | 0;
    HEAP32[i53 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i53 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i53 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i53);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 111:
   {
    if ((HEAP8[i70 + 1 >> 0] | 0) == 114) {
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 1 ? 8 : 33, i3) | 0;
     break L132;
    }
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i37 >> 2] = 0;
    HEAP32[i37 + 4 >> 2] = 0;
    HEAP32[i37 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i37, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i37, i70) | 0;
    HEAP32[i54 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i54 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i54 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i54);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 112:
   switch (HEAP8[i70 + 1 >> 0] | 0) {
   case 114:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, 43, i3) | 0;
     break L132;
    }
   case 111:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 1 ? 4 : 5, i3) | 0;
     break L132;
    }
   default:
    {
     i3 = ___cxa_allocate_exception(20) | 0;
     HEAP32[i38 >> 2] = 0;
     HEAP32[i38 + 4 >> 2] = 0;
     HEAP32[i38 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i38, 21946, 9);
     i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i38, i70) | 0;
     HEAP32[i56 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i56 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
     HEAP32[i56 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i1 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i56);
     ___cxa_throw(i3 | 0, 64, 279);
    }
   }
  case 114:
   {
    L289 : do switch (HEAP8[i70 + 1 >> 0] | 0) {
    case 101:
     switch (HEAP8[i70 + 2 >> 0] | 0) {
     case 109:
      {
       i1 = (i3 | 0) == 1;
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 4 >> 0] | 0) == 117 ? (i1 ? 6 : 31) : i1 ? 5 : 30, i3) | 0;
       break L132;
      }
     case 105:
      {
       i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 + -3 | 0) >>> 0 < 2 ? ((i3 | 0) == 3 ? 45 : 46) : (i3 | 0) == 1 ? 33 : 34, i3) | 0;
       break L132;
      }
     default:
      break L289;
     }
    case 111:
     {
      if ((HEAP8[i70 + 2 >> 0] | 0) == 116) {
       i1 = (i3 | 0) == 1;
       i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 3 >> 0] | 0) == 108 ? (i1 ? 13 : 38) : i1 ? 14 : 39, i3) | 0;
       break L132;
      }
      break;
     }
    default:
     {}
    } while (0);
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i39 >> 2] = 0;
    HEAP32[i39 + 4 >> 2] = 0;
    HEAP32[i39 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i39, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i39, i70) | 0;
    HEAP32[i57 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i57 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i57 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i57);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 115:
   switch (HEAP8[i70 + 1 >> 0] | 0) {
   case 104:
    if ((HEAP8[i70 + 2 >> 0] | 0) == 108) {
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 1 ? 10 : 35, i3) | 0;
     break L132;
    } else {
     i1 = (i3 | 0) == 1;
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 4 >> 0] | 0) == 117 ? (i1 ? 11 : 36) : i1 ? 12 : 37, i3) | 0;
     break L132;
    }
   case 117:
    {
     if ((i3 | 0) != 1) if ((i3 | 0) == 2) i1 = 26; else i1 = (i3 | 0) == 3 ? 51 : 64; else i1 = 1;
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, i1, i3) | 0;
     break L132;
    }
   case 113:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 18 : 19, i3) | 0;
     break L132;
    }
   case 116:
    {
     i1 = __ZN4wasm22SExpressionWasmBuilder9makeStoreERNS_7ElementENS_8WasmTypeE(i67, i66, i3) | 0;
     break L132;
    }
   default:
    {
     i3 = ___cxa_allocate_exception(20) | 0;
     HEAP32[i40 >> 2] = 0;
     HEAP32[i40 + 4 >> 2] = 0;
     HEAP32[i40 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i40, 21946, 9);
     i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i40, i70) | 0;
     HEAP32[i58 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i58 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
     HEAP32[i58 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i1 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i58);
     ___cxa_throw(i3 | 0, 64, 279);
    }
   }
  case 116:
   {
    L320 : do if ((HEAP8[i70 + 1 >> 0] | 0) == 114) switch (HEAP8[i70 + 6 >> 0] | 0) {
    case 115:
     {
      i1 = (i3 | 0) == 1;
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 9 >> 0] | 0) == 51 ? (i1 ? 25 : 26) : i1 ? 29 : 30, i3) | 0;
      break L132;
     }
    case 117:
     {
      i1 = (i3 | 0) == 1;
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (HEAP8[i70 + 9 >> 0] | 0) == 51 ? (i1 ? 27 : 28) : i1 ? 31 : 32, i3) | 0;
      break L132;
     }
    default:
     {
      if ((HEAP8[i70 + 2 >> 0] | 0) != 117) break L320;
      i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 3 ? 14 : 15, i3) | 0;
      break L132;
     }
    } while (0);
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i41 >> 2] = 0;
    HEAP32[i41 + 4 >> 2] = 0;
    HEAP32[i41 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i41, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i41, i70) | 0;
    HEAP32[i59 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i59 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i59 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i59);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 119:
   {
    if ((HEAP8[i70 + 1 >> 0] | 0) == 114) {
     i1 = __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i67, i66, 24, i3) | 0;
     break L132;
    }
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i42 >> 2] = 0;
    HEAP32[i42 + 4 >> 2] = 0;
    HEAP32[i42 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i42, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i42, i70) | 0;
    HEAP32[i60 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i60 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i60 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i60);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  case 120:
   {
    if ((HEAP8[i70 + 1 >> 0] | 0) == 111) {
     i1 = __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i67, i66, (i3 | 0) == 1 ? 9 : 34, i3) | 0;
     break L132;
    }
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i44 >> 2] = 0;
    HEAP32[i44 + 4 >> 2] = 0;
    HEAP32[i44 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i44, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i44, i70) | 0;
    HEAP32[i61 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i61 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i61 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i61);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  default:
   {
    i3 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i45 >> 2] = 0;
    HEAP32[i45 + 4 >> 2] = 0;
    HEAP32[i45 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i45, 21946, 9);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i45, i70) | 0;
    HEAP32[i62 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i62 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i62 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i62);
    ___cxa_throw(i3 | 0, 64, 279);
   }
  } while (0);
 } while (0);
 STACKTOP = i68;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_110parse_nameINS0_2DbEEEPKcS4_S4_RT_(i66, i62, i63) {
 i66 = i66 | 0;
 i62 = i62 | 0;
 i63 = i63 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i52 = 0, i53 = 0, i54 = 0, i55 = 0, i56 = 0, i57 = 0, i58 = 0, i59 = 0, i60 = 0, i61 = 0, i64 = 0, i65 = 0, i67 = 0;
 i67 = STACKTOP;
 STACKTOP = STACKTOP + 208 | 0;
 i65 = i67 + 188 | 0;
 i61 = i67 + 184 | 0;
 i59 = i67 + 172 | 0;
 i45 = i67 + 160 | 0;
 i46 = i67 + 144 | 0;
 i51 = i67 + 140 | 0;
 i52 = i67 + 128 | 0;
 i53 = i67 + 112 | 0;
 i54 = i67 + 108 | 0;
 i55 = i67 + 96 | 0;
 i56 = i67 + 64 | 0;
 i57 = i67 + 56 | 0;
 i58 = i67 + 40 | 0;
 i47 = i67 + 36 | 0;
 i48 = i67 + 24 | 0;
 i49 = i67 + 8 | 0;
 i50 = i67;
 i8 = i67 + 80 | 0;
 i5 = i67 + 60 | 0;
 i7 = i62;
 L1 : do if ((i7 - i66 | 0) > 1) {
  i64 = (HEAP8[i66 >> 0] | 0) == 76 ? i66 + 1 | 0 : i66;
  i1 = HEAP8[i64 >> 0] | 0;
  switch (i1 << 24 >> 24 | 0) {
  case 78:
   {
    L46 : do if ((i64 | 0) != (i62 | 0)) if (i1 << 24 >> 24 == 78) {
     i1 = __ZN10__cxxabiv112_GLOBAL__N_119parse_cv_qualifiersEPKcS2_Rj(i64 + 1 | 0, i62, i61) | 0;
     L49 : do if ((i1 | 0) != (i62 | 0)) {
      i3 = i63 + 52 | 0;
      HEAP32[i3 >> 2] = 0;
      switch (HEAP8[i1 >> 0] | 0) {
      case 82:
       {
        HEAP32[i3 >> 2] = 1;
        i1 = i1 + 1 | 0;
        break;
       }
      case 79:
       {
        HEAP32[i3 >> 2] = 2;
        i1 = i1 + 1 | 0;
        break;
       }
      default:
       {}
      }
      i44 = i63 + 4 | 0;
      i4 = HEAP32[i44 >> 2] | 0;
      i43 = HEAP32[i63 + 8 >> 2] | 0;
      i3 = i43;
      if (i4 >>> 0 < i43 >>> 0) {
       HEAP32[i4 >> 2] = 0;
       HEAP32[i4 + 4 >> 2] = 0;
       HEAP32[i4 + 8 >> 2] = 0;
       HEAP32[i4 + 12 >> 2] = 0;
       HEAP32[i4 + 16 >> 2] = 0;
       HEAP32[i4 + 20 >> 2] = 0;
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i4 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i3 = i4 + 12 | 0;
       HEAP32[i3 >> 2] = 0;
       HEAP32[i3 + 4 >> 2] = 0;
       HEAP32[i3 + 8 >> 2] = 0;
       i4 = 0;
       while (1) {
        if ((i4 | 0) == 3) break;
        HEAP32[i3 + (i4 << 2) >> 2] = 0;
        i4 = i4 + 1 | 0;
       }
       HEAP32[i44 >> 2] = (HEAP32[i44 >> 2] | 0) + 24;
      } else {
       i5 = HEAP32[i63 >> 2] | 0;
       i6 = (i4 - i5 | 0) / 24 | 0;
       i4 = i6 + 1 | 0;
       if (i4 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i63);
       i3 = (i3 - i5 | 0) / 24 | 0;
       if (i3 >>> 0 < 89478485) {
        i3 = i3 << 1;
        i3 = i3 >>> 0 < i4 >>> 0 ? i4 : i3;
       } else i3 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i65, i3, i6, i63 + 12 | 0);
       i5 = i65 + 8 | 0;
       i6 = HEAP32[i5 >> 2] | 0;
       HEAP32[i6 >> 2] = 0;
       HEAP32[i6 + 4 >> 2] = 0;
       HEAP32[i6 + 8 >> 2] = 0;
       HEAP32[i6 + 12 >> 2] = 0;
       HEAP32[i6 + 16 >> 2] = 0;
       HEAP32[i6 + 20 >> 2] = 0;
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i6 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i3 = i6 + 12 | 0;
       HEAP32[i3 >> 2] = 0;
       HEAP32[i3 + 4 >> 2] = 0;
       HEAP32[i3 + 8 >> 2] = 0;
       i4 = 0;
       while (1) {
        if ((i4 | 0) == 3) break;
        HEAP32[i3 + (i4 << 2) >> 2] = 0;
        i4 = i4 + 1 | 0;
       }
       HEAP32[i5 >> 2] = i6 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i63, i65);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i65);
      }
      if (((i7 - i1 | 0) > 1 ? (HEAP8[i1 >> 0] | 0) == 83 : 0) ? (HEAP8[i1 + 1 >> 0] | 0) == 116 : 0) {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6assignEPKcj((HEAP32[i44 >> 2] | 0) + -24 | 0, 58253, 3);
       i1 = i1 + 2 | 0;
      }
      if ((i1 | 0) == (i62 | 0)) {
       i2 = HEAP32[i44 >> 2] | 0;
       i1 = i2 + -24 | 0;
       while (1) {
        if ((i2 | 0) == (i1 | 0)) break L49;
        i65 = i2 + -24 | 0;
        HEAP32[i44 >> 2] = i65;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i65);
        i2 = HEAP32[i44 >> 2] | 0;
       }
      }
      i24 = i59 + 11 | 0;
      i25 = i59 + 4 | 0;
      i26 = i63 + 12 | 0;
      i27 = i63 + 16 | 0;
      i43 = i63 + 20 | 0;
      i28 = i63 + 24 | 0;
      i29 = i58 + 12 | 0;
      i30 = i58 + 4 | 0;
      i31 = i58 + 8 | 0;
      i32 = i63 + 28 | 0;
      i33 = i65 + 8 | 0;
      i34 = i49 + 12 | 0;
      i35 = i49 + 4 | 0;
      i36 = i49 + 8 | 0;
      i37 = i65 + 8 | 0;
      i38 = i48 + 11 | 0;
      i39 = i48 + 4 | 0;
      i40 = i45 + 11 | 0;
      i41 = i45 + 4 | 0;
      i42 = i46 + 12 | 0;
      i9 = i46 + 4 | 0;
      i10 = i46 + 8 | 0;
      i11 = i65 + 8 | 0;
      i12 = i53 + 12 | 0;
      i13 = i53 + 4 | 0;
      i14 = i53 + 8 | 0;
      i15 = i65 + 8 | 0;
      i16 = i52 + 11 | 0;
      i17 = i52 + 4 | 0;
      i18 = i56 + 12 | 0;
      i19 = i56 + 4 | 0;
      i20 = i56 + 8 | 0;
      i21 = i65 + 8 | 0;
      i22 = i55 + 11 | 0;
      i23 = i55 + 4 | 0;
      i8 = 0;
      L92 : while (1) {
       L94 : while (1) {
        i3 = HEAP8[i1 >> 0] | 0;
        if (i3 << 24 >> 24 == 69) {
         i60 = 129;
         break L92;
        }
        switch (i3 << 24 >> 24 | 0) {
        case 83:
         {
          i3 = i1;
          i60 = 39;
          break L94;
         }
        case 84:
         {
          i3 = i1;
          i60 = 59;
          break L94;
         }
        case 68:
         {
          i3 = i1;
          i60 = 77;
          break L94;
         }
        case 73:
         break;
        case 76:
         {
          i1 = i1 + 1 | 0;
          if ((i1 | 0) == (i62 | 0)) break L49; else continue L94;
         }
        default:
         {
          i3 = i1;
          break L94;
         }
        }
        i7 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i1, i62, i63) | 0;
        if ((i7 | 0) == (i1 | 0) | (i7 | 0) == (i62 | 0)) break L49;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i59, (HEAP32[i44 >> 2] | 0) + -24 | 0);
        i1 = HEAP32[i44 >> 2] | 0;
        i3 = i1 + -24 | 0;
        i4 = i1;
        while (1) {
         if ((i4 | 0) == (i3 | 0)) break;
         i6 = i4 + -24 | 0;
         HEAP32[i44 >> 2] = i6;
         __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
         i4 = HEAP32[i44 >> 2] | 0;
        }
        i6 = HEAP8[i24 >> 0] | 0;
        i3 = i6 << 24 >> 24 < 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i3 ? HEAP32[i59 >> 2] | 0 : i59, i3 ? HEAP32[i25 >> 2] | 0 : i6 & 255) | 0;
        i1 = (HEAP32[i44 >> 2] | 0) + -24 | 0;
        HEAP32[i47 >> 2] = HEAP32[i26 >> 2];
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i58, i1, i47);
        i1 = HEAP32[i43 >> 2] | 0;
        i6 = HEAP32[i28 >> 2] | 0;
        i3 = i6;
        if (i1 >>> 0 < i6 >>> 0) {
         HEAP32[i1 + 12 >> 2] = HEAP32[i29 >> 2];
         HEAP32[i1 >> 2] = HEAP32[i58 >> 2];
         HEAP32[i1 + 4 >> 2] = HEAP32[i30 >> 2];
         HEAP32[i1 + 8 >> 2] = HEAP32[i31 >> 2];
         HEAP32[i31 >> 2] = 0;
         HEAP32[i30 >> 2] = 0;
         HEAP32[i58 >> 2] = 0;
         HEAP32[i43 >> 2] = (HEAP32[i43 >> 2] | 0) + 16;
        } else {
         i4 = HEAP32[i27 >> 2] | 0;
         i6 = i1 - i4 >> 4;
         i5 = i6 + 1 | 0;
         if (i5 >>> 0 > 268435455) {
          i60 = 104;
          break L92;
         }
         i1 = i3 - i4 | 0;
         if (i1 >> 4 >>> 0 < 134217727) {
          i1 = i1 >> 3;
          i1 = i1 >>> 0 < i5 >>> 0 ? i5 : i1;
         } else i1 = 268435455;
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i65, i1, i6, i32);
         i6 = HEAP32[i33 >> 2] | 0;
         HEAP32[i6 + 12 >> 2] = HEAP32[i29 >> 2];
         HEAP32[i6 >> 2] = HEAP32[i58 >> 2];
         HEAP32[i6 + 4 >> 2] = HEAP32[i30 >> 2];
         HEAP32[i6 + 8 >> 2] = HEAP32[i31 >> 2];
         HEAP32[i31 >> 2] = 0;
         HEAP32[i30 >> 2] = 0;
         HEAP32[i58 >> 2] = 0;
         HEAP32[i33 >> 2] = i6 + 16;
         __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i27, i65);
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i65);
        }
        __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i58);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i59);
        i1 = i7;
       }
       L113 : do if ((i60 | 0) == 39) {
        i60 = 0;
        i8 = i3 + 1 | 0;
        if ((i8 | 0) != (i62 | 0) ? (HEAP8[i8 >> 0] | 0) == 116 : 0) break;
        i1 = __ZN10__cxxabiv112_GLOBAL__N_118parse_substitutionINS0_2DbEEEPKcS4_S4_RT_(i3, i62, i63) | 0;
        if ((i1 | 0) == (i3 | 0) | (i1 | 0) == (i62 | 0)) break L49;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i59, (HEAP32[i44 >> 2] | 0) + -24 | 0);
        i5 = HEAP32[i44 >> 2] | 0;
        i3 = i5 + -24 | 0;
        i4 = i5;
        while (1) {
         if ((i4 | 0) == (i3 | 0)) break;
         i8 = i4 + -24 | 0;
         HEAP32[i44 >> 2] = i8;
         __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i8);
         i4 = HEAP32[i44 >> 2] | 0;
        }
        i4 = i5 + -48 | 0;
        i3 = HEAP8[i4 + 11 >> 0] | 0;
        if (i3 << 24 >> 24 < 0) i3 = HEAP32[i5 + -44 >> 2] | 0; else i3 = i3 & 255;
        if (!i3) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEaSERKS7_(i4, i59); else {
         __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i45, 57058, i59);
         i3 = HEAP8[i40 >> 0] | 0;
         i8 = i3 << 24 >> 24 < 0;
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4, i8 ? HEAP32[i45 >> 2] | 0 : i45, i8 ? HEAP32[i41 >> 2] | 0 : i3 & 255) | 0;
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i45);
         i3 = (HEAP32[i44 >> 2] | 0) + -24 | 0;
         HEAP32[i51 >> 2] = HEAP32[i26 >> 2];
         __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i46, i3, i51);
         i3 = HEAP32[i43 >> 2] | 0;
         i8 = HEAP32[i28 >> 2] | 0;
         i4 = i8;
         if (i3 >>> 0 < i8 >>> 0) {
          HEAP32[i3 + 12 >> 2] = HEAP32[i42 >> 2];
          HEAP32[i3 >> 2] = HEAP32[i46 >> 2];
          HEAP32[i3 + 4 >> 2] = HEAP32[i9 >> 2];
          HEAP32[i3 + 8 >> 2] = HEAP32[i10 >> 2];
          HEAP32[i10 >> 2] = 0;
          HEAP32[i9 >> 2] = 0;
          HEAP32[i46 >> 2] = 0;
          HEAP32[i43 >> 2] = (HEAP32[i43 >> 2] | 0) + 16;
         } else {
          i5 = HEAP32[i27 >> 2] | 0;
          i7 = i3 - i5 >> 4;
          i6 = i7 + 1 | 0;
          if (i6 >>> 0 > 268435455) {
           i60 = 52;
           break L92;
          }
          i3 = i4 - i5 | 0;
          if (i3 >> 4 >>> 0 < 134217727) {
           i3 = i3 >> 3;
           i3 = i3 >>> 0 < i6 >>> 0 ? i6 : i3;
          } else i3 = 268435455;
          __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i65, i3, i7, i32);
          i8 = HEAP32[i11 >> 2] | 0;
          HEAP32[i8 + 12 >> 2] = HEAP32[i42 >> 2];
          HEAP32[i8 >> 2] = HEAP32[i46 >> 2];
          HEAP32[i8 + 4 >> 2] = HEAP32[i9 >> 2];
          HEAP32[i8 + 8 >> 2] = HEAP32[i10 >> 2];
          HEAP32[i10 >> 2] = 0;
          HEAP32[i9 >> 2] = 0;
          HEAP32[i46 >> 2] = 0;
          HEAP32[i11 >> 2] = i8 + 16;
          __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i27, i65);
          __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i65);
         }
         __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i46);
        }
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i59);
        i8 = 1;
        continue L92;
       } else if ((i60 | 0) == 59) {
        i60 = 0;
        i1 = __ZN10__cxxabiv112_GLOBAL__N_120parse_template_paramINS0_2DbEEEPKcS4_S4_RT_(i3, i62, i63) | 0;
        if ((i1 | 0) == (i3 | 0) | (i1 | 0) == (i62 | 0)) break L49;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i59, (HEAP32[i44 >> 2] | 0) + -24 | 0);
        i5 = HEAP32[i44 >> 2] | 0;
        i3 = i5 + -24 | 0;
        i4 = i5;
        while (1) {
         if ((i4 | 0) == (i3 | 0)) break;
         i8 = i4 + -24 | 0;
         HEAP32[i44 >> 2] = i8;
         __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i8);
         i4 = HEAP32[i44 >> 2] | 0;
        }
        i4 = i5 + -48 | 0;
        i3 = HEAP8[i4 + 11 >> 0] | 0;
        if (i3 << 24 >> 24 < 0) i3 = HEAP32[i5 + -44 >> 2] | 0; else i3 = i3 & 255;
        if (!i3) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEaSERKS7_(i4, i59); else {
         __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i52, 57058, i59);
         i8 = HEAP8[i16 >> 0] | 0;
         i7 = i8 << 24 >> 24 < 0;
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4, i7 ? HEAP32[i52 >> 2] | 0 : i52, i7 ? HEAP32[i17 >> 2] | 0 : i8 & 255) | 0;
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i52);
        }
        i3 = (HEAP32[i44 >> 2] | 0) + -24 | 0;
        HEAP32[i54 >> 2] = HEAP32[i26 >> 2];
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i53, i3, i54);
        i3 = HEAP32[i43 >> 2] | 0;
        i8 = HEAP32[i28 >> 2] | 0;
        i4 = i8;
        if (i3 >>> 0 < i8 >>> 0) {
         HEAP32[i3 + 12 >> 2] = HEAP32[i12 >> 2];
         HEAP32[i3 >> 2] = HEAP32[i53 >> 2];
         HEAP32[i3 + 4 >> 2] = HEAP32[i13 >> 2];
         HEAP32[i3 + 8 >> 2] = HEAP32[i14 >> 2];
         HEAP32[i14 >> 2] = 0;
         HEAP32[i13 >> 2] = 0;
         HEAP32[i53 >> 2] = 0;
         HEAP32[i43 >> 2] = (HEAP32[i43 >> 2] | 0) + 16;
        } else {
         i5 = HEAP32[i27 >> 2] | 0;
         i7 = i3 - i5 >> 4;
         i6 = i7 + 1 | 0;
         if (i6 >>> 0 > 268435455) {
          i60 = 72;
          break L92;
         }
         i3 = i4 - i5 | 0;
         if (i3 >> 4 >>> 0 < 134217727) {
          i3 = i3 >> 3;
          i3 = i3 >>> 0 < i6 >>> 0 ? i6 : i3;
         } else i3 = 268435455;
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i65, i3, i7, i32);
         i8 = HEAP32[i15 >> 2] | 0;
         HEAP32[i8 + 12 >> 2] = HEAP32[i12 >> 2];
         HEAP32[i8 >> 2] = HEAP32[i53 >> 2];
         HEAP32[i8 + 4 >> 2] = HEAP32[i13 >> 2];
         HEAP32[i8 + 8 >> 2] = HEAP32[i14 >> 2];
         HEAP32[i14 >> 2] = 0;
         HEAP32[i13 >> 2] = 0;
         HEAP32[i53 >> 2] = 0;
         HEAP32[i15 >> 2] = i8 + 16;
         __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i27, i65);
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i65);
        }
        __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i53);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i59);
        i8 = 1;
        continue L92;
       } else if ((i60 | 0) == 77) {
        i60 = 0;
        i1 = i3 + 1 | 0;
        if ((i1 | 0) != (i62 | 0)) switch (HEAP8[i1 >> 0] | 0) {
        case 84:
        case 116:
         break;
        default:
         break L113;
        }
        i1 = __ZN10__cxxabiv112_GLOBAL__N_114parse_decltypeINS0_2DbEEEPKcS4_S4_RT_(i3, i62, i63) | 0;
        if ((i1 | 0) == (i3 | 0) | (i1 | 0) == (i62 | 0)) break L49;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i59, (HEAP32[i44 >> 2] | 0) + -24 | 0);
        i5 = HEAP32[i44 >> 2] | 0;
        i3 = i5 + -24 | 0;
        i4 = i5;
        while (1) {
         if ((i4 | 0) == (i3 | 0)) break;
         i8 = i4 + -24 | 0;
         HEAP32[i44 >> 2] = i8;
         __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i8);
         i4 = HEAP32[i44 >> 2] | 0;
        }
        i4 = i5 + -48 | 0;
        i3 = HEAP8[i4 + 11 >> 0] | 0;
        if (i3 << 24 >> 24 < 0) i3 = HEAP32[i5 + -44 >> 2] | 0; else i3 = i3 & 255;
        if (!i3) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEaSERKS7_(i4, i59); else {
         __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i55, 57058, i59);
         i8 = HEAP8[i22 >> 0] | 0;
         i7 = i8 << 24 >> 24 < 0;
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4, i7 ? HEAP32[i55 >> 2] | 0 : i55, i7 ? HEAP32[i23 >> 2] | 0 : i8 & 255) | 0;
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i55);
        }
        i3 = (HEAP32[i44 >> 2] | 0) + -24 | 0;
        HEAP32[i57 >> 2] = HEAP32[i26 >> 2];
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i56, i3, i57);
        i3 = HEAP32[i43 >> 2] | 0;
        i8 = HEAP32[i28 >> 2] | 0;
        i4 = i8;
        if (i3 >>> 0 < i8 >>> 0) {
         HEAP32[i3 + 12 >> 2] = HEAP32[i18 >> 2];
         HEAP32[i3 >> 2] = HEAP32[i56 >> 2];
         HEAP32[i3 + 4 >> 2] = HEAP32[i19 >> 2];
         HEAP32[i3 + 8 >> 2] = HEAP32[i20 >> 2];
         HEAP32[i20 >> 2] = 0;
         HEAP32[i19 >> 2] = 0;
         HEAP32[i56 >> 2] = 0;
         HEAP32[i43 >> 2] = (HEAP32[i43 >> 2] | 0) + 16;
        } else {
         i5 = HEAP32[i27 >> 2] | 0;
         i7 = i3 - i5 >> 4;
         i6 = i7 + 1 | 0;
         if (i6 >>> 0 > 268435455) {
          i60 = 92;
          break L92;
         }
         i3 = i4 - i5 | 0;
         if (i3 >> 4 >>> 0 < 134217727) {
          i3 = i3 >> 3;
          i3 = i3 >>> 0 < i6 >>> 0 ? i6 : i3;
         } else i3 = 268435455;
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i65, i3, i7, i32);
         i8 = HEAP32[i21 >> 2] | 0;
         HEAP32[i8 + 12 >> 2] = HEAP32[i18 >> 2];
         HEAP32[i8 >> 2] = HEAP32[i56 >> 2];
         HEAP32[i8 + 4 >> 2] = HEAP32[i19 >> 2];
         HEAP32[i8 + 8 >> 2] = HEAP32[i20 >> 2];
         HEAP32[i20 >> 2] = 0;
         HEAP32[i19 >> 2] = 0;
         HEAP32[i56 >> 2] = 0;
         HEAP32[i21 >> 2] = i8 + 16;
         __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i27, i65);
         __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i65);
        }
        __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i56);
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i59);
        i8 = 1;
        continue L92;
       } while (0);
       i1 = __ZN10__cxxabiv112_GLOBAL__N_122parse_unqualified_nameINS0_2DbEEEPKcS4_S4_RT_(i3, i62, i63) | 0;
       if ((i1 | 0) == (i3 | 0) | (i1 | 0) == (i62 | 0)) break L49;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i59, (HEAP32[i44 >> 2] | 0) + -24 | 0);
       i5 = HEAP32[i44 >> 2] | 0;
       i3 = i5 + -24 | 0;
       i4 = i5;
       while (1) {
        if ((i4 | 0) == (i3 | 0)) break;
        i8 = i4 + -24 | 0;
        HEAP32[i44 >> 2] = i8;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i8);
        i4 = HEAP32[i44 >> 2] | 0;
       }
       i4 = i5 + -48 | 0;
       i3 = HEAP8[i4 + 11 >> 0] | 0;
       if (i3 << 24 >> 24 < 0) i3 = HEAP32[i5 + -44 >> 2] | 0; else i3 = i3 & 255;
       if (!i3) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEaSERKS7_(i4, i59); else {
        __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i48, 57058, i59);
        i8 = HEAP8[i38 >> 0] | 0;
        i7 = i8 << 24 >> 24 < 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4, i7 ? HEAP32[i48 >> 2] | 0 : i48, i7 ? HEAP32[i39 >> 2] | 0 : i8 & 255) | 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i48);
       }
       i3 = (HEAP32[i44 >> 2] | 0) + -24 | 0;
       HEAP32[i50 >> 2] = HEAP32[i26 >> 2];
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i49, i3, i50);
       i3 = HEAP32[i43 >> 2] | 0;
       i8 = HEAP32[i28 >> 2] | 0;
       i4 = i8;
       if (i3 >>> 0 < i8 >>> 0) {
        HEAP32[i3 + 12 >> 2] = HEAP32[i34 >> 2];
        HEAP32[i3 >> 2] = HEAP32[i49 >> 2];
        HEAP32[i3 + 4 >> 2] = HEAP32[i35 >> 2];
        HEAP32[i3 + 8 >> 2] = HEAP32[i36 >> 2];
        HEAP32[i36 >> 2] = 0;
        HEAP32[i35 >> 2] = 0;
        HEAP32[i49 >> 2] = 0;
        HEAP32[i43 >> 2] = (HEAP32[i43 >> 2] | 0) + 16;
       } else {
        i5 = HEAP32[i27 >> 2] | 0;
        i7 = i3 - i5 >> 4;
        i6 = i7 + 1 | 0;
        if (i6 >>> 0 > 268435455) {
         i60 = 123;
         break;
        }
        i3 = i4 - i5 | 0;
        if (i3 >> 4 >>> 0 < 134217727) {
         i3 = i3 >> 3;
         i3 = i3 >>> 0 < i6 >>> 0 ? i6 : i3;
        } else i3 = 268435455;
        __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i65, i3, i7, i32);
        i8 = HEAP32[i37 >> 2] | 0;
        HEAP32[i8 + 12 >> 2] = HEAP32[i34 >> 2];
        HEAP32[i8 >> 2] = HEAP32[i49 >> 2];
        HEAP32[i8 + 4 >> 2] = HEAP32[i35 >> 2];
        HEAP32[i8 + 8 >> 2] = HEAP32[i36 >> 2];
        HEAP32[i36 >> 2] = 0;
        HEAP32[i35 >> 2] = 0;
        HEAP32[i49 >> 2] = 0;
        HEAP32[i37 >> 2] = i8 + 16;
        __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i27, i65);
        __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i65);
       }
       __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i49);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i59);
       i8 = 1;
      }
      if ((i60 | 0) == 52) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i27); else if ((i60 | 0) == 72) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i27); else if ((i60 | 0) == 92) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i27); else if ((i60 | 0) == 104) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i27); else if ((i60 | 0) == 123) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i27); else if ((i60 | 0) == 129) {
       i1 = i1 + 1 | 0;
       HEAP32[i63 + 48 >> 2] = HEAP32[i61 >> 2];
       L214 : do if (i8 ? (i2 = HEAP32[i43 >> 2] | 0, (HEAP32[i63 + 16 >> 2] | 0) != (i2 | 0)) : 0) {
        i3 = i2 + -16 | 0;
        while (1) {
         if ((i2 | 0) == (i3 | 0)) break L214;
         i65 = i2 + -16 | 0;
         HEAP32[i43 >> 2] = i65;
         __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i65);
         i2 = HEAP32[i43 >> 2] | 0;
        }
       } while (0);
       break L46;
      }
     } while (0);
     i1 = i64;
    } else i1 = i64; else i1 = i62; while (0);
    i1 = (i1 | 0) == (i64 | 0) ? i66 : i1;
    break L1;
   }
  case 90:
   {
    L225 : do if (((i1 << 24 >> 24 == 90 & (i64 | 0) != (i62 | 0) ? (i61 = i64 + 1 | 0, i3 = __ZN10__cxxabiv112_GLOBAL__N_114parse_encodingINS0_2DbEEEPKcS4_S4_RT_(i61, i62, i63) | 0, !((i3 | 0) == (i61 | 0) | (i3 | 0) == (i62 | 0))) : 0) ? (HEAP8[i3 >> 0] | 0) == 69 : 0) ? (i4 = i3 + 1 | 0, (i4 | 0) != (i62 | 0)) : 0) switch (HEAP8[i4 >> 0] | 0) {
    case 115:
     {
      i1 = __ZN10__cxxabiv112_GLOBAL__N_119parse_discriminatorEPKcS2_(i3 + 2 | 0, i62) | 0;
      i2 = HEAP32[i63 + 4 >> 2] | 0;
      if ((HEAP32[i63 >> 2] | 0) == (i2 | 0)) break L225;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + -24 | 0, 58257) | 0;
      break L225;
     }
    case 100:
     {
      i1 = i3 + 2 | 0;
      if ((i1 | 0) == (i62 | 0)) {
       i1 = i64;
       break L225;
      }
      i1 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i1, i62) | 0;
      if ((i1 | 0) == (i62 | 0)) {
       i1 = i64;
       break L225;
      }
      if ((HEAP8[i1 >> 0] | 0) != 95) {
       i1 = i64;
       break L225;
      }
      i61 = i1 + 1 | 0;
      i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_nameINS0_2DbEEEPKcS4_S4_RT_(i61, i62, i63) | 0;
      i5 = i63 + 4 | 0;
      if ((i1 | 0) == (i61 | 0)) {
       i2 = HEAP32[i5 >> 2] | 0;
       i1 = i2 + -24 | 0;
       while (1) {
        if ((i2 | 0) == (i1 | 0)) {
         i1 = i64;
         break L225;
        }
        i65 = i2 + -24 | 0;
        HEAP32[i5 >> 2] = i65;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i65);
        i2 = HEAP32[i5 >> 2] | 0;
       }
      }
      i2 = HEAP32[i5 >> 2] | 0;
      if (((i2 - (HEAP32[i63 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
       i1 = i64;
       break L225;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i65, i2 + -24 | 0);
      i2 = HEAP32[i5 >> 2] | 0;
      i3 = i2 + -24 | 0;
      i4 = i2;
      while (1) {
       if ((i4 | 0) == (i3 | 0)) break;
       i63 = i4 + -24 | 0;
       HEAP32[i5 >> 2] = i63;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i63);
       i4 = HEAP32[i5 >> 2] | 0;
      }
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + -48 | 0, 57058) | 0;
      i63 = HEAP8[i65 + 11 >> 0] | 0;
      i62 = i63 << 24 >> 24 < 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj((HEAP32[i5 >> 2] | 0) + -24 | 0, i62 ? HEAP32[i65 >> 2] | 0 : i65, i62 ? HEAP32[i65 + 4 >> 2] | 0 : i63 & 255) | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i65);
      break L225;
     }
    default:
     {
      i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_nameINS0_2DbEEEPKcS4_S4_RT_(i4, i62, i63) | 0;
      if ((i1 | 0) == (i4 | 0)) {
       i1 = i63 + 4 | 0;
       i3 = HEAP32[i1 >> 2] | 0;
       i2 = i3 + -24 | 0;
       while (1) {
        if ((i3 | 0) == (i2 | 0)) {
         i1 = i64;
         break L225;
        }
        i65 = i3 + -24 | 0;
        HEAP32[i1 >> 2] = i65;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i65);
        i3 = HEAP32[i1 >> 2] | 0;
       }
      }
      i1 = __ZN10__cxxabiv112_GLOBAL__N_119parse_discriminatorEPKcS2_(i1, i62) | 0;
      i5 = i63 + 4 | 0;
      i2 = HEAP32[i5 >> 2] | 0;
      if (((i2 - (HEAP32[i63 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) break L225;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i65, i2 + -24 | 0);
      i2 = HEAP32[i5 >> 2] | 0;
      i3 = i2 + -24 | 0;
      i4 = i2;
      while (1) {
       if ((i4 | 0) == (i3 | 0)) break;
       i63 = i4 + -24 | 0;
       HEAP32[i5 >> 2] = i63;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i63);
       i4 = HEAP32[i5 >> 2] | 0;
      }
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2 + -48 | 0, 57058) | 0;
      i63 = HEAP8[i65 + 11 >> 0] | 0;
      i62 = i63 << 24 >> 24 < 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj((HEAP32[i5 >> 2] | 0) + -24 | 0, i62 ? HEAP32[i65 >> 2] | 0 : i65, i62 ? HEAP32[i65 + 4 >> 2] | 0 : i63 & 255) | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i65);
      break L225;
     }
    } else i1 = i64; while (0);
    i1 = (i1 | 0) == (i64 | 0) ? i66 : i1;
    break L1;
   }
  default:
   {
    do if ((i7 - i64 | 0) > 1) {
     if (i1 << 24 >> 24 == 83 ? (HEAP8[i64 + 1 >> 0] | 0) == 116 : 0) {
      i1 = i64 + 2 | 0;
      if ((i1 | 0) == (i62 | 0)) {
       i3 = 0;
       i2 = i62;
      } else {
       i3 = 0;
       i2 = (HEAP8[i1 >> 0] | 0) == 76 ? i64 + 3 | 0 : i1;
      }
     } else {
      i3 = 1;
      i2 = i64;
     }
     i1 = __ZN10__cxxabiv112_GLOBAL__N_122parse_unqualified_nameINS0_2DbEEEPKcS4_S4_RT_(i2, i62, i63) | 0;
     i2 = (i1 | 0) == (i2 | 0);
     if (i3 | i2) i1 = i2 ? i64 : i1; else {
      i2 = HEAP32[i63 + 4 >> 2] | 0;
      if ((HEAP32[i63 >> 2] | 0) == (i2 | 0)) break;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 57996) | 0;
     }
     if ((i1 | 0) != (i64 | 0)) {
      if ((i1 | 0) == (i62 | 0)) {
       i1 = i62;
       break L1;
      }
      if ((HEAP8[i1 >> 0] | 0) != 73) break L1;
      i7 = i63 + 4 | 0;
      i2 = HEAP32[i7 >> 2] | 0;
      if ((HEAP32[i63 >> 2] | 0) == (i2 | 0)) {
       i1 = i66;
       break L1;
      }
      i6 = i63 + 16 | 0;
      HEAP32[i5 >> 2] = HEAP32[i63 + 12 >> 2];
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i8, i2 + -24 | 0, i5);
      i2 = i63 + 20 | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      i64 = HEAP32[i63 + 24 >> 2] | 0;
      i4 = i64;
      if (i3 >>> 0 < i64 >>> 0) {
       HEAP32[i3 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
       HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
       i64 = i8 + 4 | 0;
       HEAP32[i3 + 4 >> 2] = HEAP32[i64 >> 2];
       i61 = i8 + 8 | 0;
       HEAP32[i3 + 8 >> 2] = HEAP32[i61 >> 2];
       HEAP32[i61 >> 2] = 0;
       HEAP32[i64 >> 2] = 0;
       HEAP32[i8 >> 2] = 0;
       HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
      } else {
       i2 = HEAP32[i6 >> 2] | 0;
       i5 = i3 - i2 >> 4;
       i3 = i5 + 1 | 0;
       if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
       i2 = i4 - i2 | 0;
       if (i2 >> 4 >>> 0 < 134217727) {
        i2 = i2 >> 3;
        i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
       } else i2 = 268435455;
       __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i65, i2, i5, i63 + 28 | 0);
       i64 = i65 + 8 | 0;
       i61 = HEAP32[i64 >> 2] | 0;
       HEAP32[i61 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
       HEAP32[i61 >> 2] = HEAP32[i8 >> 2];
       i60 = i8 + 4 | 0;
       HEAP32[i61 + 4 >> 2] = HEAP32[i60 >> 2];
       i59 = i8 + 8 | 0;
       HEAP32[i61 + 8 >> 2] = HEAP32[i59 >> 2];
       HEAP32[i59 >> 2] = 0;
       HEAP32[i60 >> 2] = 0;
       HEAP32[i8 >> 2] = 0;
       HEAP32[i64 >> 2] = i61 + 16;
       __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i65);
       __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i65);
      }
      __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i8);
      i4 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i1, i62, i63) | 0;
      if ((i4 | 0) == (i1 | 0)) {
       i1 = i66;
       break L1;
      }
      i1 = HEAP32[i7 >> 2] | 0;
      if (((i1 - (HEAP32[i63 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
       i1 = i66;
       break L1;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i65, i1 + -24 | 0);
      i1 = HEAP32[i7 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i66 = i3 + -24 | 0;
       HEAP32[i7 >> 2] = i66;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i66);
       i3 = HEAP32[i7 >> 2] | 0;
      }
      i66 = HEAP8[i65 + 11 >> 0] | 0;
      i64 = i66 << 24 >> 24 < 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i64 ? HEAP32[i65 >> 2] | 0 : i65, i64 ? HEAP32[i65 + 4 >> 2] | 0 : i66 & 255) | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i65);
      i1 = i4;
      break L1;
     }
    } while (0);
    i2 = __ZN10__cxxabiv112_GLOBAL__N_118parse_substitutionINS0_2DbEEEPKcS4_S4_RT_(i64, i62, i63) | 0;
    if ((i2 | 0) == (i64 | 0) | (i2 | 0) == (i62 | 0)) {
     i1 = i66;
     break L1;
    }
    if ((HEAP8[i2 >> 0] | 0) != 73) {
     i1 = i66;
     break L1;
    }
    i1 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i2, i62, i63) | 0;
    if ((i1 | 0) == (i2 | 0)) {
     i1 = i66;
     break L1;
    }
    i5 = i63 + 4 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if (((i2 - (HEAP32[i63 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
     i1 = i66;
     break L1;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i65, i2 + -24 | 0);
    i2 = HEAP32[i5 >> 2] | 0;
    i3 = i2 + -24 | 0;
    i4 = i2;
    while (1) {
     if ((i4 | 0) == (i3 | 0)) break;
     i66 = i4 + -24 | 0;
     HEAP32[i5 >> 2] = i66;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i66);
     i4 = HEAP32[i5 >> 2] | 0;
    }
    i66 = HEAP8[i65 + 11 >> 0] | 0;
    i64 = i66 << 24 >> 24 < 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i2 + -48 | 0, i64 ? HEAP32[i65 >> 2] | 0 : i65, i64 ? HEAP32[i65 + 4 >> 2] | 0 : i66 & 255) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i65);
    break L1;
   }
  }
 } else i1 = i66; while (0);
 STACKTOP = i67;
 return i1 | 0;
}

function __ZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0;
 i36 = STACKTOP;
 STACKTOP = STACKTOP + 160 | 0;
 i13 = i36 + 152 | 0;
 i12 = i36 + 148 | 0;
 i14 = i36 + 144 | 0;
 i15 = i36 + 140 | 0;
 i33 = i36 + 124 | 0;
 i34 = i36 + 108 | 0;
 i31 = i36 + 96 | 0;
 i32 = i36 + 76 | 0;
 i35 = i36 + 60 | 0;
 i29 = i36 + 36 | 0;
 i28 = i36 + 28 | 0;
 i30 = i36 + 16 | 0;
 i20 = i36 + 136 | 0;
 i21 = i36 + 120 | 0;
 i22 = i36 + 104 | 0;
 i23 = i36 + 88 | 0;
 i24 = i36 + 72 | 0;
 i25 = i36 + 56 | 0;
 i26 = i36 + 32 | 0;
 i27 = i36 + 24 | 0;
 i16 = i36 + 12 | 0;
 i17 = i36 + 8 | 0;
 i18 = i36 + 4 | 0;
 i19 = i36;
 HEAP32[i14 >> 2] = i1;
 HEAP32[i15 >> 2] = i2;
 HEAP32[i33 >> 2] = 0;
 HEAP32[i33 + 4 >> 2] = 0;
 HEAP32[i33 + 8 >> 2] = 0;
 HEAP32[i34 + 4 >> 2] = 0;
 HEAP32[i34 + 8 >> 2] = 0;
 HEAP32[i34 >> 2] = i34 + 4;
 HEAP32[i31 >> 2] = 19;
 HEAP32[i31 + 4 >> 2] = 0;
 HEAP32[i32 >> 2] = 0;
 i9 = i32 + 4 | 0;
 HEAP32[i9 >> 2] = 0;
 HEAP32[i32 + 8 >> 2] = 0;
 HEAP32[i35 >> 2] = 0;
 i10 = i35 + 4 | 0;
 HEAP32[i10 >> 2] = 0;
 HEAP32[i35 + 8 >> 2] = 0;
 HEAP32[i29 >> 2] = i33;
 HEAP32[i29 + 4 >> 2] = i34;
 HEAP32[i29 + 8 >> 2] = i32;
 HEAP32[i29 + 12 >> 2] = i31;
 HEAP32[i29 + 16 >> 2] = i35;
 HEAP32[i28 >> 2] = i34;
 HEAP32[i30 >> 2] = i33;
 HEAP32[i30 + 4 >> 2] = i34;
 i11 = i32 + 8 | 0;
 __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i14);
 i1 = HEAP32[i10 >> 2] | 0;
 i8 = i35 + 8 | 0;
 if ((i1 | 0) == (HEAP32[i8 >> 2] | 0)) {
  __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i15);
  i7 = i15;
 } else {
  HEAP32[i1 >> 2] = HEAP32[i15 >> 2];
  HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
  i7 = i15;
 }
 L5 : while (1) {
  i6 = HEAP32[i9 >> 2] | 0;
  i4 = i6;
  i2 = HEAP32[i10 >> 2] | 0;
  i1 = (i2 | 0) == (HEAP32[i35 >> 2] | 0);
  if ((i6 | 0) == (HEAP32[i32 >> 2] | 0)) {
   i2 = 210;
   break;
  }
  if (i1) {
   i1 = 0;
   i2 = 210;
   break;
  }
  i3 = i4 + -4 | 0;
  i5 = HEAP32[i3 >> 2] | 0;
  HEAP32[i14 >> 2] = i5;
  i6 = i5;
  i1 = i4;
  while (1) {
   if ((i1 | 0) == (i3 | 0)) break;
   i4 = i1 + -4 | 0;
   HEAP32[i9 >> 2] = i4;
   i1 = i4;
  }
  i1 = i2 + -4 | 0;
  i3 = HEAP32[i1 >> 2] | 0;
  HEAP32[i7 >> 2] = i3;
  i4 = i3;
  while (1) {
   if ((i2 | 0) == (i1 | 0)) break;
   i37 = i2 + -4 | 0;
   HEAP32[i10 >> 2] = i37;
   i2 = i37;
  }
  i1 = (i5 | 0) != 0;
  if ((i1 & 1 ^ 1 | 0) != ((i3 | 0) == 0 | 0)) {
   i1 = 0;
   i2 = 210;
   break;
  }
  if (!i1) continue;
  if ((i6 | 0) == (i31 | 0)) {
   __ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlvE_clEv(i30);
   continue;
  }
  i1 = HEAP32[i6 >> 2] | 0;
  if ((i1 | 0) != (HEAP32[i4 >> 2] | 0)) {
   i1 = 0;
   i2 = 210;
   break;
  }
  do switch (i1 | 0) {
  case 20:
  case 19:
   continue L5;
  case 1:
   {
    i37 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(i6) | 0) + 8 | 0;
    HEAP32[i20 >> 2] = HEAP32[i37 >> 2];
    i37 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    HEAP32[i21 >> 2] = HEAP32[i37 >> 2];
    HEAP32[i12 >> 2] = HEAP32[i20 >> 2];
    HEAP32[i13 >> 2] = HEAP32[i21 >> 2];
    if (!(__ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlNS_4NameES3_E_clES3_S3_(i29, i12, i13) | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 20 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 20 | 0;
    if ((i6 | 0) == (HEAP32[i37 >> 2] | 0)) i3 = 0; else {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    while (1) {
     i37 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 20 | 0;
     if (i3 >>> 0 >= (HEAP32[i37 >> 2] | 0) >>> 0) continue L5;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0, i3) | 0;
     i2 = HEAP32[i9 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
     }
     i2 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0, i3) | 0;
     i1 = HEAP32[i10 >> 2] | 0;
     if ((i1 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i2); else {
      HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
      HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  case 2:
   {
    i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i6) | 0) + 8 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 3:
   {
    i37 = (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i6) | 0) + 8 | 0;
    HEAP32[i22 >> 2] = HEAP32[i37 >> 2];
    i37 = (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    HEAP32[i23 >> 2] = HEAP32[i37 >> 2];
    HEAP32[i12 >> 2] = HEAP32[i22 >> 2];
    HEAP32[i13 >> 2] = HEAP32[i23 >> 2];
    if (!(__ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlNS_4NameES3_E_clES3_S3_(i29, i12, i13) | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i37 = (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0;
    HEAP32[i24 >> 2] = HEAP32[i37 >> 2];
    i37 = (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0;
    HEAP32[i25 >> 2] = HEAP32[i37 >> 2];
    HEAP32[i12 >> 2] = HEAP32[i24 >> 2];
    HEAP32[i13 >> 2] = HEAP32[i25 >> 2];
    if (!(__ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlNS_4NameES3_E_clES3_S3_(i29, i12, i13) | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i1 = (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 4:
   {
    i37 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i6) | 0) + 8 | 0;
    HEAP32[i26 >> 2] = HEAP32[i37 >> 2];
    i37 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    HEAP32[i27 >> 2] = HEAP32[i37 >> 2];
    HEAP32[i12 >> 2] = HEAP32[i26 >> 2];
    HEAP32[i13 >> 2] = HEAP32[i27 >> 2];
    if (!(__ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlNS_4NameES3_E0_clES3_S3_(i28, i12, i13) | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i1 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 5:
   {
    i6 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i6) | 0) + 16 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    if ((i6 | 0) == (HEAP32[i37 >> 2] | 0)) i2 = 0; else {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    while (1) {
     i37 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
     i1 = HEAP32[i14 >> 2] | 0;
     if (i2 >>> 0 >= (HEAP32[i37 >> 2] | 0) >>> 0) break;
     i37 = __ZNK11ArenaVectorIN4wasm4NameEEixEj((__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i1) | 0) + 8 | 0, i2) | 0;
     HEAP32[i16 >> 2] = HEAP32[i37 >> 2];
     i37 = __ZNK11ArenaVectorIN4wasm4NameEEixEj((__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0, i2) | 0;
     HEAP32[i17 >> 2] = HEAP32[i37 >> 2];
     HEAP32[i12 >> 2] = HEAP32[i16 >> 2];
     HEAP32[i13 >> 2] = HEAP32[i17 >> 2];
     if (__ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlNS_4NameES3_E0_clES3_S3_(i28, i12, i13) | 0) i2 = i2 + 1 | 0; else {
      i1 = 0;
      i2 = 210;
      break L5;
     }
    }
    i37 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i1) | 0) + 24 | 0;
    HEAP32[i18 >> 2] = HEAP32[i37 >> 2];
    i37 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 24 | 0;
    HEAP32[i19 >> 2] = HEAP32[i37 >> 2];
    HEAP32[i12 >> 2] = HEAP32[i18 >> 2];
    HEAP32[i13 >> 2] = HEAP32[i19 >> 2];
    if (!(__ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlNS_4NameES3_E0_clES3_S3_(i28, i12, i13) | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 28 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 28 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 32 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 32 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 6:
   {
    i6 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i6) | 0;
    i37 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i15 >> 2] | 0) | 0;
    if ((HEAP32[i6 + 24 >> 2] | 0) != (HEAP32[i37 + 24 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    if ((i6 | 0) == (HEAP32[i37 >> 2] | 0)) i3 = 0; else {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    while (1) {
     i37 = (__ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
     if (i3 >>> 0 >= (HEAP32[i37 >> 2] | 0) >>> 0) continue L5;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 8 | 0, i3) | 0;
     i2 = HEAP32[i9 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
     }
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0, i3) | 0;
     i2 = HEAP32[i10 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  case 7:
   {
    i6 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i6) | 0;
    i37 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i15 >> 2] | 0) | 0;
    if ((HEAP32[i6 + 24 >> 2] | 0) != (HEAP32[i37 + 24 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    if ((i6 | 0) == (HEAP32[i37 >> 2] | 0)) i3 = 0; else {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    while (1) {
     i37 = (__ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
     if (i3 >>> 0 >= (HEAP32[i37 >> 2] | 0) >>> 0) continue L5;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 8 | 0, i3) | 0;
     i2 = HEAP32[i9 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
     }
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0, i3) | 0;
     i2 = HEAP32[i10 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  case 8:
   {
    i1 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i6) | 0) + 28 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 28 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
    }
    i6 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 24 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 24 | 0;
    if ((i6 | 0) != (HEAP32[i37 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    if ((i6 | 0) == (HEAP32[i37 >> 2] | 0)) i3 = 0; else {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    while (1) {
     i37 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
     if (i3 >>> 0 >= (HEAP32[i37 >> 2] | 0) >>> 0) continue L5;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 8 | 0, i3) | 0;
     i2 = HEAP32[i9 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
     }
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0, i3) | 0;
     i2 = HEAP32[i10 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  case 9:
   {
    i6 = (__ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(i6) | 0) + 8 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    if ((i6 | 0) == (HEAP32[i37 >> 2] | 0)) continue L5; else {
     i1 = 0;
     i2 = 210;
     break L5;
    }
   }
  case 10:
   {
    i6 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i6) | 0) + 8 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    if ((i6 | 0) != (HEAP32[i37 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i1 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 11:
   {
    i6 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i6) | 0) + 8 | 0;
    i6 = HEAP8[i6 >> 0] | 0;
    i37 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    if (i6 << 24 >> 24 != (HEAP8[i37 >> 0] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 9 | 0;
    i6 = HEAP8[i6 >> 0] | 0;
    i37 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 9 | 0;
    if (i6 << 24 >> 24 != (HEAP8[i37 >> 0] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0;
    if ((i6 | 0) != (HEAP32[i37 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    if ((i6 | 0) != (HEAP32[i37 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i1 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 20 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 20 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 12:
   {
    i6 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i6) | 0) + 8 | 0;
    i6 = HEAP8[i6 >> 0] | 0;
    i37 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    if (i6 << 24 >> 24 != (HEAP8[i37 >> 0] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0;
    if ((i6 | 0) != (HEAP32[i37 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    if ((i6 | 0) != (HEAP32[i37 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i1 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 20 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 20 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 24 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 24 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 13:
   {
    i37 = __ZN4wasm10Expression4castINS_5ConstEEEPT_v(i6) | 0;
    if (__ZNK4wasm7LiteraleqERKS0_(i37 + 8 | 0, (__ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0) | 0) continue L5; else {
     i1 = 0;
     i2 = 210;
     break L5;
    }
   }
  case 14:
   {
    i6 = (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i6) | 0) + 8 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    if ((i6 | 0) != (HEAP32[i37 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i1 = (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 15:
   {
    i6 = (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i6) | 0) + 8 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    if ((i6 | 0) != (HEAP32[i37 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i1 = (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 16:
   {
    i1 = (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i6) | 0) + 8 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 17:
   {
    i1 = (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i6) | 0) + 8 | 0;
    i2 = HEAP32[i9 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    i2 = HEAP32[i10 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1);
     continue L5;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     continue L5;
    }
   }
  case 18:
   {
    i6 = (__ZN4wasm10Expression4castINS_4HostEEEPT_v(i6) | 0) + 8 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 8 | 0;
    if ((i6 | 0) != (HEAP32[i37 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i14 >> 2] | 0) | 0;
    i37 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i15 >> 2] | 0) | 0;
    if ((HEAP32[i6 + 12 >> 2] | 0) != (HEAP32[i37 + 12 >> 2] | 0)) {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    i6 = (__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 24 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i37 = (__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 24 | 0;
    if ((i6 | 0) == (HEAP32[i37 >> 2] | 0)) i3 = 0; else {
     i1 = 0;
     i2 = 210;
     break L5;
    }
    while (1) {
     i37 = (__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 24 | 0;
     if (i3 >>> 0 >= (HEAP32[i37 >> 2] | 0) >>> 0) continue L5;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i14 >> 2] | 0) | 0) + 16 | 0, i3) | 0;
     i2 = HEAP32[i9 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i11 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 4;
     }
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i15 >> 2] | 0) | 0) + 16 | 0, i3) | 0;
     i2 = HEAP32[i10 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i35, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  default:
   {
    i2 = 209;
    break L5;
   }
  } while (0);
 }
 if ((i2 | 0) != 209) if ((i2 | 0) == 210) {
  __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i35);
  __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i32);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEED2Ev(i34);
  __ZNSt3__213__vector_baseIN4wasm4NameENS_9allocatorIS2_EEED2Ev(i33);
  STACKTOP = i36;
  return i1 | 0;
 }
 return 0;
}

function __ZN4wasm15Asm2WasmBuilder10processAsmEN6cashew3RefE(i84, i6) {
 i84 = i84 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i50 = 0, i51 = 0, i52 = 0, i53 = 0, i54 = 0, i55 = 0, i56 = 0, i57 = 0, i58 = 0, i59 = 0, i60 = 0, i61 = 0, i62 = 0, i63 = 0, i64 = 0, i65 = 0, i66 = 0, i67 = 0, i68 = 0, i69 = 0, i70 = 0, i71 = 0, i72 = 0, i73 = 0, i74 = 0, i75 = 0, i76 = 0, i77 = 0, i78 = 0, i79 = 0, i80 = 0, i81 = 0, i82 = 0, i83 = 0, i85 = 0;
 i85 = STACKTOP;
 STACKTOP = STACKTOP + 352 | 0;
 i76 = i85 + 344 | 0;
 i75 = i85 + 340 | 0;
 i82 = i85 + 304 | 0;
 i5 = i85 + 256 | 0;
 i58 = i85 + 240 | 0;
 i3 = i85 + 336 | 0;
 i4 = i85 + 332 | 0;
 i57 = i85 + 232 | 0;
 i72 = i85 + 216 | 0;
 i68 = i85 + 200 | 0;
 i60 = i85 + 184 | 0;
 i61 = i85 + 176 | 0;
 i40 = i85 + 328 | 0;
 i48 = i85 + 324 | 0;
 i51 = i85 + 320 | 0;
 i52 = i85 + 316 | 0;
 i53 = i85 + 300 | 0;
 i59 = i85 + 160 | 0;
 i54 = i85 + 296 | 0;
 i55 = i85 + 292 | 0;
 i56 = i85 + 288 | 0;
 i33 = i85 + 284 | 0;
 i34 = i85 + 280 | 0;
 i35 = i85 + 276 | 0;
 i36 = i85 + 272 | 0;
 i37 = i85 + 268 | 0;
 i38 = i85 + 264 | 0;
 i39 = i85 + 260 | 0;
 i62 = i85 + 244 | 0;
 i63 = i85 + 236 | 0;
 i64 = i85 + 220 | 0;
 i65 = i85 + 212 | 0;
 i41 = i85 + 188 | 0;
 i42 = i85 + 180 | 0;
 i66 = i85 + 164 | 0;
 i67 = i85 + 156 | 0;
 i43 = i85 + 152 | 0;
 i44 = i85 + 148 | 0;
 i45 = i85 + 144 | 0;
 i46 = i85 + 140 | 0;
 i47 = i85 + 136 | 0;
 i49 = i85 + 132 | 0;
 i50 = i85 + 128 | 0;
 i69 = i85 + 124 | 0;
 i70 = i85 + 120 | 0;
 i71 = i85 + 108 | 0;
 i73 = i85 + 104 | 0;
 i77 = i85 + 100 | 0;
 i78 = i85 + 88 | 0;
 i2 = i85 + 80 | 0;
 i79 = i85 + 68 | 0;
 i80 = i85 + 64 | 0;
 i81 = i85 + 52 | 0;
 i1 = i85 + 48 | 0;
 i83 = i85;
 if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i6, 0) | 0, 59272) | 0)) ___assert_fail(16292, 16311, 443, 16326);
 i74 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i6, 1) | 0, 0) | 0;
 HEAP32[i5 >> 2] = HEAP32[i74 >> 2];
 if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i5, 0) | 0, 59276) | 0)) ___assert_fail(16337, 16311, 445, 16326);
 i74 = __ZN6cashew3RefixEj(i5, 3) | 0;
 HEAP32[i58 >> 2] = HEAP32[i74 >> 2];
 do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i58, 0) | 0, 0) | 0, 59284) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i58, 0) | 0, 1) | 0, 0) | 0, 59368) | 0 : 0) {
  i74 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i58, 0) | 0, 1) | 0, 1) | 0;
  i74 = __ZN6cashew5Value10getIStringEv(HEAP32[i74 >> 2] | 0) | 0;
  __ZN6cashew7IString3setEPKcb(i3, 49227, 1);
  if ((HEAP32[i74 >> 2] | 0) != (HEAP32[i3 >> 2] | 0) ? (i74 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i58, 0) | 0, 1) | 0, 1) | 0, i74 = __ZN6cashew5Value10getIStringEv(HEAP32[i74 >> 2] | 0) | 0, __ZN6cashew7IString3setEPKcb(i4, 16361, 1), (HEAP32[i74 >> 2] | 0) != (HEAP32[i4 >> 2] | 0)) : 0) break;
  HEAP32[i57 >> 2] = i84;
  i21 = i68 + 4 | 0;
  i22 = i68 + 8 | 0;
  i23 = i68 + 4 | 0;
  i24 = i84 + 108 | 0;
  i25 = i84 + 112 | 0;
  i26 = i84 + 80 | 0;
  i27 = i84 + 60 | 0;
  i28 = i84 + 64 | 0;
  i29 = i41 + 4 | 0;
  i30 = i41 + 5 | 0;
  i31 = i41 + 8 | 0;
  i74 = i84 + 20 | 0;
  i10 = 0;
  i7 = 0;
  i15 = 0;
  i16 = 0;
  i17 = 0;
  i18 = 0;
  i8 = 0;
  i9 = 0;
  i11 = 0;
  i12 = 0;
  i32 = 1;
  i13 = 0;
  i14 = 0;
  L13 : while (1) {
   if (i32 >>> 0 >= (__ZN6cashew5Value4sizeEv(HEAP32[i58 >> 2] | 0) | 0) >>> 0) {
    i13 = 12;
    break;
   }
   i20 = __ZN6cashew3RefixEj(i58, i32) | 0;
   HEAP32[i72 >> 2] = HEAP32[i20 >> 2];
   L16 : do if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i72, 0) | 0, 59296) | 0)) {
    if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i72, 0) | 0, 59276) | 0) {
     i5 = HEAP32[i84 >> 2] | 0;
     HEAP32[i43 >> 2] = HEAP32[i72 >> 2];
     HEAP32[i76 >> 2] = HEAP32[i43 >> 2];
     __ZN4wasm6Module11addFunctionEPNS_8FunctionE(i5, __ZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefE(i84, i76) | 0);
     i5 = i17;
     i4 = i18;
     i3 = i14;
     break;
    }
    if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i72, 0) | 0, 59312) | 0) {
     i3 = __ZN6cashew3RefixEj(i72, 1) | 0;
     HEAP32[i75 >> 2] = HEAP32[i3 >> 2];
     i3 = __ZN6cashew3RefixEj(i75, 1) | 0;
     i3 = HEAP32[i3 >> 2] | 0;
     HEAP32[i82 >> 2] = i3;
     HEAP32[i21 >> 2] = 0;
     HEAP32[i22 >> 2] = 0;
     HEAP32[i68 >> 2] = i23;
     i6 = 0;
     while (1) {
      if (i6 >>> 0 >= (__ZN6cashew5Value4sizeEv(i3) | 0) >>> 0) break;
      i3 = __ZN6cashew3RefixEj(i82, i6) | 0;
      HEAP32[i60 >> 2] = HEAP32[i3 >> 2];
      i3 = __ZN6cashew3RefixEj(i60, 0) | 0;
      i3 = __ZN6cashew5Value10getIStringEv(HEAP32[i3 >> 2] | 0) | 0;
      i3 = HEAP32[i3 >> 2] | 0;
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i60, 1) | 0, 0) | 0, 59292) | 0)) {
       i13 = 104;
       break L13;
      }
      i4 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i60, 1) | 0, 1) | 0;
      i4 = __ZN6cashew5Value10getIStringEv(HEAP32[i4 >> 2] | 0) | 0;
      i4 = HEAP32[i4 >> 2] | 0;
      __ZN6cashew7IString3setEPKcb(i44, 16939, 0);
      i5 = i3;
      do if ((i5 | 0) == (HEAP32[i44 >> 2] | 0)) {
       i20 = HEAP32[i84 >> 2] | 0;
       HEAP32[i45 >> 2] = i4;
       HEAP32[i76 >> 2] = HEAP32[i45 >> 2];
       if (__ZN4wasm6Module13checkFunctionENS_4NameE(i20, i76) | 0) {
        i13 = 107;
        break L13;
       }
      } else {
       if ((i5 | 0) != (HEAP32[14848] | 0)) {
        if ((i5 | 0) == (HEAP32[14846] | 0)) HEAP32[i25 >> 2] = i4;
       } else HEAP32[i24 >> 2] = i4;
       i20 = HEAP32[i84 >> 2] | 0;
       HEAP32[i46 >> 2] = i4;
       HEAP32[i76 >> 2] = HEAP32[i46 >> 2];
       if (!(__ZN4wasm6Module13checkFunctionENS_4NameE(i20, i76) | 0)) {
        i13 = 113;
        break L13;
       }
       HEAP32[i47 >> 2] = i3;
       if (!(__ZNKSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE14__count_uniqueIS3_EEjRKT_(i68, i47) | 0)) {
        i19 = __Znwj(8) | 0;
        HEAP32[i19 >> 2] = i3;
        HEAP32[i19 + 4 >> 2] = i4;
        __ZN4wasm6Module9addExportEPNS_6ExportE(HEAP32[i84 >> 2] | 0, i19);
        HEAP32[i50 >> 2] = i3;
        i20 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ExportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixEOS2_(i68, i50) | 0;
        HEAP32[i20 >> 2] = i19;
        break;
       } else {
        HEAP32[i49 >> 2] = i3;
        i20 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ExportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixEOS2_(i68, i49) | 0;
        HEAP32[(HEAP32[i20 >> 2] | 0) + 4 >> 2] = i4;
        break;
       }
      } while (0);
      i3 = HEAP32[i82 >> 2] | 0;
      i6 = i6 + 1 | 0;
     }
     __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEED2Ev(i68);
     i5 = i17;
     i4 = i18;
     i3 = i14;
    } else {
     i5 = i17;
     i4 = i18;
     i3 = i14;
    }
   } else {
    i20 = i7;
    i19 = 0;
    while (1) {
     i7 = __ZN6cashew3RefixEj(i72, 1) | 0;
     if (i19 >>> 0 >= (__ZN6cashew5Value4sizeEv(HEAP32[i7 >> 2] | 0) | 0) >>> 0) {
      i7 = i20;
      i5 = i17;
      i4 = i18;
      i3 = i14;
      break L16;
     }
     i7 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i72, 1) | 0, i19) | 0;
     HEAP32[i68 >> 2] = HEAP32[i7 >> 2];
     i7 = __ZN6cashew3RefixEj(i68, 0) | 0;
     i7 = __ZN6cashew5Value10getIStringEv(HEAP32[i7 >> 2] | 0) | 0;
     HEAP32[i60 >> 2] = HEAP32[i7 >> 2];
     i7 = __ZN6cashew3RefixEj(i68, 1) | 0;
     HEAP32[i61 >> 2] = HEAP32[i7 >> 2];
     do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 0) | 0, 59348) | 0) {
      i7 = __ZN6cashew3RefixEj(i61, 1) | 0;
      i7 = __ZN6cashew5Value9getNumberEv(HEAP32[i7 >> 2] | 0) | 0;
      if (!(+HEAPF64[i7 >> 3] == 0.0)) {
       i13 = 17;
       break L13;
      }
      HEAP32[i40 >> 2] = HEAP32[i60 >> 2];
      HEAP32[i48 >> 2] = 0;
      HEAP32[i51 >> 2] = 0;
      HEAP32[i82 >> 2] = HEAP32[i40 >> 2];
      HEAP32[i75 >> 2] = HEAP32[i48 >> 2];
      HEAP32[i76 >> 2] = HEAP32[i51 >> 2];
      __ZN4wasm15Asm2WasmBuilder14allocateGlobalEN6cashew7IStringENS_8WasmTypeEbS2_S2_(i84, i82, 1, 0, i75, i76);
      i3 = i20;
      i4 = i15;
      i5 = i16;
      i6 = i17;
      i7 = i18;
     } else {
      if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 0) | 0, 59308) | 0) {
       if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 1) | 0, 59436) | 0)) {
        i13 = 23;
        break L13;
       }
       if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i61, 3) | 0, 0) | 0, 59348) | 0)) {
        i13 = 23;
        break L13;
       }
       i7 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i61, 3) | 0, 1) | 0;
       i7 = __ZN6cashew5Value9getNumberEv(HEAP32[i7 >> 2] | 0) | 0;
       if (!(+HEAPF64[i7 >> 3] == 0.0)) {
        i13 = 23;
        break L13;
       }
       i3 = __ZN6cashew3RefixEj(i61, 2) | 0;
       i3 = HEAP32[i3 >> 2] | 0;
       HEAP32[i52 >> 2] = HEAP32[i60 >> 2];
       HEAP32[i53 >> 2] = i3;
       HEAP32[i75 >> 2] = HEAP32[i52 >> 2];
       HEAP32[i76 >> 2] = HEAP32[i53 >> 2];
       __ZZN4wasm15Asm2WasmBuilder10processAsmEN6cashew3RefEENK3__0clENS1_7IStringES2_NS_8WasmTypeE(i57, i75, i76, 1);
       i3 = i20;
       i4 = i15;
       i5 = i16;
       i6 = i17;
       i7 = i18;
       break;
      }
      if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 0) | 0, 59396) | 0) {
       if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 1) | 0, 59428) | 0)) {
        i13 = 27;
        break L13;
       }
       i7 = __ZN6cashew3RefixEj(i61, 2) | 0;
       HEAP32[i59 >> 2] = HEAP32[i7 >> 2];
       if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i59, 0) | 0, 59348) | 0) {
        i7 = __ZN6cashew3RefixEj(i59, 1) | 0;
        i7 = __ZN6cashew5Value9getNumberEv(HEAP32[i7 >> 2] | 0) | 0;
        if (!(+HEAPF64[i7 >> 3] == 0.0)) {
         i13 = 30;
         break L13;
        }
        HEAP32[i54 >> 2] = HEAP32[i60 >> 2];
        HEAP32[i55 >> 2] = 0;
        HEAP32[i56 >> 2] = 0;
        HEAP32[i82 >> 2] = HEAP32[i54 >> 2];
        HEAP32[i75 >> 2] = HEAP32[i55 >> 2];
        HEAP32[i76 >> 2] = HEAP32[i56 >> 2];
        __ZN4wasm15Asm2WasmBuilder14allocateGlobalEN6cashew7IStringENS_8WasmTypeEbS2_S2_(i84, i82, 4, 0, i75, i76);
       } else {
        HEAP32[i33 >> 2] = HEAP32[i60 >> 2];
        HEAP32[i34 >> 2] = HEAP32[i59 >> 2];
        HEAP32[i75 >> 2] = HEAP32[i33 >> 2];
        HEAP32[i76 >> 2] = HEAP32[i34 >> 2];
        __ZZN4wasm15Asm2WasmBuilder10processAsmEN6cashew3RefEENK3__0clENS1_7IStringES2_NS_8WasmTypeE(i57, i75, i76, 4);
       }
       i3 = i20;
       i4 = i15;
       i5 = i16;
       i6 = i17;
       i7 = i18;
       break;
      }
      if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 0) | 0, 59936) | 0) {
       if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i61, 1) | 0, 0) | 0, 59292) | 0)) {
        i13 = 39;
        break L13;
       }
       if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i61, 1) | 0, 1) | 0, i26) | 0)) {
        i13 = 39;
        break L13;
       }
       if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i61, 2) | 0, 0) | 0, 0) | 0, 59348) | 0)) {
        i13 = 39;
        break L13;
       }
       i7 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i61, 2) | 0, 0) | 0, 1) | 0;
       i7 = __ZN6cashew5Value9getNumberEv(HEAP32[i7 >> 2] | 0) | 0;
       if (!(+HEAPF64[i7 >> 3] == 0.0)) {
        i13 = 39;
        break L13;
       }
       HEAP32[i35 >> 2] = HEAP32[i60 >> 2];
       HEAP32[i36 >> 2] = 0;
       HEAP32[i37 >> 2] = 0;
       HEAP32[i82 >> 2] = HEAP32[i35 >> 2];
       HEAP32[i75 >> 2] = HEAP32[i36 >> 2];
       HEAP32[i76 >> 2] = HEAP32[i37 >> 2];
       __ZN4wasm15Asm2WasmBuilder14allocateGlobalEN6cashew7IStringENS_8WasmTypeEbS2_S2_(i84, i82, 3, 0, i75, i76);
       i3 = i20;
       i4 = i15;
       i5 = i16;
       i6 = i17;
       i7 = i18;
       break;
      }
      if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 0) | 0, 59588) | 0) {
       do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i61, 1) | 0, 0) | 0, 59292) | 0) {
        i7 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i61, 1) | 0, 1) | 0;
        i7 = __ZN6cashew5Value10getIStringEv(HEAP32[i7 >> 2] | 0) | 0;
        i7 = HEAP32[i7 >> 2] | 0;
        i3 = __ZN6cashew3RefixEj(i61, 2) | 0;
        i3 = __ZN6cashew5Value10getIStringEv(HEAP32[i3 >> 2] | 0) | 0;
        if ((i7 | 0) != (HEAP32[14941] | 0)) {
         i3 = i20;
         i4 = i15;
         i5 = i16;
         i6 = i17;
         i7 = i18;
         break;
        }
        i3 = HEAP32[i3 >> 2] | 0;
        if ((i3 | 0) == (HEAP32[14947] | 0)) {
         i3 = i20;
         i4 = i15;
         i5 = i16;
         i6 = HEAP32[i60 >> 2] | 0;
         i7 = i18;
         break;
        }
        if ((i3 | 0) == (HEAP32[14948] | 0)) {
         i3 = i20;
         i4 = HEAP32[i60 >> 2] | 0;
         i5 = i16;
         i6 = i17;
         i7 = i18;
         break;
        }
        if ((i3 | 0) == (HEAP32[14949] | 0)) {
         i3 = i20;
         i4 = i15;
         i5 = HEAP32[i60 >> 2] | 0;
         i6 = i17;
         i7 = i18;
         break;
        }
        if ((i3 | 0) == (HEAP32[14950] | 0)) {
         i3 = i20;
         i4 = i15;
         i5 = i16;
         i6 = i17;
         i7 = i18;
         i9 = HEAP32[i60 >> 2] | 0;
         break;
        }
        if ((i3 | 0) == (HEAP32[14951] | 0)) {
         i3 = i20;
         i4 = i15;
         i5 = i16;
         i6 = i17;
         i7 = HEAP32[i60 >> 2] | 0;
         break;
        }
        if ((i3 | 0) == (HEAP32[14952] | 0)) {
         i3 = i20;
         i4 = i15;
         i5 = i16;
         i6 = i17;
         i7 = i18;
         i8 = HEAP32[i60 >> 2] | 0;
         break;
        }
        if ((i3 | 0) == (HEAP32[14953] | 0)) {
         i10 = HEAP32[i60 >> 2] | 0;
         i3 = i20;
         i4 = i15;
         i5 = i16;
         i6 = i17;
         i7 = i18;
         break;
        } else {
         i3 = (i3 | 0) == (HEAP32[14954] | 0) ? HEAP32[i60 >> 2] | 0 : i20;
         i4 = i15;
         i5 = i16;
         i6 = i17;
         i7 = i18;
         break;
        }
       } else {
        i3 = i20;
        i4 = i15;
        i5 = i16;
        i6 = i17;
        i7 = i18;
       } while (0);
       HEAP32[i38 >> 2] = HEAP32[i60 >> 2];
       HEAP32[i39 >> 2] = HEAP32[i61 >> 2];
       HEAP32[i75 >> 2] = HEAP32[i38 >> 2];
       HEAP32[i76 >> 2] = HEAP32[i39 >> 2];
       __ZZN4wasm15Asm2WasmBuilder10processAsmEN6cashew3RefEENK3__0clENS1_7IStringES2_NS_8WasmTypeE(i57, i75, i76, 0);
       break;
      }
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 0) | 0, 59596) | 0)) {
       if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 0) | 0, 59600) | 0)) {
        i13 = 95;
        break L13;
       }
       i7 = HEAP32[i84 >> 2] | 0;
       i7 = (HEAP32[i7 + 52 >> 2] | 0) - (HEAP32[i7 + 48 >> 2] | 0) >> 2;
       i3 = __ZNSt3__23mapIN6cashew7IStringEiNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_iEEEEEixERS7_(i74, i60) | 0;
       HEAP32[i3 >> 2] = i7;
       i3 = __ZN6cashew3RefixEj(i61, 1) | 0;
       i3 = HEAP32[i3 >> 2] | 0;
       HEAP32[i76 >> 2] = i3;
       i7 = 0;
       while (1) {
        if (i7 >>> 0 >= (__ZN6cashew5Value4sizeEv(i3) | 0) >>> 0) break;
        i3 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i76, i7) | 0, 1) | 0;
        i3 = __ZN6cashew5Value10getIStringEv(HEAP32[i3 >> 2] | 0) | 0;
        i3 = HEAP32[i3 >> 2] | 0;
        i4 = HEAP32[i84 >> 2] | 0;
        HEAP32[i42 >> 2] = i3;
        i5 = i4 + 52 | 0;
        i6 = HEAP32[i5 >> 2] | 0;
        if (i6 >>> 0 < (HEAP32[i4 + 56 >> 2] | 0) >>> 0) {
         HEAP32[i6 >> 2] = i3;
         HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
        } else __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i4 + 48 | 0, i42);
        i3 = HEAP32[i76 >> 2] | 0;
        i7 = i7 + 1 | 0;
       }
       i3 = i20;
       i4 = i15;
       i5 = i16;
       i6 = i17;
       i7 = i18;
       break;
      }
      i14 = __ZN6cashew3RefixEj(i61, 1) | 0;
      HEAP32[i61 >> 2] = HEAP32[i14 >> 2];
      if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i61, 0) | 0, 59936) | 0)) {
       i13 = 62;
       break L13;
      }
      i14 = __ZN6cashew3RefixEj(i61, 1) | 0;
      HEAP32[i75 >> 2] = HEAP32[i14 >> 2];
      do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i75, 0) | 0, 59588) | 0) {
       i4 = __ZN6cashew3RefixEj(i75, 2) | 0;
       i4 = __ZN6cashew5Value10getIStringEv(HEAP32[i4 >> 2] | 0) | 0;
       i4 = HEAP32[i4 >> 2] | 0;
       i3 = i4;
       if ((i3 | 0) == (HEAP32[14947] | 0)) {
        i11 = 0;
        i12 = 1;
        i13 = 1;
        i14 = 1;
        break;
       }
       if ((i3 | 0) == (HEAP32[14948] | 0)) {
        i11 = 0;
        i12 = 2;
        i13 = 1;
        i14 = 1;
        break;
       }
       if ((i3 | 0) == (HEAP32[14949] | 0)) {
        i11 = 0;
        i12 = 4;
        i13 = 1;
        i14 = 1;
        break;
       }
       if ((i3 | 0) == (HEAP32[14950] | 0)) {
        i11 = 0;
        i12 = 1;
        i13 = 1;
        i14 = 0;
        break;
       }
       if ((i3 | 0) == (HEAP32[14951] | 0)) {
        i11 = 0;
        i12 = 2;
        i13 = 1;
        i14 = 0;
        break;
       }
       if ((i3 | 0) == (HEAP32[14952] | 0)) {
        i11 = 0;
        i12 = 4;
        i13 = 1;
        i14 = 0;
        break;
       }
       if ((i3 | 0) == (HEAP32[14953] | 0)) {
        i11 = 2;
        i12 = 4;
        i13 = 0;
        i14 = 1;
        break;
       }
       if ((i3 | 0) == (HEAP32[14954] | 0)) {
        i11 = 1;
        i12 = 8;
        i13 = 0;
        i14 = 1;
       } else {
        i13 = 72;
        break L13;
       }
      } else {
       if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i75, 0) | 0, 59292) | 0)) {
        i13 = 74;
        break L13;
       }
       i4 = __ZN6cashew3RefixEj(i75, 1) | 0;
       i4 = __ZN6cashew5Value10getIStringEv(HEAP32[i4 >> 2] | 0) | 0;
       i4 = HEAP32[i4 >> 2] | 0;
       i3 = i4;
       if ((i3 | 0) == (i17 | 0)) {
        i11 = 0;
        i12 = 1;
        i13 = 1;
        i14 = 1;
        break;
       }
       if ((i3 | 0) == (i15 | 0)) {
        i11 = 0;
        i12 = 2;
        i13 = 1;
        i14 = 1;
        break;
       }
       if ((i3 | 0) == (i16 | 0)) {
        i11 = 0;
        i12 = 4;
        i13 = 1;
        i14 = 1;
        break;
       }
       if ((i3 | 0) == (i9 | 0)) {
        i11 = 0;
        i12 = 1;
        i13 = 1;
        i14 = 0;
        break;
       }
       if ((i3 | 0) == (i18 | 0)) {
        i11 = 0;
        i12 = 2;
        i13 = 1;
        i14 = 0;
        break;
       }
       if ((i3 | 0) == (i8 | 0)) {
        i11 = 0;
        i12 = 4;
        i13 = 1;
        i14 = 0;
        break;
       }
       if ((i3 | 0) == (i10 | 0)) {
        i11 = 2;
        i12 = 4;
        i13 = 0;
        i14 = 1;
        break;
       }
       if ((i3 | 0) == (i20 | 0)) {
        i11 = 1;
        i12 = 8;
        i13 = 0;
        i14 = 1;
       } else {
        i13 = 83;
        break L13;
       }
      } while (0);
      if ((__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i27, i60) | 0) != (i28 | 0)) {
       i13 = 85;
       break L13;
      }
      HEAP32[i41 >> 2] = i12;
      HEAP8[i29 >> 0] = i13 & 1;
      HEAP8[i30 >> 0] = i14 & 1;
      HEAP32[i31 >> 2] = i11;
      __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS3_JRS3_S6_EEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i76, i27, i60, i60, i41);
      i3 = i20;
      i4 = i15;
      i5 = i16;
      i6 = i17;
      i7 = i18;
     } while (0);
     i20 = i3;
     i15 = i4;
     i16 = i5;
     i17 = i6;
     i18 = i7;
     i19 = i19 + 1 | 0;
    }
   } while (0);
   i17 = i5;
   i18 = i4;
   i32 = i32 + 1 | 0;
   i14 = i3;
  }
  switch (i13 | 0) {
  case 12:
   {
    HEAP32[i82 >> 2] = 0;
    i6 = i82 + 4 | 0;
    HEAP32[i6 >> 2] = 0;
    HEAP32[i82 + 8 >> 2] = 0;
    i9 = HEAP32[i84 >> 2] | 0;
    i7 = HEAP32[i9 + 16 >> 2] | 0;
    i12 = i84 + 116 | 0;
    i8 = i84 + 120 | 0;
    i5 = i82 + 8 | 0;
    i9 = HEAP32[i9 + 12 >> 2] | 0;
    while (1) {
     if ((i9 | 0) == (i7 | 0)) break;
     i4 = HEAP32[HEAP32[i9 >> 2] >> 2] | 0;
     HEAP32[i72 >> 2] = i4;
     i68 = (__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE4findIS3_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_(i12, i72) | 0) == (i8 | 0);
     i3 = HEAP32[i9 >> 2] | 0;
     do if (i68) {
      if ((HEAP32[i3 + 4 >> 2] | 0) != (HEAP32[14960] | 0)) {
       i3 = HEAP32[i6 >> 2] | 0;
       if ((i3 | 0) == (HEAP32[i5 >> 2] | 0)) {
        __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i82, i72);
        break;
       } else {
        HEAP32[i3 >> 2] = i4;
        HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + 4;
        break;
       }
      }
     } else {
      HEAP32[i69 >> 2] = HEAP32[i3 + 4 >> 2];
      HEAP32[i70 >> 2] = HEAP32[(HEAP32[i9 >> 2] | 0) + 8 >> 2];
      HEAP32[i75 >> 2] = HEAP32[i69 >> 2];
      HEAP32[i76 >> 2] = HEAP32[i70 >> 2];
      i3 = __ZN4wasm15Asm2WasmBuilder22getBuiltinFunctionTypeENS_4NameES1_P11ArenaVectorIPNS_10ExpressionEE(i84, i75, i76, 0) | 0;
      if (!i3) {
       i68 = __ZNSt3__23mapIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS5_EEEENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S8_EEEEEixERSD_(i12, i72) | 0;
       __ZN4wasm6getSigEPNS_12FunctionTypeE(i71, HEAP32[i68 >> 2] | 0);
       i68 = __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i71, HEAP32[i84 >> 2] | 0) | 0;
       HEAP32[(HEAP32[i9 >> 2] | 0) + 12 >> 2] = i68;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i71);
       break;
      } else {
       HEAP32[(HEAP32[i9 >> 2] | 0) + 12 >> 2] = i3;
       break;
      }
     } while (0);
     i9 = i9 + 4 | 0;
    }
    i3 = HEAP32[i6 >> 2] | 0;
    i4 = HEAP32[i82 >> 2] | 0;
    while (1) {
     if ((i4 | 0) == (i3 | 0)) break;
     i72 = HEAP32[i84 >> 2] | 0;
     HEAP32[i73 >> 2] = HEAP32[i4 >> 2];
     HEAP32[i76 >> 2] = HEAP32[i73 >> 2];
     __ZN4wasm6Module12removeImportENS_4NameE(i72, i76);
     i4 = i4 + 4 | 0;
    }
    i3 = i84 + 132 | 0;
    i11 = i84 + 4 | 0;
    i8 = HEAP32[i84 + 128 >> 2] | 0;
    while (1) {
     if ((i8 | 0) == (i3 | 0)) break;
     HEAP32[i76 >> 2] = HEAP32[i8 + 16 >> 2];
     i6 = __ZNSt3__23mapIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS5_EEEENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S8_EEEEEixERSD_(i12, i76) | 0;
     i6 = HEAP32[i6 >> 2] | 0;
     i4 = HEAP32[i8 + 24 >> 2] | 0;
     i5 = i6 + 8 | 0;
     i6 = i6 + 12 | 0;
     i9 = HEAP32[i8 + 20 >> 2] | 0;
     while (1) {
      if ((i9 | 0) == (i4 | 0)) break;
      i10 = HEAP32[i9 >> 2] | 0;
      i7 = i10 + 8 | 0;
      i10 = HEAP32[i10 + 16 >> 2] | 0;
      while (1) {
       if (i10 >>> 0 >= (HEAP32[i6 >> 2] | 0) - (HEAP32[i5 >> 2] | 0) >> 2 >>> 0) break;
       i73 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i11 >> 2] | 0) | 0;
       i72 = HEAP32[(HEAP32[i5 >> 2] | 0) + (i10 << 2) >> 2] | 0;
       HEAP32[i73 + 8 >> 2] = i72;
       HEAP32[i73 + 4 >> 2] = i72;
       __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i7, i73);
       i10 = i10 + 1 | 0;
      }
      i9 = i9 + 4 | 0;
     }
     i8 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i8) | 0;
    }
    i3 = i84 + 36 | 0;
    i4 = i84 + 24 | 0;
    i5 = i84 + 8 | 0;
    i7 = HEAP32[i84 + 32 >> 2] | 0;
    while (1) {
     if ((i7 | 0) == (i3 | 0)) break;
     i6 = HEAP32[i7 + 16 >> 2] | 0;
     HEAP32[i76 >> 2] = HEAP32[i7 + 20 >> 2];
     if ((__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_(i74, i76) | 0) == (i4 | 0)) {
      i13 = 145;
      break;
     }
     i72 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i11 >> 2] | 0) | 0;
     HEAP32[i72 + 8 >> 2] = 0;
     i73 = i6 + 28 | 0;
     HEAP32[i72 + 12 >> 2] = HEAP32[i73 >> 2];
     i70 = __ZNSt3__23mapIN6cashew7IStringEiNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_iEEEEEixERS7_(i74, i76) | 0;
     i70 = HEAP32[i70 >> 2] | 0;
     i71 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i5 >> 2] | 0) | 0;
     HEAP32[i71 + 8 >> 2] = 1;
     HEAP32[i71 + 16 >> 2] = i70;
     HEAP32[i71 + 4 >> 2] = 1;
     HEAP32[i72 + 16 >> 2] = i71;
     HEAP32[i72 + 4 >> 2] = 1;
     HEAP32[i73 >> 2] = i72;
     i7 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i7) | 0;
    }
    if ((i13 | 0) == 145) ___assert_fail(17019, 16311, 736, 16326);
    if (HEAP8[i84 + 44 >> 0] | 0) {
     i6 = HEAP32[i84 >> 2] | 0;
     i3 = i6 + 88 | 0;
     HEAP32[i75 >> 2] = i3;
     HEAP32[i77 >> 2] = HEAP32[14970];
     HEAP32[i2 >> 2] = HEAP32[14971];
     HEAP32[i2 + 4 >> 2] = 1;
     HEAP32[i78 >> 2] = 0;
     i4 = i78 + 4 | 0;
     HEAP32[i4 >> 2] = 0;
     HEAP32[i78 + 8 >> 2] = 0;
     __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE8allocateEj(i78, 1);
     i5 = i2 + 8 | 0;
     while (1) {
      if ((i2 | 0) == (i5 | 0)) break;
      i72 = i2;
      i73 = HEAP32[i72 + 4 >> 2] | 0;
      i74 = HEAP32[i4 >> 2] | 0;
      HEAP32[i74 >> 2] = HEAP32[i72 >> 2];
      HEAP32[i74 + 4 >> 2] = i73;
      HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 8;
      i2 = i2 + 8 | 0;
     }
     HEAP32[i79 >> 2] = 0;
     HEAP32[i79 + 4 >> 2] = 0;
     HEAP32[i79 + 8 >> 2] = 0;
     HEAP32[i80 >> 2] = 0;
     i2 = __ZN10MixedArena5allocIN4wasm8GetLocalEEEPT_v(i3) | 0;
     HEAP32[i2 + 8 >> 2] = 0;
     HEAP32[i2 + 4 >> 2] = 1;
     HEAP32[i1 >> 2] = i2;
     HEAP32[i81 >> 2] = 0;
     i2 = i81 + 4 | 0;
     HEAP32[i2 >> 2] = 0;
     HEAP32[i81 + 8 >> 2] = 0;
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE8allocateEj(i81, 1);
     i3 = i1 + 4 | 0;
     while (1) {
      if ((i1 | 0) == (i3 | 0)) break;
      HEAP32[HEAP32[i2 >> 2] >> 2] = HEAP32[i1 >> 2];
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
      i1 = i1 + 4 | 0;
     }
     HEAP32[i76 >> 2] = HEAP32[i80 >> 2];
     i80 = __ZN4wasm7Builder8makeHostENS_6HostOpENS_4NameEONSt3__26vectorIPNS_10ExpressionENS3_9allocatorIS6_EEEE(i75, 2, i76, i81) | 0;
     HEAP32[i76 >> 2] = HEAP32[i77 >> 2];
     __ZN4wasm6Module11addFunctionEPNS_8FunctionE(i6, __ZN4wasm7Builder12makeFunctionENS_4NameEONSt3__26vectorINS_8NameTypeENS2_9allocatorIS4_EEEENS_8WasmTypeES8_PNS_10ExpressionE(i75, i76, i78, 0, i79, i80) | 0);
     __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i81);
     __ZNSt3__213__vector_baseIN4wasm8NameTypeENS_9allocatorIS2_EEED2Ev(i79);
     __ZNSt3__213__vector_baseIN4wasm8NameTypeENS_9allocatorIS2_EEED2Ev(i78);
     i81 = __Znwj(8) | 0;
     i80 = HEAP32[14970] | 0;
     HEAP32[i81 + 4 >> 2] = i80;
     HEAP32[i81 >> 2] = i80;
     __ZN4wasm6Module9addExportEPNS_6ExportE(HEAP32[i84 >> 2] | 0, i81);
    }
    HEAP32[(HEAP32[i84 >> 2] | 0) + 80 >> 2] = HEAP32[14977];
    i1 = i83;
    i2 = i1 + 44 | 0;
    do {
     HEAP32[i1 >> 2] = 0;
     i1 = i1 + 4 | 0;
    } while ((i1 | 0) < (i2 | 0));
    HEAP32[i83 >> 2] = 4272;
    HEAP32[i83 + 36 >> 2] = 0;
    HEAP32[i83 + 40 >> 2] = 0;
    HEAP32[i83 + 32 >> 2] = i83 + 36;
    HEAP32[i83 + 44 >> 2] = 5;
    if (__ZN4wasm13WasmValidator8validateERNS_6ModuleE(i83, HEAP32[i84 >> 2] | 0) | 0) {
     __ZN4wasm13WasmValidatorD2Ev(i83);
     __ZNSt3__213__vector_baseIN6cashew7IStringENS_9allocatorIS2_EEED2Ev(i82);
     STACKTOP = i85;
     return;
    } else ___assert_fail(17084, 16311, 866, 16326);
    break;
   }
  case 17:
   {
    ___assert_fail(16529, 16311, 538, 16326);
    break;
   }
  case 23:
   {
    ___assert_fail(16556, 16311, 542, 16326);
    break;
   }
  case 27:
   {
    ___assert_fail(16626, 16311, 547, 16326);
    break;
   }
  case 30:
   {
    ___assert_fail(16643, 16311, 551, 16326);
    break;
   }
  case 39:
   {
    ___assert_fail(16671, 16311, 558, 16326);
    break;
   }
  case 62:
   {
    ___assert_fail(16782, 16311, 590, 16326);
    break;
   }
  case 72:
   {
    HEAP32[i62 >> 2] = 0;
    HEAP32[i62 + 4 >> 2] = 0;
    HEAP32[i62 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i62, 16799, 19);
    HEAP32[i63 >> 2] = i4;
    HEAP32[i76 >> 2] = HEAP32[i63 >> 2];
    __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew7IStringE(i62, i76);
    break;
   }
  case 74:
   {
    ___assert_fail(16819, 16311, 617, 16326);
    break;
   }
  case 83:
   {
    HEAP32[i64 >> 2] = 0;
    HEAP32[i64 + 4 >> 2] = 0;
    HEAP32[i64 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i64, 16842, 25);
    HEAP32[i65 >> 2] = i4;
    HEAP32[i76 >> 2] = HEAP32[i65 >> 2];
    __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew7IStringE(i64, i76);
    break;
   }
  case 85:
   {
    ___assert_fail(16868, 16311, 639, 16326);
    break;
   }
  case 95:
   {
    HEAP32[i66 >> 2] = 0;
    HEAP32[i66 + 4 >> 2] = 0;
    HEAP32[i66 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i66, 16900, 19);
    HEAP32[i67 >> 2] = HEAP32[i68 >> 2];
    HEAP32[i76 >> 2] = HEAP32[i67 >> 2];
    __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew3RefE(i66, i76);
    break;
   }
  case 104:
   {
    ___assert_fail(16920, 16311, 667, 16326);
    break;
   }
  case 107:
   {
    ___assert_fail(16966, 16311, 671, 16326);
    break;
   }
  case 113:
   {
    ___assert_fail(16993, 16311, 678, 16326);
    break;
   }
  }
 } while (0);
 ___assert_fail(16372, 16311, 447, 16326);
}

function _malloc(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0;
 i39 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i14 = i39;
 do if (i1 >>> 0 < 245) {
  i15 = i1 >>> 0 < 11 ? 16 : i1 + 11 & -8;
  i1 = i15 >>> 3;
  i9 = HEAP32[15034] | 0;
  i2 = i9 >>> i1;
  if (i2 & 3 | 0) {
   i2 = (i2 & 1 ^ 1) + i1 | 0;
   i3 = 60176 + (i2 << 1 << 2) | 0;
   i4 = i3 + 8 | 0;
   i5 = HEAP32[i4 >> 2] | 0;
   i6 = i5 + 8 | 0;
   i7 = HEAP32[i6 >> 2] | 0;
   do if ((i3 | 0) != (i7 | 0)) {
    if (i7 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
    i1 = i7 + 12 | 0;
    if ((HEAP32[i1 >> 2] | 0) == (i5 | 0)) {
     HEAP32[i1 >> 2] = i3;
     HEAP32[i4 >> 2] = i7;
     break;
    } else _abort();
   } else HEAP32[15034] = i9 & ~(1 << i2); while (0);
   i38 = i2 << 3;
   HEAP32[i5 + 4 >> 2] = i38 | 3;
   i38 = i5 + i38 + 4 | 0;
   HEAP32[i38 >> 2] = HEAP32[i38 >> 2] | 1;
   i38 = i6;
   STACKTOP = i39;
   return i38 | 0;
  }
  i7 = HEAP32[15036] | 0;
  if (i15 >>> 0 > i7 >>> 0) {
   if (i2 | 0) {
    i3 = 2 << i1;
    i3 = i2 << i1 & (i3 | 0 - i3);
    i3 = (i3 & 0 - i3) + -1 | 0;
    i8 = i3 >>> 12 & 16;
    i3 = i3 >>> i8;
    i5 = i3 >>> 5 & 8;
    i3 = i3 >>> i5;
    i6 = i3 >>> 2 & 4;
    i3 = i3 >>> i6;
    i4 = i3 >>> 1 & 2;
    i3 = i3 >>> i4;
    i2 = i3 >>> 1 & 1;
    i2 = (i5 | i8 | i6 | i4 | i2) + (i3 >>> i2) | 0;
    i3 = 60176 + (i2 << 1 << 2) | 0;
    i4 = i3 + 8 | 0;
    i6 = HEAP32[i4 >> 2] | 0;
    i8 = i6 + 8 | 0;
    i5 = HEAP32[i8 >> 2] | 0;
    do if ((i3 | 0) != (i5 | 0)) {
     if (i5 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
     i1 = i5 + 12 | 0;
     if ((HEAP32[i1 >> 2] | 0) == (i6 | 0)) {
      HEAP32[i1 >> 2] = i3;
      HEAP32[i4 >> 2] = i5;
      i10 = HEAP32[15036] | 0;
      break;
     } else _abort();
    } else {
     HEAP32[15034] = i9 & ~(1 << i2);
     i10 = i7;
    } while (0);
    i7 = (i2 << 3) - i15 | 0;
    HEAP32[i6 + 4 >> 2] = i15 | 3;
    i4 = i6 + i15 | 0;
    HEAP32[i4 + 4 >> 2] = i7 | 1;
    HEAP32[i4 + i7 >> 2] = i7;
    if (i10 | 0) {
     i5 = HEAP32[15039] | 0;
     i2 = i10 >>> 3;
     i3 = 60176 + (i2 << 1 << 2) | 0;
     i1 = HEAP32[15034] | 0;
     i2 = 1 << i2;
     if (i1 & i2) {
      i1 = i3 + 8 | 0;
      i2 = HEAP32[i1 >> 2] | 0;
      if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
       i11 = i1;
       i12 = i2;
      }
     } else {
      HEAP32[15034] = i1 | i2;
      i11 = i3 + 8 | 0;
      i12 = i3;
     }
     HEAP32[i11 >> 2] = i5;
     HEAP32[i12 + 12 >> 2] = i5;
     HEAP32[i5 + 8 >> 2] = i12;
     HEAP32[i5 + 12 >> 2] = i3;
    }
    HEAP32[15036] = i7;
    HEAP32[15039] = i4;
    i38 = i8;
    STACKTOP = i39;
    return i38 | 0;
   }
   i1 = HEAP32[15035] | 0;
   if (i1) {
    i3 = (i1 & 0 - i1) + -1 | 0;
    i37 = i3 >>> 12 & 16;
    i3 = i3 >>> i37;
    i36 = i3 >>> 5 & 8;
    i3 = i3 >>> i36;
    i38 = i3 >>> 2 & 4;
    i3 = i3 >>> i38;
    i2 = i3 >>> 1 & 2;
    i3 = i3 >>> i2;
    i4 = i3 >>> 1 & 1;
    i4 = HEAP32[60440 + ((i36 | i37 | i38 | i2 | i4) + (i3 >>> i4) << 2) >> 2] | 0;
    i3 = (HEAP32[i4 + 4 >> 2] & -8) - i15 | 0;
    i2 = i4;
    while (1) {
     i1 = HEAP32[i2 + 16 >> 2] | 0;
     if (!i1) {
      i1 = HEAP32[i2 + 20 >> 2] | 0;
      if (!i1) {
       i9 = i4;
       break;
      }
     }
     i2 = (HEAP32[i1 + 4 >> 2] & -8) - i15 | 0;
     i38 = i2 >>> 0 < i3 >>> 0;
     i3 = i38 ? i2 : i3;
     i2 = i1;
     i4 = i38 ? i1 : i4;
    }
    i6 = HEAP32[15038] | 0;
    if (i9 >>> 0 < i6 >>> 0) _abort();
    i8 = i9 + i15 | 0;
    if (i9 >>> 0 >= i8 >>> 0) _abort();
    i7 = HEAP32[i9 + 24 >> 2] | 0;
    i4 = HEAP32[i9 + 12 >> 2] | 0;
    do if ((i4 | 0) == (i9 | 0)) {
     i2 = i9 + 20 | 0;
     i1 = HEAP32[i2 >> 2] | 0;
     if (!i1) {
      i2 = i9 + 16 | 0;
      i1 = HEAP32[i2 >> 2] | 0;
      if (!i1) {
       i13 = 0;
       break;
      }
     }
     while (1) {
      i4 = i1 + 20 | 0;
      i5 = HEAP32[i4 >> 2] | 0;
      if (i5 | 0) {
       i1 = i5;
       i2 = i4;
       continue;
      }
      i4 = i1 + 16 | 0;
      i5 = HEAP32[i4 >> 2] | 0;
      if (!i5) break; else {
       i1 = i5;
       i2 = i4;
      }
     }
     if (i2 >>> 0 < i6 >>> 0) _abort(); else {
      HEAP32[i2 >> 2] = 0;
      i13 = i1;
      break;
     }
    } else {
     i5 = HEAP32[i9 + 8 >> 2] | 0;
     if (i5 >>> 0 < i6 >>> 0) _abort();
     i1 = i5 + 12 | 0;
     if ((HEAP32[i1 >> 2] | 0) != (i9 | 0)) _abort();
     i2 = i4 + 8 | 0;
     if ((HEAP32[i2 >> 2] | 0) == (i9 | 0)) {
      HEAP32[i1 >> 2] = i4;
      HEAP32[i2 >> 2] = i5;
      i13 = i4;
      break;
     } else _abort();
    } while (0);
    do if (i7 | 0) {
     i1 = HEAP32[i9 + 28 >> 2] | 0;
     i2 = 60440 + (i1 << 2) | 0;
     if ((i9 | 0) == (HEAP32[i2 >> 2] | 0)) {
      HEAP32[i2 >> 2] = i13;
      if (!i13) {
       HEAP32[15035] = HEAP32[15035] & ~(1 << i1);
       break;
      }
     } else {
      if (i7 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
      i1 = i7 + 16 | 0;
      if ((HEAP32[i1 >> 2] | 0) == (i9 | 0)) HEAP32[i1 >> 2] = i13; else HEAP32[i7 + 20 >> 2] = i13;
      if (!i13) break;
     }
     i2 = HEAP32[15038] | 0;
     if (i13 >>> 0 < i2 >>> 0) _abort();
     HEAP32[i13 + 24 >> 2] = i7;
     i1 = HEAP32[i9 + 16 >> 2] | 0;
     do if (i1 | 0) if (i1 >>> 0 < i2 >>> 0) _abort(); else {
      HEAP32[i13 + 16 >> 2] = i1;
      HEAP32[i1 + 24 >> 2] = i13;
      break;
     } while (0);
     i1 = HEAP32[i9 + 20 >> 2] | 0;
     if (i1 | 0) if (i1 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
      HEAP32[i13 + 20 >> 2] = i1;
      HEAP32[i1 + 24 >> 2] = i13;
      break;
     }
    } while (0);
    if (i3 >>> 0 < 16) {
     i38 = i3 + i15 | 0;
     HEAP32[i9 + 4 >> 2] = i38 | 3;
     i38 = i9 + i38 + 4 | 0;
     HEAP32[i38 >> 2] = HEAP32[i38 >> 2] | 1;
    } else {
     HEAP32[i9 + 4 >> 2] = i15 | 3;
     HEAP32[i8 + 4 >> 2] = i3 | 1;
     HEAP32[i8 + i3 >> 2] = i3;
     i1 = HEAP32[15036] | 0;
     if (i1 | 0) {
      i5 = HEAP32[15039] | 0;
      i2 = i1 >>> 3;
      i4 = 60176 + (i2 << 1 << 2) | 0;
      i1 = HEAP32[15034] | 0;
      i2 = 1 << i2;
      if (i1 & i2) {
       i1 = i4 + 8 | 0;
       i2 = HEAP32[i1 >> 2] | 0;
       if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
        i16 = i1;
        i17 = i2;
       }
      } else {
       HEAP32[15034] = i1 | i2;
       i16 = i4 + 8 | 0;
       i17 = i4;
      }
      HEAP32[i16 >> 2] = i5;
      HEAP32[i17 + 12 >> 2] = i5;
      HEAP32[i5 + 8 >> 2] = i17;
      HEAP32[i5 + 12 >> 2] = i4;
     }
     HEAP32[15036] = i3;
     HEAP32[15039] = i8;
    }
    i38 = i9 + 8 | 0;
    STACKTOP = i39;
    return i38 | 0;
   }
  }
 } else if (i1 >>> 0 <= 4294967231) {
  i1 = i1 + 11 | 0;
  i15 = i1 & -8;
  i9 = HEAP32[15035] | 0;
  if (i9) {
   i3 = 0 - i15 | 0;
   i1 = i1 >>> 8;
   if (i1) if (i15 >>> 0 > 16777215) i8 = 31; else {
    i17 = (i1 + 1048320 | 0) >>> 16 & 8;
    i31 = i1 << i17;
    i16 = (i31 + 520192 | 0) >>> 16 & 4;
    i31 = i31 << i16;
    i8 = (i31 + 245760 | 0) >>> 16 & 2;
    i8 = 14 - (i16 | i17 | i8) + (i31 << i8 >>> 15) | 0;
    i8 = i15 >>> (i8 + 7 | 0) & 1 | i8 << 1;
   } else i8 = 0;
   i2 = HEAP32[60440 + (i8 << 2) >> 2] | 0;
   L123 : do if (!i2) {
    i1 = 0;
    i2 = 0;
    i31 = 86;
   } else {
    i5 = i3;
    i1 = 0;
    i6 = i15 << ((i8 | 0) == 31 ? 0 : 25 - (i8 >>> 1) | 0);
    i7 = i2;
    i2 = 0;
    while (1) {
     i4 = HEAP32[i7 + 4 >> 2] & -8;
     i3 = i4 - i15 | 0;
     if (i3 >>> 0 < i5 >>> 0) if ((i4 | 0) == (i15 | 0)) {
      i1 = i7;
      i2 = i7;
      i31 = 90;
      break L123;
     } else i2 = i7; else i3 = i5;
     i4 = HEAP32[i7 + 20 >> 2] | 0;
     i7 = HEAP32[i7 + 16 + (i6 >>> 31 << 2) >> 2] | 0;
     i1 = (i4 | 0) == 0 | (i4 | 0) == (i7 | 0) ? i1 : i4;
     i4 = (i7 | 0) == 0;
     if (i4) {
      i31 = 86;
      break;
     } else {
      i5 = i3;
      i6 = i6 << (i4 & 1 ^ 1);
     }
    }
   } while (0);
   if ((i31 | 0) == 86) {
    if ((i1 | 0) == 0 & (i2 | 0) == 0) {
     i1 = 2 << i8;
     i1 = i9 & (i1 | 0 - i1);
     if (!i1) break;
     i17 = (i1 & 0 - i1) + -1 | 0;
     i12 = i17 >>> 12 & 16;
     i17 = i17 >>> i12;
     i11 = i17 >>> 5 & 8;
     i17 = i17 >>> i11;
     i13 = i17 >>> 2 & 4;
     i17 = i17 >>> i13;
     i16 = i17 >>> 1 & 2;
     i17 = i17 >>> i16;
     i1 = i17 >>> 1 & 1;
     i1 = HEAP32[60440 + ((i11 | i12 | i13 | i16 | i1) + (i17 >>> i1) << 2) >> 2] | 0;
    }
    if (!i1) {
     i8 = i3;
     i9 = i2;
    } else i31 = 90;
   }
   if ((i31 | 0) == 90) while (1) {
    i31 = 0;
    i17 = (HEAP32[i1 + 4 >> 2] & -8) - i15 | 0;
    i4 = i17 >>> 0 < i3 >>> 0;
    i3 = i4 ? i17 : i3;
    i2 = i4 ? i1 : i2;
    i4 = HEAP32[i1 + 16 >> 2] | 0;
    if (i4 | 0) {
     i1 = i4;
     i31 = 90;
     continue;
    }
    i1 = HEAP32[i1 + 20 >> 2] | 0;
    if (!i1) {
     i8 = i3;
     i9 = i2;
     break;
    } else i31 = 90;
   }
   if ((i9 | 0) != 0 ? i8 >>> 0 < ((HEAP32[15036] | 0) - i15 | 0) >>> 0 : 0) {
    i5 = HEAP32[15038] | 0;
    if (i9 >>> 0 < i5 >>> 0) _abort();
    i7 = i9 + i15 | 0;
    if (i9 >>> 0 >= i7 >>> 0) _abort();
    i6 = HEAP32[i9 + 24 >> 2] | 0;
    i3 = HEAP32[i9 + 12 >> 2] | 0;
    do if ((i3 | 0) == (i9 | 0)) {
     i2 = i9 + 20 | 0;
     i1 = HEAP32[i2 >> 2] | 0;
     if (!i1) {
      i2 = i9 + 16 | 0;
      i1 = HEAP32[i2 >> 2] | 0;
      if (!i1) {
       i19 = 0;
       break;
      }
     }
     while (1) {
      i3 = i1 + 20 | 0;
      i4 = HEAP32[i3 >> 2] | 0;
      if (i4 | 0) {
       i1 = i4;
       i2 = i3;
       continue;
      }
      i3 = i1 + 16 | 0;
      i4 = HEAP32[i3 >> 2] | 0;
      if (!i4) break; else {
       i1 = i4;
       i2 = i3;
      }
     }
     if (i2 >>> 0 < i5 >>> 0) _abort(); else {
      HEAP32[i2 >> 2] = 0;
      i19 = i1;
      break;
     }
    } else {
     i4 = HEAP32[i9 + 8 >> 2] | 0;
     if (i4 >>> 0 < i5 >>> 0) _abort();
     i1 = i4 + 12 | 0;
     if ((HEAP32[i1 >> 2] | 0) != (i9 | 0)) _abort();
     i2 = i3 + 8 | 0;
     if ((HEAP32[i2 >> 2] | 0) == (i9 | 0)) {
      HEAP32[i1 >> 2] = i3;
      HEAP32[i2 >> 2] = i4;
      i19 = i3;
      break;
     } else _abort();
    } while (0);
    do if (i6 | 0) {
     i1 = HEAP32[i9 + 28 >> 2] | 0;
     i2 = 60440 + (i1 << 2) | 0;
     if ((i9 | 0) == (HEAP32[i2 >> 2] | 0)) {
      HEAP32[i2 >> 2] = i19;
      if (!i19) {
       HEAP32[15035] = HEAP32[15035] & ~(1 << i1);
       break;
      }
     } else {
      if (i6 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
      i1 = i6 + 16 | 0;
      if ((HEAP32[i1 >> 2] | 0) == (i9 | 0)) HEAP32[i1 >> 2] = i19; else HEAP32[i6 + 20 >> 2] = i19;
      if (!i19) break;
     }
     i2 = HEAP32[15038] | 0;
     if (i19 >>> 0 < i2 >>> 0) _abort();
     HEAP32[i19 + 24 >> 2] = i6;
     i1 = HEAP32[i9 + 16 >> 2] | 0;
     do if (i1 | 0) if (i1 >>> 0 < i2 >>> 0) _abort(); else {
      HEAP32[i19 + 16 >> 2] = i1;
      HEAP32[i1 + 24 >> 2] = i19;
      break;
     } while (0);
     i1 = HEAP32[i9 + 20 >> 2] | 0;
     if (i1 | 0) if (i1 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
      HEAP32[i19 + 20 >> 2] = i1;
      HEAP32[i1 + 24 >> 2] = i19;
      break;
     }
    } while (0);
    do if (i8 >>> 0 >= 16) {
     HEAP32[i9 + 4 >> 2] = i15 | 3;
     HEAP32[i7 + 4 >> 2] = i8 | 1;
     HEAP32[i7 + i8 >> 2] = i8;
     i1 = i8 >>> 3;
     if (i8 >>> 0 < 256) {
      i3 = 60176 + (i1 << 1 << 2) | 0;
      i2 = HEAP32[15034] | 0;
      i1 = 1 << i1;
      if (i2 & i1) {
       i1 = i3 + 8 | 0;
       i2 = HEAP32[i1 >> 2] | 0;
       if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
        i21 = i1;
        i22 = i2;
       }
      } else {
       HEAP32[15034] = i2 | i1;
       i21 = i3 + 8 | 0;
       i22 = i3;
      }
      HEAP32[i21 >> 2] = i7;
      HEAP32[i22 + 12 >> 2] = i7;
      HEAP32[i7 + 8 >> 2] = i22;
      HEAP32[i7 + 12 >> 2] = i3;
      break;
     }
     i1 = i8 >>> 8;
     if (i1) if (i8 >>> 0 > 16777215) i3 = 31; else {
      i37 = (i1 + 1048320 | 0) >>> 16 & 8;
      i38 = i1 << i37;
      i36 = (i38 + 520192 | 0) >>> 16 & 4;
      i38 = i38 << i36;
      i3 = (i38 + 245760 | 0) >>> 16 & 2;
      i3 = 14 - (i36 | i37 | i3) + (i38 << i3 >>> 15) | 0;
      i3 = i8 >>> (i3 + 7 | 0) & 1 | i3 << 1;
     } else i3 = 0;
     i4 = 60440 + (i3 << 2) | 0;
     HEAP32[i7 + 28 >> 2] = i3;
     i1 = i7 + 16 | 0;
     HEAP32[i1 + 4 >> 2] = 0;
     HEAP32[i1 >> 2] = 0;
     i1 = HEAP32[15035] | 0;
     i2 = 1 << i3;
     if (!(i1 & i2)) {
      HEAP32[15035] = i1 | i2;
      HEAP32[i4 >> 2] = i7;
      HEAP32[i7 + 24 >> 2] = i4;
      HEAP32[i7 + 12 >> 2] = i7;
      HEAP32[i7 + 8 >> 2] = i7;
      break;
     }
     i5 = i8 << ((i3 | 0) == 31 ? 0 : 25 - (i3 >>> 1) | 0);
     i1 = HEAP32[i4 >> 2] | 0;
     while (1) {
      if ((HEAP32[i1 + 4 >> 2] & -8 | 0) == (i8 | 0)) {
       i3 = i1;
       i31 = 148;
       break;
      }
      i2 = i1 + 16 + (i5 >>> 31 << 2) | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      if (!i3) {
       i31 = 145;
       break;
      } else {
       i5 = i5 << 1;
       i1 = i3;
      }
     }
     if ((i31 | 0) == 145) if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
      HEAP32[i2 >> 2] = i7;
      HEAP32[i7 + 24 >> 2] = i1;
      HEAP32[i7 + 12 >> 2] = i7;
      HEAP32[i7 + 8 >> 2] = i7;
      break;
     } else if ((i31 | 0) == 148) {
      i1 = i3 + 8 | 0;
      i2 = HEAP32[i1 >> 2] | 0;
      i38 = HEAP32[15038] | 0;
      if (i2 >>> 0 >= i38 >>> 0 & i3 >>> 0 >= i38 >>> 0) {
       HEAP32[i2 + 12 >> 2] = i7;
       HEAP32[i1 >> 2] = i7;
       HEAP32[i7 + 8 >> 2] = i2;
       HEAP32[i7 + 12 >> 2] = i3;
       HEAP32[i7 + 24 >> 2] = 0;
       break;
      } else _abort();
     }
    } else {
     i38 = i8 + i15 | 0;
     HEAP32[i9 + 4 >> 2] = i38 | 3;
     i38 = i9 + i38 + 4 | 0;
     HEAP32[i38 >> 2] = HEAP32[i38 >> 2] | 1;
    } while (0);
    i38 = i9 + 8 | 0;
    STACKTOP = i39;
    return i38 | 0;
   }
  }
 } else i15 = -1; while (0);
 i3 = HEAP32[15036] | 0;
 if (i3 >>> 0 >= i15 >>> 0) {
  i1 = i3 - i15 | 0;
  i2 = HEAP32[15039] | 0;
  if (i1 >>> 0 > 15) {
   i38 = i2 + i15 | 0;
   HEAP32[15039] = i38;
   HEAP32[15036] = i1;
   HEAP32[i38 + 4 >> 2] = i1 | 1;
   HEAP32[i38 + i1 >> 2] = i1;
   HEAP32[i2 + 4 >> 2] = i15 | 3;
  } else {
   HEAP32[15036] = 0;
   HEAP32[15039] = 0;
   HEAP32[i2 + 4 >> 2] = i3 | 3;
   i38 = i2 + i3 + 4 | 0;
   HEAP32[i38 >> 2] = HEAP32[i38 >> 2] | 1;
  }
  i38 = i2 + 8 | 0;
  STACKTOP = i39;
  return i38 | 0;
 }
 i1 = HEAP32[15037] | 0;
 if (i1 >>> 0 > i15 >>> 0) {
  i36 = i1 - i15 | 0;
  HEAP32[15037] = i36;
  i38 = HEAP32[15040] | 0;
  i37 = i38 + i15 | 0;
  HEAP32[15040] = i37;
  HEAP32[i37 + 4 >> 2] = i36 | 1;
  HEAP32[i38 + 4 >> 2] = i15 | 3;
  i38 = i38 + 8 | 0;
  STACKTOP = i39;
  return i38 | 0;
 }
 if (!(HEAP32[15152] | 0)) {
  HEAP32[15154] = 4096;
  HEAP32[15153] = 4096;
  HEAP32[15155] = -1;
  HEAP32[15156] = -1;
  HEAP32[15157] = 0;
  HEAP32[15145] = 0;
  i22 = i14 & -16 ^ 1431655768;
  HEAP32[i14 >> 2] = i22;
  HEAP32[15152] = i22;
 }
 i7 = i15 + 48 | 0;
 i6 = HEAP32[15154] | 0;
 i8 = i15 + 47 | 0;
 i5 = i6 + i8 | 0;
 i6 = 0 - i6 | 0;
 i9 = i5 & i6;
 if (i9 >>> 0 <= i15 >>> 0) {
  i38 = 0;
  STACKTOP = i39;
  return i38 | 0;
 }
 i1 = HEAP32[15144] | 0;
 if (i1 | 0 ? (i21 = HEAP32[15142] | 0, i22 = i21 + i9 | 0, i22 >>> 0 <= i21 >>> 0 | i22 >>> 0 > i1 >>> 0) : 0) {
  i38 = 0;
  STACKTOP = i39;
  return i38 | 0;
 }
 L254 : do if (!(HEAP32[15145] & 4)) {
  i1 = HEAP32[15040] | 0;
  L256 : do if (i1) {
   i3 = 60584;
   while (1) {
    i2 = HEAP32[i3 >> 2] | 0;
    if (i2 >>> 0 <= i1 >>> 0 ? (i18 = i3 + 4 | 0, (i2 + (HEAP32[i18 >> 2] | 0) | 0) >>> 0 > i1 >>> 0) : 0) {
     i4 = i3;
     i3 = i18;
     break;
    }
    i3 = HEAP32[i3 + 8 >> 2] | 0;
    if (!i3) {
     i31 = 171;
     break L256;
    }
   }
   i1 = i5 - (HEAP32[15037] | 0) & i6;
   if (i1 >>> 0 < 2147483647) {
    i2 = _sbrk(i1 | 0) | 0;
    if ((i2 | 0) == ((HEAP32[i4 >> 2] | 0) + (HEAP32[i3 >> 2] | 0) | 0)) {
     if ((i2 | 0) != (-1 | 0)) {
      i7 = i2;
      i5 = i1;
      i31 = 191;
      break L254;
     }
    } else i31 = 181;
   }
  } else i31 = 171; while (0);
  do if ((i31 | 0) == 171 ? (i20 = _sbrk(0) | 0, (i20 | 0) != (-1 | 0)) : 0) {
   i1 = i20;
   i2 = HEAP32[15153] | 0;
   i3 = i2 + -1 | 0;
   if (!(i3 & i1)) i1 = i9; else i1 = i9 - i1 + (i3 + i1 & 0 - i2) | 0;
   i2 = HEAP32[15142] | 0;
   i3 = i2 + i1 | 0;
   if (i1 >>> 0 > i15 >>> 0 & i1 >>> 0 < 2147483647) {
    i22 = HEAP32[15144] | 0;
    if (i22 | 0 ? i3 >>> 0 <= i2 >>> 0 | i3 >>> 0 > i22 >>> 0 : 0) break;
    i2 = _sbrk(i1 | 0) | 0;
    if ((i2 | 0) == (i20 | 0)) {
     i7 = i20;
     i5 = i1;
     i31 = 191;
     break L254;
    } else i31 = 181;
   }
  } while (0);
  L276 : do if ((i31 | 0) == 181) {
   i3 = 0 - i1 | 0;
   do if (i7 >>> 0 > i1 >>> 0 & (i1 >>> 0 < 2147483647 & (i2 | 0) != (-1 | 0)) ? (i23 = HEAP32[15154] | 0, i23 = i8 - i1 + i23 & 0 - i23, i23 >>> 0 < 2147483647) : 0) if ((_sbrk(i23 | 0) | 0) == (-1 | 0)) {
    _sbrk(i3 | 0) | 0;
    break L276;
   } else {
    i1 = i23 + i1 | 0;
    break;
   } while (0);
   if ((i2 | 0) != (-1 | 0)) {
    i7 = i2;
    i5 = i1;
    i31 = 191;
    break L254;
   }
  } while (0);
  HEAP32[15145] = HEAP32[15145] | 4;
  i31 = 188;
 } else i31 = 188; while (0);
 if ((((i31 | 0) == 188 ? i9 >>> 0 < 2147483647 : 0) ? (i24 = _sbrk(i9 | 0) | 0, i25 = _sbrk(0) | 0, i24 >>> 0 < i25 >>> 0 & ((i24 | 0) != (-1 | 0) & (i25 | 0) != (-1 | 0))) : 0) ? (i26 = i25 - i24 | 0, i26 >>> 0 > (i15 + 40 | 0) >>> 0) : 0) {
  i7 = i24;
  i5 = i26;
  i31 = 191;
 }
 if ((i31 | 0) == 191) {
  i1 = (HEAP32[15142] | 0) + i5 | 0;
  HEAP32[15142] = i1;
  if (i1 >>> 0 > (HEAP32[15143] | 0) >>> 0) HEAP32[15143] = i1;
  i8 = HEAP32[15040] | 0;
  do if (i8) {
   i4 = 60584;
   do {
    i1 = HEAP32[i4 >> 2] | 0;
    i2 = i4 + 4 | 0;
    i3 = HEAP32[i2 >> 2] | 0;
    if ((i7 | 0) == (i1 + i3 | 0)) {
     i27 = i1;
     i28 = i2;
     i29 = i3;
     i30 = i4;
     i31 = 201;
     break;
    }
    i4 = HEAP32[i4 + 8 >> 2] | 0;
   } while ((i4 | 0) != 0);
   if (((i31 | 0) == 201 ? (HEAP32[i30 + 12 >> 2] & 8 | 0) == 0 : 0) ? i8 >>> 0 < i7 >>> 0 & i8 >>> 0 >= i27 >>> 0 : 0) {
    HEAP32[i28 >> 2] = i29 + i5;
    i38 = i8 + 8 | 0;
    i38 = (i38 & 7 | 0) == 0 ? 0 : 0 - i38 & 7;
    i37 = i8 + i38 | 0;
    i38 = i5 - i38 + (HEAP32[15037] | 0) | 0;
    HEAP32[15040] = i37;
    HEAP32[15037] = i38;
    HEAP32[i37 + 4 >> 2] = i38 | 1;
    HEAP32[i37 + i38 + 4 >> 2] = 40;
    HEAP32[15041] = HEAP32[15156];
    break;
   }
   i1 = HEAP32[15038] | 0;
   if (i7 >>> 0 < i1 >>> 0) {
    HEAP32[15038] = i7;
    i9 = i7;
   } else i9 = i1;
   i3 = i7 + i5 | 0;
   i1 = 60584;
   while (1) {
    if ((HEAP32[i1 >> 2] | 0) == (i3 | 0)) {
     i2 = i1;
     i31 = 209;
     break;
    }
    i1 = HEAP32[i1 + 8 >> 2] | 0;
    if (!i1) {
     i2 = 60584;
     break;
    }
   }
   if ((i31 | 0) == 209) if (!(HEAP32[i1 + 12 >> 2] & 8)) {
    HEAP32[i2 >> 2] = i7;
    i11 = i1 + 4 | 0;
    HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) + i5;
    i11 = i7 + 8 | 0;
    i11 = i7 + ((i11 & 7 | 0) == 0 ? 0 : 0 - i11 & 7) | 0;
    i1 = i3 + 8 | 0;
    i1 = i3 + ((i1 & 7 | 0) == 0 ? 0 : 0 - i1 & 7) | 0;
    i10 = i11 + i15 | 0;
    i6 = i1 - i11 - i15 | 0;
    HEAP32[i11 + 4 >> 2] = i15 | 3;
    do if ((i1 | 0) != (i8 | 0)) {
     if ((i1 | 0) == (HEAP32[15039] | 0)) {
      i38 = (HEAP32[15036] | 0) + i6 | 0;
      HEAP32[15036] = i38;
      HEAP32[15039] = i10;
      HEAP32[i10 + 4 >> 2] = i38 | 1;
      HEAP32[i10 + i38 >> 2] = i38;
      break;
     }
     i2 = HEAP32[i1 + 4 >> 2] | 0;
     if ((i2 & 3 | 0) == 1) {
      i8 = i2 & -8;
      i5 = i2 >>> 3;
      L328 : do if (i2 >>> 0 >= 256) {
       i7 = HEAP32[i1 + 24 >> 2] | 0;
       i4 = HEAP32[i1 + 12 >> 2] | 0;
       do if ((i4 | 0) == (i1 | 0)) {
        i3 = i1 + 16 | 0;
        i4 = i3 + 4 | 0;
        i2 = HEAP32[i4 >> 2] | 0;
        if (!i2) {
         i2 = HEAP32[i3 >> 2] | 0;
         if (!i2) {
          i36 = 0;
          break;
         }
        } else i3 = i4;
        while (1) {
         i4 = i2 + 20 | 0;
         i5 = HEAP32[i4 >> 2] | 0;
         if (i5 | 0) {
          i2 = i5;
          i3 = i4;
          continue;
         }
         i4 = i2 + 16 | 0;
         i5 = HEAP32[i4 >> 2] | 0;
         if (!i5) break; else {
          i2 = i5;
          i3 = i4;
         }
        }
        if (i3 >>> 0 < i9 >>> 0) _abort(); else {
         HEAP32[i3 >> 2] = 0;
         i36 = i2;
         break;
        }
       } else {
        i5 = HEAP32[i1 + 8 >> 2] | 0;
        if (i5 >>> 0 < i9 >>> 0) _abort();
        i2 = i5 + 12 | 0;
        if ((HEAP32[i2 >> 2] | 0) != (i1 | 0)) _abort();
        i3 = i4 + 8 | 0;
        if ((HEAP32[i3 >> 2] | 0) == (i1 | 0)) {
         HEAP32[i2 >> 2] = i4;
         HEAP32[i3 >> 2] = i5;
         i36 = i4;
         break;
        } else _abort();
       } while (0);
       if (!i7) break;
       i2 = HEAP32[i1 + 28 >> 2] | 0;
       i3 = 60440 + (i2 << 2) | 0;
       do if ((i1 | 0) != (HEAP32[i3 >> 2] | 0)) {
        if (i7 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
        i2 = i7 + 16 | 0;
        if ((HEAP32[i2 >> 2] | 0) == (i1 | 0)) HEAP32[i2 >> 2] = i36; else HEAP32[i7 + 20 >> 2] = i36;
        if (!i36) break L328;
       } else {
        HEAP32[i3 >> 2] = i36;
        if (i36 | 0) break;
        HEAP32[15035] = HEAP32[15035] & ~(1 << i2);
        break L328;
       } while (0);
       i4 = HEAP32[15038] | 0;
       if (i36 >>> 0 < i4 >>> 0) _abort();
       HEAP32[i36 + 24 >> 2] = i7;
       i2 = i1 + 16 | 0;
       i3 = HEAP32[i2 >> 2] | 0;
       do if (i3 | 0) if (i3 >>> 0 < i4 >>> 0) _abort(); else {
        HEAP32[i36 + 16 >> 2] = i3;
        HEAP32[i3 + 24 >> 2] = i36;
        break;
       } while (0);
       i2 = HEAP32[i2 + 4 >> 2] | 0;
       if (!i2) break;
       if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
        HEAP32[i36 + 20 >> 2] = i2;
        HEAP32[i2 + 24 >> 2] = i36;
        break;
       }
      } else {
       i3 = HEAP32[i1 + 8 >> 2] | 0;
       i4 = HEAP32[i1 + 12 >> 2] | 0;
       i2 = 60176 + (i5 << 1 << 2) | 0;
       do if ((i3 | 0) != (i2 | 0)) {
        if (i3 >>> 0 < i9 >>> 0) _abort();
        if ((HEAP32[i3 + 12 >> 2] | 0) == (i1 | 0)) break;
        _abort();
       } while (0);
       if ((i4 | 0) == (i3 | 0)) {
        HEAP32[15034] = HEAP32[15034] & ~(1 << i5);
        break;
       }
       do if ((i4 | 0) == (i2 | 0)) i33 = i4 + 8 | 0; else {
        if (i4 >>> 0 < i9 >>> 0) _abort();
        i2 = i4 + 8 | 0;
        if ((HEAP32[i2 >> 2] | 0) == (i1 | 0)) {
         i33 = i2;
         break;
        }
        _abort();
       } while (0);
       HEAP32[i3 + 12 >> 2] = i4;
       HEAP32[i33 >> 2] = i3;
      } while (0);
      i1 = i1 + i8 | 0;
      i6 = i8 + i6 | 0;
     }
     i1 = i1 + 4 | 0;
     HEAP32[i1 >> 2] = HEAP32[i1 >> 2] & -2;
     HEAP32[i10 + 4 >> 2] = i6 | 1;
     HEAP32[i10 + i6 >> 2] = i6;
     i1 = i6 >>> 3;
     if (i6 >>> 0 < 256) {
      i3 = 60176 + (i1 << 1 << 2) | 0;
      i2 = HEAP32[15034] | 0;
      i1 = 1 << i1;
      do if (!(i2 & i1)) {
       HEAP32[15034] = i2 | i1;
       i37 = i3 + 8 | 0;
       i38 = i3;
      } else {
       i1 = i3 + 8 | 0;
       i2 = HEAP32[i1 >> 2] | 0;
       if (i2 >>> 0 >= (HEAP32[15038] | 0) >>> 0) {
        i37 = i1;
        i38 = i2;
        break;
       }
       _abort();
      } while (0);
      HEAP32[i37 >> 2] = i10;
      HEAP32[i38 + 12 >> 2] = i10;
      HEAP32[i10 + 8 >> 2] = i38;
      HEAP32[i10 + 12 >> 2] = i3;
      break;
     }
     i1 = i6 >>> 8;
     do if (!i1) i3 = 0; else {
      if (i6 >>> 0 > 16777215) {
       i3 = 31;
       break;
      }
      i37 = (i1 + 1048320 | 0) >>> 16 & 8;
      i38 = i1 << i37;
      i36 = (i38 + 520192 | 0) >>> 16 & 4;
      i38 = i38 << i36;
      i3 = (i38 + 245760 | 0) >>> 16 & 2;
      i3 = 14 - (i36 | i37 | i3) + (i38 << i3 >>> 15) | 0;
      i3 = i6 >>> (i3 + 7 | 0) & 1 | i3 << 1;
     } while (0);
     i4 = 60440 + (i3 << 2) | 0;
     HEAP32[i10 + 28 >> 2] = i3;
     i1 = i10 + 16 | 0;
     HEAP32[i1 + 4 >> 2] = 0;
     HEAP32[i1 >> 2] = 0;
     i1 = HEAP32[15035] | 0;
     i2 = 1 << i3;
     if (!(i1 & i2)) {
      HEAP32[15035] = i1 | i2;
      HEAP32[i4 >> 2] = i10;
      HEAP32[i10 + 24 >> 2] = i4;
      HEAP32[i10 + 12 >> 2] = i10;
      HEAP32[i10 + 8 >> 2] = i10;
      break;
     }
     i5 = i6 << ((i3 | 0) == 31 ? 0 : 25 - (i3 >>> 1) | 0);
     i1 = HEAP32[i4 >> 2] | 0;
     while (1) {
      if ((HEAP32[i1 + 4 >> 2] & -8 | 0) == (i6 | 0)) {
       i3 = i1;
       i31 = 279;
       break;
      }
      i2 = i1 + 16 + (i5 >>> 31 << 2) | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      if (!i3) {
       i31 = 276;
       break;
      } else {
       i5 = i5 << 1;
       i1 = i3;
      }
     }
     if ((i31 | 0) == 276) if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
      HEAP32[i2 >> 2] = i10;
      HEAP32[i10 + 24 >> 2] = i1;
      HEAP32[i10 + 12 >> 2] = i10;
      HEAP32[i10 + 8 >> 2] = i10;
      break;
     } else if ((i31 | 0) == 279) {
      i1 = i3 + 8 | 0;
      i2 = HEAP32[i1 >> 2] | 0;
      i38 = HEAP32[15038] | 0;
      if (i2 >>> 0 >= i38 >>> 0 & i3 >>> 0 >= i38 >>> 0) {
       HEAP32[i2 + 12 >> 2] = i10;
       HEAP32[i1 >> 2] = i10;
       HEAP32[i10 + 8 >> 2] = i2;
       HEAP32[i10 + 12 >> 2] = i3;
       HEAP32[i10 + 24 >> 2] = 0;
       break;
      } else _abort();
     }
    } else {
     i38 = (HEAP32[15037] | 0) + i6 | 0;
     HEAP32[15037] = i38;
     HEAP32[15040] = i10;
     HEAP32[i10 + 4 >> 2] = i38 | 1;
    } while (0);
    i38 = i11 + 8 | 0;
    STACKTOP = i39;
    return i38 | 0;
   } else i2 = 60584;
   while (1) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (i1 >>> 0 <= i8 >>> 0 ? (i32 = i1 + (HEAP32[i2 + 4 >> 2] | 0) | 0, i32 >>> 0 > i8 >>> 0) : 0) {
     i2 = i32;
     break;
    }
    i2 = HEAP32[i2 + 8 >> 2] | 0;
   }
   i6 = i2 + -47 | 0;
   i3 = i6 + 8 | 0;
   i3 = i6 + ((i3 & 7 | 0) == 0 ? 0 : 0 - i3 & 7) | 0;
   i6 = i8 + 16 | 0;
   i3 = i3 >>> 0 < i6 >>> 0 ? i8 : i3;
   i1 = i3 + 8 | 0;
   i4 = i7 + 8 | 0;
   i4 = (i4 & 7 | 0) == 0 ? 0 : 0 - i4 & 7;
   i38 = i7 + i4 | 0;
   i4 = i5 + -40 - i4 | 0;
   HEAP32[15040] = i38;
   HEAP32[15037] = i4;
   HEAP32[i38 + 4 >> 2] = i4 | 1;
   HEAP32[i38 + i4 + 4 >> 2] = 40;
   HEAP32[15041] = HEAP32[15156];
   i4 = i3 + 4 | 0;
   HEAP32[i4 >> 2] = 27;
   HEAP32[i1 >> 2] = HEAP32[15146];
   HEAP32[i1 + 4 >> 2] = HEAP32[15147];
   HEAP32[i1 + 8 >> 2] = HEAP32[15148];
   HEAP32[i1 + 12 >> 2] = HEAP32[15149];
   HEAP32[15146] = i7;
   HEAP32[15147] = i5;
   HEAP32[15149] = 0;
   HEAP32[15148] = i1;
   i1 = i3 + 24 | 0;
   do {
    i1 = i1 + 4 | 0;
    HEAP32[i1 >> 2] = 7;
   } while ((i1 + 4 | 0) >>> 0 < i2 >>> 0);
   if ((i3 | 0) != (i8 | 0)) {
    i7 = i3 - i8 | 0;
    HEAP32[i4 >> 2] = HEAP32[i4 >> 2] & -2;
    HEAP32[i8 + 4 >> 2] = i7 | 1;
    HEAP32[i3 >> 2] = i7;
    i1 = i7 >>> 3;
    if (i7 >>> 0 < 256) {
     i3 = 60176 + (i1 << 1 << 2) | 0;
     i2 = HEAP32[15034] | 0;
     i1 = 1 << i1;
     if (i2 & i1) {
      i1 = i3 + 8 | 0;
      i2 = HEAP32[i1 >> 2] | 0;
      if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
       i34 = i1;
       i35 = i2;
      }
     } else {
      HEAP32[15034] = i2 | i1;
      i34 = i3 + 8 | 0;
      i35 = i3;
     }
     HEAP32[i34 >> 2] = i8;
     HEAP32[i35 + 12 >> 2] = i8;
     HEAP32[i8 + 8 >> 2] = i35;
     HEAP32[i8 + 12 >> 2] = i3;
     break;
    }
    i1 = i7 >>> 8;
    if (i1) if (i7 >>> 0 > 16777215) i3 = 31; else {
     i37 = (i1 + 1048320 | 0) >>> 16 & 8;
     i38 = i1 << i37;
     i36 = (i38 + 520192 | 0) >>> 16 & 4;
     i38 = i38 << i36;
     i3 = (i38 + 245760 | 0) >>> 16 & 2;
     i3 = 14 - (i36 | i37 | i3) + (i38 << i3 >>> 15) | 0;
     i3 = i7 >>> (i3 + 7 | 0) & 1 | i3 << 1;
    } else i3 = 0;
    i5 = 60440 + (i3 << 2) | 0;
    HEAP32[i8 + 28 >> 2] = i3;
    HEAP32[i8 + 20 >> 2] = 0;
    HEAP32[i6 >> 2] = 0;
    i1 = HEAP32[15035] | 0;
    i2 = 1 << i3;
    if (!(i1 & i2)) {
     HEAP32[15035] = i1 | i2;
     HEAP32[i5 >> 2] = i8;
     HEAP32[i8 + 24 >> 2] = i5;
     HEAP32[i8 + 12 >> 2] = i8;
     HEAP32[i8 + 8 >> 2] = i8;
     break;
    }
    i4 = i7 << ((i3 | 0) == 31 ? 0 : 25 - (i3 >>> 1) | 0);
    i1 = HEAP32[i5 >> 2] | 0;
    while (1) {
     if ((HEAP32[i1 + 4 >> 2] & -8 | 0) == (i7 | 0)) {
      i3 = i1;
      i31 = 305;
      break;
     }
     i2 = i1 + 16 + (i4 >>> 31 << 2) | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     if (!i3) {
      i31 = 302;
      break;
     } else {
      i4 = i4 << 1;
      i1 = i3;
     }
    }
    if ((i31 | 0) == 302) if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
     HEAP32[i2 >> 2] = i8;
     HEAP32[i8 + 24 >> 2] = i1;
     HEAP32[i8 + 12 >> 2] = i8;
     HEAP32[i8 + 8 >> 2] = i8;
     break;
    } else if ((i31 | 0) == 305) {
     i1 = i3 + 8 | 0;
     i2 = HEAP32[i1 >> 2] | 0;
     i38 = HEAP32[15038] | 0;
     if (i2 >>> 0 >= i38 >>> 0 & i3 >>> 0 >= i38 >>> 0) {
      HEAP32[i2 + 12 >> 2] = i8;
      HEAP32[i1 >> 2] = i8;
      HEAP32[i8 + 8 >> 2] = i2;
      HEAP32[i8 + 12 >> 2] = i3;
      HEAP32[i8 + 24 >> 2] = 0;
      break;
     } else _abort();
    }
   }
  } else {
   i38 = HEAP32[15038] | 0;
   if ((i38 | 0) == 0 | i7 >>> 0 < i38 >>> 0) HEAP32[15038] = i7;
   HEAP32[15146] = i7;
   HEAP32[15147] = i5;
   HEAP32[15149] = 0;
   HEAP32[15043] = HEAP32[15152];
   HEAP32[15042] = -1;
   i1 = 0;
   do {
    i38 = 60176 + (i1 << 1 << 2) | 0;
    HEAP32[i38 + 12 >> 2] = i38;
    HEAP32[i38 + 8 >> 2] = i38;
    i1 = i1 + 1 | 0;
   } while ((i1 | 0) != 32);
   i38 = i7 + 8 | 0;
   i38 = (i38 & 7 | 0) == 0 ? 0 : 0 - i38 & 7;
   i37 = i7 + i38 | 0;
   i38 = i5 + -40 - i38 | 0;
   HEAP32[15040] = i37;
   HEAP32[15037] = i38;
   HEAP32[i37 + 4 >> 2] = i38 | 1;
   HEAP32[i37 + i38 + 4 >> 2] = 40;
   HEAP32[15041] = HEAP32[15156];
  } while (0);
  i1 = HEAP32[15037] | 0;
  if (i1 >>> 0 > i15 >>> 0) {
   i36 = i1 - i15 | 0;
   HEAP32[15037] = i36;
   i38 = HEAP32[15040] | 0;
   i37 = i38 + i15 | 0;
   HEAP32[15040] = i37;
   HEAP32[i37 + 4 >> 2] = i36 | 1;
   HEAP32[i38 + 4 >> 2] = i15 | 3;
   i38 = i38 + 8 | 0;
   STACKTOP = i39;
   return i38 | 0;
  }
 }
 i38 = ___errno_location() | 0;
 HEAP32[i38 >> 2] = 12;
 i38 = 0;
 STACKTOP = i39;
 return i38 | 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11visitBinaryEPNS_6BinaryE(i37, i34, i33) {
 i37 = i37 | 0;
 i34 = i34 | 0;
 i33 = i33 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i35 = 0, i36 = 0, i38 = 0;
 i38 = STACKTOP;
 STACKTOP = STACKTOP + 512 | 0;
 i4 = i38 + 488 | 0;
 i35 = i38 + 472 | 0;
 i1 = i38 + 432 | 0;
 i36 = i38 + 456 | 0;
 i6 = i38 + 416 | 0;
 i17 = i38 + 400 | 0;
 i26 = i38 + 384 | 0;
 i27 = i38 + 368 | 0;
 i28 = i38 + 352 | 0;
 i29 = i38 + 336 | 0;
 i30 = i38 + 320 | 0;
 i31 = i38 + 304 | 0;
 i32 = i38 + 288 | 0;
 i7 = i38 + 272 | 0;
 i8 = i38 + 256 | 0;
 i9 = i38 + 240 | 0;
 i10 = i38 + 224 | 0;
 i11 = i38 + 208 | 0;
 i12 = i38 + 192 | 0;
 i13 = i38 + 176 | 0;
 i14 = i38 + 160 | 0;
 i15 = i38 + 144 | 0;
 i16 = i38 + 128 | 0;
 i18 = i38 + 112 | 0;
 i19 = i38 + 96 | 0;
 i20 = i38 + 80 | 0;
 i21 = i38 + 64 | 0;
 i22 = i38 + 48 | 0;
 i23 = i38 + 32 | 0;
 i24 = i38 + 16 | 0;
 i25 = i38;
 i2 = i33 + 12 | 0;
 __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i4, i34, HEAP32[i2 >> 2] | 0);
 i3 = i4 + 16 | 0;
 if ((HEAP32[i3 >> 2] | 0) == 0 ? (HEAP32[i35 >> 2] = HEAP32[i4 >> 2], HEAP32[i35 + 4 >> 2] = HEAP32[i4 + 4 >> 2], HEAP32[i35 + 8 >> 2] = HEAP32[i4 + 8 >> 2], HEAP32[i35 + 12 >> 2] = HEAP32[i4 + 12 >> 2], i5 = i33 + 16 | 0, __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i1, i34, HEAP32[i5 >> 2] | 0), HEAP32[i4 >> 2] = HEAP32[i1 >> 2], HEAP32[i4 + 4 >> 2] = HEAP32[i1 + 4 >> 2], HEAP32[i4 + 8 >> 2] = HEAP32[i1 + 8 >> 2], HEAP32[i4 + 12 >> 2] = HEAP32[i1 + 12 >> 2], HEAP32[i4 + 16 >> 2] = HEAP32[i1 + 16 >> 2], (HEAP32[i3 >> 2] | 0) == 0) : 0) {
  HEAP32[i36 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i36 + 4 >> 2] = HEAP32[i4 + 4 >> 2];
  HEAP32[i36 + 8 >> 2] = HEAP32[i4 + 8 >> 2];
  HEAP32[i36 + 12 >> 2] = HEAP32[i4 + 12 >> 2];
  i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + 4 >> 2] | 0;
  switch (i1 | 0) {
  case 0:
  case 5:
   break;
  default:
   if ((HEAP32[i35 >> 2] | 0) != (i1 | 0)) ___assert_fail(28819, 28043, 494, 28895);
  }
  i1 = HEAP32[(HEAP32[i5 >> 2] | 0) + 4 >> 2] | 0;
  switch (i1 | 0) {
  case 0:
  case 5:
   break;
  default:
   if ((HEAP32[i36 >> 2] | 0) != (i1 | 0)) ___assert_fail(28907, 28043, 495, 28895);
  }
  L13 : do switch (HEAP32[i35 >> 2] | 0) {
  case 1:
   {
    do switch (HEAP32[i33 + 8 >> 2] | 0) {
    case 0:
     {
      __ZNK4wasm7Literal3addERKS0_(i6, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i6 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i6 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 1:
     {
      __ZNK4wasm7Literal3subERKS0_(i17, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i17 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i17 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i17 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i17 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 2:
     {
      __ZNK4wasm7Literal3mulERKS0_(i26, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i26 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i26 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i26 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i26 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 3:
     {
      if ((__ZN4wasm7Literal10getIntegerEv(i36) | 0) == 0 & (tempRet0 | 0) == 0) {
       i33 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i33 >> 2] | 0) + 20 >> 2] & 1023](i33, 28986);
      }
      if ((__ZN4wasm7Literal10getIntegerEv(i35) | 0) == -2147483648 & (tempRet0 | 0) == -1 ? (i33 = __ZN4wasm7Literal10getIntegerEv(i36) | 0, (i33 | 0) == -1 & (tempRet0 | 0) == -1) : 0) {
       i34 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i34 >> 2] | 0) + 20 >> 2] & 1023](i34, 29001);
      }
      i1 = i35 + 8 | 0;
      if ((HEAP32[i35 >> 2] | 0) == 1) {
       i3 = 1;
       i1 = (HEAP32[i1 >> 2] | 0) / (HEAP32[i36 + 8 >> 2] | 0) | 0;
       i2 = 0;
      } else {
       i3 = i1;
       i1 = i36 + 8 | 0;
       i1 = ___divdi3(HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0) | 0;
       i3 = 2;
       i2 = tempRet0;
      }
      HEAP32[i37 >> 2] = i3;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i1;
      HEAP32[i36 + 4 >> 2] = i2;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 4:
     {
      if ((__ZN4wasm7Literal10getIntegerEv(i36) | 0) == 0 & (tempRet0 | 0) == 0) {
       i34 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i34 >> 2] | 0) + 20 >> 2] & 1023](i34, 29020);
      }
      i1 = i35 + 8 | 0;
      if ((HEAP32[i35 >> 2] | 0) == 1) {
       i3 = 1;
       i1 = ((HEAP32[i1 >> 2] | 0) >>> 0) / ((HEAP32[i36 + 8 >> 2] | 0) >>> 0) | 0;
       i2 = 0;
      } else {
       i3 = i1;
       i1 = i36 + 8 | 0;
       i1 = ___udivdi3(HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0) | 0;
       i3 = 2;
       i2 = tempRet0;
      }
      HEAP32[i37 >> 2] = i3;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i1;
      HEAP32[i36 + 4 >> 2] = i2;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 5:
     {
      if ((__ZN4wasm7Literal10getIntegerEv(i36) | 0) == 0 & (tempRet0 | 0) == 0) {
       i34 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i34 >> 2] | 0) + 20 >> 2] & 1023](i34, 29035);
      }
      if ((__ZN4wasm7Literal10getIntegerEv(i35) | 0) == -2147483648 & (tempRet0 | 0) == -1 ? (i34 = __ZN4wasm7Literal10getIntegerEv(i36) | 0, (i34 | 0) == -1 & (tempRet0 | 0) == -1) : 0) {
       HEAP32[i37 >> 2] = 1;
       HEAP32[i37 + 8 >> 2] = 0;
       HEAP32[i37 + 16 >> 2] = 0;
       break L13;
      }
      i1 = i35 + 8 | 0;
      if ((HEAP32[i35 >> 2] | 0) == 1) {
       i3 = 1;
       i1 = (HEAP32[i1 >> 2] | 0) % (HEAP32[i36 + 8 >> 2] | 0) | 0;
       i2 = 0;
      } else {
       i3 = i1;
       i1 = i36 + 8 | 0;
       i1 = ___remdi3(HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0) | 0;
       i3 = 2;
       i2 = tempRet0;
      }
      HEAP32[i37 >> 2] = i3;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i1;
      HEAP32[i36 + 4 >> 2] = i2;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 6:
     {
      if ((__ZN4wasm7Literal10getIntegerEv(i36) | 0) == 0 & (tempRet0 | 0) == 0) {
       i34 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i34 >> 2] | 0) + 20 >> 2] & 1023](i34, 29050);
      }
      i1 = i35 + 8 | 0;
      if ((HEAP32[i35 >> 2] | 0) == 1) {
       i3 = 1;
       i1 = ((HEAP32[i1 >> 2] | 0) >>> 0) % ((HEAP32[i36 + 8 >> 2] | 0) >>> 0) | 0;
       i2 = 0;
      } else {
       i3 = i1;
       i1 = i36 + 8 | 0;
       i1 = ___uremdi3(HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0) | 0;
       i3 = 2;
       i2 = tempRet0;
      }
      HEAP32[i37 >> 2] = i3;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i1;
      HEAP32[i36 + 4 >> 2] = i2;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 7:
     {
      i35 = HEAP32[i36 + 8 >> 2] & HEAP32[i35 + 8 >> 2];
      HEAP32[i37 >> 2] = 1;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i35;
      HEAP32[i36 + 4 >> 2] = 0;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 8:
     {
      i35 = HEAP32[i36 + 8 >> 2] | HEAP32[i35 + 8 >> 2];
      HEAP32[i37 >> 2] = 1;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i35;
      HEAP32[i36 + 4 >> 2] = 0;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 9:
     {
      i35 = HEAP32[i36 + 8 >> 2] ^ HEAP32[i35 + 8 >> 2];
      HEAP32[i37 >> 2] = 1;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i35;
      HEAP32[i36 + 4 >> 2] = 0;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 10:
     {
      i34 = i36 + 8 | 0;
      i35 = HEAP32[i35 + 8 >> 2] << (((HEAP32[i36 >> 2] | 0) == 1 ? HEAP32[i34 >> 2] | 0 : HEAP32[i34 >> 2] | 0) & 31);
      HEAP32[i37 >> 2] = 1;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i35;
      HEAP32[i36 + 4 >> 2] = 0;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 11:
     {
      i34 = i36 + 8 | 0;
      i35 = (HEAP32[i35 + 8 >> 2] | 0) >>> (((HEAP32[i36 >> 2] | 0) == 1 ? HEAP32[i34 >> 2] | 0 : HEAP32[i34 >> 2] | 0) & 31);
      HEAP32[i37 >> 2] = 1;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i35;
      HEAP32[i36 + 4 >> 2] = 0;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 12:
     {
      i34 = i36 + 8 | 0;
      i35 = HEAP32[i35 + 8 >> 2] >> (((HEAP32[i36 >> 2] | 0) == 1 ? HEAP32[i34 >> 2] | 0 : HEAP32[i34 >> 2] | 0) & 31);
      HEAP32[i37 >> 2] = 1;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i35;
      HEAP32[i36 + 4 >> 2] = 0;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 13:
     {
      __ZNK4wasm7Literal4rotLERKS0_(i27, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i27 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i27 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i27 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i27 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 14:
     {
      __ZNK4wasm7Literal4rotRERKS0_(i28, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i28 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i28 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i28 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i28 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 15:
     {
      __ZNK4wasm7Literal2eqERKS0_(i29, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i29 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i29 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i29 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i29 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 16:
     {
      __ZNK4wasm7Literal2neERKS0_(i30, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i30 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i30 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i30 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i30 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 17:
     {
      i36 = (HEAP32[i35 + 8 >> 2] | 0) < (HEAP32[i36 + 8 >> 2] | 0) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 18:
     {
      i36 = (HEAP32[i35 + 8 >> 2] | 0) >>> 0 < (HEAP32[i36 + 8 >> 2] | 0) >>> 0 & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 19:
     {
      i36 = (HEAP32[i35 + 8 >> 2] | 0) <= (HEAP32[i36 + 8 >> 2] | 0) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 20:
     {
      i36 = (HEAP32[i35 + 8 >> 2] | 0) >>> 0 <= (HEAP32[i36 + 8 >> 2] | 0) >>> 0 & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 21:
     {
      i36 = (HEAP32[i35 + 8 >> 2] | 0) > (HEAP32[i36 + 8 >> 2] | 0) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 22:
     {
      i36 = (HEAP32[i35 + 8 >> 2] | 0) >>> 0 > (HEAP32[i36 + 8 >> 2] | 0) >>> 0 & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 23:
     {
      i36 = (HEAP32[i35 + 8 >> 2] | 0) >= (HEAP32[i36 + 8 >> 2] | 0) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 24:
     {
      i36 = (HEAP32[i35 + 8 >> 2] | 0) >>> 0 >= (HEAP32[i36 + 8 >> 2] | 0) >>> 0 & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    default:
     _abort();
    } while (0);
    break;
   }
  case 2:
   {
    do switch (HEAP32[i33 + 8 >> 2] | 0) {
    case 25:
     {
      __ZNK4wasm7Literal3addERKS0_(i31, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i31 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i31 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i31 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i31 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 26:
     {
      __ZNK4wasm7Literal3subERKS0_(i32, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i32 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i32 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i32 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i32 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 27:
     {
      __ZNK4wasm7Literal3mulERKS0_(i7, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i7 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i7 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i7 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 28:
     {
      if ((__ZN4wasm7Literal10getIntegerEv(i36) | 0) == 0 & (tempRet0 | 0) == 0) {
       i33 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i33 >> 2] | 0) + 20 >> 2] & 1023](i33, 29065);
      }
      if ((__ZN4wasm7Literal10getIntegerEv(i35) | 0) == 0 & (tempRet0 | 0) == -2147483648 ? (i33 = __ZN4wasm7Literal10getIntegerEv(i36) | 0, (i33 | 0) == -1 & (tempRet0 | 0) == -1) : 0) {
       i34 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i34 >> 2] | 0) + 20 >> 2] & 1023](i34, 29080);
      }
      i1 = i35 + 8 | 0;
      if ((HEAP32[i35 >> 2] | 0) == 1) {
       i3 = 1;
       i1 = (HEAP32[i1 >> 2] | 0) / (HEAP32[i36 + 8 >> 2] | 0) | 0;
       i2 = 0;
      } else {
       i3 = i1;
       i1 = i36 + 8 | 0;
       i1 = ___divdi3(HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0) | 0;
       i3 = 2;
       i2 = tempRet0;
      }
      HEAP32[i37 >> 2] = i3;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i1;
      HEAP32[i36 + 4 >> 2] = i2;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 29:
     {
      if ((__ZN4wasm7Literal10getIntegerEv(i36) | 0) == 0 & (tempRet0 | 0) == 0) {
       i34 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i34 >> 2] | 0) + 20 >> 2] & 1023](i34, 29099);
      }
      i1 = i35 + 8 | 0;
      if ((HEAP32[i35 >> 2] | 0) == 1) {
       i3 = 1;
       i1 = ((HEAP32[i1 >> 2] | 0) >>> 0) / ((HEAP32[i36 + 8 >> 2] | 0) >>> 0) | 0;
       i2 = 0;
      } else {
       i3 = i1;
       i1 = i36 + 8 | 0;
       i1 = ___udivdi3(HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0) | 0;
       i3 = 2;
       i2 = tempRet0;
      }
      HEAP32[i37 >> 2] = i3;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i1;
      HEAP32[i36 + 4 >> 2] = i2;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 30:
     {
      if ((__ZN4wasm7Literal10getIntegerEv(i36) | 0) == 0 & (tempRet0 | 0) == 0) {
       i34 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i34 >> 2] | 0) + 20 >> 2] & 1023](i34, 29114);
      }
      if ((__ZN4wasm7Literal10getIntegerEv(i35) | 0) == 0 & (tempRet0 | 0) == -2147483648 ? (i34 = __ZN4wasm7Literal10getIntegerEv(i36) | 0, (i34 | 0) == -1 & (tempRet0 | 0) == -1) : 0) {
       HEAP32[i37 >> 2] = 2;
       i36 = i37 + 8 | 0;
       HEAP32[i36 >> 2] = 0;
       HEAP32[i36 + 4 >> 2] = 0;
       HEAP32[i37 + 16 >> 2] = 0;
       break L13;
      }
      i1 = i35 + 8 | 0;
      if ((HEAP32[i35 >> 2] | 0) == 1) {
       i3 = 1;
       i1 = (HEAP32[i1 >> 2] | 0) % (HEAP32[i36 + 8 >> 2] | 0) | 0;
       i2 = 0;
      } else {
       i3 = i1;
       i1 = i36 + 8 | 0;
       i1 = ___remdi3(HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0) | 0;
       i3 = 2;
       i2 = tempRet0;
      }
      HEAP32[i37 >> 2] = i3;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i1;
      HEAP32[i36 + 4 >> 2] = i2;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 31:
     {
      if ((__ZN4wasm7Literal10getIntegerEv(i36) | 0) == 0 & (tempRet0 | 0) == 0) {
       i34 = HEAP32[(HEAP32[i34 >> 2] | 0) + 24 >> 2] | 0;
       FUNCTION_TABLE_vii[HEAP32[(HEAP32[i34 >> 2] | 0) + 20 >> 2] & 1023](i34, 29129);
      }
      i1 = i35 + 8 | 0;
      if ((HEAP32[i35 >> 2] | 0) == 1) {
       i3 = 1;
       i1 = ((HEAP32[i1 >> 2] | 0) >>> 0) % ((HEAP32[i36 + 8 >> 2] | 0) >>> 0) | 0;
       i2 = 0;
      } else {
       i3 = i1;
       i1 = i36 + 8 | 0;
       i1 = ___uremdi3(HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0) | 0;
       i3 = 2;
       i2 = tempRet0;
      }
      HEAP32[i37 >> 2] = i3;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i1;
      HEAP32[i36 + 4 >> 2] = i2;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 32:
     {
      i35 = i35 + 8 | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 >> 2] & HEAP32[i35 >> 2];
      i35 = HEAP32[i36 + 4 >> 2] & HEAP32[i35 + 4 >> 2];
      HEAP32[i37 >> 2] = 2;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i34;
      HEAP32[i36 + 4 >> 2] = i35;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 33:
     {
      i35 = i35 + 8 | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 >> 2] | HEAP32[i35 >> 2];
      i35 = HEAP32[i36 + 4 >> 2] | HEAP32[i35 + 4 >> 2];
      HEAP32[i37 >> 2] = 2;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i34;
      HEAP32[i36 + 4 >> 2] = i35;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 34:
     {
      i35 = i35 + 8 | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 >> 2] ^ HEAP32[i35 >> 2];
      i35 = HEAP32[i36 + 4 >> 2] ^ HEAP32[i35 + 4 >> 2];
      HEAP32[i37 >> 2] = 2;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i34;
      HEAP32[i36 + 4 >> 2] = i35;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 35:
     {
      i1 = i36 + 8 | 0;
      if ((HEAP32[i36 >> 2] | 0) == 1) i1 = HEAP32[i1 >> 2] & 63; else i1 = HEAP32[i1 >> 2] & 63;
      i35 = i35 + 8 | 0;
      i35 = _bitshift64Shl(HEAP32[i35 >> 2] | 0, HEAP32[i35 + 4 >> 2] | 0, i1 & 63 | 0) | 0;
      HEAP32[i37 >> 2] = 2;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i35;
      HEAP32[i36 + 4 >> 2] = tempRet0;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 36:
     {
      i1 = i36 + 8 | 0;
      if ((HEAP32[i36 >> 2] | 0) == 1) i1 = HEAP32[i1 >> 2] & 63; else i1 = HEAP32[i1 >> 2] & 63;
      i35 = i35 + 8 | 0;
      i35 = _bitshift64Lshr(HEAP32[i35 >> 2] | 0, HEAP32[i35 + 4 >> 2] | 0, i1 & 63 | 0) | 0;
      HEAP32[i37 >> 2] = 2;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i35;
      HEAP32[i36 + 4 >> 2] = tempRet0;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 37:
     {
      i1 = i36 + 8 | 0;
      if ((HEAP32[i36 >> 2] | 0) == 1) i1 = HEAP32[i1 >> 2] & 63; else i1 = HEAP32[i1 >> 2] & 63;
      i35 = i35 + 8 | 0;
      i35 = _bitshift64Ashr(HEAP32[i35 >> 2] | 0, HEAP32[i35 + 4 >> 2] | 0, i1 & 63 | 0) | 0;
      HEAP32[i37 >> 2] = 2;
      i36 = i37 + 8 | 0;
      HEAP32[i36 >> 2] = i35;
      HEAP32[i36 + 4 >> 2] = tempRet0;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 38:
     {
      __ZNK4wasm7Literal4rotLERKS0_(i8, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i8 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 39:
     {
      __ZNK4wasm7Literal4rotRERKS0_(i9, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i9 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i9 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i9 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i9 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 40:
     {
      __ZNK4wasm7Literal2eqERKS0_(i10, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i10 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i10 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i10 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i10 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 41:
     {
      __ZNK4wasm7Literal2neERKS0_(i11, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i11 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i11 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i11 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i11 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 42:
     {
      i35 = i35 + 8 | 0;
      i33 = HEAP32[i35 + 4 >> 2] | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 + 4 >> 2] | 0;
      i36 = ((i33 | 0) < (i34 | 0) | ((i33 | 0) == (i34 | 0) ? (HEAP32[i35 >> 2] | 0) >>> 0 < (HEAP32[i36 >> 2] | 0) >>> 0 : 0)) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 43:
     {
      i35 = i35 + 8 | 0;
      i33 = HEAP32[i35 + 4 >> 2] | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 + 4 >> 2] | 0;
      i36 = (i33 >>> 0 < i34 >>> 0 | ((i33 | 0) == (i34 | 0) ? (HEAP32[i35 >> 2] | 0) >>> 0 < (HEAP32[i36 >> 2] | 0) >>> 0 : 0)) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 44:
     {
      i35 = i35 + 8 | 0;
      i33 = HEAP32[i35 + 4 >> 2] | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 + 4 >> 2] | 0;
      i36 = ((i33 | 0) < (i34 | 0) | ((i33 | 0) == (i34 | 0) ? (HEAP32[i35 >> 2] | 0) >>> 0 <= (HEAP32[i36 >> 2] | 0) >>> 0 : 0)) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 45:
     {
      i35 = i35 + 8 | 0;
      i33 = HEAP32[i35 + 4 >> 2] | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 + 4 >> 2] | 0;
      i36 = (i33 >>> 0 < i34 >>> 0 | ((i33 | 0) == (i34 | 0) ? (HEAP32[i35 >> 2] | 0) >>> 0 <= (HEAP32[i36 >> 2] | 0) >>> 0 : 0)) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 46:
     {
      i35 = i35 + 8 | 0;
      i33 = HEAP32[i35 + 4 >> 2] | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 + 4 >> 2] | 0;
      i36 = ((i33 | 0) > (i34 | 0) | ((i33 | 0) == (i34 | 0) ? (HEAP32[i35 >> 2] | 0) >>> 0 > (HEAP32[i36 >> 2] | 0) >>> 0 : 0)) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 47:
     {
      i35 = i35 + 8 | 0;
      i33 = HEAP32[i35 + 4 >> 2] | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 + 4 >> 2] | 0;
      i36 = (i33 >>> 0 > i34 >>> 0 | ((i33 | 0) == (i34 | 0) ? (HEAP32[i35 >> 2] | 0) >>> 0 > (HEAP32[i36 >> 2] | 0) >>> 0 : 0)) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 48:
     {
      i35 = i35 + 8 | 0;
      i33 = HEAP32[i35 + 4 >> 2] | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 + 4 >> 2] | 0;
      i36 = ((i33 | 0) > (i34 | 0) | ((i33 | 0) == (i34 | 0) ? (HEAP32[i35 >> 2] | 0) >>> 0 >= (HEAP32[i36 >> 2] | 0) >>> 0 : 0)) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 49:
     {
      i35 = i35 + 8 | 0;
      i33 = HEAP32[i35 + 4 >> 2] | 0;
      i36 = i36 + 8 | 0;
      i34 = HEAP32[i36 + 4 >> 2] | 0;
      i36 = (i33 >>> 0 > i34 >>> 0 | ((i33 | 0) == (i34 | 0) ? (HEAP32[i35 >> 2] | 0) >>> 0 >= (HEAP32[i36 >> 2] | 0) >>> 0 : 0)) & 1;
      HEAP32[i37 >> 2] = 1;
      HEAP32[i37 + 8 >> 2] = i36;
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    default:
     _abort();
    } while (0);
    break;
   }
  case 4:
  case 3:
   {
    do switch (HEAP32[i33 + 8 >> 2] | 0) {
    case 63:
    case 50:
     {
      __ZNK4wasm7Literal3addERKS0_(i12, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i12 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i12 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i12 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i12 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 64:
    case 51:
     {
      __ZNK4wasm7Literal3subERKS0_(i13, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i13 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i13 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i13 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i13 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 65:
    case 52:
     {
      __ZNK4wasm7Literal3mulERKS0_(i14, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i14 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i14 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i14 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i14 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 66:
    case 53:
     {
      __ZNK4wasm7Literal3divERKS0_(i15, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i15 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i15 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i15 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i15 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 67:
    case 54:
     {
      __ZNK4wasm7Literal8copysignERKS0_(i16, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i16 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i16 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i16 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i16 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 68:
    case 55:
     {
      __ZNK4wasm7Literal3minERKS0_(i18, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i18 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i18 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i18 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i18 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 69:
    case 56:
     {
      __ZNK4wasm7Literal3maxERKS0_(i19, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i19 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i19 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i19 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i19 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 70:
    case 57:
     {
      __ZNK4wasm7Literal2eqERKS0_(i20, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i20 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i20 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i20 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i20 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 71:
    case 58:
     {
      __ZNK4wasm7Literal2neERKS0_(i21, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i21 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i21 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i21 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i21 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 72:
    case 59:
     {
      __ZNK4wasm7Literal2ltERKS0_(i22, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i22 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i22 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i22 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i22 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 73:
    case 60:
     {
      __ZNK4wasm7Literal2leERKS0_(i23, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i23 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i23 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i23 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i23 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 74:
    case 61:
     {
      __ZNK4wasm7Literal2gtERKS0_(i24, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i24 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i24 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i24 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i24 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    case 75:
    case 62:
     {
      __ZNK4wasm7Literal2geERKS0_(i25, i35, i36);
      HEAP32[i37 >> 2] = HEAP32[i25 >> 2];
      HEAP32[i37 + 4 >> 2] = HEAP32[i25 + 4 >> 2];
      HEAP32[i37 + 8 >> 2] = HEAP32[i25 + 8 >> 2];
      HEAP32[i37 + 12 >> 2] = HEAP32[i25 + 12 >> 2];
      HEAP32[i37 + 16 >> 2] = 0;
      break L13;
     }
    default:
     _abort();
    } while (0);
    break;
   }
  default:
   _abort();
  } while (0);
 } else {
  HEAP32[i37 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i37 + 4 >> 2] = HEAP32[i4 + 4 >> 2];
  HEAP32[i37 + 8 >> 2] = HEAP32[i4 + 8 >> 2];
  HEAP32[i37 + 12 >> 2] = HEAP32[i4 + 12 >> 2];
  HEAP32[i37 + 16 >> 2] = HEAP32[i4 + 16 >> 2];
  HEAP32[i37 + 20 >> 2] = HEAP32[i4 + 20 >> 2];
 }
 STACKTOP = i38;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_118parse_expr_primaryINS0_2DbEEEPKcS4_S4_RT_(i1, i18, i35) {
 i1 = i1 | 0;
 i18 = i18 | 0;
 i35 = i35 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i36 = 0;
 i36 = STACKTOP;
 STACKTOP = STACKTOP + 480 | 0;
 i29 = i36 + 72 | 0;
 i28 = i36 + 48 | 0;
 i27 = i36 + 24 | 0;
 i32 = i36;
 i31 = i36 + 432 | 0;
 i33 = i36 + 408 | 0;
 i34 = i36 + 384 | 0;
 i11 = i36 + 396 | 0;
 i19 = i36 + 360 | 0;
 i20 = i36 + 336 | 0;
 i12 = i36 + 320 | 0;
 i13 = i36 + 308 | 0;
 i14 = i36 + 296 | 0;
 i15 = i36 + 284 | 0;
 i2 = i36 + 272 | 0;
 i3 = i36 + 260 | 0;
 i4 = i36 + 248 | 0;
 i5 = i36 + 236 | 0;
 i6 = i36 + 224 | 0;
 i7 = i36 + 212 | 0;
 i8 = i36 + 200 | 0;
 i9 = i36 + 188 | 0;
 i10 = i36 + 176 | 0;
 i21 = i36 + 152 | 0;
 i22 = i36 + 140 | 0;
 i23 = i36 + 128 | 0;
 i24 = i36 + 116 | 0;
 i25 = i36 + 104 | 0;
 i26 = i36 + 92 | 0;
 i17 = i18;
 L1 : do if ((i17 - i1 | 0) > 3 ? (HEAP8[i1 >> 0] | 0) == 76 : 0) {
  i16 = i1 + 1 | 0;
  do switch (HEAP8[i16 >> 0] | 0) {
  case 84:
   break L1;
  case 119:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i11 >> 2] = 0;
    HEAP32[i11 + 4 >> 2] = 0;
    HEAP32[i11 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i11, 56646, 7);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i11, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i11);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 98:
   {
    if ((HEAP8[i1 + 3 >> 0] | 0) != 69) break L1;
    switch (HEAP8[i1 + 2 >> 0] | 0) {
    case 48:
     {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj6EEERAT__Kc(i19, 56968);
      i2 = i35 + 4 | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      i34 = HEAP32[i35 + 8 >> 2] | 0;
      i4 = i34;
      if (i3 >>> 0 < i34 >>> 0) {
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i19);
       HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
      } else {
       i2 = HEAP32[i35 >> 2] | 0;
       i5 = (i3 - i2 | 0) / 24 | 0;
       i3 = i5 + 1 | 0;
       if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i35);
       i2 = (i4 - i2 | 0) / 24 | 0;
       if (i2 >>> 0 < 89478485) {
        i2 = i2 << 1;
        i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
       } else i2 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i32, i2, i5, i35 + 12 | 0);
       i34 = i32 + 8 | 0;
       i33 = HEAP32[i34 >> 2] | 0;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i19);
       HEAP32[i34 >> 2] = i33 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i35, i32);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i32);
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i19);
      i1 = i1 + 4 | 0;
      break L1;
     }
    case 49:
     {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj5EEERAT__Kc(i20, 56974);
      i2 = i35 + 4 | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      i34 = HEAP32[i35 + 8 >> 2] | 0;
      i4 = i34;
      if (i3 >>> 0 < i34 >>> 0) {
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i20);
       HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
      } else {
       i2 = HEAP32[i35 >> 2] | 0;
       i5 = (i3 - i2 | 0) / 24 | 0;
       i3 = i5 + 1 | 0;
       if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i35);
       i2 = (i4 - i2 | 0) / 24 | 0;
       if (i2 >>> 0 < 89478485) {
        i2 = i2 << 1;
        i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
       } else i2 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i32, i2, i5, i35 + 12 | 0);
       i34 = i32 + 8 | 0;
       i33 = HEAP32[i34 >> 2] | 0;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i33, i20);
       HEAP32[i34 >> 2] = i33 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i35, i32);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i32);
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i20);
      i1 = i1 + 4 | 0;
      break L1;
     }
    default:
     break L1;
    }
   }
  case 99:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i12 >> 2] = 0;
    HEAP32[i12 + 4 >> 2] = 0;
    HEAP32[i12 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i12, 56659, 4);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i12, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i12);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 97:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i13 >> 2] = 0;
    HEAP32[i13 + 4 >> 2] = 0;
    HEAP32[i13 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i13, 56664, 11);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i13, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i13);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 104:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i14 >> 2] = 0;
    HEAP32[i14 + 4 >> 2] = 0;
    HEAP32[i14 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i14, 56676, 13);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i14, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i14);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 115:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i15 >> 2] = 0;
    HEAP32[i15 + 4 >> 2] = 0;
    HEAP32[i15 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i15, 56690, 5);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i15, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 116:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i2 >> 2] = 0;
    HEAP32[i2 + 4 >> 2] = 0;
    HEAP32[i2 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i2, 56696, 14);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i2, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i2);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 105:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i3 >> 2] = 0;
    HEAP32[i3 + 4 >> 2] = 0;
    HEAP32[i3 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i3, 67717, 0);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i3, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i3);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 106:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i4 >> 2] = 0;
    HEAP32[i4 + 4 >> 2] = 0;
    HEAP32[i4 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i4, 56979, 1);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i4, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i4);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 108:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i5 >> 2] = 0;
    HEAP32[i5 + 4 >> 2] = 0;
    HEAP32[i5 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i5, 56981, 1);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i5, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i5);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 109:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i6 >> 2] = 0;
    HEAP32[i6 + 4 >> 2] = 0;
    HEAP32[i6 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i6, 56983, 2);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i6, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i6);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 120:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i7 >> 2] = 0;
    HEAP32[i7 + 4 >> 2] = 0;
    HEAP32[i7 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i7, 56986, 2);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i7, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i7);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 121:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i8 >> 2] = 0;
    HEAP32[i8 + 4 >> 2] = 0;
    HEAP32[i8 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i8, 56989, 3);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i8, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 110:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i9 >> 2] = 0;
    HEAP32[i9 + 4 >> 2] = 0;
    HEAP32[i9 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i9, 56776, 8);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i9, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i9);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 111:
   {
    i34 = i1 + 2 | 0;
    HEAP32[i10 >> 2] = 0;
    HEAP32[i10 + 4 >> 2] = 0;
    HEAP32[i10 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i10, 56785, 17);
    i35 = __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i34, i18, i10, i35) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i10);
    i1 = (i35 | 0) == (i34 | 0) ? i1 : i35;
    break L1;
   }
  case 102:
   {
    i6 = i1 + 2 | 0;
    L79 : do if ((i17 - i6 | 0) >>> 0 > 8) {
     i4 = i1 + 10 | 0;
     i2 = i32;
     i5 = i6;
     while (1) {
      i3 = HEAP8[i5 >> 0] | 0;
      if ((i5 | 0) == (i4 | 0)) {
       i30 = 41;
       break;
      }
      if (!(_isxdigit(i3 << 24 >> 24) | 0)) break;
      i29 = HEAP8[i5 >> 0] | 0;
      i28 = HEAP8[i5 + 1 >> 0] | 0;
      HEAP8[i2 >> 0] = (((i28 << 24 >> 24) + -48 | 0) >>> 0 < 10 ? 208 : 169) + (i28 & 255) + (((i29 + -48 | 0) >>> 0 < 10 ? 0 : 9) + i29 << 4);
      i2 = i2 + 1 | 0;
      i5 = i5 + 2 | 0;
     }
     do if ((i30 | 0) == 41) {
      if (i3 << 24 >> 24 == 69) {
       L89 : do if ((i32 | 0) != (i2 | 0)) {
        i3 = i32;
        while (1) {
         i2 = i2 + -1 | 0;
         if (i3 >>> 0 >= i2 >>> 0) break L89;
         i30 = HEAP8[i3 >> 0] | 0;
         HEAP8[i3 >> 0] = HEAP8[i2 >> 0] | 0;
         HEAP8[i2 >> 0] = i30;
         i3 = i3 + 1 | 0;
        }
       } while (0);
       i2 = i31;
       i3 = i2 + 24 | 0;
       do {
        HEAP8[i2 >> 0] = 0;
        i2 = i2 + 1 | 0;
       } while ((i2 | 0) < (i3 | 0));
       HEAPF64[i27 >> 3] = +HEAPF32[i32 >> 2];
       i2 = _snprintf(i31, 24, 56993, i27) | 0;
       if (i2 >>> 0 > 23) break;
       HEAP32[i34 >> 2] = 0;
       HEAP32[i34 + 4 >> 2] = 0;
       HEAP32[i34 + 8 >> 2] = 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i34, i31, i2);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i33, i34);
       i2 = i35 + 4 | 0;
       i3 = HEAP32[i2 >> 2] | 0;
       i32 = HEAP32[i35 + 8 >> 2] | 0;
       i4 = i32;
       if (i3 >>> 0 < i32 >>> 0) {
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i33);
        HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
       } else {
        i2 = HEAP32[i35 >> 2] | 0;
        i5 = (i3 - i2 | 0) / 24 | 0;
        i3 = i5 + 1 | 0;
        if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i35);
        i2 = (i4 - i2 | 0) / 24 | 0;
        if (i2 >>> 0 < 89478485) {
         i2 = i2 << 1;
         i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
        } else i2 = 178956970;
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i27, i2, i5, i35 + 12 | 0);
        i32 = i27 + 8 | 0;
        i31 = HEAP32[i32 >> 2] | 0;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i31, i33);
        HEAP32[i32 >> 2] = i31 + 24;
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i35, i27);
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i27);
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i33);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i34);
       i2 = i1 + 11 | 0;
      } else i2 = i6;
      break L79;
     } while (0);
     i2 = i6;
    } else i2 = i6; while (0);
    i1 = (i2 | 0) == (i6 | 0) ? i1 : i2;
    break L1;
   }
  case 100:
   {
    i6 = i1 + 2 | 0;
    L111 : do if ((i17 - i6 | 0) >>> 0 > 16) {
     i4 = i1 + 18 | 0;
     i2 = i32;
     i5 = i6;
     while (1) {
      i3 = HEAP8[i5 >> 0] | 0;
      if ((i5 | 0) == (i4 | 0)) {
       i30 = 63;
       break;
      }
      if (!(_isxdigit(i3 << 24 >> 24) | 0)) break;
      i29 = HEAP8[i5 >> 0] | 0;
      i27 = HEAP8[i5 + 1 >> 0] | 0;
      HEAP8[i2 >> 0] = (((i27 << 24 >> 24) + -48 | 0) >>> 0 < 10 ? 208 : 169) + (i27 & 255) + (((i29 + -48 | 0) >>> 0 < 10 ? 0 : 9) + i29 << 4);
      i2 = i2 + 1 | 0;
      i5 = i5 + 2 | 0;
     }
     do if ((i30 | 0) == 63) {
      if (i3 << 24 >> 24 == 69) {
       L121 : do if ((i32 | 0) != (i2 | 0)) {
        i3 = i32;
        while (1) {
         i2 = i2 + -1 | 0;
         if (i3 >>> 0 >= i2 >>> 0) break L121;
         i30 = HEAP8[i3 >> 0] | 0;
         HEAP8[i3 >> 0] = HEAP8[i2 >> 0] | 0;
         HEAP8[i2 >> 0] = i30;
         i3 = i3 + 1 | 0;
        }
       } while (0);
       i2 = i31;
       i3 = i2 + 32 | 0;
       do {
        HEAP8[i2 >> 0] = 0;
        i2 = i2 + 1 | 0;
       } while ((i2 | 0) < (i3 | 0));
       HEAPF64[i28 >> 3] = +HEAPF64[i32 >> 3];
       i2 = _snprintf(i31, 32, 56997, i28) | 0;
       if (i2 >>> 0 > 31) break;
       HEAP32[i34 >> 2] = 0;
       HEAP32[i34 + 4 >> 2] = 0;
       HEAP32[i34 + 8 >> 2] = 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i34, i31, i2);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i33, i34);
       i2 = i35 + 4 | 0;
       i3 = HEAP32[i2 >> 2] | 0;
       i32 = HEAP32[i35 + 8 >> 2] | 0;
       i4 = i32;
       if (i3 >>> 0 < i32 >>> 0) {
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i33);
        HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
       } else {
        i2 = HEAP32[i35 >> 2] | 0;
        i5 = (i3 - i2 | 0) / 24 | 0;
        i3 = i5 + 1 | 0;
        if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i35);
        i2 = (i4 - i2 | 0) / 24 | 0;
        if (i2 >>> 0 < 89478485) {
         i2 = i2 << 1;
         i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
        } else i2 = 178956970;
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i28, i2, i5, i35 + 12 | 0);
        i32 = i28 + 8 | 0;
        i31 = HEAP32[i32 >> 2] | 0;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i31, i33);
        HEAP32[i32 >> 2] = i31 + 24;
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i35, i28);
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i28);
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i33);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i34);
       i2 = i1 + 19 | 0;
      } else i2 = i6;
      break L111;
     } while (0);
     i2 = i6;
    } else i2 = i6; while (0);
    i1 = (i2 | 0) == (i6 | 0) ? i1 : i2;
    break L1;
   }
  case 101:
   {
    i6 = i1 + 2 | 0;
    L143 : do if ((i17 - i6 | 0) >>> 0 > 20) {
     i4 = i1 + 22 | 0;
     i2 = i32;
     i5 = i6;
     while (1) {
      i3 = HEAP8[i5 >> 0] | 0;
      if ((i5 | 0) == (i4 | 0)) {
       i30 = 85;
       break;
      }
      if (!(_isxdigit(i3 << 24 >> 24) | 0)) break;
      i28 = HEAP8[i5 >> 0] | 0;
      i27 = HEAP8[i5 + 1 >> 0] | 0;
      HEAP8[i2 >> 0] = (((i27 << 24 >> 24) + -48 | 0) >>> 0 < 10 ? 208 : 169) + (i27 & 255) + (((i28 + -48 | 0) >>> 0 < 10 ? 0 : 9) + i28 << 4);
      i2 = i2 + 1 | 0;
      i5 = i5 + 2 | 0;
     }
     do if ((i30 | 0) == 85) {
      if (i3 << 24 >> 24 == 69) {
       L153 : do if ((i32 | 0) != (i2 | 0)) {
        i3 = i32;
        while (1) {
         i2 = i2 + -1 | 0;
         if (i3 >>> 0 >= i2 >>> 0) break L153;
         i30 = HEAP8[i3 >> 0] | 0;
         HEAP8[i3 >> 0] = HEAP8[i2 >> 0] | 0;
         HEAP8[i2 >> 0] = i30;
         i3 = i3 + 1 | 0;
        }
       } while (0);
       i2 = i31;
       i3 = i2 + 40 | 0;
       do {
        HEAP8[i2 >> 0] = 0;
        i2 = i2 + 1 | 0;
       } while ((i2 | 0) < (i3 | 0));
       HEAPF64[i29 >> 3] = +HEAPF64[i32 >> 3];
       i2 = _snprintf(i31, 40, 57e3, i29) | 0;
       if (i2 >>> 0 > 39) break;
       HEAP32[i34 >> 2] = 0;
       HEAP32[i34 + 4 >> 2] = 0;
       HEAP32[i34 + 8 >> 2] = 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i34, i31, i2);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i33, i34);
       i2 = i35 + 4 | 0;
       i3 = HEAP32[i2 >> 2] | 0;
       i32 = HEAP32[i35 + 8 >> 2] | 0;
       i4 = i32;
       if (i3 >>> 0 < i32 >>> 0) {
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i33);
        HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
       } else {
        i2 = HEAP32[i35 >> 2] | 0;
        i5 = (i3 - i2 | 0) / 24 | 0;
        i3 = i5 + 1 | 0;
        if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i35);
        i2 = (i4 - i2 | 0) / 24 | 0;
        if (i2 >>> 0 < 89478485) {
         i2 = i2 << 1;
         i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
        } else i2 = 178956970;
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i29, i2, i5, i35 + 12 | 0);
        i32 = i29 + 8 | 0;
        i31 = HEAP32[i32 >> 2] | 0;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i31, i33);
        HEAP32[i32 >> 2] = i31 + 24;
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i35, i29);
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i29);
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i33);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i34);
       i2 = i1 + 23 | 0;
      } else i2 = i6;
      break L143;
     } while (0);
     i2 = i6;
    } else i2 = i6; while (0);
    i1 = (i2 | 0) == (i6 | 0) ? i1 : i2;
    break L1;
   }
  case 95:
   {
    if ((HEAP8[i1 + 2 >> 0] | 0) != 90) break L1;
    i34 = i1 + 3 | 0;
    i2 = __ZN10__cxxabiv112_GLOBAL__N_114parse_encodingINS0_2DbEEEPKcS4_S4_RT_(i34, i18, i35) | 0;
    if ((i2 | 0) == (i34 | 0) | (i2 | 0) == (i18 | 0)) break L1;
    i1 = (HEAP8[i2 >> 0] | 0) == 69 ? i2 + 1 | 0 : i1;
    break L1;
   }
  default:
   {
    i6 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i16, i18, i35) | 0;
    if ((i6 | 0) == (i16 | 0) | (i6 | 0) == (i18 | 0)) break L1;
    if ((HEAP8[i6 >> 0] | 0) == 69) {
     i1 = i6 + 1 | 0;
     break L1;
    } else i3 = i6;
    while (1) {
     if ((i3 | 0) == (i18 | 0)) break L1;
     i2 = HEAP8[i3 >> 0] | 0;
     if (((i2 << 24 >> 24) + -48 | 0) >>> 0 >= 10) {
      i7 = i3;
      break;
     }
     i3 = i3 + 1 | 0;
    }
    if (!((i7 | 0) != (i6 | 0) & i2 << 24 >> 24 == 69)) break L1;
    i2 = HEAP32[i35 + 4 >> 2] | 0;
    if ((HEAP32[i35 >> 2] | 0) == (i2 | 0)) break L1;
    i5 = i2 + -24 | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i25, i5);
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i25, 0, 56964) | 0;
    HEAP32[i24 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i24 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i24 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i24, 56966) | 0;
    HEAP32[i23 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i23 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i23 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    HEAP32[i26 >> 2] = 0;
    HEAP32[i26 + 4 >> 2] = 0;
    HEAP32[i26 + 8 >> 2] = 0;
    i3 = i7 - i6 | 0;
    if (i3 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i26);
    if (i3 >>> 0 < 11) {
     HEAP8[i26 + 11 >> 0] = i3;
     i4 = i26;
    } else {
     i35 = i3 + 16 & -16;
     i4 = _malloc(i35) | 0;
     HEAP32[i26 >> 2] = i4;
     HEAP32[i26 + 8 >> 2] = i35 | -2147483648;
     HEAP32[i26 + 4 >> 2] = i3;
    }
    i1 = i6;
    i2 = i4;
    while (1) {
     if ((i1 | 0) == (i7 | 0)) break;
     HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
     i1 = i1 + 1 | 0;
     i2 = i2 + 1 | 0;
    }
    HEAP8[i4 + i3 >> 0] = 0;
    i1 = HEAP8[i26 + 11 >> 0] | 0;
    i2 = i1 << 24 >> 24 < 0;
    i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i23, i2 ? HEAP32[i26 >> 2] | 0 : i26, i2 ? HEAP32[i26 + 4 >> 2] | 0 : i1 & 255) | 0;
    HEAP32[i22 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i22 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
    HEAP32[i22 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i21, i22);
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i5, i21);
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i21);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i22);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i26);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i23);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i24);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i25);
    i1 = i7 + 1 | 0;
    break L1;
   }
  } while (0);
 } while (0);
 STACKTOP = i36;
 return i1 | 0;
}

function _printf_core(i50, i3, i51, i52, i53) {
 i50 = i50 | 0;
 i3 = i3 | 0;
 i51 = i51 | 0;
 i52 = i52 | 0;
 i53 = i53 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0, d6 = 0.0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, d13 = 0.0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i54 = 0;
 i54 = STACKTOP;
 STACKTOP = STACKTOP + 624 | 0;
 i45 = i54 + 24 | 0;
 i47 = i54 + 16 | 0;
 i46 = i54 + 588 | 0;
 i42 = i54 + 576 | 0;
 i44 = i54;
 i37 = i54 + 536 | 0;
 i49 = i54 + 8 | 0;
 i48 = i54 + 528 | 0;
 i27 = (i50 | 0) != 0;
 i28 = i37 + 40 | 0;
 i36 = i28;
 i37 = i37 + 39 | 0;
 i38 = i49 + 4 | 0;
 i39 = i46;
 i40 = 0 - i39 | 0;
 i41 = i42 + 12 | 0;
 i42 = i42 + 11 | 0;
 i43 = i41;
 i29 = i43 - i39 | 0;
 i30 = -2 - i39 | 0;
 i31 = i43 + 2 | 0;
 i32 = i45 + 288 | 0;
 i33 = i46 + 9 | 0;
 i34 = i33;
 i35 = i46 + 8 | 0;
 i1 = 0;
 i4 = 0;
 i2 = 0;
 i14 = i3;
 L1 : while (1) {
  do if ((i1 | 0) > -1) if ((i4 | 0) > (2147483647 - i1 | 0)) {
   i1 = ___errno_location() | 0;
   HEAP32[i1 >> 2] = 75;
   i1 = -1;
   break;
  } else {
   i1 = i4 + i1 | 0;
   break;
  } while (0);
  i3 = HEAP8[i14 >> 0] | 0;
  if (!(i3 << 24 >> 24)) {
   i26 = 244;
   break;
  } else i4 = i14;
  L9 : while (1) {
   switch (i3 << 24 >> 24) {
   case 37:
    {
     i3 = i4;
     i26 = 9;
     break L9;
    }
   case 0:
    {
     i3 = i4;
     break L9;
    }
   default:
    {}
   }
   i25 = i4 + 1 | 0;
   i3 = HEAP8[i25 >> 0] | 0;
   i4 = i25;
  }
  L12 : do if ((i26 | 0) == 9) while (1) {
   i26 = 0;
   if ((HEAP8[i3 + 1 >> 0] | 0) != 37) break L12;
   i4 = i4 + 1 | 0;
   i3 = i3 + 2 | 0;
   if ((HEAP8[i3 >> 0] | 0) == 37) i26 = 9; else break;
  } while (0);
  i12 = i4 - i14 | 0;
  if (i27 ? (HEAP32[i50 >> 2] & 32 | 0) == 0 : 0) ___fwritex(i14, i12, i50) | 0;
  if ((i4 | 0) != (i14 | 0)) {
   i4 = i12;
   i14 = i3;
   continue;
  }
  i7 = i3 + 1 | 0;
  i4 = HEAP8[i7 >> 0] | 0;
  i5 = (i4 << 24 >> 24) + -48 | 0;
  if (i5 >>> 0 < 10) {
   i25 = (HEAP8[i3 + 2 >> 0] | 0) == 36;
   i7 = i25 ? i3 + 3 | 0 : i7;
   i4 = HEAP8[i7 >> 0] | 0;
   i10 = i25 ? i5 : -1;
   i2 = i25 ? 1 : i2;
  } else i10 = -1;
  i3 = i4 << 24 >> 24;
  L25 : do if ((i3 & -32 | 0) == 32) {
   i5 = 0;
   while (1) {
    if (!(1 << i3 + -32 & 75913)) {
     i8 = i5;
     break L25;
    }
    i5 = 1 << (i4 << 24 >> 24) + -32 | i5;
    i7 = i7 + 1 | 0;
    i4 = HEAP8[i7 >> 0] | 0;
    i3 = i4 << 24 >> 24;
    if ((i3 & -32 | 0) != 32) {
     i8 = i5;
     break;
    }
   }
  } else i8 = 0; while (0);
  do if (i4 << 24 >> 24 == 42) {
   i4 = i7 + 1 | 0;
   i3 = (HEAP8[i4 >> 0] | 0) + -48 | 0;
   if (i3 >>> 0 < 10 ? (HEAP8[i7 + 2 >> 0] | 0) == 36 : 0) {
    HEAP32[i53 + (i3 << 2) >> 2] = 10;
    i2 = 1;
    i7 = i7 + 3 | 0;
    i3 = HEAP32[i52 + ((HEAP8[i4 >> 0] | 0) + -48 << 3) >> 2] | 0;
   } else {
    if (i2 | 0) {
     i1 = -1;
     break L1;
    }
    if (!i27) {
     i11 = i8;
     i2 = 0;
     i7 = i4;
     i25 = 0;
     break;
    }
    i2 = (HEAP32[i51 >> 2] | 0) + (4 - 1) & ~(4 - 1);
    i3 = HEAP32[i2 >> 2] | 0;
    HEAP32[i51 >> 2] = i2 + 4;
    i2 = 0;
    i7 = i4;
   }
   if ((i3 | 0) < 0) {
    i11 = i8 | 8192;
    i25 = 0 - i3 | 0;
   } else {
    i11 = i8;
    i25 = i3;
   }
  } else {
   i5 = (i4 << 24 >> 24) + -48 | 0;
   if (i5 >>> 0 < 10) {
    i3 = i7;
    i4 = 0;
    do {
     i4 = (i4 * 10 | 0) + i5 | 0;
     i3 = i3 + 1 | 0;
     i5 = (HEAP8[i3 >> 0] | 0) + -48 | 0;
    } while (i5 >>> 0 < 10);
    if ((i4 | 0) < 0) {
     i1 = -1;
     break L1;
    } else {
     i11 = i8;
     i7 = i3;
     i25 = i4;
    }
   } else {
    i11 = i8;
    i25 = 0;
   }
  } while (0);
  L46 : do if ((HEAP8[i7 >> 0] | 0) == 46) {
   i3 = i7 + 1 | 0;
   i4 = HEAP8[i3 >> 0] | 0;
   if (i4 << 24 >> 24 != 42) {
    i5 = (i4 << 24 >> 24) + -48 | 0;
    if (i5 >>> 0 < 10) i4 = 0; else {
     i8 = 0;
     break;
    }
    while (1) {
     i4 = (i4 * 10 | 0) + i5 | 0;
     i3 = i3 + 1 | 0;
     i5 = (HEAP8[i3 >> 0] | 0) + -48 | 0;
     if (i5 >>> 0 >= 10) {
      i8 = i4;
      break L46;
     }
    }
   }
   i3 = i7 + 2 | 0;
   i4 = (HEAP8[i3 >> 0] | 0) + -48 | 0;
   if (i4 >>> 0 < 10 ? (HEAP8[i7 + 3 >> 0] | 0) == 36 : 0) {
    HEAP32[i53 + (i4 << 2) >> 2] = 10;
    i8 = HEAP32[i52 + ((HEAP8[i3 >> 0] | 0) + -48 << 3) >> 2] | 0;
    i3 = i7 + 4 | 0;
    break;
   }
   if (i2 | 0) {
    i1 = -1;
    break L1;
   }
   if (i27) {
    i24 = (HEAP32[i51 >> 2] | 0) + (4 - 1) & ~(4 - 1);
    i8 = HEAP32[i24 >> 2] | 0;
    HEAP32[i51 >> 2] = i24 + 4;
   } else i8 = 0;
  } else {
   i8 = -1;
   i3 = i7;
  } while (0);
  i9 = 0;
  while (1) {
   i4 = (HEAP8[i3 >> 0] | 0) + -65 | 0;
   if (i4 >>> 0 > 57) {
    i1 = -1;
    break L1;
   }
   i5 = i3 + 1 | 0;
   i4 = HEAP8[49955 + (i9 * 58 | 0) + i4 >> 0] | 0;
   i7 = i4 & 255;
   if ((i7 + -1 | 0) >>> 0 < 8) {
    i3 = i5;
    i9 = i7;
   } else {
    i24 = i5;
    break;
   }
  }
  if (!(i4 << 24 >> 24)) {
   i1 = -1;
   break;
  }
  i5 = (i10 | 0) > -1;
  do if (i4 << 24 >> 24 == 19) if (i5) {
   i1 = -1;
   break L1;
  } else i26 = 52; else {
   if (i5) {
    HEAP32[i53 + (i10 << 2) >> 2] = i7;
    i22 = i52 + (i10 << 3) | 0;
    i23 = HEAP32[i22 + 4 >> 2] | 0;
    i26 = i44;
    HEAP32[i26 >> 2] = HEAP32[i22 >> 2];
    HEAP32[i26 + 4 >> 2] = i23;
    i26 = 52;
    break;
   }
   if (!i27) {
    i1 = 0;
    break L1;
   }
   _pop_arg_529(i44, i7, i51);
  } while (0);
  if ((i26 | 0) == 52 ? (i26 = 0, !i27) : 0) {
   i4 = i12;
   i14 = i24;
   continue;
  }
  i10 = HEAP8[i3 >> 0] | 0;
  i10 = (i9 | 0) != 0 & (i10 & 15 | 0) == 3 ? i10 & -33 : i10;
  i5 = i11 & -65537;
  i23 = (i11 & 8192 | 0) == 0 ? i11 : i5;
  L75 : do switch (i10 | 0) {
  case 110:
   switch (i9 | 0) {
   case 0:
    {
     HEAP32[HEAP32[i44 >> 2] >> 2] = i1;
     i4 = i12;
     i14 = i24;
     continue L1;
    }
   case 1:
    {
     HEAP32[HEAP32[i44 >> 2] >> 2] = i1;
     i4 = i12;
     i14 = i24;
     continue L1;
    }
   case 2:
    {
     i4 = HEAP32[i44 >> 2] | 0;
     HEAP32[i4 >> 2] = i1;
     HEAP32[i4 + 4 >> 2] = ((i1 | 0) < 0) << 31 >> 31;
     i4 = i12;
     i14 = i24;
     continue L1;
    }
   case 3:
    {
     HEAP16[HEAP32[i44 >> 2] >> 1] = i1;
     i4 = i12;
     i14 = i24;
     continue L1;
    }
   case 4:
    {
     HEAP8[HEAP32[i44 >> 2] >> 0] = i1;
     i4 = i12;
     i14 = i24;
     continue L1;
    }
   case 6:
    {
     HEAP32[HEAP32[i44 >> 2] >> 2] = i1;
     i4 = i12;
     i14 = i24;
     continue L1;
    }
   case 7:
    {
     i4 = HEAP32[i44 >> 2] | 0;
     HEAP32[i4 >> 2] = i1;
     HEAP32[i4 + 4 >> 2] = ((i1 | 0) < 0) << 31 >> 31;
     i4 = i12;
     i14 = i24;
     continue L1;
    }
   default:
    {
     i4 = i12;
     i14 = i24;
     continue L1;
    }
   }
  case 112:
   {
    i9 = i23 | 8;
    i8 = i8 >>> 0 > 8 ? i8 : 8;
    i10 = 120;
    i26 = 64;
    break;
   }
  case 88:
  case 120:
   {
    i9 = i23;
    i26 = 64;
    break;
   }
  case 111:
   {
    i5 = i44;
    i4 = HEAP32[i5 >> 2] | 0;
    i5 = HEAP32[i5 + 4 >> 2] | 0;
    if ((i4 | 0) == 0 & (i5 | 0) == 0) i3 = i28; else {
     i3 = i28;
     do {
      i3 = i3 + -1 | 0;
      HEAP8[i3 >> 0] = i4 & 7 | 48;
      i4 = _bitshift64Lshr(i4 | 0, i5 | 0, 3) | 0;
      i5 = tempRet0;
     } while (!((i4 | 0) == 0 & (i5 | 0) == 0));
    }
    if (!(i23 & 8)) {
     i4 = i23;
     i9 = 0;
     i7 = 50435;
     i26 = 77;
    } else {
     i9 = i36 - i3 | 0;
     i4 = i23;
     i8 = (i8 | 0) > (i9 | 0) ? i8 : i9 + 1 | 0;
     i9 = 0;
     i7 = 50435;
     i26 = 77;
    }
    break;
   }
  case 105:
  case 100:
   {
    i4 = i44;
    i3 = HEAP32[i4 >> 2] | 0;
    i4 = HEAP32[i4 + 4 >> 2] | 0;
    if ((i4 | 0) < 0) {
     i3 = _i64Subtract(0, 0, i3 | 0, i4 | 0) | 0;
     i4 = tempRet0;
     i5 = i44;
     HEAP32[i5 >> 2] = i3;
     HEAP32[i5 + 4 >> 2] = i4;
     i5 = 1;
     i7 = 50435;
     i26 = 76;
     break L75;
    }
    if (!(i23 & 2048)) {
     i7 = i23 & 1;
     i5 = i7;
     i7 = (i7 | 0) == 0 ? 50435 : 50437;
     i26 = 76;
    } else {
     i5 = 1;
     i7 = 50436;
     i26 = 76;
    }
    break;
   }
  case 117:
   {
    i4 = i44;
    i3 = HEAP32[i4 >> 2] | 0;
    i4 = HEAP32[i4 + 4 >> 2] | 0;
    i5 = 0;
    i7 = 50435;
    i26 = 76;
    break;
   }
  case 99:
   {
    HEAP8[i37 >> 0] = HEAP32[i44 >> 2];
    i3 = i37;
    i10 = 1;
    i12 = 0;
    i11 = 50435;
    i4 = i28;
    break;
   }
  case 109:
   {
    i4 = ___errno_location() | 0;
    i4 = _strerror(HEAP32[i4 >> 2] | 0) | 0;
    i26 = 82;
    break;
   }
  case 115:
   {
    i4 = HEAP32[i44 >> 2] | 0;
    i4 = i4 | 0 ? i4 : 52337;
    i26 = 82;
    break;
   }
  case 67:
   {
    HEAP32[i49 >> 2] = HEAP32[i44 >> 2];
    HEAP32[i38 >> 2] = 0;
    HEAP32[i44 >> 2] = i49;
    i3 = i49;
    i8 = -1;
    i26 = 86;
    break;
   }
  case 83:
   {
    i3 = HEAP32[i44 >> 2] | 0;
    if (!i8) {
     _pad(i50, 32, i25, 0, i23);
     i3 = 0;
     i26 = 97;
    } else i26 = 86;
    break;
   }
  case 65:
  case 71:
  case 70:
  case 69:
  case 97:
  case 103:
  case 102:
  case 101:
   {
    d6 = +HEAPF64[i44 >> 3];
    HEAP32[i47 >> 2] = 0;
    HEAPF64[tempDoublePtr >> 3] = d6;
    if ((HEAP32[tempDoublePtr + 4 >> 2] | 0) >= 0) if (!(i23 & 2048)) {
     i22 = i23 & 1;
     i21 = i22;
     i22 = (i22 | 0) == 0 ? 52345 : 52350;
    } else {
     i21 = 1;
     i22 = 52347;
    } else {
     d6 = -d6;
     i21 = 1;
     i22 = 52344;
    }
    HEAPF64[tempDoublePtr >> 3] = d6;
    i20 = HEAP32[tempDoublePtr + 4 >> 2] & 2146435072;
    do if (i20 >>> 0 < 2146435072 | (i20 | 0) == 2146435072 & 0 < 0) {
     d13 = +_frexpl(d6, i47) * 2.0;
     i4 = d13 != 0.0;
     if (i4) HEAP32[i47 >> 2] = (HEAP32[i47 >> 2] | 0) + -1;
     i18 = i10 | 32;
     if ((i18 | 0) == 97) {
      i11 = i10 & 32;
      i14 = (i11 | 0) == 0 ? i22 : i22 + 9 | 0;
      i12 = i21 | 2;
      i3 = 12 - i8 | 0;
      do if (!(i8 >>> 0 > 11 | (i3 | 0) == 0)) {
       d6 = 8.0;
       do {
        i3 = i3 + -1 | 0;
        d6 = d6 * 16.0;
       } while ((i3 | 0) != 0);
       if ((HEAP8[i14 >> 0] | 0) == 45) {
        d6 = -(d6 + (-d13 - d6));
        break;
       } else {
        d6 = d13 + d6 - d6;
        break;
       }
      } else d6 = d13; while (0);
      i4 = HEAP32[i47 >> 2] | 0;
      i3 = (i4 | 0) < 0 ? 0 - i4 | 0 : i4;
      i3 = _fmt_u(i3, ((i3 | 0) < 0) << 31 >> 31, i41) | 0;
      if ((i3 | 0) == (i41 | 0)) {
       HEAP8[i42 >> 0] = 48;
       i3 = i42;
      }
      HEAP8[i3 + -1 >> 0] = (i4 >> 31 & 2) + 43;
      i9 = i3 + -2 | 0;
      HEAP8[i9 >> 0] = i10 + 15;
      i7 = (i8 | 0) < 1;
      i5 = (i23 & 8 | 0) == 0;
      i4 = i46;
      while (1) {
       i22 = ~~d6;
       i3 = i4 + 1 | 0;
       HEAP8[i4 >> 0] = HEAPU8[50419 + i22 >> 0] | i11;
       d6 = (d6 - +(i22 | 0)) * 16.0;
       do if ((i3 - i39 | 0) == 1) {
        if (i5 & (i7 & d6 == 0.0)) break;
        HEAP8[i3 >> 0] = 46;
        i3 = i4 + 2 | 0;
       } while (0);
       if (!(d6 != 0.0)) break; else i4 = i3;
      }
      i5 = i9;
      i8 = (i8 | 0) != 0 & (i30 + i3 | 0) < (i8 | 0) ? i31 + i8 - i5 | 0 : i29 - i5 + i3 | 0;
      i7 = i8 + i12 | 0;
      _pad(i50, 32, i25, i7, i23);
      if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i14, i12, i50) | 0;
      _pad(i50, 48, i25, i7, i23 ^ 65536);
      i4 = i3 - i39 | 0;
      if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i46, i4, i50) | 0;
      i3 = i43 - i5 | 0;
      _pad(i50, 48, i8 - (i4 + i3) | 0, 0, 0);
      if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i9, i3, i50) | 0;
      _pad(i50, 32, i25, i7, i23 ^ 8192);
      i3 = (i7 | 0) < (i25 | 0) ? i25 : i7;
      break;
     }
     i3 = (i8 | 0) < 0 ? 6 : i8;
     if (i4) {
      i4 = (HEAP32[i47 >> 2] | 0) + -28 | 0;
      HEAP32[i47 >> 2] = i4;
      d6 = d13 * 268435456.0;
     } else {
      d6 = d13;
      i4 = HEAP32[i47 >> 2] | 0;
     }
     i20 = (i4 | 0) < 0 ? i45 : i32;
     i19 = i20;
     i4 = i20;
     do {
      i17 = ~~d6 >>> 0;
      HEAP32[i4 >> 2] = i17;
      i4 = i4 + 4 | 0;
      d6 = (d6 - +(i17 >>> 0)) * 1.0e9;
     } while (d6 != 0.0);
     i5 = i4;
     i4 = HEAP32[i47 >> 2] | 0;
     if ((i4 | 0) > 0) {
      i8 = i20;
      while (1) {
       i9 = (i4 | 0) > 29 ? 29 : i4;
       i7 = i5 + -4 | 0;
       do if (i7 >>> 0 < i8 >>> 0) i7 = i8; else {
        i4 = 0;
        do {
         i17 = _bitshift64Shl(HEAP32[i7 >> 2] | 0, 0, i9 | 0) | 0;
         i17 = _i64Add(i17 | 0, tempRet0 | 0, i4 | 0, 0) | 0;
         i4 = tempRet0;
         i16 = ___uremdi3(i17 | 0, i4 | 0, 1e9, 0) | 0;
         HEAP32[i7 >> 2] = i16;
         i4 = ___udivdi3(i17 | 0, i4 | 0, 1e9, 0) | 0;
         i7 = i7 + -4 | 0;
        } while (i7 >>> 0 >= i8 >>> 0);
        if (!i4) {
         i7 = i8;
         break;
        }
        i7 = i8 + -4 | 0;
        HEAP32[i7 >> 2] = i4;
       } while (0);
       while (1) {
        if (i5 >>> 0 <= i7 >>> 0) break;
        i4 = i5 + -4 | 0;
        if (!(HEAP32[i4 >> 2] | 0)) i5 = i4; else break;
       }
       i4 = (HEAP32[i47 >> 2] | 0) - i9 | 0;
       HEAP32[i47 >> 2] = i4;
       if ((i4 | 0) > 0) i8 = i7; else break;
      }
     } else i7 = i20;
     if ((i4 | 0) < 0) {
      i14 = ((i3 + 25 | 0) / 9 | 0) + 1 | 0;
      i15 = (i18 | 0) == 102;
      i11 = i7;
      while (1) {
       i12 = 0 - i4 | 0;
       i12 = (i12 | 0) > 9 ? 9 : i12;
       do if (i11 >>> 0 < i5 >>> 0) {
        i4 = (1 << i12) + -1 | 0;
        i8 = 1e9 >>> i12;
        i7 = 0;
        i9 = i11;
        do {
         i17 = HEAP32[i9 >> 2] | 0;
         HEAP32[i9 >> 2] = (i17 >>> i12) + i7;
         i7 = Math_imul(i17 & i4, i8) | 0;
         i9 = i9 + 4 | 0;
        } while (i9 >>> 0 < i5 >>> 0);
        i4 = (HEAP32[i11 >> 2] | 0) == 0 ? i11 + 4 | 0 : i11;
        if (!i7) {
         i7 = i4;
         break;
        }
        HEAP32[i5 >> 2] = i7;
        i7 = i4;
        i5 = i5 + 4 | 0;
       } else i7 = (HEAP32[i11 >> 2] | 0) == 0 ? i11 + 4 | 0 : i11; while (0);
       i4 = i15 ? i20 : i7;
       i5 = (i5 - i4 >> 2 | 0) > (i14 | 0) ? i4 + (i14 << 2) | 0 : i5;
       i4 = (HEAP32[i47 >> 2] | 0) + i12 | 0;
       HEAP32[i47 >> 2] = i4;
       if ((i4 | 0) >= 0) {
        i15 = i7;
        break;
       } else i11 = i7;
      }
     } else i15 = i7;
     do if (i15 >>> 0 < i5 >>> 0) {
      i4 = (i19 - i15 >> 2) * 9 | 0;
      i8 = HEAP32[i15 >> 2] | 0;
      if (i8 >>> 0 < 10) break; else i7 = 10;
      do {
       i7 = i7 * 10 | 0;
       i4 = i4 + 1 | 0;
      } while (i8 >>> 0 >= i7 >>> 0);
     } else i4 = 0; while (0);
     i16 = (i18 | 0) == 103;
     i17 = (i3 | 0) != 0;
     i7 = i3 - ((i18 | 0) != 102 ? i4 : 0) + ((i17 & i16) << 31 >> 31) | 0;
     if ((i7 | 0) < (((i5 - i19 >> 2) * 9 | 0) + -9 | 0)) {
      i9 = i7 + 9216 | 0;
      i7 = i20 + 4 + (((i9 | 0) / 9 | 0) + -1024 << 2) | 0;
      i9 = ((i9 | 0) % 9 | 0) + 1 | 0;
      if ((i9 | 0) < 9) {
       i8 = 10;
       do {
        i8 = i8 * 10 | 0;
        i9 = i9 + 1 | 0;
       } while ((i9 | 0) != 9);
      } else i8 = 10;
      i12 = HEAP32[i7 >> 2] | 0;
      i14 = (i12 >>> 0) % (i8 >>> 0) | 0;
      i9 = (i7 + 4 | 0) == (i5 | 0);
      do if (i9 & (i14 | 0) == 0) i8 = i15; else {
       d13 = (((i12 >>> 0) / (i8 >>> 0) | 0) & 1 | 0) == 0 ? 9007199254740992.0 : 9007199254740994.0;
       i11 = (i8 | 0) / 2 | 0;
       if (i14 >>> 0 < i11 >>> 0) d6 = .5; else d6 = i9 & (i14 | 0) == (i11 | 0) ? 1.0 : 1.5;
       do if (i21) {
        if ((HEAP8[i22 >> 0] | 0) != 45) break;
        d13 = -d13;
        d6 = -d6;
       } while (0);
       i9 = i12 - i14 | 0;
       HEAP32[i7 >> 2] = i9;
       if (!(d13 + d6 != d13)) {
        i8 = i15;
        break;
       }
       i18 = i9 + i8 | 0;
       HEAP32[i7 >> 2] = i18;
       if (i18 >>> 0 > 999999999) {
        i4 = i15;
        while (1) {
         i8 = i7 + -4 | 0;
         HEAP32[i7 >> 2] = 0;
         if (i8 >>> 0 < i4 >>> 0) {
          i4 = i4 + -4 | 0;
          HEAP32[i4 >> 2] = 0;
         }
         i18 = (HEAP32[i8 >> 2] | 0) + 1 | 0;
         HEAP32[i8 >> 2] = i18;
         if (i18 >>> 0 > 999999999) i7 = i8; else {
          i11 = i4;
          i7 = i8;
          break;
         }
        }
       } else i11 = i15;
       i4 = (i19 - i11 >> 2) * 9 | 0;
       i9 = HEAP32[i11 >> 2] | 0;
       if (i9 >>> 0 < 10) {
        i8 = i11;
        break;
       } else i8 = 10;
       do {
        i8 = i8 * 10 | 0;
        i4 = i4 + 1 | 0;
       } while (i9 >>> 0 >= i8 >>> 0);
       i8 = i11;
      } while (0);
      i18 = i7 + 4 | 0;
      i15 = i8;
      i5 = i5 >>> 0 > i18 >>> 0 ? i18 : i5;
     }
     i12 = 0 - i4 | 0;
     while (1) {
      if (i5 >>> 0 <= i15 >>> 0) {
       i14 = 0;
       i18 = i5;
       break;
      }
      i7 = i5 + -4 | 0;
      if (!(HEAP32[i7 >> 2] | 0)) i5 = i7; else {
       i14 = 1;
       i18 = i5;
       break;
      }
     }
     do if (i16) {
      i3 = (i17 & 1 ^ 1) + i3 | 0;
      if ((i3 | 0) > (i4 | 0) & (i4 | 0) > -5) {
       i10 = i10 + -1 | 0;
       i3 = i3 + -1 - i4 | 0;
      } else {
       i10 = i10 + -2 | 0;
       i3 = i3 + -1 | 0;
      }
      i5 = i23 & 8;
      if (i5 | 0) break;
      do if (i14) {
       i5 = HEAP32[i18 + -4 >> 2] | 0;
       if (!i5) {
        i7 = 9;
        break;
       }
       if (!((i5 >>> 0) % 10 | 0)) {
        i8 = 10;
        i7 = 0;
       } else {
        i7 = 0;
        break;
       }
       do {
        i8 = i8 * 10 | 0;
        i7 = i7 + 1 | 0;
       } while (!((i5 >>> 0) % (i8 >>> 0) | 0 | 0));
      } else i7 = 9; while (0);
      i5 = ((i18 - i19 >> 2) * 9 | 0) + -9 | 0;
      if ((i10 | 32 | 0) == 102) {
       i5 = i5 - i7 | 0;
       i5 = (i5 | 0) < 0 ? 0 : i5;
       i3 = (i3 | 0) < (i5 | 0) ? i3 : i5;
       i5 = 0;
       break;
      } else {
       i5 = i5 + i4 - i7 | 0;
       i5 = (i5 | 0) < 0 ? 0 : i5;
       i3 = (i3 | 0) < (i5 | 0) ? i3 : i5;
       i5 = 0;
       break;
      }
     } else i5 = i23 & 8; while (0);
     i11 = i3 | i5;
     i8 = (i11 | 0) != 0 & 1;
     i9 = (i10 | 32 | 0) == 102;
     if (i9) {
      i4 = (i4 | 0) > 0 ? i4 : 0;
      i10 = 0;
     } else {
      i7 = (i4 | 0) < 0 ? i12 : i4;
      i7 = _fmt_u(i7, ((i7 | 0) < 0) << 31 >> 31, i41) | 0;
      if ((i43 - i7 | 0) < 2) do {
       i7 = i7 + -1 | 0;
       HEAP8[i7 >> 0] = 48;
      } while ((i43 - i7 | 0) < 2);
      HEAP8[i7 + -1 >> 0] = (i4 >> 31 & 2) + 43;
      i19 = i7 + -2 | 0;
      HEAP8[i19 >> 0] = i10;
      i4 = i43 - i19 | 0;
      i10 = i19;
     }
     i12 = i21 + 1 + i3 + i8 + i4 | 0;
     _pad(i50, 32, i25, i12, i23);
     if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i22, i21, i50) | 0;
     _pad(i50, 48, i25, i12, i23 ^ 65536);
     do if (i9) {
      i7 = i15 >>> 0 > i20 >>> 0 ? i20 : i15;
      i4 = i7;
      do {
       i5 = _fmt_u(HEAP32[i4 >> 2] | 0, 0, i33) | 0;
       do if ((i4 | 0) == (i7 | 0)) {
        if ((i5 | 0) != (i33 | 0)) break;
        HEAP8[i35 >> 0] = 48;
        i5 = i35;
       } else {
        if (i5 >>> 0 <= i46 >>> 0) break;
        _memset(i46 | 0, 48, i5 - i39 | 0) | 0;
        do i5 = i5 + -1 | 0; while (i5 >>> 0 > i46 >>> 0);
       } while (0);
       if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i5, i34 - i5 | 0, i50) | 0;
       i4 = i4 + 4 | 0;
      } while (i4 >>> 0 <= i20 >>> 0);
      do if (i11 | 0) {
       if (HEAP32[i50 >> 2] & 32 | 0) break;
       ___fwritex(58005, 1, i50) | 0;
      } while (0);
      if ((i3 | 0) > 0 & i4 >>> 0 < i18 >>> 0) {
       i5 = i4;
       while (1) {
        i4 = _fmt_u(HEAP32[i5 >> 2] | 0, 0, i33) | 0;
        if (i4 >>> 0 > i46 >>> 0) {
         _memset(i46 | 0, 48, i4 - i39 | 0) | 0;
         do i4 = i4 + -1 | 0; while (i4 >>> 0 > i46 >>> 0);
        }
        if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i4, (i3 | 0) > 9 ? 9 : i3, i50) | 0;
        i5 = i5 + 4 | 0;
        i4 = i3 + -9 | 0;
        if (!((i3 | 0) > 9 & i5 >>> 0 < i18 >>> 0)) {
         i3 = i4;
         break;
        } else i3 = i4;
       }
      }
      _pad(i50, 48, i3 + 9 | 0, 9, 0);
     } else {
      i9 = i14 ? i18 : i15 + 4 | 0;
      if ((i3 | 0) > -1) {
       i8 = (i5 | 0) == 0;
       i7 = i15;
       do {
        i4 = _fmt_u(HEAP32[i7 >> 2] | 0, 0, i33) | 0;
        if ((i4 | 0) == (i33 | 0)) {
         HEAP8[i35 >> 0] = 48;
         i4 = i35;
        }
        do if ((i7 | 0) == (i15 | 0)) {
         i5 = i4 + 1 | 0;
         if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i4, 1, i50) | 0;
         if (i8 & (i3 | 0) < 1) {
          i4 = i5;
          break;
         }
         if (HEAP32[i50 >> 2] & 32 | 0) {
          i4 = i5;
          break;
         }
         ___fwritex(58005, 1, i50) | 0;
         i4 = i5;
        } else {
         if (i4 >>> 0 <= i46 >>> 0) break;
         _memset(i46 | 0, 48, i4 + i40 | 0) | 0;
         do i4 = i4 + -1 | 0; while (i4 >>> 0 > i46 >>> 0);
        } while (0);
        i5 = i34 - i4 | 0;
        if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i4, (i3 | 0) > (i5 | 0) ? i5 : i3, i50) | 0;
        i3 = i3 - i5 | 0;
        i7 = i7 + 4 | 0;
       } while (i7 >>> 0 < i9 >>> 0 & (i3 | 0) > -1);
      }
      _pad(i50, 48, i3 + 18 | 0, 18, 0);
      if (HEAP32[i50 >> 2] & 32 | 0) break;
      ___fwritex(i10, i43 - i10 | 0, i50) | 0;
     } while (0);
     _pad(i50, 32, i25, i12, i23 ^ 8192);
     i3 = (i12 | 0) < (i25 | 0) ? i25 : i12;
    } else {
     i9 = (i10 & 32 | 0) != 0;
     i8 = d6 != d6 | 0.0 != 0.0;
     i4 = i8 ? 0 : i21;
     i7 = i4 + 3 | 0;
     _pad(i50, 32, i25, i7, i5);
     i3 = HEAP32[i50 >> 2] | 0;
     if (!(i3 & 32)) {
      ___fwritex(i22, i4, i50) | 0;
      i3 = HEAP32[i50 >> 2] | 0;
     }
     if (!(i3 & 32)) ___fwritex(i8 ? (i9 ? 52371 : 52375) : i9 ? 52363 : 52367, 3, i50) | 0;
     _pad(i50, 32, i25, i7, i23 ^ 8192);
     i3 = (i7 | 0) < (i25 | 0) ? i25 : i7;
    } while (0);
    i4 = i3;
    i14 = i24;
    continue L1;
   }
  default:
   {
    i3 = i14;
    i5 = i23;
    i10 = i8;
    i12 = 0;
    i11 = 50435;
    i4 = i28;
   }
  } while (0);
  L311 : do if ((i26 | 0) == 64) {
   i5 = i44;
   i4 = HEAP32[i5 >> 2] | 0;
   i5 = HEAP32[i5 + 4 >> 2] | 0;
   i7 = i10 & 32;
   if (!((i4 | 0) == 0 & (i5 | 0) == 0)) {
    i3 = i28;
    do {
     i3 = i3 + -1 | 0;
     HEAP8[i3 >> 0] = HEAPU8[50419 + (i4 & 15) >> 0] | i7;
     i4 = _bitshift64Lshr(i4 | 0, i5 | 0, 4) | 0;
     i5 = tempRet0;
    } while (!((i4 | 0) == 0 & (i5 | 0) == 0));
    i26 = i44;
    if ((i9 & 8 | 0) == 0 | (HEAP32[i26 >> 2] | 0) == 0 & (HEAP32[i26 + 4 >> 2] | 0) == 0) {
     i4 = i9;
     i9 = 0;
     i7 = 50435;
     i26 = 77;
    } else {
     i4 = i9;
     i9 = 2;
     i7 = 50435 + (i10 >> 4) | 0;
     i26 = 77;
    }
   } else {
    i3 = i28;
    i4 = i9;
    i9 = 0;
    i7 = 50435;
    i26 = 77;
   }
  } else if ((i26 | 0) == 76) {
   i3 = _fmt_u(i3, i4, i28) | 0;
   i4 = i23;
   i9 = i5;
   i26 = 77;
  } else if ((i26 | 0) == 82) {
   i26 = 0;
   i23 = _memchr(i4, 0, i8) | 0;
   i22 = (i23 | 0) == 0;
   i3 = i4;
   i10 = i22 ? i8 : i23 - i4 | 0;
   i12 = 0;
   i11 = 50435;
   i4 = i22 ? i4 + i8 | 0 : i23;
  } else if ((i26 | 0) == 86) {
   i26 = 0;
   i5 = 0;
   i4 = 0;
   i9 = i3;
   while (1) {
    i7 = HEAP32[i9 >> 2] | 0;
    if (!i7) break;
    i4 = _wctomb(i48, i7) | 0;
    if ((i4 | 0) < 0 | i4 >>> 0 > (i8 - i5 | 0) >>> 0) break;
    i5 = i4 + i5 | 0;
    if (i8 >>> 0 > i5 >>> 0) i9 = i9 + 4 | 0; else break;
   }
   if ((i4 | 0) < 0) {
    i1 = -1;
    break L1;
   }
   _pad(i50, 32, i25, i5, i23);
   if (!i5) {
    i3 = 0;
    i26 = 97;
   } else {
    i7 = 0;
    while (1) {
     i4 = HEAP32[i3 >> 2] | 0;
     if (!i4) {
      i3 = i5;
      i26 = 97;
      break L311;
     }
     i4 = _wctomb(i48, i4) | 0;
     i7 = i4 + i7 | 0;
     if ((i7 | 0) > (i5 | 0)) {
      i3 = i5;
      i26 = 97;
      break L311;
     }
     if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i48, i4, i50) | 0;
     if (i7 >>> 0 >= i5 >>> 0) {
      i3 = i5;
      i26 = 97;
      break;
     } else i3 = i3 + 4 | 0;
    }
   }
  } while (0);
  if ((i26 | 0) == 97) {
   i26 = 0;
   _pad(i50, 32, i25, i3, i23 ^ 8192);
   i4 = (i25 | 0) > (i3 | 0) ? i25 : i3;
   i14 = i24;
   continue;
  }
  if ((i26 | 0) == 77) {
   i26 = 0;
   i5 = (i8 | 0) > -1 ? i4 & -65537 : i4;
   i4 = i44;
   i4 = (HEAP32[i4 >> 2] | 0) != 0 | (HEAP32[i4 + 4 >> 2] | 0) != 0;
   if ((i8 | 0) != 0 | i4) {
    i10 = (i4 & 1 ^ 1) + (i36 - i3) | 0;
    i10 = (i8 | 0) > (i10 | 0) ? i8 : i10;
    i12 = i9;
    i11 = i7;
    i4 = i28;
   } else {
    i3 = i28;
    i10 = 0;
    i12 = i9;
    i11 = i7;
    i4 = i28;
   }
  }
  i9 = i4 - i3 | 0;
  i7 = (i10 | 0) < (i9 | 0) ? i9 : i10;
  i8 = i12 + i7 | 0;
  i4 = (i25 | 0) < (i8 | 0) ? i8 : i25;
  _pad(i50, 32, i4, i8, i5);
  if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i11, i12, i50) | 0;
  _pad(i50, 48, i4, i8, i5 ^ 65536);
  _pad(i50, 48, i7, i9, 0);
  if (!(HEAP32[i50 >> 2] & 32)) ___fwritex(i3, i9, i50) | 0;
  _pad(i50, 32, i4, i8, i5 ^ 8192);
  i14 = i24;
 }
 L345 : do if ((i26 | 0) == 244) if (!i50) if (i2) {
  i1 = 1;
  while (1) {
   i2 = HEAP32[i53 + (i1 << 2) >> 2] | 0;
   if (!i2) break;
   _pop_arg_529(i52 + (i1 << 3) | 0, i2, i51);
   i1 = i1 + 1 | 0;
   if ((i1 | 0) >= 10) {
    i1 = 1;
    break L345;
   }
  }
  if ((i1 | 0) < 10) while (1) {
   if (HEAP32[i53 + (i1 << 2) >> 2] | 0) {
    i1 = -1;
    break L345;
   }
   i1 = i1 + 1 | 0;
   if ((i1 | 0) >= 10) {
    i1 = 1;
    break;
   }
  } else i1 = 1;
 } else i1 = 0; while (0);
 STACKTOP = i54;
 return i1 | 0;
}

function ___floatscan(i24, i2, i21) {
 i24 = i24 | 0;
 i2 = i2 | 0;
 i21 = i21 | 0;
 var d1 = 0.0, i3 = 0, d4 = 0.0, i5 = 0, i6 = 0, d7 = 0.0, i8 = 0, i9 = 0, i10 = 0, d11 = 0.0, d12 = 0.0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i22 = 0, i23 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, d32 = 0.0;
 i31 = STACKTOP;
 STACKTOP = STACKTOP + 512 | 0;
 i27 = i31;
 switch (i2 | 0) {
 case 0:
  {
   i30 = 24;
   i29 = -149;
   i19 = 4;
   break;
  }
 case 1:
  {
   i30 = 53;
   i29 = -1074;
   i19 = 4;
   break;
  }
 case 2:
  {
   i30 = 53;
   i29 = -1074;
   i19 = 4;
   break;
  }
 default:
  d1 = 0.0;
 }
 L4 : do if ((i19 | 0) == 4) {
  i23 = i24 + 4 | 0;
  i22 = i24 + 100 | 0;
  do {
   i2 = HEAP32[i23 >> 2] | 0;
   if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
    HEAP32[i23 >> 2] = i2 + 1;
    i2 = HEAPU8[i2 >> 0] | 0;
   } else i2 = ___shgetc(i24) | 0;
  } while ((_isspace(i2) | 0) != 0);
  L13 : do switch (i2 | 0) {
  case 43:
  case 45:
   {
    i3 = 1 - (((i2 | 0) == 45 & 1) << 1) | 0;
    i2 = HEAP32[i23 >> 2] | 0;
    if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
     HEAP32[i23 >> 2] = i2 + 1;
     i2 = HEAPU8[i2 >> 0] | 0;
     i28 = i3;
     break L13;
    } else {
     i2 = ___shgetc(i24) | 0;
     i28 = i3;
     break L13;
    }
   }
  default:
   i28 = 1;
  } while (0);
  i3 = i2;
  i2 = 0;
  do {
   if ((i3 | 32 | 0) != (HEAP8[49946 + i2 >> 0] | 0)) break;
   do if (i2 >>> 0 < 7) {
    i3 = HEAP32[i23 >> 2] | 0;
    if (i3 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
     HEAP32[i23 >> 2] = i3 + 1;
     i3 = HEAPU8[i3 >> 0] | 0;
     break;
    } else {
     i3 = ___shgetc(i24) | 0;
     break;
    }
   } while (0);
   i2 = i2 + 1 | 0;
  } while (i2 >>> 0 < 8);
  L29 : do switch (i2 | 0) {
  case 8:
   break;
  case 3:
   {
    i19 = 23;
    break;
   }
  default:
   {
    i5 = (i21 | 0) != 0;
    if (i5 & i2 >>> 0 > 3) if ((i2 | 0) == 8) break L29; else {
     i19 = 23;
     break L29;
    }
    L34 : do if (!i2) {
     i2 = 0;
     do {
      if ((i3 | 32 | 0) != (HEAP8[52371 + i2 >> 0] | 0)) break L34;
      do if (i2 >>> 0 < 2) {
       i3 = HEAP32[i23 >> 2] | 0;
       if (i3 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
        HEAP32[i23 >> 2] = i3 + 1;
        i3 = HEAPU8[i3 >> 0] | 0;
        break;
       } else {
        i3 = ___shgetc(i24) | 0;
        break;
       }
      } while (0);
      i2 = i2 + 1 | 0;
     } while (i2 >>> 0 < 3);
    } while (0);
    switch (i2 | 0) {
    case 3:
     {
      i2 = HEAP32[i23 >> 2] | 0;
      if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
       HEAP32[i23 >> 2] = i2 + 1;
       i2 = HEAPU8[i2 >> 0] | 0;
      } else i2 = ___shgetc(i24) | 0;
      if ((i2 | 0) == 40) i2 = 1; else {
       if (!(HEAP32[i22 >> 2] | 0)) {
        d1 = nan;
        break L4;
       }
       HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
       d1 = nan;
       break L4;
      }
      while (1) {
       i3 = HEAP32[i23 >> 2] | 0;
       if (i3 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
        HEAP32[i23 >> 2] = i3 + 1;
        i3 = HEAPU8[i3 >> 0] | 0;
       } else i3 = ___shgetc(i24) | 0;
       if (!((i3 + -48 | 0) >>> 0 < 10 | (i3 + -65 | 0) >>> 0 < 26) ? !((i3 | 0) == 95 | (i3 + -97 | 0) >>> 0 < 26) : 0) break;
       i2 = i2 + 1 | 0;
      }
      if ((i3 | 0) == 41) {
       d1 = nan;
       break L4;
      }
      i3 = (HEAP32[i22 >> 2] | 0) == 0;
      if (!i3) HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
      if (!i5) {
       i30 = ___errno_location() | 0;
       HEAP32[i30 >> 2] = 22;
       ___shlim(i24, 0);
       d1 = 0.0;
       break L4;
      }
      if (!i2) {
       d1 = nan;
       break L4;
      }
      while (1) {
       i2 = i2 + -1 | 0;
       if (!i3) HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
       if (!i2) {
        d1 = nan;
        break L4;
       }
      }
     }
    case 0:
     {
      do if ((i3 | 0) == 48) {
       i2 = HEAP32[i23 >> 2] | 0;
       if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
        HEAP32[i23 >> 2] = i2 + 1;
        i2 = HEAPU8[i2 >> 0] | 0;
       } else i2 = ___shgetc(i24) | 0;
       if ((i2 | 32 | 0) != 120) {
        if (!(HEAP32[i22 >> 2] | 0)) {
         i2 = 48;
         break;
        }
        HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
        i2 = 48;
        break;
       }
       i2 = HEAP32[i23 >> 2] | 0;
       if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
        HEAP32[i23 >> 2] = i2 + 1;
        i2 = HEAPU8[i2 >> 0] | 0;
        i5 = 0;
       } else {
        i2 = ___shgetc(i24) | 0;
        i5 = 0;
       }
       L94 : while (1) {
        switch (i2 | 0) {
        case 46:
         {
          i19 = 74;
          break L94;
         }
        case 48:
         break;
        default:
         {
          i17 = 0;
          i6 = 0;
          i16 = 0;
          i3 = 0;
          i8 = i5;
          i9 = 0;
          i15 = 0;
          d7 = 1.0;
          i5 = 0;
          d1 = 0.0;
          break L94;
         }
        }
        i2 = HEAP32[i23 >> 2] | 0;
        if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
         HEAP32[i23 >> 2] = i2 + 1;
         i2 = HEAPU8[i2 >> 0] | 0;
         i5 = 1;
         continue;
        } else {
         i2 = ___shgetc(i24) | 0;
         i5 = 1;
         continue;
        }
       }
       if ((i19 | 0) == 74) {
        i2 = HEAP32[i23 >> 2] | 0;
        if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
         HEAP32[i23 >> 2] = i2 + 1;
         i2 = HEAPU8[i2 >> 0] | 0;
        } else i2 = ___shgetc(i24) | 0;
        if ((i2 | 0) == 48) {
         i5 = 0;
         i3 = 0;
         do {
          i2 = HEAP32[i23 >> 2] | 0;
          if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
           HEAP32[i23 >> 2] = i2 + 1;
           i2 = HEAPU8[i2 >> 0] | 0;
          } else i2 = ___shgetc(i24) | 0;
          i5 = _i64Add(i5 | 0, i3 | 0, -1, -1) | 0;
          i3 = tempRet0;
         } while ((i2 | 0) == 48);
         i17 = 0;
         i6 = 0;
         i16 = i5;
         i8 = 1;
         i9 = 1;
         i15 = 0;
         d7 = 1.0;
         i5 = 0;
         d1 = 0.0;
        } else {
         i17 = 0;
         i6 = 0;
         i16 = 0;
         i3 = 0;
         i8 = i5;
         i9 = 1;
         i15 = 0;
         d7 = 1.0;
         i5 = 0;
         d1 = 0.0;
        }
       }
       while (1) {
        i13 = i2 + -48 | 0;
        i10 = i2 | 32;
        if (i13 >>> 0 >= 10) {
         i14 = (i2 | 0) == 46;
         if (!(i14 | (i10 + -97 | 0) >>> 0 < 6)) {
          i10 = i16;
          i13 = i17;
          break;
         }
         if (i14) if (!i9) {
          i14 = i6;
          i3 = i17;
          i13 = i17;
          i9 = 1;
          i10 = i15;
          d4 = d7;
         } else {
          i10 = i16;
          i13 = i17;
          i2 = 46;
          break;
         } else i19 = 86;
        } else i19 = 86;
        if ((i19 | 0) == 86) {
         i19 = 0;
         i2 = (i2 | 0) > 57 ? i10 + -87 | 0 : i13;
         do if (!((i17 | 0) < 0 | (i17 | 0) == 0 & i6 >>> 0 < 8)) {
          if ((i17 | 0) < 0 | (i17 | 0) == 0 & i6 >>> 0 < 14) {
           d12 = d7 * .0625;
           i10 = i15;
           d4 = d12;
           d1 = d1 + d12 * +(i2 | 0);
           break;
          }
          if ((i15 | 0) != 0 | (i2 | 0) == 0) {
           i10 = i15;
           d4 = d7;
          } else {
           i10 = 1;
           d4 = d7;
           d1 = d1 + d7 * .5;
          }
         } else {
          i10 = i15;
          d4 = d7;
          i5 = i2 + (i5 << 4) | 0;
         } while (0);
         i6 = _i64Add(i6 | 0, i17 | 0, 1, 0) | 0;
         i14 = i16;
         i13 = tempRet0;
         i8 = 1;
        }
        i2 = HEAP32[i23 >> 2] | 0;
        if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
         HEAP32[i23 >> 2] = i2 + 1;
         i17 = i13;
         i16 = i14;
         i2 = HEAPU8[i2 >> 0] | 0;
         i15 = i10;
         d7 = d4;
         continue;
        } else {
         i17 = i13;
         i16 = i14;
         i2 = ___shgetc(i24) | 0;
         i15 = i10;
         d7 = d4;
         continue;
        }
       }
       if (!i8) {
        i2 = (HEAP32[i22 >> 2] | 0) == 0;
        if (!i2) HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
        if (i21) {
         if (!i2 ? (i18 = HEAP32[i23 >> 2] | 0, HEAP32[i23 >> 2] = i18 + -1, i9 | 0) : 0) HEAP32[i23 >> 2] = i18 + -2;
        } else ___shlim(i24, 0);
        d1 = +(i28 | 0) * 0.0;
        break L4;
       }
       i8 = (i9 | 0) == 0;
       i9 = i8 ? i6 : i10;
       i8 = i8 ? i13 : i3;
       if ((i13 | 0) < 0 | (i13 | 0) == 0 & i6 >>> 0 < 8) {
        i3 = i13;
        do {
         i5 = i5 << 4;
         i6 = _i64Add(i6 | 0, i3 | 0, 1, 0) | 0;
         i3 = tempRet0;
        } while ((i3 | 0) < 0 | (i3 | 0) == 0 & i6 >>> 0 < 8);
       }
       if ((i2 | 32 | 0) == 112) {
        i3 = _scanexp(i24, i21) | 0;
        i2 = tempRet0;
        if ((i3 | 0) == 0 & (i2 | 0) == -2147483648) {
         if (!i21) {
          ___shlim(i24, 0);
          d1 = 0.0;
          break L4;
         }
         if (!(HEAP32[i22 >> 2] | 0)) {
          i3 = 0;
          i2 = 0;
         } else {
          HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
          i3 = 0;
          i2 = 0;
         }
        }
       } else if (!(HEAP32[i22 >> 2] | 0)) {
        i3 = 0;
        i2 = 0;
       } else {
        HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
        i3 = 0;
        i2 = 0;
       }
       i27 = _bitshift64Shl(i9 | 0, i8 | 0, 2) | 0;
       i27 = _i64Add(i27 | 0, tempRet0 | 0, -32, -1) | 0;
       i2 = _i64Add(i27 | 0, tempRet0 | 0, i3 | 0, i2 | 0) | 0;
       i3 = tempRet0;
       if (!i5) {
        d1 = +(i28 | 0) * 0.0;
        break L4;
       }
       if ((i3 | 0) > 0 | (i3 | 0) == 0 & i2 >>> 0 > (0 - i29 | 0) >>> 0) {
        i30 = ___errno_location() | 0;
        HEAP32[i30 >> 2] = 34;
        d1 = +(i28 | 0) * 1797693134862315708145274.0e284 * 1797693134862315708145274.0e284;
        break L4;
       }
       i27 = i29 + -106 | 0;
       i26 = ((i27 | 0) < 0) << 31 >> 31;
       if ((i3 | 0) < (i26 | 0) | (i3 | 0) == (i26 | 0) & i2 >>> 0 < i27 >>> 0) {
        i30 = ___errno_location() | 0;
        HEAP32[i30 >> 2] = 34;
        d1 = +(i28 | 0) * 2.2250738585072014e-308 * 2.2250738585072014e-308;
        break L4;
       }
       if ((i5 | 0) > -1) {
        do {
         i26 = !(d1 >= .5);
         i27 = i26 & 1 | i5 << 1;
         i5 = i27 ^ 1;
         d1 = d1 + (i26 ? d1 : d1 + -1.0);
         i2 = _i64Add(i2 | 0, i3 | 0, -1, -1) | 0;
         i3 = tempRet0;
        } while ((i27 | 0) > -1);
        i6 = i2;
        d7 = d1;
       } else {
        i6 = i2;
        d7 = d1;
       }
       i2 = _i64Subtract(32, 0, i29 | 0, ((i29 | 0) < 0) << 31 >> 31 | 0) | 0;
       i2 = _i64Add(i6 | 0, i3 | 0, i2 | 0, tempRet0 | 0) | 0;
       i29 = tempRet0;
       if (0 > (i29 | 0) | 0 == (i29 | 0) & i30 >>> 0 > i2 >>> 0) if ((i2 | 0) < 0) {
        i2 = 0;
        i19 = 127;
       } else i19 = 125; else {
        i2 = i30;
        i19 = 125;
       }
       if ((i19 | 0) == 125) if ((i2 | 0) < 53) i19 = 127; else {
        i3 = i2;
        d4 = +(i28 | 0);
        d1 = 0.0;
       }
       if ((i19 | 0) == 127) {
        d1 = +(i28 | 0);
        i3 = i2;
        d4 = d1;
        d1 = +_copysignl(+_scalbn(1.0, 84 - i2 | 0), d1);
       }
       i30 = (i5 & 1 | 0) == 0 & (d7 != 0.0 & (i3 | 0) < 32);
       d1 = d4 * (i30 ? 0.0 : d7) + (d1 + d4 * +(((i30 & 1) + i5 | 0) >>> 0)) - d1;
       if (!(d1 != 0.0)) {
        i30 = ___errno_location() | 0;
        HEAP32[i30 >> 2] = 34;
       }
       d1 = +_scalbnl(d1, i6);
       break L4;
      } else i2 = i3; while (0);
      i25 = i29 + i30 | 0;
      i26 = 0 - i25 | 0;
      i5 = 0;
      L184 : while (1) {
       switch (i2 | 0) {
       case 46:
        {
         i19 = 138;
         break L184;
        }
       case 48:
        break;
       default:
        {
         i3 = 0;
         i10 = 0;
         i9 = 0;
         break L184;
        }
       }
       i2 = HEAP32[i23 >> 2] | 0;
       if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
        HEAP32[i23 >> 2] = i2 + 1;
        i2 = HEAPU8[i2 >> 0] | 0;
        i5 = 1;
        continue;
       } else {
        i2 = ___shgetc(i24) | 0;
        i5 = 1;
        continue;
       }
      }
      if ((i19 | 0) == 138) {
       i2 = HEAP32[i23 >> 2] | 0;
       if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
        HEAP32[i23 >> 2] = i2 + 1;
        i2 = HEAPU8[i2 >> 0] | 0;
       } else i2 = ___shgetc(i24) | 0;
       if ((i2 | 0) == 48) {
        i3 = 0;
        i2 = 0;
        while (1) {
         i3 = _i64Add(i3 | 0, i2 | 0, -1, -1) | 0;
         i5 = tempRet0;
         i2 = HEAP32[i23 >> 2] | 0;
         if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
          HEAP32[i23 >> 2] = i2 + 1;
          i2 = HEAPU8[i2 >> 0] | 0;
         } else i2 = ___shgetc(i24) | 0;
         if ((i2 | 0) == 48) i2 = i5; else {
          i10 = i5;
          i5 = 1;
          i9 = 1;
          break;
         }
        }
       } else {
        i3 = 0;
        i10 = 0;
        i9 = 1;
       }
      }
      HEAP32[i27 >> 2] = 0;
      i8 = i2 + -48 | 0;
      i6 = (i2 | 0) == 46;
      L203 : do if (i6 | i8 >>> 0 < 10) {
       i20 = i27 + 496 | 0;
       i17 = 0;
       i14 = 0;
       i15 = i6;
       i19 = i10;
       i13 = i5;
       i18 = i9;
       i5 = 0;
       i6 = 0;
       i9 = 0;
       L205 : while (1) {
        do if (i15) if (!i18) {
         i3 = i17;
         i10 = i14;
         i18 = 1;
        } else {
         i10 = i19;
         i2 = i17;
         i8 = i14;
         break L205;
        } else {
         i15 = _i64Add(i17 | 0, i14 | 0, 1, 0) | 0;
         i14 = tempRet0;
         i16 = (i2 | 0) != 48;
         if ((i6 | 0) >= 125) {
          if (!i16) {
           i10 = i19;
           i17 = i15;
           break;
          }
          HEAP32[i20 >> 2] = HEAP32[i20 >> 2] | 1;
          i10 = i19;
          i17 = i15;
          break;
         }
         i10 = i27 + (i6 << 2) | 0;
         if (i5) i8 = i2 + -48 + ((HEAP32[i10 >> 2] | 0) * 10 | 0) | 0;
         HEAP32[i10 >> 2] = i8;
         i5 = i5 + 1 | 0;
         i8 = (i5 | 0) == 9;
         i10 = i19;
         i17 = i15;
         i13 = 1;
         i5 = i8 ? 0 : i5;
         i6 = (i8 & 1) + i6 | 0;
         i9 = i16 ? i15 : i9;
        } while (0);
        i2 = HEAP32[i23 >> 2] | 0;
        if (i2 >>> 0 < (HEAP32[i22 >> 2] | 0) >>> 0) {
         HEAP32[i23 >> 2] = i2 + 1;
         i2 = HEAPU8[i2 >> 0] | 0;
        } else i2 = ___shgetc(i24) | 0;
        i8 = i2 + -48 | 0;
        i15 = (i2 | 0) == 46;
        if (!(i15 | i8 >>> 0 < 10)) {
         i8 = i18;
         i19 = 161;
         break L203;
        } else i19 = i10;
       }
       i13 = (i13 | 0) != 0;
       i19 = 169;
      } else {
       i17 = 0;
       i14 = 0;
       i13 = i5;
       i8 = i9;
       i5 = 0;
       i6 = 0;
       i9 = 0;
       i19 = 161;
      } while (0);
      do if ((i19 | 0) == 161) {
       i20 = (i8 | 0) == 0;
       i3 = i20 ? i17 : i3;
       i10 = i20 ? i14 : i10;
       i13 = (i13 | 0) != 0;
       if (!((i2 | 32 | 0) == 101 & i13)) if ((i2 | 0) > -1) {
        i2 = i17;
        i8 = i14;
        i19 = 169;
        break;
       } else {
        i2 = i17;
        i8 = i14;
        i19 = 171;
        break;
       }
       i8 = _scanexp(i24, i21) | 0;
       i2 = tempRet0;
       if ((i8 | 0) == 0 & (i2 | 0) == -2147483648) {
        if (!i21) {
         ___shlim(i24, 0);
         d1 = 0.0;
         break;
        }
        if (!(HEAP32[i22 >> 2] | 0)) {
         i8 = 0;
         i2 = 0;
        } else {
         HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
         i8 = 0;
         i2 = 0;
        }
       }
       i3 = _i64Add(i8 | 0, i2 | 0, i3 | 0, i10 | 0) | 0;
       i13 = i17;
       i10 = tempRet0;
       i8 = i14;
       i19 = 173;
      } while (0);
      if ((i19 | 0) == 169) if (HEAP32[i22 >> 2] | 0) {
       HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
       if (i13) {
        i13 = i2;
        i19 = 173;
       } else i19 = 172;
      } else i19 = 171;
      if ((i19 | 0) == 171) if (i13) {
       i13 = i2;
       i19 = 173;
      } else i19 = 172;
      do if ((i19 | 0) == 172) {
       i30 = ___errno_location() | 0;
       HEAP32[i30 >> 2] = 22;
       ___shlim(i24, 0);
       d1 = 0.0;
      } else if ((i19 | 0) == 173) {
       i2 = HEAP32[i27 >> 2] | 0;
       if (!i2) {
        d1 = +(i28 | 0) * 0.0;
        break;
       }
       if (((i8 | 0) < 0 | (i8 | 0) == 0 & i13 >>> 0 < 10) & ((i3 | 0) == (i13 | 0) & (i10 | 0) == (i8 | 0)) ? i30 >>> 0 > 30 | (i2 >>> i30 | 0) == 0 : 0) {
        d1 = +(i28 | 0) * +(i2 >>> 0);
        break;
       }
       i24 = (i29 | 0) / -2 | 0;
       i23 = ((i24 | 0) < 0) << 31 >> 31;
       if ((i10 | 0) > (i23 | 0) | (i10 | 0) == (i23 | 0) & i3 >>> 0 > i24 >>> 0) {
        i30 = ___errno_location() | 0;
        HEAP32[i30 >> 2] = 34;
        d1 = +(i28 | 0) * 1797693134862315708145274.0e284 * 1797693134862315708145274.0e284;
        break;
       }
       i24 = i29 + -106 | 0;
       i23 = ((i24 | 0) < 0) << 31 >> 31;
       if ((i10 | 0) < (i23 | 0) | (i10 | 0) == (i23 | 0) & i3 >>> 0 < i24 >>> 0) {
        i30 = ___errno_location() | 0;
        HEAP32[i30 >> 2] = 34;
        d1 = +(i28 | 0) * 2.2250738585072014e-308 * 2.2250738585072014e-308;
        break;
       }
       if (i5) {
        if ((i5 | 0) < 9) {
         i8 = i27 + (i6 << 2) | 0;
         i2 = HEAP32[i8 >> 2] | 0;
         do {
          i2 = i2 * 10 | 0;
          i5 = i5 + 1 | 0;
         } while ((i5 | 0) != 9);
         HEAP32[i8 >> 2] = i2;
        }
        i6 = i6 + 1 | 0;
       }
       if ((i9 | 0) < 9 ? (i9 | 0) <= (i3 | 0) & (i3 | 0) < 18 : 0) {
        if ((i3 | 0) == 9) {
         d1 = +(i28 | 0) * +((HEAP32[i27 >> 2] | 0) >>> 0);
         break;
        }
        if ((i3 | 0) < 9) {
         d1 = +(i28 | 0) * +((HEAP32[i27 >> 2] | 0) >>> 0) / +(HEAP32[8400 + (8 - i3 << 2) >> 2] | 0);
         break;
        }
        i24 = i30 + 27 + (Math_imul(i3, -3) | 0) | 0;
        i2 = HEAP32[i27 >> 2] | 0;
        if ((i24 | 0) > 30 | (i2 >>> i24 | 0) == 0) {
         d1 = +(i28 | 0) * +(i2 >>> 0) * +(HEAP32[8400 + (i3 + -10 << 2) >> 2] | 0);
         break;
        }
       }
       i2 = (i3 | 0) % 9 | 0;
       if (!i2) {
        i5 = 0;
        i2 = 0;
       } else {
        i13 = (i3 | 0) > -1 ? i2 : i2 + 9 | 0;
        i8 = HEAP32[8400 + (8 - i13 << 2) >> 2] | 0;
        if (i6) {
         i9 = 1e9 / (i8 | 0) | 0;
         i5 = 0;
         i2 = 0;
         i10 = 0;
         do {
          i22 = i27 + (i10 << 2) | 0;
          i23 = HEAP32[i22 >> 2] | 0;
          i24 = ((i23 >>> 0) / (i8 >>> 0) | 0) + i2 | 0;
          HEAP32[i22 >> 2] = i24;
          i2 = Math_imul((i23 >>> 0) % (i8 >>> 0) | 0, i9) | 0;
          i24 = (i10 | 0) == (i5 | 0) & (i24 | 0) == 0;
          i10 = i10 + 1 | 0;
          i3 = i24 ? i3 + -9 | 0 : i3;
          i5 = i24 ? i10 & 127 : i5;
         } while ((i10 | 0) != (i6 | 0));
         if (i2) {
          HEAP32[i27 + (i6 << 2) >> 2] = i2;
          i6 = i6 + 1 | 0;
         }
        } else {
         i5 = 0;
         i6 = 0;
        }
        i2 = 0;
        i3 = 9 - i13 + i3 | 0;
       }
       L284 : while (1) {
        i14 = (i3 | 0) < 18;
        i15 = (i3 | 0) == 18;
        i16 = i27 + (i5 << 2) | 0;
        do {
         if (!i14) {
          if (!i15) {
           i17 = i6;
           break L284;
          }
          if ((HEAP32[i16 >> 2] | 0) >>> 0 >= 9007199) {
           i3 = 18;
           i17 = i6;
           break L284;
          }
         }
         i8 = 0;
         i9 = i6 + 127 | 0;
         while (1) {
          i13 = i9 & 127;
          i10 = i27 + (i13 << 2) | 0;
          i9 = _bitshift64Shl(HEAP32[i10 >> 2] | 0, 0, 29) | 0;
          i9 = _i64Add(i9 | 0, tempRet0 | 0, i8 | 0, 0) | 0;
          i8 = tempRet0;
          if (i8 >>> 0 > 0 | (i8 | 0) == 0 & i9 >>> 0 > 1e9) {
           i24 = ___udivdi3(i9 | 0, i8 | 0, 1e9, 0) | 0;
           i9 = ___uremdi3(i9 | 0, i8 | 0, 1e9, 0) | 0;
           i8 = i24;
          } else i8 = 0;
          HEAP32[i10 >> 2] = i9;
          i24 = (i13 | 0) == (i5 | 0);
          i6 = (i13 | 0) != (i6 + 127 & 127 | 0) | i24 ? i6 : (i9 | 0) == 0 ? i13 : i6;
          if (i24) break; else i9 = i13 + -1 | 0;
         }
         i2 = i2 + -29 | 0;
        } while ((i8 | 0) == 0);
        i5 = i5 + 127 & 127;
        if ((i5 | 0) == (i6 | 0)) {
         i24 = i6 + 127 & 127;
         i6 = i27 + ((i6 + 126 & 127) << 2) | 0;
         HEAP32[i6 >> 2] = HEAP32[i6 >> 2] | HEAP32[i27 + (i24 << 2) >> 2];
         i6 = i24;
        }
        HEAP32[i27 + (i5 << 2) >> 2] = i8;
        i3 = i3 + 9 | 0;
       }
       L302 : while (1) {
        i6 = i17 + 1 & 127;
        i16 = i27 + ((i17 + 127 & 127) << 2) | 0;
        while (1) {
         i14 = (i3 | 0) == 18;
         i15 = (i3 | 0) > 27 ? 9 : 1;
         i13 = i14 ^ 1;
         while (1) {
          i9 = i5 & 127;
          i10 = (i9 | 0) == (i17 | 0);
          do if (!i10) {
           i8 = HEAP32[i27 + (i9 << 2) >> 2] | 0;
           if (i8 >>> 0 < 9007199) {
            i19 = 219;
            break;
           }
           if (i8 >>> 0 > 9007199) break;
           i8 = i5 + 1 & 127;
           if ((i8 | 0) == (i17 | 0)) {
            i19 = 219;
            break;
           }
           i8 = HEAP32[i27 + (i8 << 2) >> 2] | 0;
           if (i8 >>> 0 < 254740991) {
            i19 = 219;
            break;
           }
           if (!(i8 >>> 0 > 254740991 | i13)) {
            i3 = i9;
            i6 = i17;
            break L302;
           }
          } else i19 = 219; while (0);
          if ((i19 | 0) == 219 ? (i19 = 0, i14) : 0) {
           i19 = 220;
           break L302;
          }
          i2 = i2 + i15 | 0;
          if ((i5 | 0) == (i17 | 0)) i5 = i17; else break;
         }
         i13 = (1 << i15) + -1 | 0;
         i14 = 1e9 >>> i15;
         i9 = i5;
         i8 = 0;
         i10 = i5;
         while (1) {
          i23 = i27 + (i10 << 2) | 0;
          i24 = HEAP32[i23 >> 2] | 0;
          i5 = (i24 >>> i15) + i8 | 0;
          HEAP32[i23 >> 2] = i5;
          i8 = Math_imul(i24 & i13, i14) | 0;
          i5 = (i10 | 0) == (i9 | 0) & (i5 | 0) == 0;
          i10 = i10 + 1 & 127;
          i3 = i5 ? i3 + -9 | 0 : i3;
          i5 = i5 ? i10 : i9;
          if ((i10 | 0) == (i17 | 0)) break; else i9 = i5;
         }
         if (!i8) continue;
         if ((i6 | 0) != (i5 | 0)) break;
         HEAP32[i16 >> 2] = HEAP32[i16 >> 2] | 1;
        }
        HEAP32[i27 + (i17 << 2) >> 2] = i8;
        i17 = i6;
       }
       if ((i19 | 0) == 220) if (i10) {
        HEAP32[i27 + (i6 + -1 << 2) >> 2] = 0;
        i3 = i17;
       } else {
        i3 = i9;
        i6 = i17;
       }
       d1 = +((HEAP32[i27 + (i3 << 2) >> 2] | 0) >>> 0);
       i3 = i5 + 1 & 127;
       if ((i3 | 0) == (i6 | 0)) {
        i6 = i5 + 2 & 127;
        HEAP32[i27 + (i6 + -1 << 2) >> 2] = 0;
       }
       d12 = +(i28 | 0);
       d4 = d12 * (d1 * 1.0e9 + +((HEAP32[i27 + (i3 << 2) >> 2] | 0) >>> 0));
       i14 = i2 + 53 | 0;
       i10 = i14 - i29 | 0;
       i13 = (i10 | 0) < (i30 | 0);
       i3 = i13 & 1;
       i9 = i13 ? ((i10 | 0) < 0 ? 0 : i10) : i30;
       if ((i9 | 0) < 53) {
        d32 = +_copysignl(+_scalbn(1.0, 105 - i9 | 0), d4);
        d7 = +_fmodl(d4, +_scalbn(1.0, 53 - i9 | 0));
        d11 = d32;
        d1 = d7;
        d7 = d32 + (d4 - d7);
       } else {
        d11 = 0.0;
        d1 = 0.0;
        d7 = d4;
       }
       i8 = i5 + 2 & 127;
       do if ((i8 | 0) == (i6 | 0)) d4 = d1; else {
        i8 = HEAP32[i27 + (i8 << 2) >> 2] | 0;
        do if (i8 >>> 0 >= 5e8) {
         if (i8 >>> 0 > 5e8) {
          d1 = d12 * .75 + d1;
          break;
         }
         if ((i5 + 3 & 127 | 0) == (i6 | 0)) {
          d1 = d12 * .5 + d1;
          break;
         } else {
          d1 = d12 * .75 + d1;
          break;
         }
        } else {
         if ((i8 | 0) == 0 ? (i5 + 3 & 127 | 0) == (i6 | 0) : 0) break;
         d1 = d12 * .25 + d1;
        } while (0);
        if ((53 - i9 | 0) <= 1) {
         d4 = d1;
         break;
        }
        if (+_fmodl(d1, 1.0) != 0.0) {
         d4 = d1;
         break;
        }
        d4 = d1 + 1.0;
       } while (0);
       d1 = d7 + d4 - d11;
       do if ((i14 & 2147483647 | 0) > (-2 - i25 | 0)) {
        if (+Math_abs(+d1) >= 9007199254740992.0) {
         i3 = i13 & (i9 | 0) == (i10 | 0) ? 0 : i3;
         i2 = i2 + 1 | 0;
         d1 = d1 * .5;
        }
        if ((i2 + 50 | 0) <= (i26 | 0) ? !(d4 != 0.0 & (i3 | 0) != 0) : 0) break;
        i30 = ___errno_location() | 0;
        HEAP32[i30 >> 2] = 34;
       } while (0);
       d1 = +_scalbnl(d1, i2);
      } while (0);
      break L4;
     }
    default:
     {
      if (HEAP32[i22 >> 2] | 0) HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
      i30 = ___errno_location() | 0;
      HEAP32[i30 >> 2] = 22;
      ___shlim(i24, 0);
      d1 = 0.0;
      break L4;
     }
    }
   }
  } while (0);
  if ((i19 | 0) == 23) {
   i3 = (HEAP32[i22 >> 2] | 0) == 0;
   if (!i3) HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
   if ((i21 | 0) != 0 & i2 >>> 0 > 3) do {
    if (!i3) HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + -1;
    i2 = i2 + -1 | 0;
   } while (i2 >>> 0 > 3);
  }
  d1 = +(i28 | 0) * inf;
 } while (0);
 STACKTOP = i31;
 return +d1;
}

function __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_(i37, i38, i2, i3, i4, i39, i31, i26, i34, i35, i1) {
 i37 = i37 | 0;
 i38 = i38 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i39 = i39 | 0;
 i31 = i31 | 0;
 i26 = i26 | 0;
 i34 = i34 | 0;
 i35 = i35 | 0;
 i1 = i1 | 0;
 var i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i32 = 0, i33 = 0, i36 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0;
 i48 = STACKTOP;
 STACKTOP = STACKTOP + 512 | 0;
 i25 = i48 + 96 | 0;
 i8 = i48 + 104 | 0;
 i47 = i48 + 88 | 0;
 i30 = i48 + 80 | 0;
 i29 = i48 + 76 | 0;
 i32 = i48 + 504 | 0;
 i27 = i48 + 72 | 0;
 i33 = i48 + 68 | 0;
 i42 = i48 + 56 | 0;
 i46 = i48 + 44 | 0;
 i44 = i48 + 32 | 0;
 i43 = i48 + 20 | 0;
 i45 = i48 + 8 | 0;
 i28 = i48 + 4 | 0;
 i40 = i48;
 HEAP32[i25 >> 2] = i1;
 HEAP32[i47 >> 2] = i8;
 i41 = i47 + 4 | 0;
 HEAP32[i41 >> 2] = 300;
 HEAP32[i30 >> 2] = i8;
 HEAP32[i29 >> 2] = i8 + 400;
 HEAP32[i42 >> 2] = 0;
 HEAP32[i42 + 4 >> 2] = 0;
 HEAP32[i42 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i42 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i46 >> 2] = 0;
 HEAP32[i46 + 4 >> 2] = 0;
 HEAP32[i46 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i46 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i44 >> 2] = 0;
 HEAP32[i44 + 4 >> 2] = 0;
 HEAP32[i44 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i44 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i43 >> 2] = 0;
 HEAP32[i43 + 4 >> 2] = 0;
 HEAP32[i43 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i43 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i45 >> 2] = 0;
 HEAP32[i45 + 4 >> 2] = 0;
 HEAP32[i45 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i45 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 __ZNSt3__211__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri(i2, i3, i32, i27, i33, i42, i46, i44, i43, i28);
 HEAP32[i35 >> 2] = HEAP32[i34 >> 2];
 i21 = i44 + 8 + 3 | 0;
 i22 = i44 + 4 | 0;
 i23 = i43 + 8 + 3 | 0;
 i24 = i43 + 4 | 0;
 i13 = (i4 & 512 | 0) != 0;
 i14 = i46 + 8 + 3 | 0;
 i15 = i46 + 4 | 0;
 i16 = i45 + 8 + 3 | 0;
 i17 = i45 + 4 | 0;
 i18 = i32 + 3 | 0;
 i19 = i42 + 11 | 0;
 i20 = i42 + 4 | 0;
 i12 = 0;
 i7 = 0;
 L21 : while (1) {
  if (i12 >>> 0 >= 4) {
   i36 = 232;
   break;
  }
  i1 = HEAP32[i37 >> 2] | 0;
  do if (i1) {
   i2 = HEAP32[i1 + 12 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i37 >> 2] = 0;
    i3 = 1;
    break;
   } else {
    i3 = (HEAP32[i37 >> 2] | 0) == 0;
    break;
   }
  } else i3 = 1; while (0);
  i2 = HEAP32[i38 >> 2] | 0;
  do if (i2) {
   i1 = HEAP32[i2 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i3) {
    i11 = i2;
    break;
   } else {
    i36 = 232;
    break L21;
   } else {
    HEAP32[i38 >> 2] = 0;
    i36 = 31;
    break;
   }
  } else i36 = 31; while (0);
  if ((i36 | 0) == 31) {
   i36 = 0;
   if (i3) {
    i36 = 232;
    break;
   } else i11 = 0;
  }
  L46 : do switch (HEAP8[i32 + i12 >> 0] | 0) {
  case 1:
   {
    if ((i12 | 0) != 3) {
     i1 = HEAP32[i37 >> 2] | 0;
     i2 = HEAP32[i1 + 12 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
     if (!(FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i26 >> 2] | 0) + 12 >> 2] & 31](i26, 8192, i1) | 0)) {
      i36 = 44;
      break L21;
     }
     i1 = HEAP32[i37 >> 2] | 0;
     i2 = i1 + 12 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0; else {
      HEAP32[i2 >> 2] = i3 + 4;
      i1 = HEAP32[i3 >> 2] | 0;
     }
     __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw(i45, i1);
     i1 = i11;
     i4 = i11;
     i36 = 46;
    }
    break;
   }
  case 0:
   {
    if ((i12 | 0) != 3) {
     i1 = i11;
     i4 = i11;
     i36 = 46;
    }
    break;
   }
  case 3:
   {
    i1 = HEAP8[i21 >> 0] | 0;
    i2 = i1 << 24 >> 24 < 0 ? HEAP32[i22 >> 2] | 0 : i1 & 255;
    i4 = HEAP8[i23 >> 0] | 0;
    i4 = i4 << 24 >> 24 < 0 ? HEAP32[i24 >> 2] | 0 : i4 & 255;
    if ((i2 | 0) != (0 - i4 | 0)) {
     i5 = (i2 | 0) == 0;
     i6 = HEAP32[i37 >> 2] | 0;
     i9 = HEAP32[i6 + 12 >> 2] | 0;
     i2 = HEAP32[i6 + 16 >> 2] | 0;
     i3 = (i9 | 0) == (i2 | 0);
     if (i5 | (i4 | 0) == 0) {
      if (i3) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 36 >> 2] & 255](i6) | 0; else i2 = HEAP32[i9 >> 2] | 0;
      if (i5) {
       i1 = HEAP8[i23 >> 0] | 0;
       if ((i2 | 0) != (HEAP32[(i1 << 24 >> 24 < 0 ? HEAP32[i43 >> 2] | 0 : i43) >> 2] | 0)) break L46;
       i2 = HEAP32[i37 >> 2] | 0;
       i3 = i2 + 12 | 0;
       i4 = HEAP32[i3 >> 2] | 0;
       if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) {
        FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
        i1 = HEAP8[i23 >> 0] | 0;
       } else HEAP32[i3 >> 2] = i4 + 4;
       HEAP8[i31 >> 0] = 1;
       i7 = (i1 << 24 >> 24 < 0 ? HEAP32[i24 >> 2] | 0 : i1 & 255) >>> 0 > 1 ? i43 : i7;
       break L46;
      }
      i1 = HEAP8[i21 >> 0] | 0;
      if ((i2 | 0) != (HEAP32[(i1 << 24 >> 24 < 0 ? HEAP32[i44 >> 2] | 0 : i44) >> 2] | 0)) {
       HEAP8[i31 >> 0] = 1;
       break L46;
      }
      i2 = HEAP32[i37 >> 2] | 0;
      i3 = i2 + 12 | 0;
      i4 = HEAP32[i3 >> 2] | 0;
      if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) {
       FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
       i1 = HEAP8[i21 >> 0] | 0;
      } else HEAP32[i3 >> 2] = i4 + 4;
      i7 = (i1 << 24 >> 24 < 0 ? HEAP32[i22 >> 2] | 0 : i1 & 255) >>> 0 > 1 ? i44 : i7;
      break L46;
     }
     if (i3) {
      i5 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 36 >> 2] & 255](i6) | 0;
      i2 = HEAP32[i37 >> 2] | 0;
      i1 = HEAP8[i21 >> 0] | 0;
      i6 = i2;
      i4 = HEAP32[i2 + 12 >> 2] | 0;
      i2 = HEAP32[i2 + 16 >> 2] | 0;
     } else {
      i5 = HEAP32[i9 >> 2] | 0;
      i4 = i9;
     }
     i3 = i6 + 12 | 0;
     i2 = (i4 | 0) == (i2 | 0);
     if ((i5 | 0) == (HEAP32[(i1 << 24 >> 24 < 0 ? HEAP32[i44 >> 2] | 0 : i44) >> 2] | 0)) {
      if (i2) {
       FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 40 >> 2] & 255](i6) | 0;
       i1 = HEAP8[i21 >> 0] | 0;
      } else HEAP32[i3 >> 2] = i4 + 4;
      i7 = (i1 << 24 >> 24 < 0 ? HEAP32[i22 >> 2] | 0 : i1 & 255) >>> 0 > 1 ? i44 : i7;
      break L46;
     }
     if (i2) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 36 >> 2] & 255](i6) | 0; else i1 = HEAP32[i4 >> 2] | 0;
     i4 = HEAP8[i23 >> 0] | 0;
     if ((i1 | 0) != (HEAP32[(i4 << 24 >> 24 < 0 ? HEAP32[i43 >> 2] | 0 : i43) >> 2] | 0)) {
      i36 = 102;
      break L21;
     }
     i1 = HEAP32[i37 >> 2] | 0;
     i2 = i1 + 12 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
      FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
      i1 = HEAP8[i23 >> 0] | 0;
     } else {
      HEAP32[i2 >> 2] = i3 + 4;
      i1 = i4;
     }
     HEAP8[i31 >> 0] = 1;
     i7 = (i1 << 24 >> 24 < 0 ? HEAP32[i24 >> 2] | 0 : i1 & 255) >>> 0 > 1 ? i43 : i7;
    }
    break;
   }
  case 2:
   {
    if (!(i12 >>> 0 < 2 | (i7 | 0) != 0) ? !(i13 | (i12 | 0) == 2 & (HEAP8[i18 >> 0] | 0) != 0) : 0) {
     i7 = 0;
     break L46;
    }
    i2 = HEAP8[i14 >> 0] | 0;
    i3 = HEAP32[i46 >> 2] | 0;
    i1 = i2 << 24 >> 24 < 0 ? i3 : i46;
    L107 : do if ((i12 | 0) != 0 ? (HEAPU8[i32 + (i12 + -1) >> 0] | 0) < 2 : 0) {
     i4 = i3;
     while (1) {
      i10 = i2 << 24 >> 24 < 0;
      i3 = i1;
      if ((i3 | 0) == ((i10 ? i4 : i46) + ((i10 ? HEAP32[i15 >> 2] | 0 : i2 & 255) << 2) | 0)) break;
      if (!(FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i26 >> 2] | 0) + 12 >> 2] & 31](i26, 8192, HEAP32[i3 >> 2] | 0) | 0)) {
       i36 = 109;
       break;
      }
      i2 = HEAP8[i14 >> 0] | 0;
      i4 = HEAP32[i46 >> 2] | 0;
      i1 = i3 + 4 | 0;
     }
     if ((i36 | 0) == 109) {
      i36 = 0;
      i2 = HEAP8[i14 >> 0] | 0;
      i4 = HEAP32[i46 >> 2] | 0;
     }
     i6 = i2 << 24 >> 24 < 0 ? i4 : i46;
     i3 = i6;
     i10 = i1 - i3 >> 2;
     i9 = HEAP8[i16 >> 0] | 0;
     i5 = i9 << 24 >> 24 < 0;
     i9 = i5 ? HEAP32[i17 >> 2] | 0 : i9 & 255;
     if (i10 >>> 0 > i9 >>> 0) {
      i9 = i11;
      i5 = i11;
     } else {
      i9 = (i5 ? HEAP32[i45 >> 2] | 0 : i45) + (i9 << 2) | 0;
      i5 = i9 + (0 - i10 << 2) | 0;
      while (1) {
       if ((i5 | 0) == (i9 | 0)) {
        i9 = i11;
        i5 = i11;
        i3 = i1;
        break L107;
       }
       if ((HEAP32[i5 >> 2] | 0) != (HEAP32[i6 >> 2] | 0)) {
        i9 = i11;
        i5 = i11;
        break L107;
       }
       i6 = i6 + 4 | 0;
       i5 = i5 + 4 | 0;
      }
     }
    } else {
     i9 = i11;
     i4 = i3;
     i5 = i11;
     i3 = i1;
    } while (0);
    L121 : while (1) {
     i1 = i2 << 24 >> 24 < 0;
     i1 = (i1 ? i4 : i46) + ((i1 ? HEAP32[i15 >> 2] | 0 : i2 & 255) << 2) | 0;
     i6 = i3;
     if ((i6 | 0) == (i1 | 0)) break;
     i1 = HEAP32[i37 >> 2] | 0;
     do if (i1) {
      i2 = HEAP32[i1 + 12 >> 2] | 0;
      if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
      if ((i1 | 0) == -1) {
       HEAP32[i37 >> 2] = 0;
       i2 = 1;
       break;
      } else {
       i2 = (HEAP32[i37 >> 2] | 0) == 0;
       break;
      }
     } else i2 = 1; while (0);
     do if (i5) {
      i1 = HEAP32[i5 + 12 >> 2] | 0;
      if ((i1 | 0) == (HEAP32[i5 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0; else i1 = HEAP32[i1 >> 2] | 0;
      if ((i1 | 0) != -1) if (i2 ^ (i9 | 0) == 0) {
       i1 = i9;
       i5 = i9;
       break;
      } else {
       i1 = i6;
       break L121;
      } else {
       HEAP32[i38 >> 2] = 0;
       i1 = 0;
       i36 = 130;
       break;
      }
     } else {
      i1 = i9;
      i36 = 130;
     } while (0);
     if ((i36 | 0) == 130) {
      i36 = 0;
      if (i2) {
       i1 = i6;
       break;
      } else i5 = 0;
     }
     i2 = HEAP32[i37 >> 2] | 0;
     i3 = HEAP32[i2 + 12 >> 2] | 0;
     if ((i3 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i2 = HEAP32[i3 >> 2] | 0;
     if ((i2 | 0) != (HEAP32[i6 >> 2] | 0)) {
      i1 = i6;
      break;
     }
     i2 = HEAP32[i37 >> 2] | 0;
     i3 = i2 + 12 | 0;
     i4 = HEAP32[i3 >> 2] | 0;
     if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0; else HEAP32[i3 >> 2] = i4 + 4;
     i9 = i1;
     i2 = HEAP8[i14 >> 0] | 0;
     i4 = HEAP32[i46 >> 2] | 0;
     i3 = i6 + 4 | 0;
    }
    if (i13 ? (i11 = HEAP8[i14 >> 0] | 0, i10 = i11 << 24 >> 24 < 0, (i1 | 0) != ((i10 ? HEAP32[i46 >> 2] | 0 : i46) + ((i10 ? HEAP32[i15 >> 2] | 0 : i11 & 255) << 2) | 0)) : 0) {
     i36 = 142;
     break L21;
    }
    break;
   }
  case 4:
   {
    i9 = HEAP32[i33 >> 2] | 0;
    i5 = i11;
    i4 = i11;
    i1 = 0;
    L158 : while (1) {
     i2 = HEAP32[i37 >> 2] | 0;
     do if (i2) {
      i3 = HEAP32[i2 + 12 >> 2] | 0;
      if ((i3 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i2 = HEAP32[i3 >> 2] | 0;
      if ((i2 | 0) == -1) {
       HEAP32[i37 >> 2] = 0;
       i3 = 1;
       break;
      } else {
       i3 = (HEAP32[i37 >> 2] | 0) == 0;
       break;
      }
     } else i3 = 1; while (0);
     do if (i4) {
      i2 = HEAP32[i4 + 12 >> 2] | 0;
      if ((i2 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i2 = HEAP32[i2 >> 2] | 0;
      if ((i2 | 0) != -1) if (i3 ^ (i5 | 0) == 0) {
       i2 = i5;
       i6 = i5;
       break;
      } else break L158; else {
       HEAP32[i38 >> 2] = 0;
       i2 = 0;
       i36 = 156;
       break;
      }
     } else {
      i2 = i5;
      i36 = 156;
     } while (0);
     if ((i36 | 0) == 156) {
      i36 = 0;
      if (i3) {
       i5 = i2;
       break;
      } else i6 = 0;
     }
     i3 = HEAP32[i37 >> 2] | 0;
     i4 = HEAP32[i3 + 12 >> 2] | 0;
     if ((i4 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i4 = HEAP32[i4 >> 2] | 0;
     if (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i26 >> 2] | 0) + 12 >> 2] & 31](i26, 2048, i4) | 0) {
      i3 = HEAP32[i35 >> 2] | 0;
      if ((i3 | 0) == (HEAP32[i25 >> 2] | 0)) {
       __ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i34, i35, i25);
       i3 = HEAP32[i35 >> 2] | 0;
      }
      HEAP32[i35 >> 2] = i3 + 4;
      HEAP32[i3 >> 2] = i4;
      i1 = i1 + 1 | 0;
     } else {
      i11 = HEAP8[i19 >> 0] | 0;
      if (!((i4 | 0) == (i9 | 0) & (i1 | 0 ? ((i11 << 24 >> 24 < 0 ? HEAP32[i20 >> 2] | 0 : i11 & 255) | 0) != 0 : 0))) {
       i5 = i2;
       break;
      }
      if ((i8 | 0) == (HEAP32[i29 >> 2] | 0)) {
       __ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i47, i30, i29);
       i8 = HEAP32[i30 >> 2] | 0;
      }
      i11 = i8 + 4 | 0;
      HEAP32[i30 >> 2] = i11;
      HEAP32[i8 >> 2] = i1;
      i8 = i11;
      i1 = 0;
     }
     i3 = HEAP32[i37 >> 2] | 0;
     i4 = i3 + 12 | 0;
     i5 = HEAP32[i4 >> 2] | 0;
     if ((i5 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) {
      FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
      i5 = i2;
      i4 = i6;
      continue;
     } else {
      HEAP32[i4 >> 2] = i5 + 4;
      i5 = i2;
      i4 = i6;
      continue;
     }
    }
    if (i1 | 0 ? (HEAP32[i47 >> 2] | 0) != (i8 | 0) : 0) {
     if ((i8 | 0) == (HEAP32[i29 >> 2] | 0)) {
      __ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i47, i30, i29);
      i8 = HEAP32[i30 >> 2] | 0;
     }
     i11 = i8 + 4 | 0;
     HEAP32[i30 >> 2] = i11;
     HEAP32[i8 >> 2] = i1;
     i8 = i11;
    }
    i4 = HEAP32[i28 >> 2] | 0;
    L207 : do if ((i4 | 0) > 0) {
     i1 = HEAP32[i37 >> 2] | 0;
     do if (i1) {
      i2 = HEAP32[i1 + 12 >> 2] | 0;
      if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
      if ((i1 | 0) == -1) {
       HEAP32[i37 >> 2] = 0;
       i2 = 1;
       break;
      } else {
       i2 = (HEAP32[i37 >> 2] | 0) == 0;
       break;
      }
     } else i2 = 1; while (0);
     do if (i5) {
      i1 = HEAP32[i5 + 12 >> 2] | 0;
      if ((i1 | 0) == (HEAP32[i5 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0; else i1 = HEAP32[i1 >> 2] | 0;
      if ((i1 | 0) != -1) if (i2) break; else {
       i36 = 196;
       break L21;
      } else {
       HEAP32[i38 >> 2] = 0;
       i36 = 190;
       break;
      }
     } else i36 = 190; while (0);
     if ((i36 | 0) == 190) {
      i36 = 0;
      if (i2) {
       i36 = 196;
       break L21;
      } else i5 = 0;
     }
     i1 = HEAP32[i37 >> 2] | 0;
     i2 = HEAP32[i1 + 12 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
     if ((i1 | 0) != (HEAP32[i27 >> 2] | 0)) {
      i36 = 196;
      break L21;
     }
     i1 = HEAP32[i37 >> 2] | 0;
     i2 = i1 + 12 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
      FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
      i1 = i5;
     } else {
      HEAP32[i2 >> 2] = i3 + 4;
      i1 = i5;
     }
     while (1) {
      if ((i4 | 0) <= 0) break L207;
      i2 = HEAP32[i37 >> 2] | 0;
      do if (i2) {
       i3 = HEAP32[i2 + 12 >> 2] | 0;
       if ((i3 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i2 = HEAP32[i3 >> 2] | 0;
       if ((i2 | 0) == -1) {
        HEAP32[i37 >> 2] = 0;
        i3 = 1;
        break;
       } else {
        i3 = (HEAP32[i37 >> 2] | 0) == 0;
        break;
       }
      } else i3 = 1; while (0);
      do if (i5) {
       i2 = HEAP32[i5 + 12 >> 2] | 0;
       if ((i2 | 0) == (HEAP32[i5 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0; else i2 = HEAP32[i2 >> 2] | 0;
       if ((i2 | 0) != -1) if (i3 ^ (i1 | 0) == 0) {
        i6 = i1;
        i5 = i1;
        break;
       } else {
        i36 = 220;
        break L21;
       } else {
        HEAP32[i38 >> 2] = 0;
        i1 = 0;
        i36 = 214;
        break;
       }
      } else i36 = 214; while (0);
      if ((i36 | 0) == 214) {
       i36 = 0;
       if (i3) {
        i36 = 220;
        break L21;
       } else {
        i6 = i1;
        i5 = 0;
       }
      }
      i1 = HEAP32[i37 >> 2] | 0;
      i2 = HEAP32[i1 + 12 >> 2] | 0;
      if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
      if (!(FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i26 >> 2] | 0) + 12 >> 2] & 31](i26, 2048, i1) | 0)) {
       i36 = 220;
       break L21;
      }
      if ((HEAP32[i35 >> 2] | 0) == (HEAP32[i25 >> 2] | 0)) __ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i34, i35, i25);
      i1 = HEAP32[i37 >> 2] | 0;
      i2 = HEAP32[i1 + 12 >> 2] | 0;
      if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
      i2 = HEAP32[i35 >> 2] | 0;
      HEAP32[i35 >> 2] = i2 + 4;
      HEAP32[i2 >> 2] = i1;
      i4 = i4 + -1 | 0;
      HEAP32[i28 >> 2] = i4;
      i1 = HEAP32[i37 >> 2] | 0;
      i2 = i1 + 12 | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
       FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
       i1 = i6;
       continue;
      } else {
       HEAP32[i2 >> 2] = i3 + 4;
       i1 = i6;
       continue;
      }
     }
    } while (0);
    if ((HEAP32[i35 >> 2] | 0) == (HEAP32[i34 >> 2] | 0)) {
     i36 = 230;
     break L21;
    }
    break;
   }
  default:
   {}
  } while (0);
  L280 : do if ((i36 | 0) == 46) while (1) {
   i36 = 0;
   i2 = HEAP32[i37 >> 2] | 0;
   do if (i2) {
    i3 = HEAP32[i2 + 12 >> 2] | 0;
    if ((i3 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i2 = HEAP32[i3 >> 2] | 0;
    if ((i2 | 0) == -1) {
     HEAP32[i37 >> 2] = 0;
     i3 = 1;
     break;
    } else {
     i3 = (HEAP32[i37 >> 2] | 0) == 0;
     break;
    }
   } else i3 = 1; while (0);
   do if (i4) {
    i2 = HEAP32[i4 + 12 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i2 = HEAP32[i2 >> 2] | 0;
    if ((i2 | 0) != -1) if (i3 ^ (i1 | 0) == 0) {
     i5 = i1;
     i4 = i1;
     break;
    } else break L280; else {
     HEAP32[i38 >> 2] = 0;
     i1 = 0;
     i36 = 59;
     break;
    }
   } else i36 = 59; while (0);
   if ((i36 | 0) == 59) {
    i36 = 0;
    if (i3) break L280; else {
     i5 = i1;
     i4 = 0;
    }
   }
   i1 = HEAP32[i37 >> 2] | 0;
   i2 = HEAP32[i1 + 12 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
   if (!(FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i26 >> 2] | 0) + 12 >> 2] & 31](i26, 8192, i1) | 0)) break L280;
   i1 = HEAP32[i37 >> 2] | 0;
   i2 = i1 + 12 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0; else {
    HEAP32[i2 >> 2] = i3 + 4;
    i1 = HEAP32[i3 >> 2] | 0;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw(i45, i1);
   i1 = i5;
   i36 = 46;
  } while (0);
  i12 = i12 + 1 | 0;
 }
 L315 : do if ((i36 | 0) == 44) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 102) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 142) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 196) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 220) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 230) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 232) {
  L317 : do if (i7 | 0) {
   i5 = i7 + 8 + 3 | 0;
   i6 = i7 + 4 | 0;
   i4 = 1;
   L319 : while (1) {
    i1 = HEAP8[i5 >> 0] | 0;
    if (i1 << 24 >> 24 < 0) i1 = HEAP32[i6 >> 2] | 0; else i1 = i1 & 255;
    if (i4 >>> 0 >= i1 >>> 0) break L317;
    i1 = HEAP32[i37 >> 2] | 0;
    do if (i1) {
     i2 = HEAP32[i1 + 12 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
     if ((i1 | 0) == -1) {
      HEAP32[i37 >> 2] = 0;
      i3 = 1;
      break;
     } else {
      i3 = (HEAP32[i37 >> 2] | 0) == 0;
      break;
     }
    } else i3 = 1; while (0);
    i1 = HEAP32[i38 >> 2] | 0;
    do if (i1) {
     i2 = HEAP32[i1 + 12 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
     if ((i1 | 0) != -1) if (i3) break; else break L319; else {
      HEAP32[i38 >> 2] = 0;
      i36 = 251;
      break;
     }
    } else i36 = 251; while (0);
    if ((i36 | 0) == 251 ? (i36 = 0, i3) : 0) break;
    i1 = HEAP32[i37 >> 2] | 0;
    i2 = HEAP32[i1 + 12 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
    if ((HEAP8[i5 >> 0] | 0) < 0) i2 = HEAP32[i7 >> 2] | 0; else i2 = i7;
    if ((i1 | 0) != (HEAP32[i2 + (i4 << 2) >> 2] | 0)) break;
    i1 = i4 + 1 | 0;
    i2 = HEAP32[i37 >> 2] | 0;
    i3 = i2 + 12 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) {
     FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
     i4 = i1;
     continue;
    } else {
     HEAP32[i3 >> 2] = i4 + 4;
     i4 = i1;
     continue;
    }
   }
   HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
   i2 = 0;
   break L315;
  } while (0);
  i1 = HEAP32[i47 >> 2] | 0;
  if ((i1 | 0) != (i8 | 0)) {
   HEAP32[i40 >> 2] = 0;
   __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i42, i1, i8, i40);
   if (!(HEAP32[i40 >> 2] | 0)) {
    i2 = 1;
    break;
   } else {
    HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
    i2 = 0;
    break;
   }
  } else i2 = 1;
 } while (0);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i45);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i43);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i44);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i46);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i42);
 i1 = HEAP32[i47 >> 2] | 0;
 HEAP32[i47 >> 2] = 0;
 if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[i41 >> 2] & 511](i1);
 STACKTOP = i48;
 return i2 | 0;
}

function __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_(i37, i38, i3, i4, i5, i39, i31, i2, i34, i35, i1) {
 i37 = i37 | 0;
 i38 = i38 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i39 = i39 | 0;
 i31 = i31 | 0;
 i2 = i2 | 0;
 i34 = i34 | 0;
 i35 = i35 | 0;
 i1 = i1 | 0;
 var i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i32 = 0, i33 = 0, i36 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0;
 i48 = STACKTOP;
 STACKTOP = STACKTOP + 512 | 0;
 i26 = i48 + 88 | 0;
 i8 = i48 + 96 | 0;
 i47 = i48 + 80 | 0;
 i30 = i48 + 72 | 0;
 i29 = i48 + 68 | 0;
 i32 = i48 + 500 | 0;
 i27 = i48 + 497 | 0;
 i33 = i48 + 496 | 0;
 i42 = i48 + 56 | 0;
 i46 = i48 + 44 | 0;
 i44 = i48 + 32 | 0;
 i43 = i48 + 20 | 0;
 i45 = i48 + 8 | 0;
 i28 = i48 + 4 | 0;
 i40 = i48;
 HEAP32[i26 >> 2] = i1;
 HEAP32[i47 >> 2] = i8;
 i41 = i47 + 4 | 0;
 HEAP32[i41 >> 2] = 300;
 HEAP32[i30 >> 2] = i8;
 HEAP32[i29 >> 2] = i8 + 400;
 HEAP32[i42 >> 2] = 0;
 HEAP32[i42 + 4 >> 2] = 0;
 HEAP32[i42 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i42 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i46 >> 2] = 0;
 HEAP32[i46 + 4 >> 2] = 0;
 HEAP32[i46 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i46 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i44 >> 2] = 0;
 HEAP32[i44 + 4 >> 2] = 0;
 HEAP32[i44 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i44 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i43 >> 2] = 0;
 HEAP32[i43 + 4 >> 2] = 0;
 HEAP32[i43 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i43 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i45 >> 2] = 0;
 HEAP32[i45 + 4 >> 2] = 0;
 HEAP32[i45 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i45 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 __ZNSt3__211__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri(i3, i4, i32, i27, i33, i42, i46, i44, i43, i28);
 HEAP32[i35 >> 2] = HEAP32[i34 >> 2];
 i21 = i2 + 8 | 0;
 i22 = i44 + 11 | 0;
 i23 = i44 + 4 | 0;
 i24 = i43 + 11 | 0;
 i25 = i43 + 4 | 0;
 i13 = (i5 & 512 | 0) != 0;
 i14 = i46 + 11 | 0;
 i15 = i46 + 4 | 0;
 i16 = i45 + 11 | 0;
 i17 = i45 + 4 | 0;
 i18 = i32 + 3 | 0;
 i19 = i42 + 11 | 0;
 i20 = i42 + 4 | 0;
 i12 = 0;
 i7 = 0;
 L21 : while (1) {
  if (i12 >>> 0 >= 4) {
   i36 = 218;
   break;
  }
  i1 = HEAP32[i37 >> 2] | 0;
  do if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
    HEAP32[i37 >> 2] = 0;
    i1 = 0;
    break;
   } else {
    i1 = HEAP32[i37 >> 2] | 0;
    break;
   }
  } else i1 = 0; while (0);
  i1 = (i1 | 0) == 0;
  i2 = HEAP32[i38 >> 2] | 0;
  do if (i2) {
   if ((HEAP32[i2 + 12 >> 2] | 0) != (HEAP32[i2 + 16 >> 2] | 0)) if (i1) break; else {
    i36 = 218;
    break L21;
   }
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) != -1) if (i1) break; else {
    i36 = 218;
    break L21;
   } else {
    HEAP32[i38 >> 2] = 0;
    i36 = 28;
    break;
   }
  } else i36 = 28; while (0);
  if ((i36 | 0) == 28) {
   i36 = 0;
   if (i1) {
    i36 = 218;
    break;
   } else i2 = 0;
  }
  L42 : do switch (HEAP8[i32 + i12 >> 0] | 0) {
  case 1:
   {
    if ((i12 | 0) != 3) {
     i1 = HEAP32[i37 >> 2] | 0;
     i3 = HEAP32[i1 + 12 >> 2] | 0;
     if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAPU8[i3 >> 0] | 0;
     if ((i1 & 255) << 24 >> 24 <= -1) {
      i36 = 42;
      break L21;
     }
     if (!(HEAP16[(HEAP32[i21 >> 2] | 0) + (i1 << 24 >> 24 << 1) >> 1] & 8192)) {
      i36 = 42;
      break L21;
     }
     i1 = HEAP32[i37 >> 2] | 0;
     i3 = i1 + 12 | 0;
     i4 = HEAP32[i3 >> 2] | 0;
     if ((i4 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0; else {
      HEAP32[i3 >> 2] = i4 + 1;
      i1 = HEAPU8[i4 >> 0] | 0;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i45, i1 & 255);
     i1 = i2;
     i3 = i2;
     i36 = 44;
    }
    break;
   }
  case 0:
   {
    if ((i12 | 0) != 3) {
     i1 = i2;
     i3 = i2;
     i36 = 44;
    }
    break;
   }
  case 3:
   {
    i1 = HEAP8[i22 >> 0] | 0;
    i2 = i1 << 24 >> 24 < 0 ? HEAP32[i23 >> 2] | 0 : i1 & 255;
    i4 = HEAP8[i24 >> 0] | 0;
    i4 = i4 << 24 >> 24 < 0 ? HEAP32[i25 >> 2] | 0 : i4 & 255;
    if ((i2 | 0) != (0 - i4 | 0)) {
     i5 = (i2 | 0) == 0;
     i6 = HEAP32[i37 >> 2] | 0;
     i9 = HEAP32[i6 + 12 >> 2] | 0;
     i2 = HEAP32[i6 + 16 >> 2] | 0;
     i3 = (i9 | 0) == (i2 | 0);
     if (i5 | (i4 | 0) == 0) {
      if (i3) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 36 >> 2] & 255](i6) | 0; else i1 = HEAPU8[i9 >> 0] | 0;
      i2 = i1 & 255;
      if (i5) {
       i1 = HEAP8[i24 >> 0] | 0;
       if (i2 << 24 >> 24 != (HEAP8[(i1 << 24 >> 24 < 0 ? HEAP32[i43 >> 2] | 0 : i43) >> 0] | 0)) break L42;
       i2 = HEAP32[i37 >> 2] | 0;
       i3 = i2 + 12 | 0;
       i4 = HEAP32[i3 >> 2] | 0;
       if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) {
        FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
        i1 = HEAP8[i24 >> 0] | 0;
       } else HEAP32[i3 >> 2] = i4 + 1;
       HEAP8[i31 >> 0] = 1;
       i7 = (i1 << 24 >> 24 < 0 ? HEAP32[i25 >> 2] | 0 : i1 & 255) >>> 0 > 1 ? i43 : i7;
       break L42;
      }
      i1 = HEAP8[i22 >> 0] | 0;
      if (i2 << 24 >> 24 != (HEAP8[(i1 << 24 >> 24 < 0 ? HEAP32[i44 >> 2] | 0 : i44) >> 0] | 0)) {
       HEAP8[i31 >> 0] = 1;
       break L42;
      }
      i2 = HEAP32[i37 >> 2] | 0;
      i3 = i2 + 12 | 0;
      i4 = HEAP32[i3 >> 2] | 0;
      if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) {
       FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
       i1 = HEAP8[i22 >> 0] | 0;
      } else HEAP32[i3 >> 2] = i4 + 1;
      i7 = (i1 << 24 >> 24 < 0 ? HEAP32[i23 >> 2] | 0 : i1 & 255) >>> 0 > 1 ? i44 : i7;
      break L42;
     }
     if (i3) {
      i5 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 36 >> 2] & 255](i6) | 0;
      i2 = HEAP32[i37 >> 2] | 0;
      i1 = HEAP8[i22 >> 0] | 0;
      i6 = i2;
      i4 = HEAP32[i2 + 12 >> 2] | 0;
      i2 = HEAP32[i2 + 16 >> 2] | 0;
     } else {
      i5 = HEAPU8[i9 >> 0] | 0;
      i4 = i9;
     }
     i3 = i6 + 12 | 0;
     i2 = (i4 | 0) == (i2 | 0);
     if ((i5 & 255) << 24 >> 24 == (HEAP8[(i1 << 24 >> 24 < 0 ? HEAP32[i44 >> 2] | 0 : i44) >> 0] | 0)) {
      if (i2) {
       FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 40 >> 2] & 255](i6) | 0;
       i1 = HEAP8[i22 >> 0] | 0;
      } else HEAP32[i3 >> 2] = i4 + 1;
      i7 = (i1 << 24 >> 24 < 0 ? HEAP32[i23 >> 2] | 0 : i1 & 255) >>> 0 > 1 ? i44 : i7;
      break L42;
     }
     if (i2) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 36 >> 2] & 255](i6) | 0; else i1 = HEAPU8[i4 >> 0] | 0;
     i4 = HEAP8[i24 >> 0] | 0;
     if ((i1 & 255) << 24 >> 24 != (HEAP8[(i4 << 24 >> 24 < 0 ? HEAP32[i43 >> 2] | 0 : i43) >> 0] | 0)) {
      i36 = 98;
      break L21;
     }
     i1 = HEAP32[i37 >> 2] | 0;
     i2 = i1 + 12 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
      FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
      i1 = HEAP8[i24 >> 0] | 0;
     } else {
      HEAP32[i2 >> 2] = i3 + 1;
      i1 = i4;
     }
     HEAP8[i31 >> 0] = 1;
     i7 = (i1 << 24 >> 24 < 0 ? HEAP32[i25 >> 2] | 0 : i1 & 255) >>> 0 > 1 ? i43 : i7;
    }
    break;
   }
  case 2:
   {
    if (!(i12 >>> 0 < 2 | (i7 | 0) != 0) ? !(i13 | (i12 | 0) == 2 & (HEAP8[i18 >> 0] | 0) != 0) : 0) {
     i7 = 0;
     break L42;
    }
    i9 = HEAP8[i14 >> 0] | 0;
    i1 = i9 << 24 >> 24 < 0;
    i10 = HEAP32[i46 >> 2] | 0;
    i3 = i1 ? i10 : i46;
    i11 = i3;
    L104 : do if ((i12 | 0) != 0 ? (HEAPU8[i32 + (i12 + -1) >> 0] | 0) < 2 : 0) {
     i1 = i3 + (i1 ? HEAP32[i15 >> 2] | 0 : i9 & 255) | 0;
     i6 = i11;
     while (1) {
      i4 = i6;
      if ((i4 | 0) == (i1 | 0)) break;
      i5 = HEAP8[i4 >> 0] | 0;
      if (i5 << 24 >> 24 <= -1) break;
      if (!(HEAP16[(HEAP32[i21 >> 2] | 0) + (i5 << 24 >> 24 << 1) >> 1] & 8192)) break;
      i6 = i4 + 1 | 0;
     }
     i5 = i6 - i11 | 0;
     i4 = HEAP8[i16 >> 0] | 0;
     i1 = i4 << 24 >> 24 < 0;
     i4 = i1 ? HEAP32[i17 >> 2] | 0 : i4 & 255;
     if (i5 >>> 0 <= i4 >>> 0) {
      i4 = (i1 ? HEAP32[i45 >> 2] | 0 : i45) + i4 | 0;
      i1 = i4 + (0 - i5) | 0;
      while (1) {
       if ((i1 | 0) == (i4 | 0)) {
        i4 = i2;
        i3 = i9;
        i1 = i10;
        i5 = i2;
        i2 = i6;
        break L104;
       }
       if ((HEAP8[i1 >> 0] | 0) != (HEAP8[i3 >> 0] | 0)) {
        i4 = i2;
        i3 = i9;
        i1 = i10;
        i5 = i2;
        i2 = i11;
        break L104;
       }
       i3 = i3 + 1 | 0;
       i1 = i1 + 1 | 0;
      }
     } else {
      i4 = i2;
      i3 = i9;
      i1 = i10;
      i5 = i2;
      i2 = i11;
     }
    } else {
     i4 = i2;
     i3 = i9;
     i1 = i10;
     i5 = i2;
     i2 = i11;
    } while (0);
    L118 : while (1) {
     i6 = i3 << 24 >> 24 < 0;
     i1 = (i6 ? i1 : i46) + (i6 ? HEAP32[i15 >> 2] | 0 : i3 & 255) | 0;
     i6 = i2;
     if ((i6 | 0) == (i1 | 0)) break;
     i1 = HEAP32[i37 >> 2] | 0;
     do if (i1) {
      if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
       HEAP32[i37 >> 2] = 0;
       i1 = 0;
       break;
      } else {
       i1 = HEAP32[i37 >> 2] | 0;
       break;
      }
     } else i1 = 0; while (0);
     i2 = (i1 | 0) == 0;
     do if (i5) {
      if ((HEAP32[i5 + 12 >> 2] | 0) != (HEAP32[i5 + 16 >> 2] | 0)) if (i2) {
       i1 = i4;
       break;
      } else {
       i1 = i6;
       break L118;
      }
      if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0) != -1) if (i2 ^ (i4 | 0) == 0) {
       i1 = i4;
       i5 = i4;
       break;
      } else {
       i1 = i6;
       break L118;
      } else {
       HEAP32[i38 >> 2] = 0;
       i1 = 0;
       i36 = 124;
       break;
      }
     } else {
      i1 = i4;
      i36 = 124;
     } while (0);
     if ((i36 | 0) == 124) {
      i36 = 0;
      if (i2) {
       i1 = i6;
       break;
      } else i5 = 0;
     }
     i2 = HEAP32[i37 >> 2] | 0;
     i3 = HEAP32[i2 + 12 >> 2] | 0;
     if ((i3 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i2 = HEAPU8[i3 >> 0] | 0;
     if ((i2 & 255) << 24 >> 24 != (HEAP8[i6 >> 0] | 0)) {
      i1 = i6;
      break;
     }
     i2 = HEAP32[i37 >> 2] | 0;
     i3 = i2 + 12 | 0;
     i4 = HEAP32[i3 >> 2] | 0;
     if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0; else HEAP32[i3 >> 2] = i4 + 1;
     i4 = i1;
     i3 = HEAP8[i14 >> 0] | 0;
     i1 = HEAP32[i46 >> 2] | 0;
     i2 = i6 + 1 | 0;
    }
    if (i13 ? (i11 = HEAP8[i14 >> 0] | 0, i10 = i11 << 24 >> 24 < 0, (i1 | 0) != ((i10 ? HEAP32[i46 >> 2] | 0 : i46) + (i10 ? HEAP32[i15 >> 2] | 0 : i11 & 255) | 0)) : 0) {
     i36 = 136;
     break L21;
    }
    break;
   }
  case 4:
   {
    i9 = HEAP8[i33 >> 0] | 0;
    i5 = i2;
    i4 = i2;
    i1 = 0;
    L151 : while (1) {
     i2 = HEAP32[i37 >> 2] | 0;
     do if (i2) {
      if ((HEAP32[i2 + 12 >> 2] | 0) == (HEAP32[i2 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) == -1) {
       HEAP32[i37 >> 2] = 0;
       i2 = 0;
       break;
      } else {
       i2 = HEAP32[i37 >> 2] | 0;
       break;
      }
     } else i2 = 0; while (0);
     i3 = (i2 | 0) == 0;
     do if (i4) {
      if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i3) {
       i2 = i5;
       i6 = i4;
       break;
      } else {
       i2 = i5;
       break L151;
      }
      if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i3 ^ (i5 | 0) == 0) {
       i2 = i5;
       i6 = i5;
       break;
      } else {
       i2 = i5;
       break L151;
      } else {
       HEAP32[i38 >> 2] = 0;
       i2 = 0;
       i36 = 147;
       break;
      }
     } else {
      i2 = i5;
      i36 = 147;
     } while (0);
     if ((i36 | 0) == 147) {
      i36 = 0;
      if (i3) break; else i6 = 0;
     }
     i3 = HEAP32[i37 >> 2] | 0;
     i4 = HEAP32[i3 + 12 >> 2] | 0;
     if ((i4 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i3 = HEAPU8[i4 >> 0] | 0;
     i4 = i3 & 255;
     if (i4 << 24 >> 24 > -1 ? (HEAP16[(HEAP32[i21 >> 2] | 0) + (i3 << 24 >> 24 << 1) >> 1] & 2048) != 0 : 0) {
      i3 = HEAP32[i35 >> 2] | 0;
      if ((i3 | 0) == (HEAP32[i26 >> 2] | 0)) {
       __ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i34, i35, i26);
       i3 = HEAP32[i35 >> 2] | 0;
      }
      HEAP32[i35 >> 2] = i3 + 1;
      HEAP8[i3 >> 0] = i4;
      i1 = i1 + 1 | 0;
     } else {
      i11 = HEAP8[i19 >> 0] | 0;
      if (!(i4 << 24 >> 24 == i9 << 24 >> 24 & (i1 | 0 ? ((i11 << 24 >> 24 < 0 ? HEAP32[i20 >> 2] | 0 : i11 & 255) | 0) != 0 : 0))) break;
      if ((i8 | 0) == (HEAP32[i29 >> 2] | 0)) {
       __ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i47, i30, i29);
       i8 = HEAP32[i30 >> 2] | 0;
      }
      i11 = i8 + 4 | 0;
      HEAP32[i30 >> 2] = i11;
      HEAP32[i8 >> 2] = i1;
      i8 = i11;
      i1 = 0;
     }
     i3 = HEAP32[i37 >> 2] | 0;
     i4 = i3 + 12 | 0;
     i5 = HEAP32[i4 >> 2] | 0;
     if ((i5 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) {
      FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
      i5 = i2;
      i4 = i6;
      continue;
     } else {
      HEAP32[i4 >> 2] = i5 + 1;
      i5 = i2;
      i4 = i6;
      continue;
     }
    }
    if (i1 | 0 ? (HEAP32[i47 >> 2] | 0) != (i8 | 0) : 0) {
     if ((i8 | 0) == (HEAP32[i29 >> 2] | 0)) {
      __ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i47, i30, i29);
      i8 = HEAP32[i30 >> 2] | 0;
     }
     i11 = i8 + 4 | 0;
     HEAP32[i30 >> 2] = i11;
     HEAP32[i8 >> 2] = i1;
     i8 = i11;
    }
    i4 = HEAP32[i28 >> 2] | 0;
    L198 : do if ((i4 | 0) > 0) {
     i1 = HEAP32[i37 >> 2] | 0;
     do if (i1) {
      if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
       HEAP32[i37 >> 2] = 0;
       i1 = 0;
       break;
      } else {
       i1 = HEAP32[i37 >> 2] | 0;
       break;
      }
     } else i1 = 0; while (0);
     i1 = (i1 | 0) == 0;
     do if (i2) {
      if ((HEAP32[i2 + 12 >> 2] | 0) == (HEAP32[i2 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) == -1 : 0) {
       HEAP32[i38 >> 2] = 0;
       i36 = 179;
       break;
      }
      if (i1) i5 = i2; else {
       i36 = 184;
       break L21;
      }
     } else i36 = 179; while (0);
     if ((i36 | 0) == 179) {
      i36 = 0;
      if (i1) {
       i36 = 184;
       break L21;
      } else i5 = 0;
     }
     i1 = HEAP32[i37 >> 2] | 0;
     i2 = HEAP32[i1 + 12 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAPU8[i2 >> 0] | 0;
     if ((i1 & 255) << 24 >> 24 != (HEAP8[i27 >> 0] | 0)) {
      i36 = 184;
      break L21;
     }
     i1 = HEAP32[i37 >> 2] | 0;
     i2 = i1 + 12 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
      FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
      i1 = i5;
      i3 = i5;
     } else {
      HEAP32[i2 >> 2] = i3 + 1;
      i1 = i5;
      i3 = i5;
     }
     while (1) {
      if ((i4 | 0) <= 0) break L198;
      i2 = HEAP32[i37 >> 2] | 0;
      do if (i2) {
       if ((HEAP32[i2 + 12 >> 2] | 0) == (HEAP32[i2 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) == -1) {
        HEAP32[i37 >> 2] = 0;
        i2 = 0;
        break;
       } else {
        i2 = HEAP32[i37 >> 2] | 0;
        break;
       }
      } else i2 = 0; while (0);
      i2 = (i2 | 0) == 0;
      do if (i3) {
       if ((HEAP32[i3 + 12 >> 2] | 0) != (HEAP32[i3 + 16 >> 2] | 0)) if (i2) {
        i6 = i1;
        i5 = i3;
        break;
       } else {
        i36 = 206;
        break L21;
       }
       if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0) != -1) if (i2 ^ (i1 | 0) == 0) {
        i6 = i1;
        i5 = i1;
        break;
       } else {
        i36 = 206;
        break L21;
       } else {
        HEAP32[i38 >> 2] = 0;
        i1 = 0;
        i36 = 199;
        break;
       }
      } else i36 = 199; while (0);
      if ((i36 | 0) == 199) {
       i36 = 0;
       if (i2) {
        i36 = 206;
        break L21;
       } else {
        i6 = i1;
        i5 = 0;
       }
      }
      i1 = HEAP32[i37 >> 2] | 0;
      i2 = HEAP32[i1 + 12 >> 2] | 0;
      if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAPU8[i2 >> 0] | 0;
      if ((i1 & 255) << 24 >> 24 <= -1) {
       i36 = 206;
       break L21;
      }
      if (!(HEAP16[(HEAP32[i21 >> 2] | 0) + (i1 << 24 >> 24 << 1) >> 1] & 2048)) {
       i36 = 206;
       break L21;
      }
      if ((HEAP32[i35 >> 2] | 0) == (HEAP32[i26 >> 2] | 0)) __ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i34, i35, i26);
      i1 = HEAP32[i37 >> 2] | 0;
      i2 = HEAP32[i1 + 12 >> 2] | 0;
      if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAPU8[i2 >> 0] | 0;
      i2 = HEAP32[i35 >> 2] | 0;
      HEAP32[i35 >> 2] = i2 + 1;
      HEAP8[i2 >> 0] = i1;
      i4 = i4 + -1 | 0;
      HEAP32[i28 >> 2] = i4;
      i1 = HEAP32[i37 >> 2] | 0;
      i2 = i1 + 12 | 0;
      i3 = HEAP32[i2 >> 2] | 0;
      if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
       FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
       i1 = i6;
       i3 = i5;
       continue;
      } else {
       HEAP32[i2 >> 2] = i3 + 1;
       i1 = i6;
       i3 = i5;
       continue;
      }
     }
    } while (0);
    if ((HEAP32[i35 >> 2] | 0) == (HEAP32[i34 >> 2] | 0)) {
     i36 = 216;
     break L21;
    }
    break;
   }
  default:
   {}
  } while (0);
  L262 : do if ((i36 | 0) == 44) while (1) {
   i36 = 0;
   i2 = HEAP32[i37 >> 2] | 0;
   do if (i2) {
    if ((HEAP32[i2 + 12 >> 2] | 0) == (HEAP32[i2 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) == -1) {
     HEAP32[i37 >> 2] = 0;
     i2 = 0;
     break;
    } else {
     i2 = HEAP32[i37 >> 2] | 0;
     break;
    }
   } else i2 = 0; while (0);
   i2 = (i2 | 0) == 0;
   do if (i3) {
    if ((HEAP32[i3 + 12 >> 2] | 0) != (HEAP32[i3 + 16 >> 2] | 0)) if (i2) {
     i5 = i1;
     i4 = i3;
     break;
    } else break L262;
    if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0) != -1) if (i2 ^ (i1 | 0) == 0) {
     i5 = i1;
     i4 = i1;
     break;
    } else break L262; else {
     HEAP32[i38 >> 2] = 0;
     i1 = 0;
     i36 = 54;
     break;
    }
   } else i36 = 54; while (0);
   if ((i36 | 0) == 54) {
    i36 = 0;
    if (i2) break L262; else {
     i5 = i1;
     i4 = 0;
    }
   }
   i1 = HEAP32[i37 >> 2] | 0;
   i2 = HEAP32[i1 + 12 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAPU8[i2 >> 0] | 0;
   if ((i1 & 255) << 24 >> 24 <= -1) break L262;
   if (!(HEAP16[(HEAP32[i21 >> 2] | 0) + (i1 << 24 >> 24 << 1) >> 1] & 8192)) break L262;
   i1 = HEAP32[i37 >> 2] | 0;
   i2 = i1 + 12 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0; else {
    HEAP32[i2 >> 2] = i3 + 1;
    i1 = HEAPU8[i3 >> 0] | 0;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i45, i1 & 255);
   i1 = i5;
   i3 = i4;
   i36 = 44;
  } while (0);
  i12 = i12 + 1 | 0;
 }
 L294 : do if ((i36 | 0) == 42) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 98) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 136) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 184) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 206) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 216) {
  HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
  i2 = 0;
 } else if ((i36 | 0) == 218) {
  L296 : do if (i7 | 0) {
   i5 = i7 + 11 | 0;
   i6 = i7 + 4 | 0;
   i3 = 1;
   L298 : while (1) {
    i1 = HEAP8[i5 >> 0] | 0;
    if (i1 << 24 >> 24 < 0) i1 = HEAP32[i6 >> 2] | 0; else i1 = i1 & 255;
    if (i3 >>> 0 >= i1 >>> 0) break L296;
    i1 = HEAP32[i37 >> 2] | 0;
    do if (i1) {
     if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
      HEAP32[i37 >> 2] = 0;
      i1 = 0;
      break;
     } else {
      i1 = HEAP32[i37 >> 2] | 0;
      break;
     }
    } else i1 = 0; while (0);
    i1 = (i1 | 0) == 0;
    i2 = HEAP32[i38 >> 2] | 0;
    do if (i2) {
     if ((HEAP32[i2 + 12 >> 2] | 0) == (HEAP32[i2 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) == -1 : 0) {
      HEAP32[i38 >> 2] = 0;
      i36 = 234;
      break;
     }
     if (!i1) break L298;
    } else i36 = 234; while (0);
    if ((i36 | 0) == 234 ? (i36 = 0, i1) : 0) break;
    i1 = HEAP32[i37 >> 2] | 0;
    i2 = HEAP32[i1 + 12 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAPU8[i2 >> 0] | 0;
    if ((HEAP8[i5 >> 0] | 0) < 0) i2 = HEAP32[i7 >> 2] | 0; else i2 = i7;
    if ((i1 & 255) << 24 >> 24 != (HEAP8[i2 + i3 >> 0] | 0)) break;
    i1 = i3 + 1 | 0;
    i2 = HEAP32[i37 >> 2] | 0;
    i3 = i2 + 12 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) {
     FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
     i3 = i1;
     continue;
    } else {
     HEAP32[i3 >> 2] = i4 + 1;
     i3 = i1;
     continue;
    }
   }
   HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
   i2 = 0;
   break L294;
  } while (0);
  i1 = HEAP32[i47 >> 2] | 0;
  if ((i1 | 0) != (i8 | 0)) {
   HEAP32[i40 >> 2] = 0;
   __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i42, i1, i8, i40);
   if (!(HEAP32[i40 >> 2] | 0)) {
    i2 = 1;
    break;
   } else {
    HEAP32[i39 >> 2] = HEAP32[i39 >> 2] | 4;
    i2 = 0;
    break;
   }
  } else i2 = 1;
 } while (0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i45);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i43);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i44);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i46);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i42);
 i1 = HEAP32[i47 >> 2] | 0;
 HEAP32[i47 >> 2] = 0;
 if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[i41 >> 2] & 511](i1);
 STACKTOP = i48;
 return i2 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_114parse_encodingINS0_2DbEEEPKcS4_S4_RT_(i21, i17, i19) {
 i21 = i21 | 0;
 i17 = i17 | 0;
 i19 = i19 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i20 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0;
 i26 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i20 = i26 + 60 | 0;
 i18 = i26 + 48 | 0;
 i7 = i26 + 36 | 0;
 i8 = i26 + 24 | 0;
 i9 = i26 + 12 | 0;
 i12 = i26;
 L1 : do if ((i21 | 0) == (i17 | 0)) i1 = i21; else {
  i23 = i19 + 56 | 0;
  i24 = HEAP32[i23 >> 2] | 0;
  i16 = i24 + 1 | 0;
  HEAP32[i23 >> 2] = i16;
  i25 = i19 + 61 | 0;
  i22 = HEAP8[i25 >> 0] | 0;
  if (i16 >>> 0 > 1) HEAP8[i25 >> 0] = 1;
  i1 = HEAP8[i21 >> 0] | 0;
  L6 : do switch (i1 | 0) {
  case 84:
  case 71:
   {
    L118 : do if ((i17 - i21 | 0) > 2) {
     switch (i1 | 0) {
     case 84:
      break;
     case 71:
      switch (HEAP8[i21 + 1 >> 0] | 0) {
      case 86:
       {
        i20 = i21 + 2 | 0;
        i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_nameINS0_2DbEEEPKcS4_S4_RT_(i20, i17, i19) | 0;
        if ((i1 | 0) == (i20 | 0)) {
         i1 = i21;
         break L118;
        }
        i2 = HEAP32[i19 + 4 >> 2] | 0;
        if ((HEAP32[i19 >> 2] | 0) == (i2 | 0)) {
         i1 = i21;
         break L118;
        }
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 58448) | 0;
        break L118;
       }
      case 82:
       {
        i20 = i21 + 2 | 0;
        i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_nameINS0_2DbEEEPKcS4_S4_RT_(i20, i17, i19) | 0;
        if ((i1 | 0) == (i20 | 0)) {
         i1 = i21;
         break L118;
        }
        i2 = HEAP32[i19 + 4 >> 2] | 0;
        if ((HEAP32[i19 >> 2] | 0) == (i2 | 0)) {
         i1 = i21;
         break L118;
        }
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 58468) | 0;
        break L118;
       }
      default:
       {
        i1 = i21;
        break L118;
       }
      }
     default:
      {
       i1 = i21;
       break L118;
      }
     }
     i1 = i21 + 1 | 0;
     switch (HEAP8[i1 >> 0] | 0) {
     case 86:
      {
       i20 = i21 + 2 | 0;
       i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i20, i17, i19) | 0;
       if ((i1 | 0) == (i20 | 0)) {
        i1 = i21;
        break L118;
       }
       i2 = HEAP32[i19 + 4 >> 2] | 0;
       if ((HEAP32[i19 >> 2] | 0) == (i2 | 0)) {
        i1 = i21;
        break L118;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 58297) | 0;
       break L118;
      }
     case 84:
      {
       i20 = i21 + 2 | 0;
       i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i20, i17, i19) | 0;
       if ((i1 | 0) == (i20 | 0)) {
        i1 = i21;
        break L118;
       }
       i2 = HEAP32[i19 + 4 >> 2] | 0;
       if ((HEAP32[i19 >> 2] | 0) == (i2 | 0)) {
        i1 = i21;
        break L118;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 58309) | 0;
       break L118;
      }
     case 73:
      {
       i20 = i21 + 2 | 0;
       i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i20, i17, i19) | 0;
       if ((i1 | 0) == (i20 | 0)) {
        i1 = i21;
        break L118;
       }
       i2 = HEAP32[i19 + 4 >> 2] | 0;
       if ((HEAP32[i19 >> 2] | 0) == (i2 | 0)) {
        i1 = i21;
        break L118;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 58318) | 0;
       break L118;
      }
     case 83:
      {
       i20 = i21 + 2 | 0;
       i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i20, i17, i19) | 0;
       if ((i1 | 0) == (i20 | 0)) {
        i1 = i21;
        break L118;
       }
       i2 = HEAP32[i19 + 4 >> 2] | 0;
       if ((HEAP32[i19 >> 2] | 0) == (i2 | 0)) {
        i1 = i21;
        break L118;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 58332) | 0;
       break L118;
      }
     case 99:
      {
       i20 = i21 + 2 | 0;
       i1 = __ZN10__cxxabiv112_GLOBAL__N_117parse_call_offsetEPKcS2_(i20, i17) | 0;
       if ((i1 | 0) == (i20 | 0)) {
        i1 = i21;
        break L118;
       }
       i2 = __ZN10__cxxabiv112_GLOBAL__N_117parse_call_offsetEPKcS2_(i1, i17) | 0;
       if ((i2 | 0) == (i1 | 0)) {
        i1 = i21;
        break L118;
       }
       i1 = __ZN10__cxxabiv112_GLOBAL__N_114parse_encodingINS0_2DbEEEPKcS4_S4_RT_(i2, i17, i19) | 0;
       if ((i1 | 0) == (i2 | 0)) {
        i1 = i21;
        break L118;
       }
       i2 = HEAP32[i19 + 4 >> 2] | 0;
       if ((HEAP32[i19 >> 2] | 0) == (i2 | 0)) {
        i1 = i21;
        break L118;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 58351) | 0;
       break L118;
      }
     case 67:
      {
       i16 = i21 + 2 | 0;
       i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i16, i17, i19) | 0;
       if ((i1 | 0) == (i16 | 0)) {
        i1 = i21;
        break L118;
       }
       i2 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i1, i17) | 0;
       if ((i2 | 0) == (i1 | 0) | (i2 | 0) == (i17 | 0)) {
        i1 = i21;
        break L118;
       }
       if ((HEAP8[i2 >> 0] | 0) != 95) {
        i1 = i21;
        break L118;
       }
       i16 = i2 + 1 | 0;
       i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i16, i17, i19) | 0;
       if ((i1 | 0) == (i16 | 0)) {
        i1 = i21;
        break L118;
       }
       i4 = i19 + 4 | 0;
       i2 = HEAP32[i4 >> 2] | 0;
       if (((i2 - (HEAP32[i19 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
        i1 = i21;
        break L118;
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i20, i2 + -24 | 0);
       i6 = HEAP32[i4 >> 2] | 0;
       i2 = i6 + -24 | 0;
       i3 = i6;
       while (1) {
        if ((i3 | 0) == (i2 | 0)) break;
        i21 = i3 + -24 | 0;
        HEAP32[i4 >> 2] = i21;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i21);
        i3 = HEAP32[i4 >> 2] | 0;
       }
       i5 = i6 + -48 | 0;
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i20, 0, 58378) | 0;
       HEAP32[i8 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i8 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i8 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i8, 58403) | 0;
       HEAP32[i7 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i7 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i7 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i9, (HEAP32[i4 >> 2] | 0) + -24 | 0);
       i2 = HEAP8[i9 + 11 >> 0] | 0;
       i3 = i2 << 24 >> 24 < 0;
       i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i7, i3 ? HEAP32[i9 >> 2] | 0 : i9, i3 ? HEAP32[i9 + 4 >> 2] | 0 : i2 & 255) | 0;
       HEAP32[i18 >> 2] = HEAP32[i2 >> 2];
       HEAP32[i18 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
       HEAP32[i18 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
       i3 = 0;
       while (1) {
        if ((i3 | 0) == 3) break;
        HEAP32[i2 + (i3 << 2) >> 2] = 0;
        i3 = i3 + 1 | 0;
       }
       i2 = i5 + 11 | 0;
       do if ((HEAP8[i2 >> 0] | 0) < 0) {
        HEAP8[HEAP32[i5 >> 2] >> 0] = 0;
        i4 = i6 + -44 | 0;
        HEAP32[i4 >> 2] = 0;
        i3 = HEAP8[i2 >> 0] | 0;
        if (i3 << 24 >> 24 < 0) {
         if ((HEAP32[i6 + -40 >> 2] & 2147483647 | 0) == 11) break;
         i21 = HEAP32[i5 >> 2] | 0;
         HEAP8[i5 >> 0] = HEAP8[i21 >> 0] | 0;
         _free(i21);
         HEAP8[i2 >> 0] = 0;
         break;
        } else {
         i2 = i3 & 255;
         if ((i3 & 255) < 11) break;
         i19 = i2 + 16 & 496;
         i21 = _malloc(i19) | 0;
         _memcpy(i21 | 0, i5 | 0, i2 + 1 | 0) | 0;
         HEAP32[i6 + -40 >> 2] = i19 | -2147483648;
         HEAP32[i4 >> 2] = i2;
         HEAP32[i5 >> 2] = i21;
         break;
        }
       } else {
        HEAP8[i5 >> 0] = 0;
        HEAP8[i2 >> 0] = 0;
       } while (0);
       HEAP32[i5 >> 2] = HEAP32[i18 >> 2];
       HEAP32[i5 + 4 >> 2] = HEAP32[i18 + 4 >> 2];
       HEAP32[i5 + 8 >> 2] = HEAP32[i18 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i18 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i18);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i9);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i7);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i20);
       break L118;
      }
     default:
      {
       i2 = __ZN10__cxxabiv112_GLOBAL__N_117parse_call_offsetEPKcS2_(i1, i17) | 0;
       if ((i2 | 0) == (i1 | 0)) {
        i1 = i21;
        break L118;
       }
       i1 = __ZN10__cxxabiv112_GLOBAL__N_114parse_encodingINS0_2DbEEEPKcS4_S4_RT_(i2, i17, i19) | 0;
       if ((i1 | 0) == (i2 | 0)) {
        i1 = i21;
        break L118;
       }
       i2 = HEAP32[i19 + 4 >> 2] | 0;
       if ((HEAP32[i19 >> 2] | 0) == (i2 | 0)) {
        i1 = i21;
        break L118;
       }
       i2 = i2 + -24 | 0;
       if ((HEAP8[i21 + 2 >> 0] | 0) == 118) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2, 0, 58408) | 0;
        break L118;
       } else {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2, 0, 58426) | 0;
        break L118;
       }
      }
     }
    } else i1 = i21; while (0);
    break;
   }
  default:
   {
    i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_nameINS0_2DbEEEPKcS4_S4_RT_(i21, i17, i19) | 0;
    i14 = HEAP32[i19 + 48 >> 2] | 0;
    i15 = HEAP32[i19 + 52 >> 2] | 0;
    if ((i1 | 0) != (i21 | 0)) if ((i1 | 0) != (i17 | 0)) {
     switch (HEAP8[i1 >> 0] | 0) {
     case 46:
     case 69:
      break L6;
     default:
      {}
     }
     i16 = HEAP8[i25 >> 0] | 0;
     HEAP8[i25 >> 0] = 0;
     HEAP32[i20 >> 2] = 0;
     HEAP32[i20 + 4 >> 2] = 0;
     HEAP32[i20 + 8 >> 2] = 0;
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i20 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     i13 = i19 + 4 | 0;
     i7 = HEAP32[i13 >> 2] | 0;
     L15 : do if ((HEAP32[i19 >> 2] | 0) != (i7 | 0)) {
      i2 = i7 + -24 | 0;
      i5 = HEAP8[i2 + 11 >> 0] | 0;
      i6 = i5 << 24 >> 24 < 0;
      if (i6) i3 = HEAP32[i7 + -20 >> 2] | 0; else i3 = i5 & 255;
      if (i3) {
       if (!(HEAP8[i19 + 60 >> 0] | 0)) {
        if (i6) {
         i3 = HEAP32[i2 >> 2] | 0;
         i4 = HEAP32[i7 + -20 >> 2] | 0;
        } else {
         i3 = i2;
         i4 = i5 & 255;
        }
        if ((HEAP8[i3 + i4 + -1 >> 0] | 0) == 62) {
         if (i6) {
          i3 = HEAP32[i7 + -20 >> 2] | 0;
          i4 = HEAP32[i2 >> 2] | 0;
         } else {
          i3 = i5 & 255;
          i4 = i2;
         }
         if ((HEAP8[i4 + (i3 + -2) >> 0] | 0) != 45) {
          if (i6) {
           i3 = HEAP32[i7 + -20 >> 2] | 0;
           i2 = HEAP32[i2 >> 2] | 0;
          } else i3 = i5 & 255;
          if ((HEAP8[i2 + (i3 + -2) >> 0] | 0) != 62) {
           i4 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i1, i17, i19) | 0;
           if ((i4 | 0) == (i1 | 0)) {
            i1 = i21;
            i2 = 0;
            break;
           }
           i11 = HEAP32[i13 >> 2] | 0;
           i1 = i11;
           if (((i11 - (HEAP32[i19 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
            i1 = i21;
            i2 = 0;
            break;
           }
           i2 = i1 + -24 | 0;
           HEAP32[i18 >> 2] = HEAP32[i2 >> 2];
           HEAP32[i18 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
           HEAP32[i18 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
           i3 = 0;
           while (1) {
            if ((i3 | 0) == 3) break;
            HEAP32[i2 + (i3 << 2) >> 2] = 0;
            i3 = i3 + 1 | 0;
           }
           i2 = i1 + -12 | 0;
           i3 = i20 + 11 | 0;
           do if ((HEAP8[i3 >> 0] | 0) < 0) {
            i1 = HEAP32[i20 >> 2] | 0;
            HEAP8[i1 >> 0] = 0;
            HEAP32[i20 + 4 >> 2] = 0;
            if ((HEAP32[i20 + 8 >> 2] & 2147483647 | 0) == 11) break;
            HEAP8[i20 >> 0] = 0;
            _free(i1);
            HEAP8[i3 >> 0] = 0;
           } else {
            HEAP8[i20 >> 0] = 0;
            HEAP8[i3 >> 0] = 0;
           } while (0);
           HEAP32[i20 >> 2] = HEAP32[i2 >> 2];
           HEAP32[i20 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
           HEAP32[i20 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
           i1 = 0;
           while (1) {
            if ((i1 | 0) == 3) break;
            HEAP32[i2 + (i1 << 2) >> 2] = 0;
            i1 = i1 + 1 | 0;
           }
           i11 = HEAP8[i3 >> 0] | 0;
           if (!((i11 << 24 >> 24 < 0 ? HEAP32[i20 + 4 >> 2] | 0 : i11 & 255) | 0)) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9push_backEc(i18, 32);
           i1 = HEAP32[i13 >> 2] | 0;
           i2 = i1 + -24 | 0;
           i3 = i1;
           while (1) {
            if ((i3 | 0) == (i2 | 0)) break;
            i11 = i3 + -24 | 0;
            HEAP32[i13 >> 2] = i11;
            __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i11);
            i3 = HEAP32[i13 >> 2] | 0;
           }
           i2 = HEAP8[i18 + 11 >> 0] | 0;
           i11 = i2 << 24 >> 24 < 0;
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKcj(i1 + -48 | 0, 0, i11 ? HEAP32[i18 >> 2] | 0 : i18, i11 ? HEAP32[i18 + 4 >> 2] | 0 : i2 & 255) | 0;
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i18);
           i2 = HEAP32[i13 >> 2] | 0;
           i1 = i4;
          } else i2 = i7;
         } else i2 = i7;
        } else i2 = i7;
       } else i2 = i7;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9push_backEc(i2 + -24 | 0, 40);
       if ((i1 | 0) != (i17 | 0) ? (HEAP8[i1 >> 0] | 0) == 118 : 0) {
        i2 = HEAP32[i19 >> 2] | 0;
        i3 = HEAP32[i13 >> 2] | 0;
        i1 = i1 + 1 | 0;
       } else i10 = 111;
       do if ((i10 | 0) == 111) {
        i8 = i18 + 11 | 0;
        i9 = i18 + 4 | 0;
        i10 = i12 + 11 | 0;
        i11 = i12 + 4 | 0;
        i7 = 1;
        L67 : while (1) {
         i2 = HEAP32[i19 >> 2] | 0;
         i3 = HEAP32[i13 >> 2] | 0;
         while (1) {
          i4 = (i3 - i2 | 0) / 24 | 0;
          i5 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i1, i17, i19) | 0;
          i3 = HEAP32[i13 >> 2] | 0;
          i2 = HEAP32[i19 >> 2] | 0;
          i6 = (i3 - i2 | 0) / 24 | 0;
          if ((i5 | 0) == (i1 | 0)) {
           i10 = 134;
           break L67;
          }
          if (i6 >>> 0 > i4 >>> 0) {
           i1 = i5;
           i5 = i6;
           break;
          } else i1 = i5;
         }
         HEAP32[i18 >> 2] = 0;
         HEAP32[i18 + 4 >> 2] = 0;
         HEAP32[i18 + 8 >> 2] = 0;
         i2 = 0;
         while (1) {
          if ((i2 | 0) == 3) {
           i2 = i4;
           break;
          }
          HEAP32[i18 + (i2 << 2) >> 2] = 0;
          i2 = i2 + 1 | 0;
         }
         while (1) {
          if (i2 >>> 0 >= i5 >>> 0) break;
          i6 = HEAP8[i8 >> 0] | 0;
          if ((i6 << 24 >> 24 < 0 ? HEAP32[i9 >> 2] | 0 : i6 & 255) | 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i18, 57598) | 0;
          __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i12, (HEAP32[i19 >> 2] | 0) + (i2 * 24 | 0) | 0);
          i6 = HEAP8[i10 >> 0] | 0;
          i3 = i6 << 24 >> 24 < 0;
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i18, i3 ? HEAP32[i12 >> 2] | 0 : i12, i3 ? HEAP32[i11 >> 2] | 0 : i6 & 255) | 0;
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i12);
          i2 = i2 + 1 | 0;
         }
         while (1) {
          if (i4 >>> 0 >= i5 >>> 0) break;
          i3 = HEAP32[i13 >> 2] | 0;
          i2 = i3 + -24 | 0;
          while (1) {
           if ((i3 | 0) == (i2 | 0)) break;
           i6 = i3 + -24 | 0;
           HEAP32[i13 >> 2] = i6;
           __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
           i3 = HEAP32[i13 >> 2] | 0;
          }
          i4 = i4 + 1 | 0;
         }
         i4 = HEAP8[i8 >> 0] | 0;
         i2 = HEAP32[i9 >> 2] | 0;
         if (!((i4 << 24 >> 24 < 0 ? i2 : i4 & 255) | 0)) i2 = i7; else {
          i3 = HEAP32[i13 >> 2] | 0;
          if ((HEAP32[i19 >> 2] | 0) == (i3 | 0)) {
           i10 = 146;
           break;
          }
          if (!i7) {
           __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i3 + -24 | 0, 57598) | 0;
           i3 = HEAP32[i13 >> 2] | 0;
           i4 = HEAP8[i8 >> 0] | 0;
           i2 = HEAP32[i9 >> 2] | 0;
          }
          i7 = i4 << 24 >> 24 < 0;
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i3 + -24 | 0, i7 ? HEAP32[i18 >> 2] | 0 : i18, i7 ? i2 : i4 & 255) | 0;
          i2 = 0;
         }
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i18);
         i7 = i2;
        }
        if ((i10 | 0) == 134) break; else if ((i10 | 0) == 146) {
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i18);
         i1 = i21;
         i2 = 0;
         break L15;
        }
       } while (0);
       if ((i2 | 0) != (i3 | 0)) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9push_backEc(i3 + -24 | 0, 41);
        if (i14 & 1 | 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i13 >> 2] | 0) + -24 | 0, 56614) | 0;
        if (i14 & 2 | 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i13 >> 2] | 0) + -24 | 0, 56621) | 0;
        if (i14 & 4 | 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i13 >> 2] | 0) + -24 | 0, 56631) | 0;
        switch (i15 | 0) {
        case 1:
         {
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i13 >> 2] | 0) + -24 | 0, 58205) | 0;
          break;
         }
        case 2:
         {
          __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i13 >> 2] | 0) + -24 | 0, 58208) | 0;
          break;
         }
        default:
         {}
        }
        i2 = HEAP8[i20 + 11 >> 0] | 0;
        i19 = i2 << 24 >> 24 < 0;
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj((HEAP32[i13 >> 2] | 0) + -24 | 0, i19 ? HEAP32[i20 >> 2] | 0 : i20, i19 ? HEAP32[i20 + 4 >> 2] | 0 : i2 & 255) | 0;
        i2 = 1;
       } else {
        i1 = i21;
        i2 = 0;
       }
      } else {
       i1 = i21;
       i2 = 0;
      }
     } else {
      i1 = i21;
      i2 = 0;
     } while (0);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i20);
     HEAP8[i25 >> 0] = i16;
     if (!i2) {
      HEAP8[i25 >> 0] = i22;
      HEAP32[i23 >> 2] = i24;
      i1 = i21;
      break L1;
     }
    } else i1 = i17; else i1 = i21;
   }
  } while (0);
  HEAP8[i25 >> 0] = i22;
  HEAP32[i23 >> 2] = i24;
 } while (0);
 STACKTOP = i26;
 return i1 | 0;
}

function __ZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0;
 i25 = STACKTOP;
 STACKTOP = STACKTOP + 144 | 0;
 i7 = i25 + 132 | 0;
 i8 = i25 + 128 | 0;
 i21 = i25 + 124 | 0;
 i15 = i25 + 120 | 0;
 i16 = i25 + 116 | 0;
 i23 = i25 + 104 | 0;
 i6 = i25 + 100 | 0;
 i22 = i25 + 88 | 0;
 i20 = i25 + 80 | 0;
 i24 = i25 + 60 | 0;
 i18 = i25 + 36 | 0;
 i17 = i25 + 20 | 0;
 i19 = i25 + 8 | 0;
 i9 = i25 + 72 | 0;
 i10 = i25 + 56 | 0;
 i11 = i25 + 32 | 0;
 i12 = i25 + 16 | 0;
 i13 = i25 + 4 | 0;
 i14 = i25;
 HEAP32[i8 >> 2] = i1;
 HEAP32[i21 >> 2] = 0;
 HEAP32[i15 >> 2] = i21;
 HEAP32[i16 >> 2] = i21;
 HEAP32[i23 >> 2] = 0;
 HEAP32[i23 + 4 >> 2] = 0;
 HEAP32[i23 + 8 >> 2] = 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i22 + 4 >> 2] = 0;
 HEAP32[i22 + 8 >> 2] = 0;
 HEAP32[i22 >> 2] = i22 + 4;
 HEAP32[i20 >> 2] = 19;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i24 >> 2] = 0;
 i5 = i24 + 4 | 0;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i24 + 8 >> 2] = 0;
 HEAP32[i18 >> 2] = i23;
 HEAP32[i18 + 4 >> 2] = i22;
 HEAP32[i18 + 8 >> 2] = i6;
 HEAP32[i18 + 12 >> 2] = i24;
 HEAP32[i18 + 16 >> 2] = i20;
 HEAP32[i17 >> 2] = i22;
 HEAP32[i17 + 4 >> 2] = i16;
 HEAP32[i17 + 8 >> 2] = i15;
 HEAP32[i19 >> 2] = i23;
 HEAP32[i19 + 4 >> 2] = i22;
 i6 = i24 + 8 | 0;
 __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i8);
 L1 : while (1) {
  i4 = HEAP32[i5 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i24 >> 2] | 0)) {
   i1 = 106;
   break;
  }
  i2 = i1 + -4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  HEAP32[i8 >> 2] = i3;
  i4 = i3;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i26 = i1 + -4 | 0;
   HEAP32[i5 >> 2] = i26;
   i1 = i26;
  }
  if (!i3) continue;
  if ((i4 | 0) == (i20 | 0)) {
   __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlvE_clEv(i19);
   continue;
  }
  __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i4 >> 2] | 0);
  i1 = HEAP32[i8 >> 2] | 0;
  do switch (HEAP32[i1 >> 2] | 0) {
  case 20:
  case 19:
   continue L1;
  case 1:
   {
    i3 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(i1) | 0) + 8 | 0;
    HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
    HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlNS_4NameEE_clES3_(i18, i7) | 0;
    i3 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 20 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i3 >> 2] | 0);
    i3 = 0;
    while (1) {
     i26 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 20 | 0;
     if (i3 >>> 0 >= (HEAP32[i26 >> 2] | 0) >>> 0) continue L1;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0, i3) | 0;
     i2 = HEAP32[i5 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  case 2:
   {
    i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i1) | 0) + 8 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 3:
   {
    i1 = (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i1) | 0) + 8 | 0;
    HEAP32[i10 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i7 >> 2] = HEAP32[i10 >> 2];
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlNS_4NameEE_clES3_(i18, i7) | 0;
    i1 = (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i7 >> 2] = HEAP32[i11 >> 2];
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlNS_4NameEE_clES3_(i18, i7) | 0;
    i1 = (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 4:
   {
    i1 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i1) | 0) + 8 | 0;
    HEAP32[i12 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i7 >> 2] = HEAP32[i12 >> 2];
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlNS_4NameEE0_clES3_(i17, i7);
    i1 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 5:
   {
    i2 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i1) | 0) + 16 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i2 >> 2] | 0);
    i2 = 0;
    while (1) {
     i26 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
     i1 = HEAP32[i8 >> 2] | 0;
     if (i2 >>> 0 >= (HEAP32[i26 >> 2] | 0) >>> 0) break;
     i26 = __ZNK11ArenaVectorIN4wasm4NameEEixEj((__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i1) | 0) + 8 | 0, i2) | 0;
     HEAP32[i13 >> 2] = HEAP32[i26 >> 2];
     HEAP32[i7 >> 2] = HEAP32[i13 >> 2];
     __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlNS_4NameEE0_clES3_(i17, i7);
     i2 = i2 + 1 | 0;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i1) | 0) + 24 | 0;
    HEAP32[i14 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i7 >> 2] = HEAP32[i14 >> 2];
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlNS_4NameEE0_clES3_(i17, i7);
    i1 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 28 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 32 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 6:
   {
    i3 = (__ZN4wasm10Expression4castINS_4CallEEEPT_v(i1) | 0) + 24 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlyE_clEy(i16, HEAP32[i3 >> 2] | 0, 0);
    i3 = (__ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i3 >> 2] | 0);
    i3 = 0;
    while (1) {
     i26 = (__ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
     if (i3 >>> 0 >= (HEAP32[i26 >> 2] | 0) >>> 0) continue L1;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 8 | 0, i3) | 0;
     i2 = HEAP32[i5 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  case 7:
   {
    i3 = (__ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i1) | 0) + 24 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlyE_clEy(i16, HEAP32[i3 >> 2] | 0, 0);
    i3 = (__ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i3 >> 2] | 0);
    i3 = 0;
    while (1) {
     i26 = (__ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
     if (i3 >>> 0 >= (HEAP32[i26 >> 2] | 0) >>> 0) continue L1;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 8 | 0, i3) | 0;
     i2 = HEAP32[i5 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  case 8:
   {
    i1 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i1) | 0) + 28 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
    }
    i3 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 24 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlyE_clEy(i16, HEAP32[i3 >> 2] | 0, 0);
    i3 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i3 >> 2] | 0);
    i3 = 0;
    while (1) {
     i26 = (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
     if (i3 >>> 0 >= (HEAP32[i26 >> 2] | 0) >>> 0) continue L1;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 8 | 0, i3) | 0;
     i2 = HEAP32[i5 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  case 9:
   {
    i26 = (__ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(i1) | 0) + 8 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i26 >> 2] | 0);
    continue L1;
   }
  case 10:
   {
    i1 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i1) | 0) + 8 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i1 >> 2] | 0);
    i1 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 11:
   {
    i1 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i1) | 0) + 8 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAPU8[i1 >> 0] | 0);
    i1 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 9 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAPU8[i1 >> 0] | 0);
    i1 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i1 >> 2] | 0);
    i1 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i1 >> 2] | 0);
    i1 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 20 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 12:
   {
    i1 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i1) | 0) + 8 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAPU8[i1 >> 0] | 0);
    i1 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i1 >> 2] | 0);
    i1 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i1 >> 2] | 0);
    i1 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 20 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 24 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 13:
   {
    i26 = (__ZN4wasm10Expression4castINS_5ConstEEEPT_v(i1) | 0) + 8 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i26 >> 2] | 0);
    i26 = __ZN4wasm7Literal7getBitsEv((__ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 8 | 0) | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlyE_clEy(i16, i26, tempRet0);
    continue L1;
   }
  case 14:
   {
    i1 = (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i1) | 0) + 8 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i1 >> 2] | 0);
    i1 = (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 15:
   {
    i1 = (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i1) | 0) + 8 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i1 >> 2] | 0);
    i1 = (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 16:
   {
    i1 = (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i1) | 0) + 8 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
    }
    i1 = (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 17:
   {
    i1 = (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i1) | 0) + 8 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1);
     continue L1;
    } else {
     HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     continue L1;
    }
   }
  case 18:
   {
    i3 = (__ZN4wasm10Expression4castINS_4HostEEEPT_v(i1) | 0) + 8 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i3 >> 2] | 0);
    i3 = (__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 12 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlyE_clEy(i16, HEAP32[i3 >> 2] | 0, 0);
    i3 = (__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 24 | 0;
    __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i15, HEAP32[i3 >> 2] | 0);
    i3 = 0;
    while (1) {
     i26 = (__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 24 | 0;
     if (i3 >>> 0 >= (HEAP32[i26 >> 2] | 0) >>> 0) continue L1;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj((__ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i8 >> 2] | 0) | 0) + 16 | 0, i3) | 0;
     i2 = HEAP32[i5 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i24, i1); else {
      HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
      HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
     }
     i3 = i3 + 1 | 0;
    }
   }
  default:
   {
    i1 = 105;
    break L1;
   }
  } while (0);
 }
 if ((i1 | 0) != 105) if ((i1 | 0) == 106) {
  i26 = HEAP32[i21 >> 2] | 0;
  __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i24);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEED2Ev(i22);
  __ZNSt3__213__vector_baseIN4wasm4NameENS_9allocatorIS2_EEED2Ev(i23);
  STACKTOP = i25;
  return i26 | 0;
 }
 return 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner10visitUnaryEPNS_5UnaryE(i41, i38, i36) {
 i41 = i41 | 0;
 i38 = i38 | 0;
 i36 = i36 | 0;
 var d1 = 0.0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i37 = 0, i39 = 0, i40 = 0, i42 = 0, i43 = 0, d44 = 0.0;
 i43 = STACKTOP;
 STACKTOP = STACKTOP + 624 | 0;
 i39 = i43 + 600 | 0;
 i37 = i43 + 544 | 0;
 i42 = i43 + 512 | 0;
 i2 = i43 + 584 | 0;
 i3 = i43 + 568 | 0;
 i14 = i43 + 528 | 0;
 i25 = i43 + 496 | 0;
 i30 = i43 + 480 | 0;
 i31 = i43 + 464 | 0;
 i32 = i43 + 448 | 0;
 i33 = i43 + 432 | 0;
 i34 = i43 + 416 | 0;
 i35 = i43 + 400 | 0;
 i4 = i43 + 384 | 0;
 i5 = i43 + 368 | 0;
 i6 = i43 + 352 | 0;
 i7 = i43 + 336 | 0;
 i8 = i43 + 320 | 0;
 i9 = i43 + 304 | 0;
 i10 = i43 + 288 | 0;
 i11 = i43 + 272 | 0;
 i12 = i43 + 256 | 0;
 i13 = i43 + 240 | 0;
 i15 = i43 + 224 | 0;
 i16 = i43 + 208 | 0;
 i17 = i43 + 192 | 0;
 i18 = i43 + 176 | 0;
 i19 = i43 + 160 | 0;
 i20 = i43 + 144 | 0;
 i21 = i43 + 128 | 0;
 i22 = i43 + 112 | 0;
 i23 = i43 + 96 | 0;
 i24 = i43 + 80 | 0;
 i26 = i43 + 64 | 0;
 i27 = i43 + 48 | 0;
 i28 = i43 + 32 | 0;
 i29 = i43 + 16 | 0;
 i40 = i43;
 __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i37, i38, HEAP32[i36 + 12 >> 2] | 0);
 if (!(HEAP32[i37 + 16 >> 2] | 0)) {
  HEAP32[i42 >> 2] = HEAP32[i37 >> 2];
  HEAP32[i42 + 4 >> 2] = HEAP32[i37 + 4 >> 2];
  HEAP32[i42 + 8 >> 2] = HEAP32[i37 + 8 >> 2];
  HEAP32[i42 + 12 >> 2] = HEAP32[i37 + 12 >> 2];
  L3 : do switch (HEAP32[i42 >> 2] | 0) {
  case 1:
   {
    do switch (HEAP32[i36 + 8 >> 2] | 0) {
    case 0:
     {
      __ZNK4wasm7Literal18countLeadingZeroesEv(i2, i42);
      HEAP32[i41 >> 2] = HEAP32[i2 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 2:
     {
      __ZNK4wasm7Literal19countTrailingZeroesEv(i3, i42);
      HEAP32[i41 >> 2] = HEAP32[i3 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 4:
     {
      __ZNK4wasm7Literal8popCountEv(i14, i42);
      HEAP32[i41 >> 2] = HEAP32[i14 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i14 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i14 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i14 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 20:
     {
      HEAP32[i25 >> 2] = 1;
      HEAP32[i25 + 8 >> 2] = 0;
      i42 = (__ZNK4wasm7LiteraleqERKS0_(i42, i25) | 0) & 1;
      HEAP32[i41 >> 2] = 1;
      HEAP32[i41 + 8 >> 2] = i42;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 45:
     {
      __ZN4wasm7Literal9castToF32Ev(i30, i42);
      HEAP32[i41 >> 2] = HEAP32[i30 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i30 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i30 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i30 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 22:
     {
      __ZNK4wasm7Literal12extendToSI64Ev(i31, i42);
      HEAP32[i41 >> 2] = HEAP32[i31 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i31 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i31 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i31 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 23:
     {
      __ZNK4wasm7Literal12extendToUI64Ev(i32, i42);
      HEAP32[i41 >> 2] = HEAP32[i32 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i32 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i32 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i32 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 37:
     {
      d1 = +((HEAP32[i42 + 8 >> 2] | 0) >>> 0);
      HEAP32[i41 >> 2] = 3;
      HEAPF32[i41 + 8 >> 2] = d1;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 38:
     {
      d1 = +((HEAP32[i42 + 8 >> 2] | 0) >>> 0);
      HEAP32[i41 >> 2] = 4;
      HEAPF64[i41 + 8 >> 3] = d1;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 35:
     {
      d1 = +(HEAP32[i42 + 8 >> 2] | 0);
      HEAP32[i41 >> 2] = 3;
      HEAPF32[i41 + 8 >> 2] = d1;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 36:
     {
      d1 = +(HEAP32[i42 + 8 >> 2] | 0);
      HEAP32[i41 >> 2] = 4;
      HEAPF64[i41 + 8 >> 3] = d1;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    default:
     _abort();
    } while (0);
    break;
   }
  case 2:
   {
    do switch (HEAP32[i36 + 8 >> 2] | 0) {
    case 1:
     {
      __ZNK4wasm7Literal18countLeadingZeroesEv(i33, i42);
      HEAP32[i41 >> 2] = HEAP32[i33 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i33 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i33 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i33 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 3:
     {
      __ZNK4wasm7Literal19countTrailingZeroesEv(i34, i42);
      HEAP32[i41 >> 2] = HEAP32[i34 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i34 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i34 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i34 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 5:
     {
      __ZNK4wasm7Literal8popCountEv(i35, i42);
      HEAP32[i41 >> 2] = HEAP32[i35 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i35 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i35 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i35 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 21:
     {
      HEAP32[i4 >> 2] = 2;
      i40 = i4 + 8 | 0;
      HEAP32[i40 >> 2] = 0;
      HEAP32[i40 + 4 >> 2] = 0;
      i42 = (__ZNK4wasm7LiteraleqERKS0_(i42, i4) | 0) & 1;
      HEAP32[i41 >> 2] = 1;
      HEAP32[i41 + 8 >> 2] = i42;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 24:
     {
      __ZNK4wasm7Literal13truncateToI32Ev(i5, i42);
      HEAP32[i41 >> 2] = HEAP32[i5 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i5 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i5 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i5 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 46:
     {
      __ZN4wasm7Literal9castToF64Ev(i6, i42);
      HEAP32[i41 >> 2] = HEAP32[i6 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i6 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 41:
     {
      i42 = i42 + 8 | 0;
      d1 = +((HEAP32[i42 >> 2] | 0) >>> 0) + 4294967296.0 * +((HEAP32[i42 + 4 >> 2] | 0) >>> 0);
      HEAP32[i41 >> 2] = 3;
      HEAPF32[i41 + 8 >> 2] = d1;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 42:
     {
      i42 = i42 + 8 | 0;
      d1 = +((HEAP32[i42 >> 2] | 0) >>> 0) + 4294967296.0 * +((HEAP32[i42 + 4 >> 2] | 0) >>> 0);
      HEAP32[i41 >> 2] = 4;
      HEAPF64[i41 + 8 >> 3] = d1;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 39:
     {
      i42 = i42 + 8 | 0;
      d1 = +((HEAP32[i42 >> 2] | 0) >>> 0) + 4294967296.0 * +(HEAP32[i42 + 4 >> 2] | 0);
      HEAP32[i41 >> 2] = 3;
      HEAPF32[i41 + 8 >> 2] = d1;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 40:
     {
      i42 = i42 + 8 | 0;
      d1 = +((HEAP32[i42 >> 2] | 0) >>> 0) + 4294967296.0 * +(HEAP32[i42 + 4 >> 2] | 0);
      HEAP32[i41 >> 2] = 4;
      HEAPF64[i41 + 8 >> 3] = d1;
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    default:
     _abort();
    } while (0);
    break;
   }
  case 3:
   {
    do switch (HEAP32[i36 + 8 >> 2] | 0) {
    case 6:
     {
      __ZNK4wasm7Literal3negEv(i7, i42);
      HEAP32[i41 >> 2] = HEAP32[i7 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i7 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i7 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 8:
     {
      __ZNK4wasm7Literal3absEv(i8, i42);
      HEAP32[i41 >> 2] = HEAP32[i8 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 10:
     {
      __ZNK4wasm7Literal4ceilEv(i9, i42);
      HEAP32[i41 >> 2] = HEAP32[i9 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i9 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i9 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i9 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 12:
     {
      __ZNK4wasm7Literal5floorEv(i10, i42);
      HEAP32[i41 >> 2] = HEAP32[i10 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i10 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i10 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i10 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 14:
     {
      __ZNK4wasm7Literal5truncEv(i11, i42);
      HEAP32[i41 >> 2] = HEAP32[i11 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i11 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i11 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i11 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 16:
     {
      __ZNK4wasm7Literal9nearbyintEv(i12, i42);
      HEAP32[i41 >> 2] = HEAP32[i12 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i12 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i12 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i12 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 18:
     {
      __ZNK4wasm7Literal4sqrtEv(i13, i42);
      HEAP32[i41 >> 2] = HEAP32[i13 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i13 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i13 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i13 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 26:
    case 25:
     {
      HEAP32[i39 >> 2] = HEAP32[i42 >> 2];
      HEAP32[i39 + 4 >> 2] = HEAP32[i42 + 4 >> 2];
      HEAP32[i39 + 8 >> 2] = HEAP32[i42 + 8 >> 2];
      HEAP32[i39 + 12 >> 2] = HEAP32[i42 + 12 >> 2];
      __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11truncSFloatEPNS_5UnaryES5_(i15, i38, i36, i39);
      HEAP32[i41 >> 2] = HEAP32[i15 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i15 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i15 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i15 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 28:
    case 27:
     {
      HEAP32[i39 >> 2] = HEAP32[i42 >> 2];
      HEAP32[i39 + 4 >> 2] = HEAP32[i42 + 4 >> 2];
      HEAP32[i39 + 8 >> 2] = HEAP32[i42 + 8 >> 2];
      HEAP32[i39 + 12 >> 2] = HEAP32[i42 + 12 >> 2];
      __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11truncUFloatEPNS_5UnaryES5_(i16, i38, i36, i39);
      HEAP32[i41 >> 2] = HEAP32[i16 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i16 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i16 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i16 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 33:
     {
      __ZN4wasm7Literal9castToI32Ev(i17, i42);
      HEAP32[i41 >> 2] = HEAP32[i17 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i17 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i17 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i17 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 43:
     {
      __ZNK4wasm7Literal11extendToF64Ev(i18, i42);
      HEAP32[i41 >> 2] = HEAP32[i18 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i18 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i18 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i18 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    default:
     _abort();
    } while (0);
    break;
   }
  case 4:
   {
    do switch (HEAP32[i36 + 8 >> 2] | 0) {
    case 7:
     {
      __ZNK4wasm7Literal3negEv(i19, i42);
      HEAP32[i41 >> 2] = HEAP32[i19 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i19 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i19 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i19 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 9:
     {
      __ZNK4wasm7Literal3absEv(i20, i42);
      HEAP32[i41 >> 2] = HEAP32[i20 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i20 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i20 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i20 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 11:
     {
      __ZNK4wasm7Literal4ceilEv(i21, i42);
      HEAP32[i41 >> 2] = HEAP32[i21 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i21 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i21 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i21 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 13:
     {
      __ZNK4wasm7Literal5floorEv(i22, i42);
      HEAP32[i41 >> 2] = HEAP32[i22 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i22 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i22 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i22 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 15:
     {
      __ZNK4wasm7Literal5truncEv(i23, i42);
      HEAP32[i41 >> 2] = HEAP32[i23 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i23 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i23 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i23 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 17:
     {
      __ZNK4wasm7Literal9nearbyintEv(i24, i42);
      HEAP32[i41 >> 2] = HEAP32[i24 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i24 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i24 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i24 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 19:
     {
      __ZNK4wasm7Literal4sqrtEv(i26, i42);
      HEAP32[i41 >> 2] = HEAP32[i26 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i26 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i26 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i26 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 30:
    case 29:
     {
      HEAP32[i39 >> 2] = HEAP32[i42 >> 2];
      HEAP32[i39 + 4 >> 2] = HEAP32[i42 + 4 >> 2];
      HEAP32[i39 + 8 >> 2] = HEAP32[i42 + 8 >> 2];
      HEAP32[i39 + 12 >> 2] = HEAP32[i42 + 12 >> 2];
      __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11truncSFloatEPNS_5UnaryES5_(i27, i38, i36, i39);
      HEAP32[i41 >> 2] = HEAP32[i27 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i27 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i27 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i27 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 32:
    case 31:
     {
      HEAP32[i39 >> 2] = HEAP32[i42 >> 2];
      HEAP32[i39 + 4 >> 2] = HEAP32[i42 + 4 >> 2];
      HEAP32[i39 + 8 >> 2] = HEAP32[i42 + 8 >> 2];
      HEAP32[i39 + 12 >> 2] = HEAP32[i42 + 12 >> 2];
      __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11truncUFloatEPNS_5UnaryES5_(i28, i38, i36, i39);
      HEAP32[i41 >> 2] = HEAP32[i28 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i28 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i28 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i28 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 34:
     {
      __ZN4wasm7Literal9castToI64Ev(i29, i42);
      HEAP32[i41 >> 2] = HEAP32[i29 >> 2];
      HEAP32[i41 + 4 >> 2] = HEAP32[i29 + 4 >> 2];
      HEAP32[i41 + 8 >> 2] = HEAP32[i29 + 8 >> 2];
      HEAP32[i41 + 12 >> 2] = HEAP32[i29 + 12 >> 2];
      HEAP32[i41 + 16 >> 2] = 0;
      break L3;
     }
    case 44:
     {
      d1 = +__ZN4wasm7Literal8getFloatEv(i42);
      d44 = +Math_abs(+d1);
      HEAPF64[tempDoublePtr >> 3] = d44;
      i2 = HEAP32[tempDoublePtr >> 2] | 0;
      i3 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
      if (i3 >>> 0 > 2146435072 | (i3 | 0) == 2146435072 & i2 >>> 0 > 0) {
       HEAP32[i41 >> 2] = 3;
       HEAPF32[i41 + 8 >> 2] = d1;
       HEAP32[i41 + 16 >> 2] = 0;
       break L3;
      }
      if ((i2 | 0) == 0 & (i3 | 0) == 2146435072) {
       HEAP32[i41 >> 2] = 3;
       HEAPF32[i41 + 8 >> 2] = d1;
       HEAP32[i41 + 16 >> 2] = 0;
       break L3;
      }
      if (d1 < -3402823466385288598117041.0e14) {
       HEAP32[i41 >> 2] = 3;
       HEAPF32[i41 + 8 >> 2] = -inf;
       HEAP32[i41 + 16 >> 2] = 0;
       break L3;
      }
      if (d1 > 3402823466385288598117041.0e14) {
       HEAP32[i41 >> 2] = 3;
       HEAPF32[i41 + 8 >> 2] = inf;
       HEAP32[i41 + 16 >> 2] = 0;
       break L3;
      } else {
       __ZNK4wasm7Literal13truncateToF32Ev(i40, i42);
       HEAP32[i41 >> 2] = HEAP32[i40 >> 2];
       HEAP32[i41 + 4 >> 2] = HEAP32[i40 + 4 >> 2];
       HEAP32[i41 + 8 >> 2] = HEAP32[i40 + 8 >> 2];
       HEAP32[i41 + 12 >> 2] = HEAP32[i40 + 12 >> 2];
       HEAP32[i41 + 16 >> 2] = 0;
       break L3;
      }
     }
    default:
     _abort();
    } while (0);
    break;
   }
  default:
   _abort();
  } while (0);
 } else {
  HEAP32[i41 >> 2] = HEAP32[i37 >> 2];
  HEAP32[i41 + 4 >> 2] = HEAP32[i37 + 4 >> 2];
  HEAP32[i41 + 8 >> 2] = HEAP32[i37 + 8 >> 2];
  HEAP32[i41 + 12 >> 2] = HEAP32[i37 + 12 >> 2];
  HEAP32[i41 + 16 >> 2] = HEAP32[i37 + 16 >> 2];
  HEAP32[i41 + 20 >> 2] = HEAP32[i37 + 20 >> 2];
 }
 STACKTOP = i43;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_122parse_unqualified_nameINS0_2DbEEEPKcS4_S4_RT_(i1, i15, i12) {
 i1 = i1 | 0;
 i15 = i15 | 0;
 i12 = i12 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i14 = i16 + 88 | 0;
 i8 = i16 + 64 | 0;
 i9 = i16 + 48 | 0;
 i7 = i16 + 24 | 0;
 i10 = i16 + 12 | 0;
 i11 = i16;
 L1 : do if ((i1 | 0) != (i15 | 0)) {
  i3 = HEAP8[i1 >> 0] | 0;
  i4 = i3 << 24 >> 24;
  switch (i4 | 0) {
  case 68:
  case 67:
   {
    L6 : do if ((i15 - i1 | 0) > 1 ? (i6 = i12 + 4 | 0, i2 = HEAP32[i6 >> 2] | 0, (HEAP32[i12 >> 2] | 0) != (i2 | 0)) : 0) {
     switch (i4 | 0) {
     case 67:
      {
       switch (HEAP8[i1 + 1 >> 0] | 0) {
       case 53:
       case 51:
       case 50:
       case 49:
        break;
       default:
        break L6;
       }
       __ZN10__cxxabiv112_GLOBAL__N_19base_nameINSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEEEET_RS9_(i9, i2 + -24 | 0);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i8, i9);
       i2 = HEAP32[i6 >> 2] | 0;
       i15 = HEAP32[i12 + 8 >> 2] | 0;
       i5 = i15;
       if (i2 >>> 0 < i15 >>> 0) {
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i8);
        HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + 24;
       } else {
        i3 = HEAP32[i12 >> 2] | 0;
        i6 = (i2 - i3 | 0) / 24 | 0;
        i4 = i6 + 1 | 0;
        if (i4 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i12);
        i2 = (i5 - i3 | 0) / 24 | 0;
        if (i2 >>> 0 < 89478485) {
         i2 = i2 << 1;
         i2 = i2 >>> 0 < i4 >>> 0 ? i4 : i2;
        } else i2 = 178956970;
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i2, i6, i12 + 12 | 0);
        i15 = i14 + 8 | 0;
        i13 = HEAP32[i15 >> 2] | 0;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i13, i8);
        HEAP32[i15 >> 2] = i13 + 24;
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i12, i14);
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i8);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i9);
       HEAP8[i12 + 60 >> 0] = 1;
       i1 = i1 + 2 | 0;
       break L6;
      }
     case 68:
      break;
     default:
      break L6;
     }
     switch (HEAP8[i1 + 1 >> 0] | 0) {
     case 53:
     case 50:
     case 49:
     case 48:
      break;
     default:
      break L6;
     }
     __ZN10__cxxabiv112_GLOBAL__N_19base_nameINSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEEEET_RS9_(i11, i2 + -24 | 0);
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i11, 0, 57053) | 0;
     HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i10 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i10 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i7, i10);
     i2 = HEAP32[i6 >> 2] | 0;
     i15 = HEAP32[i12 + 8 >> 2] | 0;
     i5 = i15;
     if (i2 >>> 0 < i15 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i7);
      HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + 24;
     } else {
      i3 = HEAP32[i12 >> 2] | 0;
      i6 = (i2 - i3 | 0) / 24 | 0;
      i4 = i6 + 1 | 0;
      if (i4 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i12);
      i2 = (i5 - i3 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i4 >>> 0 ? i4 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i2, i6, i12 + 12 | 0);
      i15 = i14 + 8 | 0;
      i13 = HEAP32[i15 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i13, i7);
      HEAP32[i15 >> 2] = i13 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i12, i14);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i7);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i10);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i11);
     HEAP8[i12 + 60 >> 0] = 1;
     i1 = i1 + 2 | 0;
    } while (0);
    break L1;
   }
  case 85:
   {
    L40 : do if ((i15 - i1 | 0) > 2 & i3 << 24 >> 24 == 85) {
     switch (HEAP8[i1 + 1 >> 0] | 0) {
     case 116:
      {
       HEAP32[i9 >> 2] = 0;
       HEAP32[i9 + 4 >> 2] = 0;
       HEAP32[i9 + 8 >> 2] = 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i9, 57977, 8);
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i8, i9);
       i7 = i12 + 4 | 0;
       i2 = HEAP32[i7 >> 2] | 0;
       i13 = HEAP32[i12 + 8 >> 2] | 0;
       i3 = i13;
       if (i2 >>> 0 < i13 >>> 0) {
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i8);
        HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
       } else {
        i4 = HEAP32[i12 >> 2] | 0;
        i6 = (i2 - i4 | 0) / 24 | 0;
        i5 = i6 + 1 | 0;
        if (i5 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i12);
        i2 = (i3 - i4 | 0) / 24 | 0;
        if (i2 >>> 0 < 89478485) {
         i2 = i2 << 1;
         i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
        } else i2 = 178956970;
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i2, i6, i12 + 12 | 0);
        i13 = i14 + 8 | 0;
        i11 = HEAP32[i13 >> 2] | 0;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i11, i8);
        HEAP32[i13 >> 2] = i11 + 24;
        __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i12, i14);
        __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i8);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i9);
       i2 = i1 + 2 | 0;
       if ((i2 | 0) == (i15 | 0)) {
        i3 = HEAP32[i7 >> 2] | 0;
        i2 = i3 + -24 | 0;
        while (1) {
         if ((i3 | 0) == (i2 | 0)) break L40;
         i15 = i3 + -24 | 0;
         HEAP32[i7 >> 2] = i15;
         __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
         i3 = HEAP32[i7 >> 2] | 0;
        }
       }
       if (((HEAP8[i2 >> 0] | 0) + -48 | 0) >>> 0 < 10) {
        i3 = i1 + 3 | 0;
        while (1) {
         if ((i3 | 0) == (i15 | 0)) {
          i3 = i15;
          break;
         }
         if (((HEAP8[i3 >> 0] | 0) + -48 | 0) >>> 0 >= 10) break;
         i3 = i3 + 1 | 0;
        }
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendIPKcEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorISC_EE5valueERS7_E4typeESC_SC_((HEAP32[i7 >> 2] | 0) + -24 | 0, i2, i3);
        i2 = i3;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9push_backEc((HEAP32[i7 >> 2] | 0) + -24 | 0, 39);
       if ((i2 | 0) != (i15 | 0) ? (HEAP8[i2 >> 0] | 0) == 95 : 0) {
        i1 = i2 + 1 | 0;
        break L40;
       }
       i3 = HEAP32[i7 >> 2] | 0;
       i2 = i3 + -24 | 0;
       while (1) {
        if ((i3 | 0) == (i2 | 0)) break L40;
        i15 = i3 + -24 | 0;
        HEAP32[i7 >> 2] = i15;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
        i3 = HEAP32[i7 >> 2] | 0;
       }
      }
     case 108:
      break;
     default:
      break L40;
     }
     HEAP32[i10 >> 2] = 0;
     HEAP32[i10 + 4 >> 2] = 0;
     HEAP32[i10 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i10, 57986, 9);
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i7, i10);
     i13 = i12 + 4 | 0;
     i2 = HEAP32[i13 >> 2] | 0;
     i9 = HEAP32[i12 + 8 >> 2] | 0;
     i3 = i9;
     if (i2 >>> 0 < i9 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i7);
      HEAP32[i13 >> 2] = (HEAP32[i13 >> 2] | 0) + 24;
     } else {
      i4 = HEAP32[i12 >> 2] | 0;
      i6 = (i2 - i4 | 0) / 24 | 0;
      i5 = i6 + 1 | 0;
      if (i5 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i12);
      i2 = (i3 - i4 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i2, i6, i12 + 12 | 0);
      i9 = i14 + 8 | 0;
      i8 = HEAP32[i9 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i8, i7);
      HEAP32[i9 >> 2] = i8 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i12, i14);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i7);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i10);
     i3 = i1 + 2 | 0;
     do if ((HEAP8[i3 >> 0] | 0) != 118) {
      i2 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i3, i15, i12) | 0;
      if ((i2 | 0) == (i3 | 0)) {
       i3 = HEAP32[i13 >> 2] | 0;
       i2 = i3 + -24 | 0;
       while (1) {
        if ((i3 | 0) == (i2 | 0)) break L40;
        i15 = i3 + -24 | 0;
        HEAP32[i13 >> 2] = i15;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
        i3 = HEAP32[i13 >> 2] | 0;
       }
      }
      i3 = HEAP32[i13 >> 2] | 0;
      if (((i3 - (HEAP32[i12 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) break L40;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i14, i3 + -24 | 0);
      i5 = HEAP32[i13 >> 2] | 0;
      i3 = i5 + -24 | 0;
      i4 = i5;
      while (1) {
       if ((i4 | 0) == (i3 | 0)) break;
       i10 = i4 + -24 | 0;
       HEAP32[i13 >> 2] = i10;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i10);
       i4 = HEAP32[i13 >> 2] | 0;
      }
      i8 = i14 + 11 | 0;
      i3 = HEAP8[i8 >> 0] | 0;
      i7 = i3 << 24 >> 24 < 0;
      i9 = i14 + 4 | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i5 + -48 | 0, i7 ? HEAP32[i14 >> 2] | 0 : i14, i7 ? HEAP32[i9 >> 2] | 0 : i3 & 255) | 0;
      i7 = i14 + 8 | 0;
      while (1) {
       i6 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i2, i15, i12) | 0;
       if ((i6 | 0) == (i2 | 0)) {
        i4 = 85;
        break;
       }
       i2 = HEAP32[i13 >> 2] | 0;
       if (((i2 - (HEAP32[i12 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
        i4 = 123;
        break;
       }
       __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i11, i2 + -24 | 0);
       if (i3 << 24 >> 24 < 0) {
        i2 = HEAP32[i14 >> 2] | 0;
        HEAP8[i2 >> 0] = 0;
        HEAP32[i9 >> 2] = 0;
        if ((HEAP32[i7 >> 2] & 2147483647 | 0) != 11) {
         HEAP8[i14 >> 0] = 0;
         _free(i2);
         HEAP8[i8 >> 0] = 0;
        }
       } else {
        HEAP8[i14 >> 0] = 0;
        HEAP8[i8 >> 0] = 0;
       };
       HEAP32[i14 >> 2] = HEAP32[i11 >> 2];
       HEAP32[i14 + 4 >> 2] = HEAP32[i11 + 4 >> 2];
       HEAP32[i14 + 8 >> 2] = HEAP32[i11 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i11 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i11);
       i5 = HEAP32[i13 >> 2] | 0;
       i2 = i5 + -24 | 0;
       i3 = i5;
       while (1) {
        if ((i3 | 0) == (i2 | 0)) break;
        i10 = i3 + -24 | 0;
        HEAP32[i13 >> 2] = i10;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i10);
        i3 = HEAP32[i13 >> 2] | 0;
       }
       i3 = HEAP8[i8 >> 0] | 0;
       i2 = i3 << 24 >> 24 < 0;
       i4 = i2 ? HEAP32[i9 >> 2] | 0 : i3 & 255;
       if (!i4) {
        i2 = i6;
        continue;
       }
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i5 + -48 | 0, 57598) | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj((HEAP32[i13 >> 2] | 0) + -24 | 0, i2 ? HEAP32[i14 >> 2] | 0 : i14, i4) | 0;
       i2 = i6;
      }
      if ((i4 | 0) == 85) {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc((HEAP32[i13 >> 2] | 0) + -24 | 0, 56966) | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i14);
       i3 = i2;
       break;
      } else if ((i4 | 0) == 123) {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i14);
       break L40;
      }
     } else {
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9push_backEc((HEAP32[i13 >> 2] | 0) + -24 | 0, 41);
      i3 = i1 + 3 | 0;
     } while (0);
     if ((i3 | 0) != (i15 | 0) ? (HEAP8[i3 >> 0] | 0) == 69 : 0) {
      i2 = i3 + 1 | 0;
      if ((i2 | 0) == (i15 | 0)) {
       i3 = HEAP32[i13 >> 2] | 0;
       i2 = i3 + -24 | 0;
       while (1) {
        if ((i3 | 0) == (i2 | 0)) break L40;
        i15 = i3 + -24 | 0;
        HEAP32[i13 >> 2] = i15;
        __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
        i3 = HEAP32[i13 >> 2] | 0;
       }
      }
      L131 : do if (((HEAP8[i2 >> 0] | 0) + -48 | 0) >>> 0 < 10) {
       i3 = i3 + 2 | 0;
       while (1) {
        if ((i3 | 0) == (i15 | 0)) {
         i3 = i15;
         break;
        }
        if (((HEAP8[i3 >> 0] | 0) + -48 | 0) >>> 0 >= 10) break;
        i3 = i3 + 1 | 0;
       }
       i10 = HEAP32[i13 >> 2] | 0;
       i4 = i10 + -24 | 0;
       i11 = i4 + 11 | 0;
       i5 = HEAP8[i11 >> 0] | 0;
       i8 = i5 << 24 >> 24 < 0;
       if (i8) {
        i7 = HEAP32[i4 >> 2] | 0;
        i6 = i7;
        i9 = HEAP32[i10 + -20 >> 2] | 0;
        i5 = (HEAP32[i10 + -16 >> 2] & 2147483647) + -1 | 0;
       } else {
        i6 = i4;
        i7 = i4;
        i9 = i5 & 255;
        i5 = 10;
       }
       i7 = i7 + 7 - i6 | 0;
       i6 = i3 - i2 | 0;
       if ((i3 | 0) != (i2 | 0)) {
        if ((i5 - i9 | 0) >>> 0 >= i6 >>> 0) {
         if (i8) i4 = HEAP32[i4 >> 2] | 0;
         if ((i9 | 0) == (i7 | 0)) i5 = i4; else {
          i5 = i4 + i7 | 0;
          _memmove(i5 + i6 | 0, i5 | 0, i9 - i7 | 0) | 0;
          i5 = i4;
         }
        } else {
         __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9__grow_byEjjjjjj(i4, i5, i9 + i6 - i5 | 0, i9, i7, i6);
         i5 = HEAP32[i4 >> 2] | 0;
        }
        i4 = i9 + i6 | 0;
        if ((HEAP8[i11 >> 0] | 0) < 0) HEAP32[i10 + -20 >> 2] = i4; else HEAP8[i11 >> 0] = i4;
        HEAP8[i5 + i4 >> 0] = 0;
        i4 = i5 + i7 | 0;
        while (1) {
         if ((i2 | 0) == (i3 | 0)) {
          i2 = i3;
          break L131;
         }
         HEAP8[i4 >> 0] = HEAP8[i2 >> 0] | 0;
         i2 = i2 + 1 | 0;
         i4 = i4 + 1 | 0;
        }
       }
      } while (0);
      if ((i2 | 0) != (i15 | 0) ? (HEAP8[i2 >> 0] | 0) == 95 : 0) {
       i1 = i2 + 1 | 0;
       break;
      }
      i3 = HEAP32[i13 >> 2] | 0;
      i2 = i3 + -24 | 0;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break L40;
       i15 = i3 + -24 | 0;
       HEAP32[i13 >> 2] = i15;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
       i3 = HEAP32[i13 >> 2] | 0;
      }
     }
     i3 = HEAP32[i13 >> 2] | 0;
     i2 = i3 + -24 | 0;
     while (1) {
      if ((i3 | 0) == (i2 | 0)) break L40;
      i15 = i3 + -24 | 0;
      HEAP32[i13 >> 2] = i15;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
      i3 = HEAP32[i13 >> 2] | 0;
     }
    } while (0);
    break L1;
   }
  case 57:
  case 56:
  case 55:
  case 54:
  case 53:
  case 52:
  case 51:
  case 50:
  case 49:
   {
    i1 = __ZN10__cxxabiv112_GLOBAL__N_117parse_source_nameINS0_2DbEEEPKcS4_S4_RT_(i1, i15, i12) | 0;
    break L1;
   }
  default:
   {
    i15 = __ZN10__cxxabiv112_GLOBAL__N_119parse_operator_nameINS0_2DbEEEPKcS4_S4_RT_(i1, i15, i12) | 0;
    STACKTOP = i16;
    return i15 | 0;
   }
  }
 } while (0);
 STACKTOP = i16;
 return i1 | 0;
}

function __ZN4wasm10parseConstEN6cashew7IStringENS_8WasmTypeER10MixedArena(i1, i19, i2) {
 i1 = i1 | 0;
 i19 = i19 | 0;
 i2 = i2 | 0;
 var d3 = 0.0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, d24 = 0.0;
 i23 = STACKTOP;
 STACKTOP = STACKTOP + 432 | 0;
 i21 = i23 + 208 | 0;
 i20 = i23 + 64 | 0;
 i6 = i23 + 408 | 0;
 i13 = i23 + 48 | 0;
 i14 = i23 + 32 | 0;
 i7 = i23 + 396 | 0;
 i15 = i23 + 16 | 0;
 i16 = i23;
 i11 = i23 + 384 | 0;
 i8 = i23 + 372 | 0;
 i12 = i23 + 360 | 0;
 i9 = i23 + 348 | 0;
 i4 = HEAP32[i1 >> 2] | 0;
 i22 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(i2) | 0;
 HEAP32[i22 + 4 >> 2] = i19;
 L1 : do if ((i19 + -3 | 0) >>> 0 < 2) {
  if ((i4 | 0) == (HEAP32[14943] | 0)) switch (i19 | 0) {
  case 3:
   {
    HEAP32[i22 + 8 >> 2] = 3;
    HEAPF32[i22 + 16 >> 2] = inf;
    i18 = i22;
    break L1;
   }
  case 4:
   {
    HEAP32[i22 + 8 >> 2] = 4;
    HEAPF64[i22 + 16 >> 3] = inf;
    i18 = i22;
    break L1;
   }
  default:
   {
    i18 = 0;
    break L1;
   }
  }
  if ((i4 | 0) == (HEAP32[14991] | 0)) switch (i19 | 0) {
  case 3:
   {
    HEAP32[i22 + 8 >> 2] = 3;
    HEAPF32[i22 + 16 >> 2] = -inf;
    i18 = i22;
    break L1;
   }
  case 4:
   {
    HEAP32[i22 + 8 >> 2] = 4;
    HEAPF64[i22 + 16 >> 3] = -inf;
    i18 = i22;
    break L1;
   }
  default:
   {
    i18 = 0;
    break L1;
   }
  }
  if ((i4 | 0) == (HEAP32[14942] | 0)) switch (i19 | 0) {
  case 3:
   {
    d3 = +_nan(67717);
    HEAP32[i22 + 8 >> 2] = 3;
    HEAPF32[i22 + 16 >> 2] = d3;
    i18 = i22;
    break L1;
   }
  case 4:
   {
    d3 = +_nan(67717);
    HEAP32[i22 + 8 >> 2] = 4;
    HEAPF64[i22 + 16 >> 3] = d3;
    i18 = i22;
    break L1;
   }
  default:
   {
    i18 = 0;
    break L1;
   }
  }
  i10 = (HEAP8[i4 >> 0] | 0) == 45;
  i1 = i4 + 1 | 0;
  i2 = i10 ? i1 : i4;
  if (i10) i5 = i1; else i5 = (HEAP8[i2 >> 0] | 0) == 43 ? i2 + 1 | 0 : i2;
  if (((HEAP8[i5 >> 0] | 0) == 110 ? (HEAP8[i5 + 1 >> 0] | 0) == 97 : 0) ? (HEAP8[i5 + 2 >> 0] | 0) == 110 : 0) {
   i1 = (HEAP8[i5 + 3 >> 0] | 0) == 58;
   i2 = i5 + 4 | 0;
   i4 = i1 ? i2 : 0;
   do if (i1) {
    if ((HEAP8[i2 >> 0] | 0) == 48 ? (HEAP8[i5 + 5 >> 0] | 0) == 120 : 0) break;
    ___assert_fail(22065, 22121, 73, 22135);
   } while (0);
   switch (i19 | 0) {
   case 3:
    {
     if (i1) {
      HEAP32[i6 >> 2] = 0;
      HEAP32[i6 + 4 >> 2] = 0;
      HEAP32[i6 + 8 >> 2] = 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i6, i4, _strlen(i4) | 0);
      i2 = i20 + 60 | 0;
      i1 = i20 + 8 | 0;
      HEAP32[i20 >> 2] = 4356;
      HEAP32[i2 >> 2] = 4376;
      HEAP32[i20 + 4 >> 2] = 0;
      __ZNSt3__28ios_base4initEPv(i20 + 60 | 0, i1);
      HEAP32[i20 + 132 >> 2] = 0;
      HEAP32[i20 + 136 >> 2] = -1;
      HEAP32[i20 >> 2] = 4300;
      HEAP32[i2 >> 2] = 4320;
      __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i1);
      HEAP32[i1 >> 2] = 4392;
      i2 = i20 + 40 | 0;
      HEAP32[i2 >> 2] = 0;
      HEAP32[i2 + 4 >> 2] = 0;
      HEAP32[i2 + 8 >> 2] = 0;
      i4 = 0;
      while (1) {
       if ((i4 | 0) == 3) break;
       HEAP32[i2 + (i4 << 2) >> 2] = 0;
       i4 = i4 + 1 | 0;
      }
      HEAP32[i20 + 52 >> 2] = 0;
      HEAP32[i20 + 56 >> 2] = 8;
      __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE(i1, i6);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i6);
      i19 = i20 + (HEAP32[(HEAP32[i20 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
      HEAP32[i19 >> 2] = HEAP32[i19 >> 2] & -75 | 8;
      __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERj(i20, i21) | 0;
      HEAP32[i21 >> 2] = HEAP32[i21 >> 2] | 2139095040;
      __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i20);
     } else HEAP32[i21 >> 2] = 2143289344;
     if (i10) {
      i1 = HEAP32[i21 >> 2] | -2147483648;
      HEAP32[i21 >> 2] = i1;
      d3 = (HEAP32[tempDoublePtr >> 2] = i1, +HEAPF32[tempDoublePtr >> 2]);
     } else {
      d24 = +HEAPF32[i21 >> 2];
      d3 = d24;
      i1 = (HEAPF32[tempDoublePtr >> 2] = d24, HEAP32[tempDoublePtr >> 2] | 0);
     }
     d24 = +Math_abs(+d3);
     if ((HEAPF32[tempDoublePtr >> 2] = d24, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 <= 2139095040) {
      i1 = i1 | 1;
      HEAP32[i21 >> 2] = i1;
     }
     i18 = i22 + 8 | 0;
     HEAP32[i14 >> 2] = 1;
     HEAP32[i14 + 8 >> 2] = i1;
     __ZN4wasm7Literal9castToF32Ev(i13, i14);
     HEAP32[i18 >> 2] = HEAP32[i13 >> 2];
     HEAP32[i18 + 4 >> 2] = HEAP32[i13 + 4 >> 2];
     HEAP32[i18 + 8 >> 2] = HEAP32[i13 + 8 >> 2];
     HEAP32[i18 + 12 >> 2] = HEAP32[i13 + 12 >> 2];
     i18 = i22;
     break L1;
    }
   case 4:
    {
     if (i1) {
      HEAP32[i7 >> 2] = 0;
      HEAP32[i7 + 4 >> 2] = 0;
      HEAP32[i7 + 8 >> 2] = 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i7, i4, _strlen(i4) | 0);
      i1 = i20 + 60 | 0;
      i2 = i20 + 8 | 0;
      HEAP32[i20 >> 2] = 4356;
      HEAP32[i1 >> 2] = 4376;
      HEAP32[i20 + 4 >> 2] = 0;
      __ZNSt3__28ios_base4initEPv(i20 + 60 | 0, i2);
      HEAP32[i20 + 132 >> 2] = 0;
      HEAP32[i20 + 136 >> 2] = -1;
      HEAP32[i20 >> 2] = 4300;
      HEAP32[i1 >> 2] = 4320;
      __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i2);
      HEAP32[i2 >> 2] = 4392;
      i1 = i20 + 40 | 0;
      HEAP32[i1 >> 2] = 0;
      HEAP32[i1 + 4 >> 2] = 0;
      HEAP32[i1 + 8 >> 2] = 0;
      i4 = 0;
      while (1) {
       if ((i4 | 0) == 3) break;
       HEAP32[i1 + (i4 << 2) >> 2] = 0;
       i4 = i4 + 1 | 0;
      }
      HEAP32[i20 + 52 >> 2] = 0;
      HEAP32[i20 + 56 >> 2] = 8;
      __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE(i2, i7);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i7);
      i14 = i20 + (HEAP32[(HEAP32[i20 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
      HEAP32[i14 >> 2] = HEAP32[i14 >> 2] & -75 | 8;
      __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERy(i20, i21) | 0;
      i14 = i21;
      i18 = HEAP32[i14 + 4 >> 2] | 2146435072;
      i19 = i21;
      HEAP32[i19 >> 2] = HEAP32[i14 >> 2];
      HEAP32[i19 + 4 >> 2] = i18;
      __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i20);
     } else {
      i20 = i21;
      HEAP32[i20 >> 2] = 0;
      HEAP32[i20 + 4 >> 2] = 2146959360;
     }
     if (i10) {
      i1 = i21;
      i2 = HEAP32[i1 >> 2] | 0;
      i1 = HEAP32[i1 + 4 >> 2] | -2147483648;
      i20 = i21;
      HEAP32[i20 >> 2] = i2;
      HEAP32[i20 + 4 >> 2] = i1;
      HEAP32[tempDoublePtr >> 2] = i2;
      HEAP32[tempDoublePtr + 4 >> 2] = i1;
      d3 = +HEAPF64[tempDoublePtr >> 3];
     } else {
      d3 = +HEAPF64[i21 >> 3];
      HEAPF64[tempDoublePtr >> 3] = d3;
      i2 = HEAP32[tempDoublePtr >> 2] | 0;
      i1 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
     }
     d24 = +Math_abs(+d3);
     HEAPF64[tempDoublePtr >> 3] = d24;
     i20 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
     if (!(i20 >>> 0 > 2146435072 | (i20 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0)) {
      i2 = i2 | 1;
      HEAP32[i21 >> 2] = i2;
      HEAP32[i21 + 4 >> 2] = i1;
     }
     i18 = i22 + 8 | 0;
     HEAP32[i16 >> 2] = 2;
     i21 = i16 + 8 | 0;
     HEAP32[i21 >> 2] = i2;
     HEAP32[i21 + 4 >> 2] = i1;
     __ZN4wasm7Literal9castToF64Ev(i15, i16);
     HEAP32[i18 >> 2] = HEAP32[i15 >> 2];
     HEAP32[i18 + 4 >> 2] = HEAP32[i15 + 4 >> 2];
     HEAP32[i18 + 8 >> 2] = HEAP32[i15 + 8 >> 2];
     HEAP32[i18 + 12 >> 2] = HEAP32[i15 + 12 >> 2];
     i18 = i22;
     break L1;
    }
   default:
    {
     i18 = 0;
     break L1;
    }
   }
  }
  if ((i4 | 0) == (HEAP32[14992] | 0)) switch (i19 | 0) {
  case 3:
   {
    d24 = -+_nan(67717);
    HEAP32[i22 + 8 >> 2] = 3;
    HEAPF32[i22 + 16 >> 2] = d24;
    i18 = i22;
    break L1;
   }
  case 4:
   {
    d24 = -+_nan(67717);
    HEAP32[i22 + 8 >> 2] = 4;
    HEAPF64[i22 + 16 >> 3] = d24;
    i18 = i22;
    break L1;
   }
  default:
   {
    i18 = 0;
    break L1;
   }
  } else i17 = 52;
 } else i17 = 52; while (0);
 L72 : do if ((i17 | 0) == 52) {
  L74 : do switch (i19 | 0) {
  case 1:
   {
    i2 = HEAP8[i4 >> 0] | 0;
    switch (i2 << 24 >> 24) {
    case 48:
     {
      i1 = i4 + 1 | 0;
      if ((HEAP8[i1 >> 0] | 0) == 120) i17 = 57; else i17 = 61;
      break;
     }
    case 45:
     {
      i1 = i4 + 1 | 0;
      if ((HEAP8[i1 >> 0] | 0) == 48 ? (HEAP8[i4 + 2 >> 0] | 0) == 120 : 0) i17 = 57; else i17 = 61;
      break;
     }
    default:
     i17 = 61;
    }
    if ((i17 | 0) == 57) {
     i5 = i2 << 24 >> 24 == 45;
     i2 = i5 ? i1 : i4;
     HEAP32[i11 >> 2] = 0;
     HEAP32[i11 + 4 >> 2] = 0;
     HEAP32[i11 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i11, i2, _strlen(i2) | 0);
     i2 = i21 + 60 | 0;
     i1 = i21 + 8 | 0;
     HEAP32[i21 >> 2] = 4356;
     HEAP32[i2 >> 2] = 4376;
     HEAP32[i21 + 4 >> 2] = 0;
     __ZNSt3__28ios_base4initEPv(i21 + 60 | 0, i1);
     HEAP32[i21 + 132 >> 2] = 0;
     HEAP32[i21 + 136 >> 2] = -1;
     HEAP32[i21 >> 2] = 4300;
     HEAP32[i2 >> 2] = 4320;
     __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i1);
     HEAP32[i1 >> 2] = 4392;
     i2 = i21 + 40 | 0;
     HEAP32[i2 >> 2] = 0;
     HEAP32[i2 + 4 >> 2] = 0;
     HEAP32[i2 + 8 >> 2] = 0;
     i4 = 0;
     while (1) {
      if ((i4 | 0) == 3) break;
      HEAP32[i2 + (i4 << 2) >> 2] = 0;
      i4 = i4 + 1 | 0;
     }
     HEAP32[i21 + 52 >> 2] = 0;
     HEAP32[i21 + 56 >> 2] = 8;
     __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE(i1, i11);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i11);
     i1 = i21 + (HEAP32[(HEAP32[i21 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
     HEAP32[i1 >> 2] = HEAP32[i1 >> 2] & -75 | 8;
     __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERj(i21, i20) | 0;
     i20 = HEAP32[i20 >> 2] | 0;
     i1 = i22 + 8 | 0;
     HEAP32[i1 >> 2] = 1;
     HEAP32[i22 + 16 >> 2] = i5 ? 0 - i20 | 0 : i20;
     __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i21);
     break L74;
    } else if ((i17 | 0) == 61) {
     HEAP32[i8 >> 2] = 0;
     HEAP32[i8 + 4 >> 2] = 0;
     HEAP32[i8 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i8, i4, _strlen(i4) | 0);
     i2 = i21 + 60 | 0;
     i1 = i21 + 8 | 0;
     HEAP32[i21 >> 2] = 4356;
     HEAP32[i2 >> 2] = 4376;
     HEAP32[i21 + 4 >> 2] = 0;
     __ZNSt3__28ios_base4initEPv(i21 + 60 | 0, i1);
     HEAP32[i21 + 132 >> 2] = 0;
     HEAP32[i21 + 136 >> 2] = -1;
     HEAP32[i21 >> 2] = 4300;
     HEAP32[i2 >> 2] = 4320;
     __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i1);
     HEAP32[i1 >> 2] = 4392;
     i2 = i21 + 40 | 0;
     HEAP32[i2 >> 2] = 0;
     HEAP32[i2 + 4 >> 2] = 0;
     HEAP32[i2 + 8 >> 2] = 0;
     i4 = 0;
     while (1) {
      if ((i4 | 0) == 3) break;
      HEAP32[i2 + (i4 << 2) >> 2] = 0;
      i4 = i4 + 1 | 0;
     }
     HEAP32[i21 + 52 >> 2] = 0;
     HEAP32[i21 + 56 >> 2] = 8;
     __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE(i1, i8);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i8);
     __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERi(i21, i20) | 0;
     i20 = HEAP32[i20 >> 2] | 0;
     i1 = i22 + 8 | 0;
     HEAP32[i1 >> 2] = 1;
     HEAP32[i22 + 16 >> 2] = i20;
     __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i21);
     break L74;
    }
    break;
   }
  case 2:
   {
    i2 = HEAP8[i4 >> 0] | 0;
    switch (i2 << 24 >> 24) {
    case 48:
     {
      i1 = i4 + 1 | 0;
      if ((HEAP8[i1 >> 0] | 0) == 120) i17 = 69; else i17 = 73;
      break;
     }
    case 45:
     {
      i1 = i4 + 1 | 0;
      if ((HEAP8[i1 >> 0] | 0) == 48 ? (HEAP8[i4 + 2 >> 0] | 0) == 120 : 0) i17 = 69; else i17 = 73;
      break;
     }
    default:
     i17 = 73;
    }
    if ((i17 | 0) == 69) {
     i5 = i2 << 24 >> 24 == 45;
     i2 = i5 ? i1 : i4;
     HEAP32[i12 >> 2] = 0;
     HEAP32[i12 + 4 >> 2] = 0;
     HEAP32[i12 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i12, i2, _strlen(i2) | 0);
     i2 = i21 + 60 | 0;
     i1 = i21 + 8 | 0;
     HEAP32[i21 >> 2] = 4356;
     HEAP32[i2 >> 2] = 4376;
     HEAP32[i21 + 4 >> 2] = 0;
     __ZNSt3__28ios_base4initEPv(i21 + 60 | 0, i1);
     HEAP32[i21 + 132 >> 2] = 0;
     HEAP32[i21 + 136 >> 2] = -1;
     HEAP32[i21 >> 2] = 4300;
     HEAP32[i2 >> 2] = 4320;
     __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i1);
     HEAP32[i1 >> 2] = 4392;
     i2 = i21 + 40 | 0;
     HEAP32[i2 >> 2] = 0;
     HEAP32[i2 + 4 >> 2] = 0;
     HEAP32[i2 + 8 >> 2] = 0;
     i4 = 0;
     while (1) {
      if ((i4 | 0) == 3) break;
      HEAP32[i2 + (i4 << 2) >> 2] = 0;
      i4 = i4 + 1 | 0;
     }
     HEAP32[i21 + 52 >> 2] = 0;
     HEAP32[i21 + 56 >> 2] = 8;
     __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE(i1, i12);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i12);
     i17 = i21 + (HEAP32[(HEAP32[i21 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
     HEAP32[i17 >> 2] = HEAP32[i17 >> 2] & -75 | 8;
     __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERy(i21, i20) | 0;
     i17 = i20;
     i16 = HEAP32[i17 >> 2] | 0;
     i17 = HEAP32[i17 + 4 >> 2] | 0;
     i15 = _i64Subtract(0, 0, i16 | 0, i17 | 0) | 0;
     i1 = i22 + 8 | 0;
     HEAP32[i1 >> 2] = 2;
     i20 = i22 + 16 | 0;
     HEAP32[i20 >> 2] = i5 ? i15 : i16;
     HEAP32[i20 + 4 >> 2] = i5 ? tempRet0 : i17;
     __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i21);
     break L74;
    } else if ((i17 | 0) == 73) {
     HEAP32[i9 >> 2] = 0;
     HEAP32[i9 + 4 >> 2] = 0;
     HEAP32[i9 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i9, i4, _strlen(i4) | 0);
     i2 = i21 + 60 | 0;
     i1 = i21 + 8 | 0;
     HEAP32[i21 >> 2] = 4356;
     HEAP32[i2 >> 2] = 4376;
     HEAP32[i21 + 4 >> 2] = 0;
     __ZNSt3__28ios_base4initEPv(i21 + 60 | 0, i1);
     HEAP32[i21 + 132 >> 2] = 0;
     HEAP32[i21 + 136 >> 2] = -1;
     HEAP32[i21 >> 2] = 4300;
     HEAP32[i2 >> 2] = 4320;
     __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i1);
     HEAP32[i1 >> 2] = 4392;
     i2 = i21 + 40 | 0;
     HEAP32[i2 >> 2] = 0;
     HEAP32[i2 + 4 >> 2] = 0;
     HEAP32[i2 + 8 >> 2] = 0;
     i4 = 0;
     while (1) {
      if ((i4 | 0) == 3) break;
      HEAP32[i2 + (i4 << 2) >> 2] = 0;
      i4 = i4 + 1 | 0;
     }
     HEAP32[i21 + 52 >> 2] = 0;
     HEAP32[i21 + 56 >> 2] = 8;
     __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE(i1, i9);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i9);
     __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERx(i21, i20) | 0;
     i17 = i20;
     i16 = HEAP32[i17 >> 2] | 0;
     i17 = HEAP32[i17 + 4 >> 2] | 0;
     i1 = i22 + 8 | 0;
     HEAP32[i1 >> 2] = 2;
     i20 = i22 + 16 | 0;
     HEAP32[i20 >> 2] = i16;
     HEAP32[i20 + 4 >> 2] = i17;
     __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i21);
     break L74;
    }
    break;
   }
  case 3:
   {
    d24 = +_strtof(i4, i21);
    i1 = i22 + 8 | 0;
    HEAP32[i1 >> 2] = 3;
    HEAPF32[i22 + 16 >> 2] = d24;
    break;
   }
  case 4:
   {
    d24 = +_strtod(i4, i21);
    i1 = i22 + 8 | 0;
    HEAP32[i1 >> 2] = 4;
    HEAPF64[i22 + 16 >> 3] = d24;
    break;
   }
  default:
   {
    i18 = 0;
    break L72;
   }
  } while (0);
  if ((HEAP32[i1 >> 2] | 0) == (i19 | 0)) i18 = i22; else ___assert_fail(22146, 22121, 163, 22135);
 } while (0);
 STACKTOP = i23;
 return i18 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i40, i17, i15, i14) {
 i40 = i40 | 0;
 i17 = i17 | 0;
 i15 = i15 | 0;
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i41 = 0, i42 = 0;
 i42 = STACKTOP;
 STACKTOP = STACKTOP + 128 | 0;
 i39 = i42 + 112 | 0;
 i19 = i42 + 16 | 0;
 i18 = i42 + 100 | 0;
 i11 = i42 + 8 | 0;
 i5 = i42 + 104 | 0;
 i8 = i42 + 96 | 0;
 i9 = i42;
 i38 = i42 + 44 | 0;
 i32 = i42 + 92 | 0;
 i33 = i42 + 88 | 0;
 i34 = i42 + 84 | 0;
 i35 = i42 + 80 | 0;
 i36 = i42 + 76 | 0;
 i37 = i42 + 72 | 0;
 i20 = i42 + 68 | 0;
 i21 = i42 + 64 | 0;
 i22 = i42 + 60 | 0;
 i23 = i42 + 56 | 0;
 i24 = i42 + 52 | 0;
 i25 = i42 + 48 | 0;
 i26 = i42 + 40 | 0;
 i27 = i42 + 36 | 0;
 i29 = i42 + 32 | 0;
 i13 = i40 + 4 | 0;
 i12 = HEAP32[i13 >> 2] | 0;
 i16 = i12 + -12 | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i15);
 i4 = HEAP32[i15 >> 2] | 0;
 i2 = HEAP8[i4 >> 0] | 0;
 L1 : do if (i2 << 24 >> 24) {
  i1 = i14;
  while (1) {
   i3 = HEAP8[i1 >> 0] | 0;
   if (!(i3 << 24 >> 24)) break;
   if (i3 << 24 >> 24 == i2 << 24 >> 24) {
    i41 = 4;
    break L1;
   } else i1 = i1 + 1 | 0;
  }
  i3 = i12 + -8 | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  i10 = (i1 | 0) == (HEAP32[i16 >> 2] | 0);
  do if (!(HEAP8[i17 >> 0] | 0)) if ((i1 | 0) == (HEAP32[i12 + -4 >> 2] | 0)) {
   __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE21__push_back_slow_pathIRKS6_EEvOT_(i16, i17);
   break;
  } else {
   i12 = i17;
   i16 = HEAP32[i12 + 4 >> 2] | 0;
   i17 = i1;
   HEAP32[i17 >> 2] = HEAP32[i12 >> 2];
   HEAP32[i17 + 4 >> 2] = i16;
   HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 8;
   break;
  } else {
   __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i19, i4);
   if ((HEAP32[i19 + 12 >> 2] | 0) != 1) {
    i1 = HEAP32[i15 >> 2] | 0;
    switch (HEAP8[i1 >> 0] | 0) {
    case 40:
     {
      i7 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i17) | 0;
      HEAP32[i5 >> 2] = i7;
      HEAP32[i39 >> 2] = HEAP32[i5 >> 2];
      i7 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseCallES1_RPc(i40, i39, i15) | 0;
      i6 = i17;
      HEAP32[i6 >> 2] = 1;
      HEAP32[i6 + 4 >> 2] = i7;
      i6 = 1;
      break;
     }
    case 91:
     {
      i7 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i17) | 0;
      HEAP32[i8 >> 2] = i7;
      HEAP32[i39 >> 2] = HEAP32[i8 >> 2];
      i7 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseIndexingES1_RPc(i40, i39, i15) | 0;
      i6 = i17;
      HEAP32[i6 >> 2] = 1;
      HEAP32[i6 + 4 >> 2] = i7;
      i6 = 1;
      break;
     }
    default:
     {
      __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4dumpEPKcPc(31967, i1);
      _abort();
     }
    }
    i1 = i9;
    HEAP32[i1 >> 2] = i6;
    HEAP32[i1 + 4 >> 2] = i7;
    HEAP32[i39 >> 2] = HEAP32[i9 >> 2];
    HEAP32[i39 + 4 >> 2] = HEAP32[i9 + 4 >> 2];
    i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i40, i39, i15, i14) | 0;
    break L1;
   }
   i1 = HEAP32[i3 >> 2] | 0;
   i2 = i12 + -4 | 0;
   if ((i1 | 0) == (HEAP32[i2 >> 2] | 0)) __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE21__push_back_slow_pathIRKS6_EEvOT_(i16, i17); else {
    i9 = i17;
    i12 = HEAP32[i9 + 4 >> 2] | 0;
    i17 = i1;
    HEAP32[i17 >> 2] = HEAP32[i9 >> 2];
    HEAP32[i17 + 4 >> 2] = i12;
    HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 8;
   }
   HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + (HEAP32[i19 + 8 >> 2] | 0);
   i1 = HEAP32[i19 >> 2] | 0;
   HEAP8[i11 >> 0] = 0;
   HEAP32[i11 + 4 >> 2] = i1;
   i1 = HEAP32[i3 >> 2] | 0;
   if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
    i12 = i11;
    i16 = HEAP32[i12 + 4 >> 2] | 0;
    i17 = i1;
    HEAP32[i17 >> 2] = HEAP32[i12 >> 2];
    HEAP32[i17 + 4 >> 2] = i16;
    HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 8;
   } else __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i16, i11);
  } while (0);
  i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i40, i15, i14) | 0;
  if (i10) {
   i12 = HEAP32[i13 >> 2] | 0;
   i11 = i12 + -12 | 0;
   i9 = HEAP32[14913] | 0;
   i12 = i12 + -8 | 0;
   i10 = HEAP32[14912] | 0;
   L30 : while (1) {
    if ((i10 | 0) == (i9 | 0)) break;
    L33 : do if (!(HEAP8[i10 + 32 >> 0] | 0)) {
     i8 = i10 + 36 | 0;
     i7 = 0;
     while (1) {
      i17 = HEAP32[i11 >> 2] | 0;
      i1 = i17;
      if ((i7 | 0) >= ((HEAP32[i12 >> 2] | 0) - i17 >> 3 | 0)) break L33;
      if (!(HEAP8[i1 + (i7 << 3) >> 0] | 0)) {
       i3 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement5getOpEv(i1 + (i7 << 3) | 0) | 0;
       HEAP32[i38 >> 2] = i3;
       L40 : do if (__ZNKSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE4findIS2_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS2_PvEEEERKT_(i10, i38) | 0) {
        i1 = HEAP32[i8 >> 2] | 0;
        i2 = (i7 | 0) > 0;
        if (i2 & (i1 | 0) == 0 ? (i17 = HEAP32[i11 >> 2] | 0, i30 = i17, (i7 | 0) < (((HEAP32[i12 >> 2] | 0) - i17 >> 3) + -1 | 0)) : 0) {
         i1 = i7 + -1 | 0;
         i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i30 + (i1 << 3) | 0) | 0;
         HEAP32[i24 >> 2] = i2;
         HEAP32[i25 >> 2] = i3;
         i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv((HEAP32[i11 >> 2] | 0) + (i7 + 1 << 3) | 0) | 0;
         HEAP32[i26 >> 2] = i2;
         HEAP32[i18 >> 2] = HEAP32[i24 >> 2];
         HEAP32[i19 >> 2] = HEAP32[i25 >> 2];
         HEAP32[i39 >> 2] = HEAP32[i26 >> 2];
         i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10makeBinaryES1_NS_7IStringES1_(i40, i18, i19, i39) | 0;
         i5 = i30 + (i7 << 3) | 0;
         HEAP32[i5 >> 2] = 1;
         HEAP32[i5 + 4 >> 2] = i2;
         i5 = (HEAP32[i11 >> 2] | 0) + (i7 << 3) + 8 | 0;
         i2 = i5 + 8 | 0;
         i4 = HEAP32[i12 >> 2] | 0;
         i3 = i4 - i2 | 0;
         i6 = i3 >> 3;
         if (!i6) {
          i3 = i4;
          i2 = i4;
         } else {
          _memmove(i5 | 0, i2 | 0, i3 | 0) | 0;
          i2 = HEAP32[i12 >> 2] | 0;
          i3 = i2;
         }
         i4 = i5 + (i6 << 3) | 0;
         while (1) {
          if ((i3 | 0) == (i4 | 0)) break;
          i2 = i3 + -8 | 0;
          HEAP32[i12 >> 2] = i2;
          i3 = i2;
         }
         i5 = (HEAP32[i11 >> 2] | 0) + (i7 << 3) + -8 | 0;
         i3 = i5 + 8 | 0;
         i4 = i2 - i3 | 0;
         i6 = i4 >> 3;
         if (i6) {
          _memmove(i5 | 0, i3 | 0, i4 | 0) | 0;
          i2 = HEAP32[i12 >> 2] | 0;
         }
         i3 = i5 + (i6 << 3) | 0;
         while (1) {
          if ((i2 | 0) == (i3 | 0)) break L40;
          i17 = i2 + -8 | 0;
          HEAP32[i12 >> 2] = i17;
          i2 = i17;
         }
        }
        if ((i1 | 0) == 1 ? (i17 = HEAP32[i11 >> 2] | 0, i31 = i17, (i7 | 0) < (((HEAP32[i12 >> 2] | 0) - i17 >> 3) + -1 | 0)) : 0) {
         if (i2 ? HEAP8[i31 + (i7 + -1 << 3) >> 0] | 0 : 0) {
          i1 = i7;
          break;
         }
         HEAP32[i27 >> 2] = i3;
         i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i31 + (i7 + 1 << 3) | 0) | 0;
         HEAP32[i29 >> 2] = i2;
         HEAP32[i19 >> 2] = HEAP32[i27 >> 2];
         HEAP32[i39 >> 2] = HEAP32[i29 >> 2];
         i2 = __ZN6cashew12ValueBuilder10makePrefixENS_7IStringENS_3RefE(i19, i39) | 0;
         i4 = i31 + (i7 << 3) | 0;
         HEAP32[i4 >> 2] = 1;
         HEAP32[i4 + 4 >> 2] = i2;
         i4 = (HEAP32[i11 >> 2] | 0) + (i7 << 3) + 8 | 0;
         i2 = i4 + 8 | 0;
         i1 = HEAP32[i12 >> 2] | 0;
         i3 = i1 - i2 | 0;
         i5 = i3 >> 3;
         if (i5) {
          _memmove(i4 | 0, i2 | 0, i3 | 0) | 0;
          i1 = HEAP32[i12 >> 2] | 0;
         }
         i2 = i4 + (i5 << 3) | 0;
         while (1) {
          if ((i1 | 0) == (i2 | 0)) break;
          i17 = i1 + -8 | 0;
          HEAP32[i12 >> 2] = i17;
          i1 = i17;
         }
         i1 = i7 + -2 | 0;
         i1 = (i1 | 0) < 0 ? 0 : i1;
        } else i1 = i7;
       } else i1 = i7; while (0);
      } else i1 = i7;
      i7 = i1 + 1 | 0;
     }
    } else {
     i7 = i10 + 36 | 0;
     i6 = (HEAP32[i12 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 3;
     while (1) {
      i1 = i6 + -1 | 0;
      if ((i1 | 0) <= -1) break L33;
      i2 = HEAP32[i11 >> 2] | 0;
      if (HEAP8[i2 + (i1 << 3) >> 0] | 0) {
       i6 = i1;
       continue;
      }
      i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement5getOpEv(i2 + (i1 << 3) | 0) | 0;
      HEAP32[i38 >> 2] = i2;
      i4 = i2;
      L78 : do if (__ZNKSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE4findIS2_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS2_PvEEEERKT_(i10, i38) | 0) {
       i3 = HEAP32[i7 >> 2] | 0;
       i5 = (i1 | 0) > 0;
       if (i5 & (i3 | 0) == 0 ? (i17 = HEAP32[i11 >> 2] | 0, i28 = i17, (i1 | 0) < (((HEAP32[i12 >> 2] | 0) - i17 >> 3) + -1 | 0)) : 0) {
        i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i28 + (i6 + -2 << 3) | 0) | 0;
        HEAP32[i32 >> 2] = i2;
        HEAP32[i33 >> 2] = i4;
        i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv((HEAP32[i11 >> 2] | 0) + (i6 << 3) | 0) | 0;
        HEAP32[i34 >> 2] = i2;
        HEAP32[i18 >> 2] = HEAP32[i32 >> 2];
        HEAP32[i19 >> 2] = HEAP32[i33 >> 2];
        HEAP32[i39 >> 2] = HEAP32[i34 >> 2];
        i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10makeBinaryES1_NS_7IStringES1_(i40, i18, i19, i39) | 0;
        i5 = i28 + (i1 << 3) | 0;
        HEAP32[i5 >> 2] = 1;
        HEAP32[i5 + 4 >> 2] = i2;
        i5 = (HEAP32[i11 >> 2] | 0) + (i1 << 3) + 8 | 0;
        i2 = i5 + 8 | 0;
        i4 = HEAP32[i12 >> 2] | 0;
        i3 = i4 - i2 | 0;
        i6 = i3 >> 3;
        if (!i6) {
         i3 = i4;
         i2 = i4;
        } else {
         _memmove(i5 | 0, i2 | 0, i3 | 0) | 0;
         i2 = HEAP32[i12 >> 2] | 0;
         i3 = i2;
        }
        i4 = i5 + (i6 << 3) | 0;
        while (1) {
         if ((i3 | 0) == (i4 | 0)) break;
         i2 = i3 + -8 | 0;
         HEAP32[i12 >> 2] = i2;
         i3 = i2;
        }
        i5 = (HEAP32[i11 >> 2] | 0) + (i1 << 3) + -8 | 0;
        i3 = i5 + 8 | 0;
        i4 = i2 - i3 | 0;
        i6 = i4 >> 3;
        if (i6) {
         _memmove(i5 | 0, i3 | 0, i4 | 0) | 0;
         i2 = HEAP32[i12 >> 2] | 0;
        }
        i3 = i5 + (i6 << 3) | 0;
        while (1) {
         if ((i2 | 0) == (i3 | 0)) break L78;
         i17 = i2 + -8 | 0;
         HEAP32[i12 >> 2] = i17;
         i2 = i17;
        }
       }
       switch (i3 | 0) {
       case 1:
        break;
       case 3:
        {
         if ((i2 | 0) != (HEAP32[14894] | 0)) break L78;
         i2 = HEAP32[i11 >> 2] | 0;
         if (!((i1 | 0) > 2 ? (i1 | 0) < (((HEAP32[i12 >> 2] | 0) - i2 >> 3) + -1 | 0) : 0)) {
          i41 = 59;
          break L30;
         }
         if ((__ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement5getOpEv(i2 + (i6 + -3 << 3) | 0) | 0) != (HEAP32[14893] | 0)) break L78;
         i17 = (HEAP32[i11 >> 2] | 0) + (i6 + -4 << 3) | 0;
         i16 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i17) | 0;
         HEAP32[i37 >> 2] = i16;
         i16 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv((HEAP32[i11 >> 2] | 0) + (i6 + -2 << 3) | 0) | 0;
         HEAP32[i20 >> 2] = i16;
         i16 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv((HEAP32[i11 >> 2] | 0) + (i6 << 3) | 0) | 0;
         HEAP32[i21 >> 2] = i16;
         HEAP32[i18 >> 2] = HEAP32[i37 >> 2];
         HEAP32[i19 >> 2] = HEAP32[i20 >> 2];
         HEAP32[i39 >> 2] = HEAP32[i21 >> 2];
         i16 = __ZN6cashew12ValueBuilder15makeConditionalENS_3RefES1_S1_(i18, i19, i39) | 0;
         HEAP32[i17 >> 2] = 1;
         HEAP32[i17 + 4 >> 2] = i16;
         i1 = (HEAP32[i11 >> 2] | 0) + (i1 << 3) | 0;
         HEAP32[i22 >> 2] = i1 + -16;
         HEAP32[i23 >> 2] = i1 + 16;
         HEAP32[i19 >> 2] = HEAP32[i22 >> 2];
         HEAP32[i39 >> 2] = HEAP32[i23 >> 2];
         __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE5eraseENS_11__wrap_iterIPKS6_EESD_(i11, i19, i39) | 0;
         i1 = (HEAP32[i12 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 3;
         break L78;
        }
       default:
        break L78;
       }
       i17 = HEAP32[i11 >> 2] | 0;
       i2 = i17;
       if ((i1 | 0) < (((HEAP32[i12 >> 2] | 0) - i17 >> 3) + -1 | 0)) {
        if (i5 ? HEAP8[i2 + (i6 + -2 << 3) >> 0] | 0 : 0) break;
        HEAP32[i35 >> 2] = i4;
        i3 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i2 + (i6 << 3) | 0) | 0;
        HEAP32[i36 >> 2] = i3;
        HEAP32[i19 >> 2] = HEAP32[i35 >> 2];
        HEAP32[i39 >> 2] = HEAP32[i36 >> 2];
        i3 = __ZN6cashew12ValueBuilder10makePrefixENS_7IStringENS_3RefE(i19, i39) | 0;
        i5 = i2 + (i1 << 3) | 0;
        HEAP32[i5 >> 2] = 1;
        HEAP32[i5 + 4 >> 2] = i3;
        i5 = (HEAP32[i11 >> 2] | 0) + (i1 << 3) + 8 | 0;
        i3 = i5 + 8 | 0;
        i2 = HEAP32[i12 >> 2] | 0;
        i4 = i2 - i3 | 0;
        i6 = i4 >> 3;
        if (i6) {
         _memmove(i5 | 0, i3 | 0, i4 | 0) | 0;
         i2 = HEAP32[i12 >> 2] | 0;
        }
        i3 = i5 + (i6 << 3) | 0;
        while (1) {
         if ((i2 | 0) == (i3 | 0)) break L78;
         i17 = i2 + -8 | 0;
         HEAP32[i12 >> 2] = i17;
         i2 = i17;
        }
       }
      } while (0);
      i6 = i1;
     }
    } while (0);
    i10 = i10 + 40 | 0;
   }
   if ((i41 | 0) == 59) ___assert_fail(31993, 31173, 797, 32027);
   i1 = HEAP32[i11 >> 2] | 0;
   if (((HEAP32[i12 >> 2] | 0) - i1 | 0) != 8) ___assert_fail(32043, 31173, 824, 32027);
   i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i1) | 0;
   i2 = HEAP32[i11 >> 2] | 0;
   i3 = HEAP32[i12 >> 2] | 0;
   while (1) {
    if ((i3 | 0) == (i2 | 0)) break L1;
    i40 = i3 + -8 | 0;
    HEAP32[i12 >> 2] = i40;
    i3 = i40;
   }
  }
 } else i41 = 4; while (0);
 if ((i41 | 0) == 4) {
  i1 = i12 + -8 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  do if ((i2 | 0) != (HEAP32[i16 >> 2] | 0)) if ((i2 | 0) == (HEAP32[i12 + -4 >> 2] | 0)) {
   __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE21__push_back_slow_pathIRKS6_EEvOT_(i16, i17);
   break;
  } else {
   i39 = i17;
   i40 = HEAP32[i39 + 4 >> 2] | 0;
   i41 = i2;
   HEAP32[i41 >> 2] = HEAP32[i39 >> 2];
   HEAP32[i41 + 4 >> 2] = i40;
   HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 8;
   break;
  } while (0);
  i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i17) | 0;
 }
 STACKTOP = i42;
 return i1 | 0;
}

function _vfscanf(i33, i2, i24) {
 i33 = i33 | 0;
 i2 = i2 | 0;
 i24 = i24 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, d7 = 0.0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i34 = 0;
 i34 = STACKTOP;
 STACKTOP = STACKTOP + 304 | 0;
 i25 = i34 + 16 | 0;
 i27 = i34 + 8 | 0;
 i26 = i34 + 33 | 0;
 i28 = i34;
 i16 = i34 + 32 | 0;
 if ((HEAP32[i33 + 76 >> 2] | 0) > -1) i32 = ___lockfile(i33) | 0; else i32 = 0;
 i1 = HEAP8[i2 >> 0] | 0;
 L4 : do if (i1 << 24 >> 24) {
  i29 = i33 + 4 | 0;
  i30 = i33 + 100 | 0;
  i23 = i33 + 108 | 0;
  i17 = i33 + 8 | 0;
  i18 = i26 + 10 | 0;
  i19 = i26 + 33 | 0;
  i20 = i27 + 4 | 0;
  i21 = i26 + 46 | 0;
  i22 = i26 + 94 | 0;
  i4 = i1;
  i1 = 0;
  i5 = i2;
  i10 = 0;
  i3 = 0;
  i2 = 0;
  L6 : while (1) {
   L8 : do if (!(_isspace(i4 & 255) | 0)) {
    i4 = (HEAP8[i5 >> 0] | 0) == 37;
    L10 : do if (i4) {
     i8 = i5 + 1 | 0;
     i6 = HEAP8[i8 >> 0] | 0;
     L12 : do switch (i6 << 24 >> 24) {
     case 37:
      break L10;
     case 42:
      {
       i15 = 0;
       i6 = i5 + 2 | 0;
       break;
      }
     default:
      {
       i6 = (i6 & 255) + -48 | 0;
       if (i6 >>> 0 < 10 ? (HEAP8[i5 + 2 >> 0] | 0) == 36 : 0) {
        HEAP32[i25 >> 2] = HEAP32[i24 >> 2];
        while (1) {
         i15 = (HEAP32[i25 >> 2] | 0) + (4 - 1) & ~(4 - 1);
         i4 = HEAP32[i15 >> 2] | 0;
         HEAP32[i25 >> 2] = i15 + 4;
         if (i6 >>> 0 > 1) i6 = i6 + -1 | 0; else break;
        }
        i15 = i4;
        i6 = i5 + 3 | 0;
        break L12;
       }
       i6 = (HEAP32[i24 >> 2] | 0) + (4 - 1) & ~(4 - 1);
       i15 = HEAP32[i6 >> 2] | 0;
       HEAP32[i24 >> 2] = i6 + 4;
       i6 = i8;
      }
     } while (0);
     i4 = HEAP8[i6 >> 0] | 0;
     i5 = i4 & 255;
     if ((i5 + -48 | 0) >>> 0 < 10) {
      i4 = 0;
      while (1) {
       i8 = (i4 * 10 | 0) + -48 + i5 | 0;
       i6 = i6 + 1 | 0;
       i4 = HEAP8[i6 >> 0] | 0;
       i5 = i4 & 255;
       if ((i5 + -48 | 0) >>> 0 >= 10) break; else i4 = i8;
      }
     } else i8 = 0;
     if (i4 << 24 >> 24 == 109) {
      i6 = i6 + 1 | 0;
      i9 = HEAP8[i6 >> 0] | 0;
      i4 = (i15 | 0) != 0 & 1;
      i3 = 0;
      i2 = 0;
     } else {
      i9 = i4;
      i4 = 0;
     }
     i5 = i6 + 1 | 0;
     switch (i9 & 255 | 0) {
     case 104:
      {
       i14 = (HEAP8[i5 >> 0] | 0) == 104;
       i5 = i14 ? i6 + 2 | 0 : i5;
       i6 = i14 ? -2 : -1;
       break;
      }
     case 108:
      {
       i14 = (HEAP8[i5 >> 0] | 0) == 108;
       i5 = i14 ? i6 + 2 | 0 : i5;
       i6 = i14 ? 3 : 1;
       break;
      }
     case 106:
      {
       i6 = 3;
       break;
      }
     case 116:
     case 122:
      {
       i6 = 1;
       break;
      }
     case 76:
      {
       i6 = 2;
       break;
      }
     case 110:
     case 112:
     case 67:
     case 83:
     case 91:
     case 99:
     case 115:
     case 88:
     case 71:
     case 70:
     case 69:
     case 65:
     case 103:
     case 102:
     case 101:
     case 97:
     case 120:
     case 117:
     case 111:
     case 105:
     case 100:
      {
       i5 = i6;
       i6 = 0;
       break;
      }
     default:
      {
       i31 = 154;
       break L6;
      }
     }
     i9 = HEAPU8[i5 >> 0] | 0;
     i11 = (i9 & 47 | 0) == 3;
     i9 = i11 ? i9 | 32 : i9;
     i11 = i11 ? 1 : i6;
     switch (i9 | 0) {
     case 99:
      {
       i14 = i10;
       i13 = (i8 | 0) < 1 ? 1 : i8;
       break;
      }
     case 91:
      {
       i14 = i10;
       i13 = i8;
       break;
      }
     case 110:
      {
       if (!i15) {
        i6 = i10;
        break L8;
       }
       switch (i11 | 0) {
       case -2:
        {
         HEAP8[i15 >> 0] = i10;
         i6 = i10;
         break L8;
        }
       case -1:
        {
         HEAP16[i15 >> 1] = i10;
         i6 = i10;
         break L8;
        }
       case 0:
        {
         HEAP32[i15 >> 2] = i10;
         i6 = i10;
         break L8;
        }
       case 1:
        {
         HEAP32[i15 >> 2] = i10;
         i6 = i10;
         break L8;
        }
       case 3:
        {
         i6 = i15;
         HEAP32[i6 >> 2] = i10;
         HEAP32[i6 + 4 >> 2] = ((i10 | 0) < 0) << 31 >> 31;
         i6 = i10;
         break L8;
        }
       default:
        {
         i6 = i10;
         break L8;
        }
       }
      }
     default:
      {
       ___shlim(i33, 0);
       do {
        i6 = HEAP32[i29 >> 2] | 0;
        if (i6 >>> 0 < (HEAP32[i30 >> 2] | 0) >>> 0) {
         HEAP32[i29 >> 2] = i6 + 1;
         i6 = HEAPU8[i6 >> 0] | 0;
        } else i6 = ___shgetc(i33) | 0;
       } while ((_isspace(i6) | 0) != 0);
       if (!(HEAP32[i30 >> 2] | 0)) i6 = HEAP32[i29 >> 2] | 0; else {
        i6 = (HEAP32[i29 >> 2] | 0) + -1 | 0;
        HEAP32[i29 >> 2] = i6;
       }
       i14 = (HEAP32[i23 >> 2] | 0) + i10 + i6 - (HEAP32[i17 >> 2] | 0) | 0;
       i13 = i8;
      }
     }
     ___shlim(i33, i13);
     i6 = HEAP32[i29 >> 2] | 0;
     i8 = HEAP32[i30 >> 2] | 0;
     if (i6 >>> 0 < i8 >>> 0) HEAP32[i29 >> 2] = i6 + 1; else {
      if ((___shgetc(i33) | 0) < 0) {
       i31 = 154;
       break L6;
      }
      i8 = HEAP32[i30 >> 2] | 0;
     }
     if (i8 | 0) HEAP32[i29 >> 2] = (HEAP32[i29 >> 2] | 0) + -1;
     L68 : do switch (i9 | 0) {
     case 91:
     case 99:
     case 115:
      {
       i12 = (i9 | 0) == 99;
       L70 : do if ((i9 | 16 | 0) == 115) {
        _memset(i26 | 0, -1, 257) | 0;
        HEAP8[i26 >> 0] = 0;
        if ((i9 | 0) == 115) {
         HEAP8[i19 >> 0] = 0;
         HEAP8[i18 >> 0] = 0;
         HEAP8[i18 + 1 >> 0] = 0;
         HEAP8[i18 + 2 >> 0] = 0;
         HEAP8[i18 + 3 >> 0] = 0;
         HEAP8[i18 + 4 >> 0] = 0;
        }
       } else {
        i9 = i5 + 1 | 0;
        i10 = (HEAP8[i9 >> 0] | 0) == 94;
        i6 = i10 & 1;
        i5 = i10 ? i5 + 2 | 0 : i9;
        _memset(i26 | 0, i10 & 1 | 0, 257) | 0;
        HEAP8[i26 >> 0] = 0;
        switch (HEAP8[i5 >> 0] | 0) {
        case 45:
         {
          i10 = (i6 ^ 1) & 255;
          HEAP8[i21 >> 0] = i10;
          i5 = i5 + 1 | 0;
          break;
         }
        case 93:
         {
          i10 = (i6 ^ 1) & 255;
          HEAP8[i22 >> 0] = i10;
          i5 = i5 + 1 | 0;
          break;
         }
        default:
         i10 = (i6 ^ 1) & 255;
        }
        while (1) {
         i6 = HEAP8[i5 >> 0] | 0;
         L81 : do switch (i6 << 24 >> 24) {
         case 0:
          {
           i31 = 154;
           break L6;
          }
         case 93:
          break L70;
         case 45:
          {
           i9 = i5 + 1 | 0;
           i6 = HEAP8[i9 >> 0] | 0;
           switch (i6 << 24 >> 24) {
           case 93:
           case 0:
            {
             i6 = 45;
             break L81;
            }
           default:
            {}
           }
           i5 = HEAP8[i5 + -1 >> 0] | 0;
           if ((i5 & 255) < (i6 & 255)) {
            i5 = i5 & 255;
            do {
             i5 = i5 + 1 | 0;
             HEAP8[i26 + i5 >> 0] = i10;
             i6 = HEAP8[i9 >> 0] | 0;
            } while ((i5 | 0) < (i6 & 255 | 0));
            i5 = i9;
           } else i5 = i9;
           break;
          }
         default:
          {}
         } while (0);
         HEAP8[i26 + ((i6 & 255) + 1) >> 0] = i10;
         i5 = i5 + 1 | 0;
        }
       } while (0);
       i9 = i12 ? i13 + 1 | 0 : 31;
       i10 = (i11 | 0) == 1;
       i11 = (i4 | 0) != 0;
       L89 : do if (i10) {
        if (i11) {
         i2 = _malloc(i9 << 2) | 0;
         if (!i2) {
          i3 = 0;
          i31 = 154;
          break L6;
         }
        } else i2 = i15;
        HEAP32[i27 >> 2] = 0;
        HEAP32[i20 >> 2] = 0;
        i3 = 0;
        L95 : while (1) {
         i8 = (i2 | 0) == 0;
         do {
          L99 : while (1) {
           i6 = HEAP32[i29 >> 2] | 0;
           if (i6 >>> 0 < (HEAP32[i30 >> 2] | 0) >>> 0) {
            HEAP32[i29 >> 2] = i6 + 1;
            i6 = HEAPU8[i6 >> 0] | 0;
           } else i6 = ___shgetc(i33) | 0;
           if (!(HEAP8[i26 + (i6 + 1) >> 0] | 0)) break L95;
           HEAP8[i16 >> 0] = i6;
           switch (_mbrtowc(i28, i16, 1, i27) | 0) {
           case -1:
            {
             i3 = 0;
             i31 = 154;
             break L6;
            }
           case -2:
            break;
           default:
            break L99;
           }
          }
          if (!i8) {
           HEAP32[i2 + (i3 << 2) >> 2] = HEAP32[i28 >> 2];
           i3 = i3 + 1 | 0;
          }
         } while (!(i11 & (i3 | 0) == (i9 | 0)));
         i3 = i9 << 1 | 1;
         i6 = _realloc(i2, i3 << 2) | 0;
         if (!i6) {
          i3 = 0;
          i31 = 154;
          break L6;
         } else {
          i8 = i9;
          i9 = i3;
          i2 = i6;
          i3 = i8;
         }
        }
        if (!(_mbsinit(i27) | 0)) {
         i3 = 0;
         i31 = 154;
         break L6;
        } else {
         i8 = i3;
         i3 = 0;
        }
       } else {
        if (i11) {
         i3 = _malloc(i9) | 0;
         if (!i3) {
          i3 = 0;
          i2 = 0;
          i31 = 154;
          break L6;
         } else i6 = 0;
         while (1) {
          do {
           i2 = HEAP32[i29 >> 2] | 0;
           if (i2 >>> 0 < (HEAP32[i30 >> 2] | 0) >>> 0) {
            HEAP32[i29 >> 2] = i2 + 1;
            i2 = HEAPU8[i2 >> 0] | 0;
           } else i2 = ___shgetc(i33) | 0;
           if (!(HEAP8[i26 + (i2 + 1) >> 0] | 0)) {
            i8 = i6;
            i2 = 0;
            break L89;
           }
           HEAP8[i3 + i6 >> 0] = i2;
           i6 = i6 + 1 | 0;
          } while ((i6 | 0) != (i9 | 0));
          i2 = i9 << 1 | 1;
          i6 = _realloc(i3, i2) | 0;
          if (!i6) {
           i2 = 0;
           i31 = 154;
           break L6;
          } else {
           i8 = i9;
           i9 = i2;
           i3 = i6;
           i6 = i8;
          }
         }
        }
        if (!i15) {
         i3 = i8;
         while (1) {
          i2 = HEAP32[i29 >> 2] | 0;
          if (i2 >>> 0 < i3 >>> 0) {
           HEAP32[i29 >> 2] = i2 + 1;
           i2 = HEAPU8[i2 >> 0] | 0;
          } else i2 = ___shgetc(i33) | 0;
          if (!(HEAP8[i26 + (i2 + 1) >> 0] | 0)) {
           i8 = 0;
           i3 = 0;
           i2 = 0;
           break L89;
          }
          i3 = HEAP32[i30 >> 2] | 0;
         }
        } else {
         i3 = 0;
         while (1) {
          i2 = HEAP32[i29 >> 2] | 0;
          if (i2 >>> 0 < i8 >>> 0) {
           HEAP32[i29 >> 2] = i2 + 1;
           i2 = HEAPU8[i2 >> 0] | 0;
          } else i2 = ___shgetc(i33) | 0;
          if (!(HEAP8[i26 + (i2 + 1) >> 0] | 0)) {
           i8 = i3;
           i3 = i15;
           i2 = 0;
           break L89;
          }
          HEAP8[i15 + i3 >> 0] = i2;
          i8 = HEAP32[i30 >> 2] | 0;
          i3 = i3 + 1 | 0;
         }
        }
       } while (0);
       if (!(HEAP32[i30 >> 2] | 0)) i6 = HEAP32[i29 >> 2] | 0; else {
        i6 = (HEAP32[i29 >> 2] | 0) + -1 | 0;
        HEAP32[i29 >> 2] = i6;
       }
       i6 = i6 - (HEAP32[i17 >> 2] | 0) + (HEAP32[i23 >> 2] | 0) | 0;
       if (!i6) break L6;
       if (!((i6 | 0) == (i13 | 0) | i12 ^ 1)) break L6;
       do if (i11) if (i10) {
        HEAP32[i15 >> 2] = i2;
        break;
       } else {
        HEAP32[i15 >> 2] = i3;
        break;
       } while (0);
       if (!i12) {
        if (i2 | 0) HEAP32[i2 + (i8 << 2) >> 2] = 0;
        if (!i3) {
         i3 = 0;
         break L68;
        }
        HEAP8[i3 + i8 >> 0] = 0;
       }
       break;
      }
     case 120:
     case 88:
     case 112:
      {
       i6 = 16;
       i31 = 136;
       break;
      }
     case 111:
      {
       i6 = 8;
       i31 = 136;
       break;
      }
     case 117:
     case 100:
      {
       i6 = 10;
       i31 = 136;
       break;
      }
     case 105:
      {
       i6 = 0;
       i31 = 136;
       break;
      }
     case 71:
     case 103:
     case 70:
     case 102:
     case 69:
     case 101:
     case 65:
     case 97:
      {
       d7 = +___floatscan(i33, i11, 0);
       if ((HEAP32[i23 >> 2] | 0) == ((HEAP32[i17 >> 2] | 0) - (HEAP32[i29 >> 2] | 0) | 0)) break L6;
       if (i15) switch (i11 | 0) {
       case 0:
        {
         HEAPF32[i15 >> 2] = d7;
         break L68;
        }
       case 1:
        {
         HEAPF64[i15 >> 3] = d7;
         break L68;
        }
       case 2:
        {
         HEAPF64[i15 >> 3] = d7;
         break L68;
        }
       default:
        break L68;
       }
       break;
      }
     default:
      {}
     } while (0);
     L169 : do if ((i31 | 0) == 136) {
      i31 = 0;
      i6 = ___intscan(i33, i6, 0, -1, -1) | 0;
      if ((HEAP32[i23 >> 2] | 0) == ((HEAP32[i17 >> 2] | 0) - (HEAP32[i29 >> 2] | 0) | 0)) break L6;
      if ((i15 | 0) != 0 & (i9 | 0) == 112) {
       HEAP32[i15 >> 2] = i6;
       break;
      }
      if (i15) switch (i11 | 0) {
      case -2:
       {
        HEAP8[i15 >> 0] = i6;
        break L169;
       }
      case -1:
       {
        HEAP16[i15 >> 1] = i6;
        break L169;
       }
      case 0:
       {
        HEAP32[i15 >> 2] = i6;
        break L169;
       }
      case 1:
       {
        HEAP32[i15 >> 2] = i6;
        break L169;
       }
      case 3:
       {
        i13 = i15;
        HEAP32[i13 >> 2] = i6;
        HEAP32[i13 + 4 >> 2] = tempRet0;
        break L169;
       }
      default:
       break L169;
      }
     } while (0);
     i1 = ((i15 | 0) != 0 & 1) + i1 | 0;
     i6 = (HEAP32[i23 >> 2] | 0) + i14 + (HEAP32[i29 >> 2] | 0) - (HEAP32[i17 >> 2] | 0) | 0;
     break L8;
    } while (0);
    i5 = i5 + (i4 & 1) | 0;
    ___shlim(i33, 0);
    i4 = HEAP32[i29 >> 2] | 0;
    if (i4 >>> 0 < (HEAP32[i30 >> 2] | 0) >>> 0) {
     HEAP32[i29 >> 2] = i4 + 1;
     i4 = HEAPU8[i4 >> 0] | 0;
    } else i4 = ___shgetc(i33) | 0;
    if ((i4 | 0) != (HEAPU8[i5 >> 0] | 0)) {
     i31 = 22;
     break L6;
    }
    i6 = i10 + 1 | 0;
   } else {
    while (1) {
     i4 = i5 + 1 | 0;
     if (!(_isspace(HEAPU8[i4 >> 0] | 0) | 0)) break; else i5 = i4;
    }
    ___shlim(i33, 0);
    do {
     i4 = HEAP32[i29 >> 2] | 0;
     if (i4 >>> 0 < (HEAP32[i30 >> 2] | 0) >>> 0) {
      HEAP32[i29 >> 2] = i4 + 1;
      i4 = HEAPU8[i4 >> 0] | 0;
     } else i4 = ___shgetc(i33) | 0;
    } while ((_isspace(i4) | 0) != 0);
    if (!(HEAP32[i30 >> 2] | 0)) i4 = HEAP32[i29 >> 2] | 0; else {
     i4 = (HEAP32[i29 >> 2] | 0) + -1 | 0;
     HEAP32[i29 >> 2] = i4;
    }
    i6 = (HEAP32[i23 >> 2] | 0) + i10 + i4 - (HEAP32[i17 >> 2] | 0) | 0;
   } while (0);
   i5 = i5 + 1 | 0;
   i4 = HEAP8[i5 >> 0] | 0;
   if (!(i4 << 24 >> 24)) break L4; else i10 = i6;
  }
  if ((i31 | 0) == 22) {
   if (HEAP32[i30 >> 2] | 0) HEAP32[i29 >> 2] = (HEAP32[i29 >> 2] | 0) + -1;
   if ((i1 | 0) != 0 | (i4 | 0) > -1) break; else {
    i1 = 0;
    i31 = 155;
   }
  } else if ((i31 | 0) == 154) if (!i1) {
   i1 = i4;
   i31 = 155;
  }
  if ((i31 | 0) == 155) {
   i4 = i1;
   i1 = -1;
  }
  if (i4) {
   _free(i3);
   _free(i2);
  }
 } else i1 = 0; while (0);
 if (i32 | 0) ___unlockfile(i33);
 STACKTOP = i34;
 return i1 | 0;
}

function __ZN4wasm17WasmBinaryBuilder16maybeVisitBinaryERPNS_10ExpressionEh(i4, i3, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i5 = 0, i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i6;
 do switch (i1 & 255 | 0) {
 case 64:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 0;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 91:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 25;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 117:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 50;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 137:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 63;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 65:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 1;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 92:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 26;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 118:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 51;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 138:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 64;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 66:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 2;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 93:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 27;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 119:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 52;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 139:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 65;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 67:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 3;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 94:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 28;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 68:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 4;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 95:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 29;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 69:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 5;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 96:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 30;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 70:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 6;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 97:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 31;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 71:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 7;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 98:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 32;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 72:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 8;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 99:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 33;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 73:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 9;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 100:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 34;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 74:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 10;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 101:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 35;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 75:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 11;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 102:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 36;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 76:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 12;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 103:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 37;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 183:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 13;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 185:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 38;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 182:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 14;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 184:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 39;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 120:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 53;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 140:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 66;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 125:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 54;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 145:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 67;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 121:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 55;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 141:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 68;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 122:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 56;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 142:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 69;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 77:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 15;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 104:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 40;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 131:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 57;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 151:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 70;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 78:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 16;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 105:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 41;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 132:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 58;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 152:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 71;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 79:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 17;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 106:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 42;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 81:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 18;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 108:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 43;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 80:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 19;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 107:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 44;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 82:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 20;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 109:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 45;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 83:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 21;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 110:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 46;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 85:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 22;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 112:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 47;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 84:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 23;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 111:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 48;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 86:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 24;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 78;
   break;
  }
 case 113:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 49;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 78;
   break;
  }
 case 133:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 59;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 153:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 72;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 134:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 60;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 154:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 73;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 135:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 61;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 155:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 74;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 case 136:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 62;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 78;
   break;
  }
 case 156:
  {
   i1 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 75;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 78;
   break;
  }
 default:
  i1 = 0;
 } while (0);
 if ((i5 | 0) == 78) {
  if (HEAP8[i4 + 12 >> 0] | 0) {
   i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24646) | 0;
   i7 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i2 >> 2] = i7;
   i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
   i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
   __ZNSt3__26localeD2Ev(i2);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i7) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  }
  i7 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i4) | 0;
  HEAP32[i1 + 16 >> 2] = i7;
  i7 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i4) | 0;
  HEAP32[i1 + 12 >> 2] = i7;
  __ZN4wasm6Binary8finalizeEv(i1);
  HEAP32[i3 >> 2] = i1;
  i1 = 1;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_118parse_substitutionINS0_2DbEEEPKcS4_S4_RT_(i12, i5, i15) {
 i12 = i12 | 0;
 i5 = i5 | 0;
 i15 = i15 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 176 | 0;
 i14 = i16 + 144 | 0;
 i6 = i16 + 120 | 0;
 i7 = i16 + 96 | 0;
 i8 = i16 + 72 | 0;
 i9 = i16 + 48 | 0;
 i10 = i16 + 24 | 0;
 i11 = i16;
 L1 : do if ((i5 - i12 | 0) > 1 ? (HEAP8[i12 >> 0] | 0) == 83 : 0) {
  i2 = i12 + 1 | 0;
  i1 = HEAP8[i2 >> 0] | 0;
  i3 = i1 << 24 >> 24;
  switch (i3 | 0) {
  case 97:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj15EEERAT__Kc(i6, 57614);
    i1 = i15 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i13 = HEAP32[i15 + 8 >> 2] | 0;
    i3 = i13;
    if (i2 >>> 0 < i13 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i6);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i15 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i15);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i1, i4, i15 + 12 | 0);
     i13 = i14 + 8 | 0;
     i11 = HEAP32[i13 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i11, i6);
     HEAP32[i13 >> 2] = i11 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i15, i14);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
    i13 = i12 + 2 | 0;
    break L1;
   }
  case 98:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj18EEERAT__Kc(i7, 57629);
    i1 = i15 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i13 = HEAP32[i15 + 8 >> 2] | 0;
    i3 = i13;
    if (i2 >>> 0 < i13 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i7);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i15 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i15);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i1, i4, i15 + 12 | 0);
     i13 = i14 + 8 | 0;
     i11 = HEAP32[i13 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i11, i7);
     HEAP32[i13 >> 2] = i11 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i15, i14);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i7);
    i13 = i12 + 2 | 0;
    break L1;
   }
  case 115:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj12EEERAT__Kc(i8, 57647);
    i1 = i15 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i13 = HEAP32[i15 + 8 >> 2] | 0;
    i3 = i13;
    if (i2 >>> 0 < i13 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i8);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i15 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i15);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i1, i4, i15 + 12 | 0);
     i13 = i14 + 8 | 0;
     i11 = HEAP32[i13 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i11, i8);
     HEAP32[i13 >> 2] = i11 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i15, i14);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i8);
    i13 = i12 + 2 | 0;
    break L1;
   }
  case 105:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj13EEERAT__Kc(i9, 57659);
    i1 = i15 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i13 = HEAP32[i15 + 8 >> 2] | 0;
    i4 = i13;
    if (i2 >>> 0 < i13 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i9);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i15 >> 2] | 0;
     i3 = (i2 - i1 | 0) / 24 | 0;
     i2 = i3 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i15);
     i1 = (i4 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i1, i3, i15 + 12 | 0);
     i13 = i14 + 8 | 0;
     i11 = HEAP32[i13 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i11, i9);
     HEAP32[i13 >> 2] = i11 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i15, i14);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i9);
    i13 = i12 + 2 | 0;
    break L1;
   }
  case 111:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj13EEERAT__Kc(i10, 57672);
    i1 = i15 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i13 = HEAP32[i15 + 8 >> 2] | 0;
    i3 = i13;
    if (i2 >>> 0 < i13 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i10);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i15 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i15);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i1, i4, i15 + 12 | 0);
     i13 = i14 + 8 | 0;
     i11 = HEAP32[i13 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i11, i10);
     HEAP32[i13 >> 2] = i11 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i15, i14);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i10);
    i13 = i12 + 2 | 0;
    break L1;
   }
  case 100:
   {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj14EEERAT__Kc(i11, 57685);
    i1 = i15 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i13 = HEAP32[i15 + 8 >> 2] | 0;
    i3 = i13;
    if (i2 >>> 0 < i13 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i11);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i15 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i15);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i1, i4, i15 + 12 | 0);
     i13 = i14 + 8 | 0;
     i10 = HEAP32[i13 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i10, i11);
     HEAP32[i13 >> 2] = i10 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i15, i14);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i11);
    i13 = i12 + 2 | 0;
    break L1;
   }
  case 95:
   {
    i1 = HEAP32[i15 + 16 >> 2] | 0;
    if ((i1 | 0) == (HEAP32[i15 + 20 >> 2] | 0)) {
     i13 = i12;
     break L1;
    }
    i7 = HEAP32[i1 + 4 >> 2] | 0;
    i8 = i15 + 4 | 0;
    i9 = i15 + 8 | 0;
    i10 = i15 + 12 | 0;
    i11 = i14 + 8 | 0;
    i6 = HEAP32[i1 >> 2] | 0;
    while (1) {
     if ((i6 | 0) == (i7 | 0)) {
      i1 = 55;
      break;
     }
     i1 = HEAP32[i8 >> 2] | 0;
     i5 = HEAP32[i9 >> 2] | 0;
     i2 = i5;
     if ((i1 | 0) == (i5 | 0)) {
      i3 = HEAP32[i15 >> 2] | 0;
      i5 = (i1 - i3 | 0) / 24 | 0;
      i4 = i5 + 1 | 0;
      if (i4 >>> 0 > 178956970) {
       i1 = 59;
       break;
      }
      i1 = (i2 - i3 | 0) / 24 | 0;
      if (i1 >>> 0 < 89478485) {
       i1 = i1 << 1;
       i1 = i1 >>> 0 < i4 >>> 0 ? i4 : i1;
      } else i1 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i1, i5, i10);
      i5 = HEAP32[i11 >> 2] | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i5, i6);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i5 + 12 | 0, i6 + 12 | 0);
      HEAP32[i11 >> 2] = i5 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i15, i14);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
     } else {
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1, i6);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1 + 12 | 0, i6 + 12 | 0);
      HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + 24;
     }
     i6 = i6 + 24 | 0;
    }
    if ((i1 | 0) == 55) {
     i13 = i12 + 2 | 0;
     break L1;
    } else if ((i1 | 0) == 59) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i15);
    break;
   }
  default:
   {
    if ((i3 + -48 | 0) >>> 0 >= 10) {
     if (!(_isupper(i3) | 0)) {
      i13 = i12;
      break L1;
     }
     i1 = HEAP8[i2 >> 0] | 0;
    }
    i2 = i1 << 24 >> 24;
    i4 = i2 + -48 | 0;
    i2 = i4 >>> 0 < 10 ? i4 : i2 + -55 | 0;
    i4 = i12 + 2 | 0;
    while (1) {
     if ((i4 | 0) == (i5 | 0)) {
      i13 = i12;
      break L1;
     }
     i1 = HEAP8[i4 >> 0] | 0;
     i3 = i1 << 24 >> 24;
     if ((i3 + -48 | 0) >>> 0 >= 10) {
      i11 = (_isupper(i3) | 0) == 0;
      i1 = HEAP8[i4 >> 0] | 0;
      if (i11) break;
     }
     i11 = i1 << 24 >> 24;
     i10 = i11 + -48 | 0;
     i2 = (i10 >>> 0 < 10 ? i10 : i11 + -55 | 0) + (i2 * 36 | 0) | 0;
     i4 = i4 + 1 | 0;
    }
    if (i1 << 24 >> 24 != 95) {
     i13 = i12;
     break L1;
    }
    i1 = i2 + 1 | 0;
    i11 = HEAP32[i15 + 16 >> 2] | 0;
    i2 = i11;
    if (i1 >>> 0 >= (HEAP32[i15 + 20 >> 2] | 0) - i11 >> 4 >>> 0) {
     i13 = i12;
     break L1;
    }
    i8 = HEAP32[i2 + (i1 << 4) + 4 >> 2] | 0;
    i9 = i15 + 4 | 0;
    i10 = i15 + 8 | 0;
    i11 = i15 + 12 | 0;
    i12 = i14 + 8 | 0;
    i7 = HEAP32[i2 + (i1 << 4) >> 2] | 0;
    while (1) {
     if ((i7 | 0) == (i8 | 0)) {
      i1 = 76;
      break;
     }
     i1 = HEAP32[i9 >> 2] | 0;
     i6 = HEAP32[i10 >> 2] | 0;
     i2 = i6;
     if ((i1 | 0) == (i6 | 0)) {
      i3 = HEAP32[i15 >> 2] | 0;
      i6 = (i1 - i3 | 0) / 24 | 0;
      i5 = i6 + 1 | 0;
      if (i5 >>> 0 > 178956970) {
       i1 = 80;
       break;
      }
      i1 = (i2 - i3 | 0) / 24 | 0;
      if (i1 >>> 0 < 89478485) {
       i1 = i1 << 1;
       i1 = i1 >>> 0 < i5 >>> 0 ? i5 : i1;
      } else i1 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i14, i1, i6, i11);
      i6 = HEAP32[i12 >> 2] | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i6, i7);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i6 + 12 | 0, i7 + 12 | 0);
      HEAP32[i12 >> 2] = i6 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i15, i14);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i14);
     } else {
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1, i7);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1 + 12 | 0, i7 + 12 | 0);
      HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 24;
     }
     i7 = i7 + 24 | 0;
    }
    if ((i1 | 0) == 76) {
     i13 = i4 + 1 | 0;
     break L1;
    } else if ((i1 | 0) == 80) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i15);
   }
  }
 } else i13 = i12; while (0);
 STACKTOP = i16;
 return i13 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i14, i12, i13) {
 i14 = i14 | 0;
 i12 = i12 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i15 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i15 = i16 + 60 | 0;
 i9 = i16 + 48 | 0;
 i11 = i16 + 36 | 0;
 i6 = i16 + 24 | 0;
 i8 = i16 + 12 | 0;
 i10 = i16;
 i2 = i12;
 L1 : do if ((i2 - i14 | 0) > 2) {
  if ((HEAP8[i14 >> 0] | 0) == 103) {
   i4 = (HEAP8[i14 + 1 >> 0] | 0) == 115;
   i5 = i4;
   i4 = i4 ? i14 + 2 | 0 : i14;
  } else {
   i5 = 0;
   i4 = i14;
  }
  i1 = __ZN10__cxxabiv112_GLOBAL__N_126parse_base_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i4, i12, i13) | 0;
  if ((i1 | 0) != (i4 | 0)) {
   if (!i5) break;
   i2 = HEAP32[i13 + 4 >> 2] | 0;
   if ((HEAP32[i13 >> 2] | 0) == (i2 | 0)) {
    i1 = i14;
    break;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 57058) | 0;
   break;
  }
  if (((i2 - i4 | 0) > 2 ? (HEAP8[i4 >> 0] | 0) == 115 : 0) ? (HEAP8[i4 + 1 >> 0] | 0) == 114 : 0) {
   i3 = i4 + 2 | 0;
   if ((HEAP8[i3 >> 0] | 0) == 78) {
    i10 = i4 + 3 | 0;
    i1 = __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_typeINS0_2DbEEEPKcS4_S4_RT_(i10, i12, i13) | 0;
    if ((i1 | 0) == (i10 | 0) | (i1 | 0) == (i12 | 0)) {
     i1 = i14;
     break;
    }
    i4 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i1, i12, i13) | 0;
    i8 = i13 + 4 | 0;
    do if ((i4 | 0) == (i1 | 0)) i7 = i13; else {
     i1 = HEAP32[i8 >> 2] | 0;
     if (((i1 - (HEAP32[i13 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
      i1 = i14;
      break L1;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i15, i1 + -24 | 0);
     i1 = HEAP32[i8 >> 2] | 0;
     i2 = i1 + -24 | 0;
     i3 = i1;
     while (1) {
      if ((i3 | 0) == (i2 | 0)) break;
      i10 = i3 + -24 | 0;
      HEAP32[i8 >> 2] = i10;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i10);
      i3 = HEAP32[i8 >> 2] | 0;
     }
     i10 = HEAP8[i15 + 11 >> 0] | 0;
     i7 = i10 << 24 >> 24 < 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i7 ? HEAP32[i15 >> 2] | 0 : i15, i7 ? HEAP32[i15 + 4 >> 2] | 0 : i10 & 255) | 0;
     if ((i4 | 0) != (i12 | 0)) {
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
      i7 = i13;
      i1 = i4;
      break;
     }
     i2 = HEAP32[i8 >> 2] | 0;
     i1 = i2 + -24 | 0;
     while (1) {
      if ((i2 | 0) == (i1 | 0)) break;
      i13 = i2 + -24 | 0;
      HEAP32[i8 >> 2] = i13;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i13);
      i2 = HEAP32[i8 >> 2] | 0;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
     i1 = i14;
     break L1;
    } while (0);
    i5 = i9 + 11 | 0;
    i6 = i9 + 4 | 0;
    while (1) {
     if ((HEAP8[i1 >> 0] | 0) == 69) break;
     i4 = __ZN10__cxxabiv112_GLOBAL__N_115parse_simple_idINS0_2DbEEEPKcS4_S4_RT_(i1, i12, i13) | 0;
     if ((i4 | 0) == (i1 | 0) | (i4 | 0) == (i12 | 0)) {
      i1 = i14;
      break L1;
     }
     i1 = HEAP32[i8 >> 2] | 0;
     if (((i1 - (HEAP32[i7 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
      i1 = i14;
      break L1;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i15, i1 + -24 | 0);
     i3 = HEAP32[i8 >> 2] | 0;
     i1 = i3 + -24 | 0;
     i2 = i3;
     while (1) {
      if ((i2 | 0) == (i1 | 0)) break;
      i10 = i2 + -24 | 0;
      HEAP32[i8 >> 2] = i10;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i10);
      i2 = HEAP32[i8 >> 2] | 0;
     }
     i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i15, 0, 57058) | 0;
     HEAP32[i9 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i9 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
     HEAP32[i9 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i1 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     i1 = HEAP8[i5 >> 0] | 0;
     i10 = i1 << 24 >> 24 < 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i3 + -48 | 0, i10 ? HEAP32[i9 >> 2] | 0 : i9, i10 ? HEAP32[i6 >> 2] | 0 : i1 & 255) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i9);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
     i1 = i4;
    }
    i10 = i1 + 1 | 0;
    i1 = __ZN10__cxxabiv112_GLOBAL__N_126parse_base_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i10, i12, i13) | 0;
    if ((i1 | 0) == (i10 | 0)) {
     i1 = HEAP32[i8 >> 2] | 0;
     if ((HEAP32[i13 >> 2] | 0) == (i1 | 0)) {
      i1 = i14;
      break;
     }
     i2 = i1 + -24 | 0;
     while (1) {
      if ((i1 | 0) == (i2 | 0)) {
       i1 = i14;
       break L1;
      }
      i15 = i1 + -24 | 0;
      HEAP32[i8 >> 2] = i15;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
      i1 = HEAP32[i8 >> 2] | 0;
     }
    }
    i2 = HEAP32[i8 >> 2] | 0;
    if (((i2 - (HEAP32[i7 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
     i1 = i14;
     break;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i15, i2 + -24 | 0);
    i4 = HEAP32[i8 >> 2] | 0;
    i2 = i4 + -24 | 0;
    i3 = i4;
    while (1) {
     if ((i3 | 0) == (i2 | 0)) break;
     i14 = i3 + -24 | 0;
     HEAP32[i8 >> 2] = i14;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i14);
     i3 = HEAP32[i8 >> 2] | 0;
    }
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i15, 0, 57058) | 0;
    HEAP32[i11 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i11 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i11 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    i14 = HEAP8[i11 + 11 >> 0] | 0;
    i13 = i14 << 24 >> 24 < 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4 + -48 | 0, i13 ? HEAP32[i11 >> 2] | 0 : i11, i13 ? HEAP32[i11 + 4 >> 2] | 0 : i14 & 255) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i11);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
    break;
   }
   i2 = __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_typeINS0_2DbEEEPKcS4_S4_RT_(i3, i12, i13) | 0;
   if ((i2 | 0) != (i3 | 0)) {
    i5 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i2, i12, i13) | 0;
    if ((i5 | 0) != (i2 | 0)) {
     i4 = i13 + 4 | 0;
     i1 = HEAP32[i4 >> 2] | 0;
     if (((i1 - (HEAP32[i13 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
      i1 = i14;
      break;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i15, i1 + -24 | 0);
     i1 = HEAP32[i4 >> 2] | 0;
     i2 = i1 + -24 | 0;
     i3 = i1;
     while (1) {
      if ((i3 | 0) == (i2 | 0)) break;
      i11 = i3 + -24 | 0;
      HEAP32[i4 >> 2] = i11;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i11);
      i3 = HEAP32[i4 >> 2] | 0;
     }
     i2 = HEAP8[i15 + 11 >> 0] | 0;
     i11 = i2 << 24 >> 24 < 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i11 ? HEAP32[i15 >> 2] | 0 : i15, i11 ? HEAP32[i15 + 4 >> 2] | 0 : i2 & 255) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
     i2 = i5;
    }
    i1 = __ZN10__cxxabiv112_GLOBAL__N_126parse_base_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i2, i12, i13) | 0;
    if ((i1 | 0) == (i2 | 0)) {
     i3 = i13 + 4 | 0;
     i1 = HEAP32[i3 >> 2] | 0;
     if ((HEAP32[i13 >> 2] | 0) == (i1 | 0)) {
      i1 = i14;
      break;
     }
     i2 = i1 + -24 | 0;
     while (1) {
      if ((i1 | 0) == (i2 | 0)) {
       i1 = i14;
       break L1;
      }
      i15 = i1 + -24 | 0;
      HEAP32[i3 >> 2] = i15;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
      i1 = HEAP32[i3 >> 2] | 0;
     }
    }
    i5 = i13 + 4 | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    if (((i2 - (HEAP32[i13 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
     i1 = i14;
     break;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i15, i2 + -24 | 0);
    i4 = HEAP32[i5 >> 2] | 0;
    i2 = i4 + -24 | 0;
    i3 = i4;
    while (1) {
     if ((i3 | 0) == (i2 | 0)) break;
     i14 = i3 + -24 | 0;
     HEAP32[i5 >> 2] = i14;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i14);
     i3 = HEAP32[i5 >> 2] | 0;
    }
    i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i15, 0, 57058) | 0;
    HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i6 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i6 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    i14 = HEAP8[i6 + 11 >> 0] | 0;
    i13 = i14 << 24 >> 24 < 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4 + -48 | 0, i13 ? HEAP32[i6 >> 2] | 0 : i6, i13 ? HEAP32[i6 + 4 >> 2] | 0 : i14 & 255) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i6);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
    break;
   }
   i1 = __ZN10__cxxabiv112_GLOBAL__N_115parse_simple_idINS0_2DbEEEPKcS4_S4_RT_(i3, i12, i13) | 0;
   if (!((i1 | 0) == (i3 | 0) | (i1 | 0) == (i12 | 0))) {
    if (i5) {
     i2 = i13 + 4 | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     if ((HEAP32[i13 >> 2] | 0) == (i3 | 0)) {
      i1 = i14;
      break;
     }
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i3 + -24 | 0, 0, 57058) | 0;
     i7 = i2;
    } else i7 = i13 + 4 | 0;
    i5 = i8 + 11 | 0;
    i6 = i8 + 4 | 0;
    while (1) {
     if ((HEAP8[i1 >> 0] | 0) == 69) break;
     i4 = __ZN10__cxxabiv112_GLOBAL__N_115parse_simple_idINS0_2DbEEEPKcS4_S4_RT_(i1, i12, i13) | 0;
     if ((i4 | 0) == (i1 | 0) | (i4 | 0) == (i12 | 0)) {
      i1 = i14;
      break L1;
     }
     i1 = HEAP32[i7 >> 2] | 0;
     if (((i1 - (HEAP32[i13 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
      i1 = i14;
      break L1;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i15, i1 + -24 | 0);
     i3 = HEAP32[i7 >> 2] | 0;
     i1 = i3 + -24 | 0;
     i2 = i3;
     while (1) {
      if ((i2 | 0) == (i1 | 0)) break;
      i11 = i2 + -24 | 0;
      HEAP32[i7 >> 2] = i11;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i11);
      i2 = HEAP32[i7 >> 2] | 0;
     }
     i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i15, 0, 57058) | 0;
     HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i8 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
     HEAP32[i8 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i1 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     i1 = HEAP8[i5 >> 0] | 0;
     i11 = i1 << 24 >> 24 < 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i3 + -48 | 0, i11 ? HEAP32[i8 >> 2] | 0 : i8, i11 ? HEAP32[i6 >> 2] | 0 : i1 & 255) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
     i1 = i4;
    }
    i11 = i1 + 1 | 0;
    i1 = __ZN10__cxxabiv112_GLOBAL__N_126parse_base_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i11, i12, i13) | 0;
    if ((i1 | 0) == (i11 | 0)) {
     i1 = HEAP32[i7 >> 2] | 0;
     if ((HEAP32[i13 >> 2] | 0) == (i1 | 0)) {
      i1 = i14;
      break;
     }
     i2 = i1 + -24 | 0;
     while (1) {
      if ((i1 | 0) == (i2 | 0)) {
       i1 = i14;
       break L1;
      }
      i15 = i1 + -24 | 0;
      HEAP32[i7 >> 2] = i15;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
      i1 = HEAP32[i7 >> 2] | 0;
     }
    }
    i2 = HEAP32[i7 >> 2] | 0;
    if (((i2 - (HEAP32[i13 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i15, i2 + -24 | 0);
     i4 = HEAP32[i7 >> 2] | 0;
     i2 = i4 + -24 | 0;
     i3 = i4;
     while (1) {
      if ((i3 | 0) == (i2 | 0)) break;
      i14 = i3 + -24 | 0;
      HEAP32[i7 >> 2] = i14;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i14);
      i3 = HEAP32[i7 >> 2] | 0;
     }
     i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i15, 0, 57058) | 0;
     HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i10 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
     HEAP32[i10 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
     i3 = 0;
     while (1) {
      if ((i3 | 0) == 3) break;
      HEAP32[i2 + (i3 << 2) >> 2] = 0;
      i3 = i3 + 1 | 0;
     }
     i14 = HEAP8[i10 + 11 >> 0] | 0;
     i13 = i14 << 24 >> 24 < 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4 + -48 | 0, i13 ? HEAP32[i10 >> 2] | 0 : i10, i13 ? HEAP32[i10 + 4 >> 2] | 0 : i14 & 255) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i10);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
    } else i1 = i14;
   } else i1 = i14;
  } else i1 = i14;
 } else i1 = i14; while (0);
 STACKTOP = i16;
 return i1 | 0;
}

function __ZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefE(i50, i7) {
 i50 = i50 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, d9 = 0.0, d10 = 0.0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0, i51 = 0;
 i51 = STACKTOP;
 STACKTOP = STACKTOP + 288 | 0;
 i33 = i51 + 72 | 0;
 i32 = i51 + 280 | 0;
 i40 = i51 + 276 | 0;
 i36 = i51 + 272 | 0;
 i8 = i51 + 268 | 0;
 i44 = i51 + 260 | 0;
 i42 = i51 + 285 | 0;
 i43 = i51 + 284 | 0;
 i41 = i51 + 216 | 0;
 i46 = i51 + 212 | 0;
 i37 = i51 + 196 | 0;
 i38 = i51 + 180 | 0;
 i35 = i51 + 124 | 0;
 i39 = i51 + 104 | 0;
 i16 = i51 + 264 | 0;
 i17 = i51 + 256 | 0;
 i18 = i51 + 252 | 0;
 i19 = i51 + 248 | 0;
 i45 = i51 + 100 | 0;
 i27 = i51 + 208 | 0;
 i28 = i51 + 192 | 0;
 i29 = i51 + 176 | 0;
 i30 = i51 + 120 | 0;
 i48 = i51 + 48 | 0;
 i49 = i51 + 24 | 0;
 i47 = i51;
 i34 = i51 + 96 | 0;
 i1 = __ZN6cashew3RefixEj(i7, 1) | 0;
 i1 = __ZN6cashew5Value10getIStringEv(HEAP32[i1 >> 2] | 0) | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 if (HEAP8[i50 + 45 >> 0] | 0) {
  i25 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60808, 17115) | 0;
  i26 = __ZN6cashew3RefixEj(i7, 1) | 0;
  i26 = __ZN6cashew5Value10getIStringEv(HEAP32[i26 >> 2] | 0) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i25, HEAP32[i26 >> 2] | 0) | 0, 10) | 0;
  __ZN6cashew5Value9stringifyERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEb(HEAP32[i7 >> 2] | 0, 60808, 0);
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(60808, 10) | 0;
 }
 i2 = __Znwj(64) | 0;
 HEAP32[i2 + 40 >> 2] = 0;
 HEAP32[i2 + 44 >> 2] = 0;
 HEAP32[i2 + 48 >> 2] = 0;
 i3 = i2 + 52 | 0;
 i4 = i2 + 56 | 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i2 + 60 >> 2] = 0;
 i5 = i2;
 i6 = i5 + 36 | 0;
 do {
  HEAP32[i5 >> 2] = 0;
  i5 = i5 + 4 | 0;
 } while ((i5 | 0) < (i6 | 0));
 HEAP32[i3 >> 2] = i4;
 HEAP32[i40 >> 2] = i2;
 HEAP32[i2 >> 2] = i1;
 i15 = __ZN6cashew3RefixEj(i7, 2) | 0;
 i15 = HEAP32[i15 >> 2] | 0;
 i20 = __ZN6cashew3RefixEj(i7, 3) | 0;
 HEAP32[i36 >> 2] = HEAP32[i20 >> 2];
 HEAP32[i8 >> 2] = 0;
 HEAP32[i44 >> 2] = i8;
 i20 = i41 + 16 | 0;
 HEAP32[i41 >> 2] = 0;
 HEAP32[i41 + 4 >> 2] = 0;
 HEAP32[i41 + 8 >> 2] = 0;
 HEAP32[i41 + 12 >> 2] = 0;
 HEAPF32[i20 >> 2] = 1.0;
 HEAP32[i41 + 20 >> 2] = 0;
 HEAP32[i41 + 24 >> 2] = 0;
 HEAP32[i41 + 28 >> 2] = 0;
 HEAP32[i46 >> 2] = 0;
 HEAP32[i37 >> 2] = 0;
 i25 = i37 + 4 | 0;
 HEAP32[i25 >> 2] = 0;
 HEAP32[i37 + 8 >> 2] = 0;
 HEAP32[i38 >> 2] = 0;
 i26 = i38 + 4 | 0;
 HEAP32[i26 >> 2] = 0;
 HEAP32[i38 + 8 >> 2] = 0;
 HEAP32[i35 >> 2] = 0;
 HEAP32[i35 + 4 >> 2] = 0;
 HEAP32[i35 + 8 >> 2] = 0;
 HEAP32[i35 + 12 >> 2] = 0;
 HEAPF32[i35 + 16 >> 2] = 1.0;
 i21 = i35 + 20 | 0;
 HEAP32[i35 + 48 >> 2] = 0;
 HEAP32[i21 >> 2] = 0;
 HEAP32[i21 + 4 >> 2] = 0;
 HEAP32[i21 + 8 >> 2] = 0;
 HEAP32[i21 + 12 >> 2] = 0;
 HEAP32[i21 + 16 >> 2] = 0;
 HEAP32[i21 + 20 >> 2] = 0;
 i21 = i50 + 80 | 0;
 i22 = i41 + 4 | 0;
 i23 = i41 + 12 | 0;
 i24 = i41 + 8 | 0;
 i14 = 0;
 while (1) {
  if (i14 >>> 0 >= (__ZN6cashew5Value4sizeEv(i15) | 0) >>> 0) {
   i31 = 5;
   break;
  }
  i13 = __ZN6cashew3RefixEj(i36, i14) | 0;
  HEAP32[i39 >> 2] = HEAP32[i13 >> 2];
  if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i39, 0) | 0, 59284) | 0)) {
   i31 = 7;
   break;
  }
  i13 = __ZN6cashew3RefixEj(i39, 1) | 0;
  HEAP32[i39 >> 2] = HEAP32[i13 >> 2];
  if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i39, 0) | 0, 59288) | 0)) {
   i31 = 10;
   break;
  }
  if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i39, 2) | 0, 0) | 0, 59292) | 0)) {
   i31 = 10;
   break;
  }
  i12 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i39, 2) | 0, 1) | 0;
  i12 = __ZN6cashew5Value10getIStringEv(HEAP32[i12 >> 2] | 0) | 0;
  i12 = HEAP32[i12 >> 2] | 0;
  i13 = __ZN6cashew3RefixEj(i39, 3) | 0;
  HEAP32[i16 >> 2] = HEAP32[i13 >> 2];
  HEAP32[i17 >> 2] = HEAP32[i21 >> 2];
  HEAP32[i32 >> 2] = HEAP32[i16 >> 2];
  HEAP32[i33 >> 2] = HEAP32[i17 >> 2];
  i13 = __Z10detectTypeN6cashew3RefEP7AsmDatabNS_7IStringE(i32, 0, 0, i33) | 0;
  i8 = HEAP32[i40 >> 2] | 0;
  HEAP32[i18 >> 2] = i12;
  i11 = __ZN4wasm13asmToWasmTypeE7AsmType(i13) | 0;
  HEAP32[i33 >> 2] = HEAP32[i18 >> 2];
  __ZN4wasm7Builder8addParamEPNS_8FunctionENS_4NameENS_8WasmTypeE(i8, i33, i11) | 0;
  i11 = i12 * 33 ^ 5381;
  i8 = HEAP32[i22 >> 2] | 0;
  i7 = (i8 | 0) == 0;
  i4 = i12;
  L10 : do if (!i7) {
   i5 = i8 + -1 | 0;
   i6 = (i5 & i8 | 0) == 0;
   if (i6) i1 = i5 & i11; else i1 = (i11 >>> 0) % (i8 >>> 0) | 0;
   i2 = HEAP32[(HEAP32[i41 >> 2] | 0) + (i1 << 2) >> 2] | 0;
   if (!i2) i31 = 22; else do {
    i2 = HEAP32[i2 >> 2] | 0;
    if (!i2) {
     i31 = 22;
     break L10;
    }
    i3 = HEAP32[i2 + 4 >> 2] | 0;
    if (i6) i3 = i3 & i5; else i3 = (i3 >>> 0) % (i8 >>> 0) | 0;
    if ((i3 | 0) != (i1 | 0)) {
     i31 = 22;
     break L10;
    }
   } while ((HEAP32[i2 + 8 >> 2] | 0) != (i4 | 0));
  } else {
   i1 = 0;
   i31 = 22;
  } while (0);
  if ((i31 | 0) == 22) {
   i31 = 0;
   i4 = __Znwj(12) | 0;
   HEAP32[i4 + 8 >> 2] = i12;
   HEAP32[i4 + 4 >> 2] = i11;
   HEAP32[i4 >> 2] = 0;
   d9 = +(((HEAP32[i23 >> 2] | 0) + 1 | 0) >>> 0);
   d10 = +HEAPF32[i20 >> 2];
   do if (i7 | d9 > +(i8 >>> 0) * d10) {
    if (i8 >>> 0 > 2) i1 = (i8 + -1 & i8 | 0) == 0; else i1 = 0;
    i1 = (i1 & 1 | i8 << 1) ^ 1;
    i2 = ~~+Math_ceil(+(d9 / d10)) >>> 0;
    __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE6rehashEj(i41, i1 >>> 0 < i2 >>> 0 ? i2 : i1);
    i1 = HEAP32[i22 >> 2] | 0;
    i2 = i1 + -1 | 0;
    if (!(i2 & i1)) {
     i3 = i1;
     i1 = i2 & i11;
     break;
    } else {
     i3 = i1;
     i1 = (i11 >>> 0) % (i1 >>> 0) | 0;
     break;
    }
   } else i3 = i8; while (0);
   i1 = (HEAP32[i41 >> 2] | 0) + (i1 << 2) | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if (!i2) {
    HEAP32[i4 >> 2] = HEAP32[i24 >> 2];
    HEAP32[i24 >> 2] = i4;
    HEAP32[i1 >> 2] = i24;
    i1 = HEAP32[i4 >> 2] | 0;
    if (i1 | 0) {
     i1 = HEAP32[i1 + 4 >> 2] | 0;
     i2 = i3 + -1 | 0;
     if (!(i2 & i3)) i1 = i1 & i2; else i1 = (i1 >>> 0) % (i3 >>> 0) | 0;
     HEAP32[(HEAP32[i41 >> 2] | 0) + (i1 << 2) >> 2] = i4;
    }
   } else {
    HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i2 >> 2] = i4;
   }
   HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + 1;
  }
  HEAP32[i19 >> 2] = i12;
  HEAP32[i33 >> 2] = HEAP32[i19 >> 2];
  __ZN7AsmData8addParamEN6cashew7IStringE7AsmType(i35, i33, i13);
  i14 = i14 + 1 | 0;
 }
 if ((i31 | 0) == 5) {
  i1 = __ZN6cashew5Value4sizeEv(i15) | 0;
  while (1) {
   if (i1 >>> 0 >= (__ZN6cashew5Value4sizeEv(HEAP32[i36 >> 2] | 0) | 0) >>> 0) break;
   if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i36, i1) | 0, 0) | 0, 59296) | 0)) break;
   i15 = __ZN6cashew3RefixEj(i36, i1) | 0;
   HEAP32[i39 >> 2] = HEAP32[i15 >> 2];
   i15 = 0;
   while (1) {
    i19 = __ZN6cashew3RefixEj(i39, 1) | 0;
    if (i15 >>> 0 >= (__ZN6cashew5Value4sizeEv(HEAP32[i19 >> 2] | 0) | 0) >>> 0) break;
    i13 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i39, 1) | 0, i15) | 0;
    HEAP32[i45 >> 2] = HEAP32[i13 >> 2];
    i13 = __ZN6cashew3RefixEj(i45, 0) | 0;
    i13 = __ZN6cashew5Value10getIStringEv(HEAP32[i13 >> 2] | 0) | 0;
    i13 = HEAP32[i13 >> 2] | 0;
    i14 = __ZN6cashew3RefixEj(i45, 1) | 0;
    HEAP32[i27 >> 2] = HEAP32[i14 >> 2];
    HEAP32[i28 >> 2] = HEAP32[i21 >> 2];
    HEAP32[i32 >> 2] = HEAP32[i27 >> 2];
    HEAP32[i33 >> 2] = HEAP32[i28 >> 2];
    i14 = __Z10detectTypeN6cashew3RefEP7AsmDatabNS_7IStringE(i32, 0, 1, i33) | 0;
    i11 = HEAP32[i40 >> 2] | 0;
    HEAP32[i29 >> 2] = i13;
    i12 = __ZN4wasm13asmToWasmTypeE7AsmType(i14) | 0;
    HEAP32[i33 >> 2] = HEAP32[i29 >> 2];
    __ZN4wasm7Builder6addVarEPNS_8FunctionENS_4NameENS_8WasmTypeE(i11, i33, i12) | 0;
    i12 = i13 * 33 ^ 5381;
    i11 = HEAP32[i22 >> 2] | 0;
    i8 = (i11 | 0) == 0;
    i5 = i13;
    L54 : do if (!i8) {
     i6 = i11 + -1 | 0;
     i7 = (i6 & i11 | 0) == 0;
     if (i7) i2 = i6 & i12; else i2 = (i12 >>> 0) % (i11 >>> 0) | 0;
     i3 = HEAP32[(HEAP32[i41 >> 2] | 0) + (i2 << 2) >> 2] | 0;
     if (!i3) i31 = 53; else do {
      i3 = HEAP32[i3 >> 2] | 0;
      if (!i3) {
       i31 = 53;
       break L54;
      }
      i4 = HEAP32[i3 + 4 >> 2] | 0;
      if (i7) i4 = i4 & i6; else i4 = (i4 >>> 0) % (i11 >>> 0) | 0;
      if ((i4 | 0) != (i2 | 0)) {
       i31 = 53;
       break L54;
      }
     } while ((HEAP32[i3 + 8 >> 2] | 0) != (i5 | 0));
    } else {
     i2 = 0;
     i31 = 53;
    } while (0);
    if ((i31 | 0) == 53) {
     i31 = 0;
     i5 = __Znwj(12) | 0;
     HEAP32[i5 + 8 >> 2] = i13;
     HEAP32[i5 + 4 >> 2] = i12;
     HEAP32[i5 >> 2] = 0;
     d9 = +(((HEAP32[i23 >> 2] | 0) + 1 | 0) >>> 0);
     d10 = +HEAPF32[i20 >> 2];
     do if (i8 | d9 > +(i11 >>> 0) * d10) {
      if (i11 >>> 0 > 2) i2 = (i11 + -1 & i11 | 0) == 0; else i2 = 0;
      i2 = (i2 & 1 | i11 << 1) ^ 1;
      i3 = ~~+Math_ceil(+(d9 / d10)) >>> 0;
      __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE6rehashEj(i41, i2 >>> 0 < i3 >>> 0 ? i3 : i2);
      i2 = HEAP32[i22 >> 2] | 0;
      i3 = i2 + -1 | 0;
      if (!(i3 & i2)) {
       i4 = i2;
       i2 = i3 & i12;
       break;
      } else {
       i4 = i2;
       i2 = (i12 >>> 0) % (i2 >>> 0) | 0;
       break;
      }
     } else i4 = i11; while (0);
     i2 = (HEAP32[i41 >> 2] | 0) + (i2 << 2) | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     if (!i3) {
      HEAP32[i5 >> 2] = HEAP32[i24 >> 2];
      HEAP32[i24 >> 2] = i5;
      HEAP32[i2 >> 2] = i24;
      i2 = HEAP32[i5 >> 2] | 0;
      if (i2 | 0) {
       i2 = HEAP32[i2 + 4 >> 2] | 0;
       i3 = i4 + -1 | 0;
       if (!(i3 & i4)) i2 = i2 & i3; else i2 = (i2 >>> 0) % (i4 >>> 0) | 0;
       HEAP32[(HEAP32[i41 >> 2] | 0) + (i2 << 2) >> 2] = i5;
      }
     } else {
      HEAP32[i5 >> 2] = HEAP32[i3 >> 2];
      HEAP32[i3 >> 2] = i5;
     }
     HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + 1;
    }
    HEAP32[i30 >> 2] = i13;
    HEAP32[i33 >> 2] = HEAP32[i30 >> 2];
    __ZN7AsmData6addVarEN6cashew7IStringE7AsmType(i35, i33, i14);
    i15 = i15 + 1 | 0;
   }
   i1 = i1 + 1 | 0;
  }
  HEAP8[i32 >> 0] = 0;
  HEAP32[i39 >> 2] = i32;
  HEAP32[i39 + 4 >> 2] = i40;
  HEAP32[i39 + 8 >> 2] = i41;
  HEAP32[i39 + 12 >> 2] = i35;
  HEAP8[i45 >> 0] = 0;
  HEAP32[i48 + 16 >> 2] = 0;
  HEAP32[i49 + 16 >> 2] = 0;
  i32 = __Znwj(64) | 0;
  HEAP32[i32 >> 2] = 4940;
  HEAP32[i32 + 4 >> 2] = i50;
  HEAP32[i32 + 8 >> 2] = i47;
  HEAP32[i32 + 12 >> 2] = i41;
  HEAP32[i32 + 16 >> 2] = i40;
  HEAP32[i32 + 20 >> 2] = i49;
  HEAP32[i32 + 24 >> 2] = i35;
  HEAP32[i32 + 28 >> 2] = i39;
  HEAP32[i32 + 32 >> 2] = i45;
  HEAP32[i32 + 36 >> 2] = i46;
  HEAP32[i32 + 40 >> 2] = i42;
  HEAP32[i32 + 44 >> 2] = i37;
  HEAP32[i32 + 48 >> 2] = i48;
  HEAP32[i32 + 52 >> 2] = i38;
  HEAP32[i32 + 56 >> 2] = i43;
  HEAP32[i32 + 60 >> 2] = i44;
  HEAP32[i47 + 16 >> 2] = i32;
  i45 = i50;
  i50 = i47;
  HEAP32[i33 >> 2] = 4984;
  HEAP32[i33 + 4 >> 2] = i45;
  HEAP32[i33 + 8 >> 2] = i50;
  HEAP32[i33 + 16 >> 2] = i33;
  __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEE4swapERS7_(i33, i49);
  __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEED2Ev(i33);
  HEAP32[i33 >> 2] = 5028;
  HEAP32[i33 + 4 >> 2] = i45;
  HEAP32[i33 + 8 >> 2] = i50;
  HEAP32[i33 + 16 >> 2] = i33;
  __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEE4swapERS7_(i33, i48);
  __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEED2Ev(i33);
  HEAP32[i34 >> 2] = HEAP32[i36 >> 2];
  HEAP32[i33 >> 2] = HEAP32[i34 >> 2];
  i50 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEEclES5_j(i48, i33, i1) | 0;
  HEAP32[(HEAP32[i40 >> 2] | 0) + 36 >> 2] = i50;
  if ((HEAP32[i25 >> 2] | 0) == (HEAP32[i37 >> 2] | 0) ? (HEAP32[i26 >> 2] | 0) == (HEAP32[i38 >> 2] | 0) : 0) if (!(HEAP32[i46 >> 2] | 0)) {
   i50 = HEAP32[i40 >> 2] | 0;
   __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEED2Ev(i47);
   __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEED2Ev(i49);
   __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEED2Ev(i48);
   __ZN7AsmDataD2Ev(i35);
   __ZNSt3__213__vector_baseIN6cashew7IStringENS_9allocatorIS2_EEED2Ev(i38);
   __ZNSt3__213__vector_baseIN6cashew7IStringENS_9allocatorIS2_EEED2Ev(i37);
   __ZN6cashew10IStringSetD2Ev(i41);
   STACKTOP = i51;
   return i50 | 0;
  } else ___assert_fail(17247, 16311, 1725, 17139);
  ___assert_fail(17195, 16311, 1724, 17139);
 } else if ((i31 | 0) == 7) ___assert_fail(17123, 16311, 906, 17139); else if ((i31 | 0) == 10) ___assert_fail(17155, 16311, 908, 17139);
 return 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i29, i28, i35) {
 i29 = i29 | 0;
 i28 = i28 | 0;
 i35 = i35 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i36 = 0;
 i36 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i33 = i36 + 60 | 0;
 i34 = i36;
 i24 = i36 + 48 | 0;
 i31 = i36 + 24 | 0;
 i32 = i36 + 12 | 0;
 do if ((i28 - i29 | 0) > 1 ? (HEAP8[i29 >> 0] | 0) == 73 : 0) {
  i27 = i35 + 61 | 0;
  i23 = i35 + 36 | 0;
  L4 : do if (HEAP8[i27 >> 0] | 0) {
   i2 = HEAP32[i23 >> 2] | 0;
   i1 = HEAP32[i2 + -16 >> 2] | 0;
   i2 = i2 + -12 | 0;
   while (1) {
    i3 = HEAP32[i2 >> 2] | 0;
    if ((i3 | 0) == (i1 | 0)) break L4;
    i30 = i3 + -16 | 0;
    HEAP32[i2 >> 2] = i30;
    __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i30);
   }
  } while (0);
  HEAP32[i34 >> 2] = 0;
  HEAP32[i34 + 4 >> 2] = 0;
  HEAP32[i34 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i34, 57596, 1);
  i30 = i35 + 4 | 0;
  i14 = i35 + 12 | 0;
  i15 = i33 + 8 | 0;
  i16 = i33 + 8 | 0;
  i25 = i34 + 11 | 0;
  i26 = i34 + 4 | 0;
  i17 = i24 + 11 | 0;
  i18 = i24 + 4 | 0;
  i22 = i35 + 32 | 0;
  i19 = i35 + 40 | 0;
  i20 = i35 + 44 | 0;
  i21 = i33 + 8 | 0;
  i1 = i29 + 1 | 0;
  L10 : while (1) {
   if ((HEAP8[i1 >> 0] | 0) == 69) {
    i2 = 48;
    break;
   }
   do if (HEAP8[i27 >> 0] | 0) {
    i8 = HEAP32[i14 >> 2] | 0;
    i2 = HEAP32[i23 >> 2] | 0;
    i3 = HEAP32[i19 >> 2] | 0;
    if (i2 >>> 0 < i3 >>> 0) {
     HEAP32[i2 >> 2] = 0;
     HEAP32[i2 + 4 >> 2] = 0;
     HEAP32[i2 + 8 >> 2] = 0;
     HEAP32[i2 + 12 >> 2] = i8;
     HEAP32[i23 >> 2] = (HEAP32[i23 >> 2] | 0) + 16;
     break;
    }
    i4 = HEAP32[i22 >> 2] | 0;
    i7 = i2 - i4 >> 4;
    i5 = i7 + 1 | 0;
    if (i5 >>> 0 > 268435455) {
     i2 = 13;
     break L10;
    }
    i2 = i3 - i4 | 0;
    if (i2 >> 4 >>> 0 < 134217727) {
     i2 = i2 >> 3;
     i2 = i2 >>> 0 < i5 >>> 0 ? i5 : i2;
    } else i2 = 268435455;
    __ZNSt3__214__split_bufferINS_6vectorINS1_IN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEEERNS5_IS9_Lj4096EEEEC2EjjSB_(i33, i2, i7, i20);
    i13 = HEAP32[i21 >> 2] | 0;
    HEAP32[i13 >> 2] = 0;
    HEAP32[i13 + 4 >> 2] = 0;
    HEAP32[i13 + 8 >> 2] = 0;
    HEAP32[i13 + 12 >> 2] = i8;
    HEAP32[i21 >> 2] = i13 + 16;
    __ZNSt3__26vectorINS0_INS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEEENS4_IS8_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS8_RS9_EE(i22, i33);
    __ZNSt3__214__split_bufferINS_6vectorINS1_IN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEEERNS5_IS9_Lj4096EEEED2Ev(i33);
   } while (0);
   i12 = ((HEAP32[i30 >> 2] | 0) - (HEAP32[i35 >> 2] | 0) | 0) / 24 | 0;
   i13 = __ZN10__cxxabiv112_GLOBAL__N_118parse_template_argINS0_2DbEEEPKcS4_S4_RT_(i1, i28, i35) | 0;
   i3 = ((HEAP32[i30 >> 2] | 0) - (HEAP32[i35 >> 2] | 0) | 0) / 24 | 0;
   L23 : do if (HEAP8[i27 >> 0] | 0) {
    i4 = HEAP32[i23 >> 2] | 0;
    i2 = i4 + -16 | 0;
    while (1) {
     if ((i4 | 0) == (i2 | 0)) break L23;
     i11 = i4 + -16 | 0;
     HEAP32[i23 >> 2] = i11;
     __ZNSt3__213__vector_baseINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEED2Ev(i11);
     i4 = HEAP32[i23 >> 2] | 0;
    }
   } while (0);
   if ((i13 | 0) == (i1 | 0) | (i13 | 0) == (i28 | 0)) {
    i2 = 62;
    break;
   }
   L30 : do if (!(HEAP8[i27 >> 0] | 0)) i1 = i12; else {
    i8 = HEAP32[i23 >> 2] | 0;
    i1 = i8 + -16 | 0;
    i9 = HEAP32[i14 >> 2] | 0;
    i2 = i8 + -12 | 0;
    i4 = HEAP32[i2 >> 2] | 0;
    i11 = HEAP32[i8 + -8 >> 2] | 0;
    i7 = i11;
    if (i4 >>> 0 < i11 >>> 0) {
     HEAP32[i4 >> 2] = 0;
     HEAP32[i4 + 4 >> 2] = 0;
     HEAP32[i4 + 8 >> 2] = 0;
     HEAP32[i4 + 12 >> 2] = i9;
     HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
     i11 = i12;
    } else {
     i2 = HEAP32[i1 >> 2] | 0;
     i5 = i4 - i2 >> 4;
     i4 = i5 + 1 | 0;
     if (i4 >>> 0 > 268435455) {
      i2 = 26;
      break L10;
     }
     i2 = i7 - i2 | 0;
     if (i2 >> 4 >>> 0 < 134217727) {
      i2 = i2 >> 3;
      i2 = i2 >>> 0 < i4 >>> 0 ? i4 : i2;
     } else i2 = 268435455;
     __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i33, i2, i5, i8 + -4 | 0);
     i11 = HEAP32[i15 >> 2] | 0;
     HEAP32[i11 >> 2] = 0;
     HEAP32[i11 + 4 >> 2] = 0;
     HEAP32[i11 + 8 >> 2] = 0;
     HEAP32[i11 + 12 >> 2] = i9;
     HEAP32[i15 >> 2] = i11 + 16;
     __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i1, i33);
     __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i33);
     i11 = i12;
    }
    while (1) {
     if (i11 >>> 0 >= i3 >>> 0) {
      i1 = i12;
      break L30;
     }
     i8 = HEAP32[(HEAP32[i23 >> 2] | 0) + -12 >> 2] | 0;
     i1 = i8 + -16 | 0;
     i9 = HEAP32[i35 >> 2] | 0;
     i10 = i9 + (i11 * 24 | 0) | 0;
     i2 = i8 + -12 | 0;
     i4 = HEAP32[i2 >> 2] | 0;
     i7 = HEAP32[i8 + -8 >> 2] | 0;
     i5 = i7;
     if ((i4 | 0) == (i7 | 0)) {
      i2 = HEAP32[i1 >> 2] | 0;
      i7 = (i4 - i2 | 0) / 24 | 0;
      i4 = i7 + 1 | 0;
      if (i4 >>> 0 > 178956970) {
       i2 = 34;
       break L10;
      }
      i2 = (i5 - i2 | 0) / 24 | 0;
      if (i2 >>> 0 < 89478485) {
       i2 = i2 << 1;
       i2 = i2 >>> 0 < i4 >>> 0 ? i4 : i2;
      } else i2 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i33, i2, i7, i8 + -4 | 0);
      i8 = HEAP32[i16 >> 2] | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i8, i10);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i8 + 12 | 0, i9 + (i11 * 24 | 0) + 12 | 0);
      HEAP32[i16 >> 2] = i8 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i1, i33);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i33);
     } else {
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i4, i10);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i4 + 12 | 0, i9 + (i11 * 24 | 0) + 12 | 0);
      HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
     }
     i11 = i11 + 1 | 0;
    }
   } while (0);
   while (1) {
    if (i1 >>> 0 >= i3 >>> 0) break;
    i11 = HEAP8[i25 >> 0] | 0;
    if ((i11 << 24 >> 24 < 0 ? HEAP32[i26 >> 2] | 0 : i11 & 255) >>> 0 > 1) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i34, 57598) | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i24, (HEAP32[i35 >> 2] | 0) + (i1 * 24 | 0) | 0);
    i11 = HEAP8[i17 >> 0] | 0;
    i10 = i11 << 24 >> 24 < 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i34, i10 ? HEAP32[i24 >> 2] | 0 : i24, i10 ? HEAP32[i18 >> 2] | 0 : i11 & 255) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i24);
    i1 = i1 + 1 | 0;
   }
   while (1) {
    if ((i3 | 0) == (i12 | 0)) {
     i1 = i13;
     continue L10;
    }
    i2 = HEAP32[i30 >> 2] | 0;
    i1 = i2 + -24 | 0;
    while (1) {
     if ((i2 | 0) == (i1 | 0)) break;
     i11 = i2 + -24 | 0;
     HEAP32[i30 >> 2] = i11;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i11);
     i2 = HEAP32[i30 >> 2] | 0;
    }
    i3 = i3 + -1 | 0;
   }
  }
  if ((i2 | 0) == 13) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i22); else if ((i2 | 0) == 26) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i1); else if ((i2 | 0) == 34) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i1); else if ((i2 | 0) == 48) {
   i6 = i1 + 1 | 0;
   i29 = HEAP8[i25 >> 0] | 0;
   i28 = i29 << 24 >> 24 < 0;
   if ((HEAP8[(i28 ? HEAP32[i34 >> 2] | 0 : i34) + (i28 ? HEAP32[i26 >> 2] | 0 : i29 & 255) + -1 >> 0] | 0) == 62) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i34, 57601) | 0; else __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i34, 57011) | 0;
   HEAP32[i32 >> 2] = HEAP32[i34 >> 2];
   HEAP32[i32 + 4 >> 2] = HEAP32[i34 + 4 >> 2];
   HEAP32[i32 + 8 >> 2] = HEAP32[i34 + 8 >> 2];
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break;
    HEAP32[i34 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i31, i32);
   i1 = HEAP32[i30 >> 2] | 0;
   i29 = HEAP32[i35 + 8 >> 2] | 0;
   i4 = i29;
   if (i1 >>> 0 < i29 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i1, i31);
    HEAP32[i30 >> 2] = (HEAP32[i30 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i35 >> 2] | 0;
    i5 = (i1 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i35);
    i1 = (i4 - i2 | 0) / 24 | 0;
    if (i1 >>> 0 < 89478485) {
     i1 = i1 << 1;
     i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
    } else i1 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i33, i1, i5, i35 + 12 | 0);
    i30 = i33 + 8 | 0;
    i29 = HEAP32[i30 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i29, i31);
    HEAP32[i30 >> 2] = i29 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i35, i33);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i33);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i31);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i32);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i34);
   break;
  } else if ((i2 | 0) == 62) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i34);
   i6 = i29;
   break;
  }
 } else i6 = i29; while (0);
 STACKTOP = i36;
 return i6 | 0;
}

function __ZN4wasm10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE4scanEPS4_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 252, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 253, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 254, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 255, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 256, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 257, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 258, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 259, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i1 + 16 | 0, 260, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 261, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 262, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 263, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i1 + 16 | 0, 264, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 265, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 266, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 267, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 268, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 269, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 251, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i1 + 16 | 0, 270, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i1 + 16 | 0, 271, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE4scanEPS4_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 231, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 232, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 233, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 234, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 235, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 236, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 237, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 238, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i1 + 16 | 0, 239, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 240, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 241, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 242, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i1 + 16 | 0, 243, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 244, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 245, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 246, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 247, i2);
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 248, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i4, 230, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i1 + 16 | 0, 249, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i1 + 16 | 0, 250, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm16PrintSExpression11visitBinaryEPNS_6BinaryE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i2 >> 2] | 0, 40) | 0;
 __Z12prepareColorRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE(HEAP32[i2 >> 2] | 0) | 0;
 do switch (HEAP32[i1 + 8 >> 2] | 0) {
 case 0:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35438) | 0;
   break;
  }
 case 1:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35446) | 0;
   break;
  }
 case 2:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35454) | 0;
   break;
  }
 case 3:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35462) | 0;
   break;
  }
 case 4:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35472) | 0;
   break;
  }
 case 5:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35482) | 0;
   break;
  }
 case 6:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35492) | 0;
   break;
  }
 case 7:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35502) | 0;
   break;
  }
 case 8:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35510) | 0;
   break;
  }
 case 9:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35517) | 0;
   break;
  }
 case 10:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35525) | 0;
   break;
  }
 case 11:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35533) | 0;
   break;
  }
 case 12:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35543) | 0;
   break;
  }
 case 13:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35553) | 0;
   break;
  }
 case 14:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35562) | 0;
   break;
  }
 case 15:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35571) | 0;
   break;
  }
 case 16:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35578) | 0;
   break;
  }
 case 17:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35585) | 0;
   break;
  }
 case 18:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35594) | 0;
   break;
  }
 case 19:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35603) | 0;
   break;
  }
 case 20:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35612) | 0;
   break;
  }
 case 21:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35621) | 0;
   break;
  }
 case 22:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35630) | 0;
   break;
  }
 case 23:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35639) | 0;
   break;
  }
 case 24:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35648) | 0;
   break;
  }
 case 25:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35657) | 0;
   break;
  }
 case 26:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35665) | 0;
   break;
  }
 case 27:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35673) | 0;
   break;
  }
 case 28:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35681) | 0;
   break;
  }
 case 29:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35691) | 0;
   break;
  }
 case 30:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35701) | 0;
   break;
  }
 case 31:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35711) | 0;
   break;
  }
 case 32:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35721) | 0;
   break;
  }
 case 33:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35729) | 0;
   break;
  }
 case 34:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35736) | 0;
   break;
  }
 case 35:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35744) | 0;
   break;
  }
 case 36:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35752) | 0;
   break;
  }
 case 37:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35762) | 0;
   break;
  }
 case 38:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35772) | 0;
   break;
  }
 case 39:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35781) | 0;
   break;
  }
 case 40:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35790) | 0;
   break;
  }
 case 41:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35797) | 0;
   break;
  }
 case 42:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35804) | 0;
   break;
  }
 case 43:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35813) | 0;
   break;
  }
 case 44:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35822) | 0;
   break;
  }
 case 45:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35831) | 0;
   break;
  }
 case 46:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35840) | 0;
   break;
  }
 case 47:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35849) | 0;
   break;
  }
 case 48:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35858) | 0;
   break;
  }
 case 49:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35867) | 0;
   break;
  }
 case 50:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35876) | 0;
   break;
  }
 case 51:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35884) | 0;
   break;
  }
 case 52:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35892) | 0;
   break;
  }
 case 53:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35900) | 0;
   break;
  }
 case 54:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35908) | 0;
   break;
  }
 case 55:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35921) | 0;
   break;
  }
 case 56:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35929) | 0;
   break;
  }
 case 57:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35937) | 0;
   break;
  }
 case 58:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35944) | 0;
   break;
  }
 case 59:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35951) | 0;
   break;
  }
 case 60:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35958) | 0;
   break;
  }
 case 61:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35965) | 0;
   break;
  }
 case 62:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35972) | 0;
   break;
  }
 case 63:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35979) | 0;
   break;
  }
 case 64:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35987) | 0;
   break;
  }
 case 65:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35995) | 0;
   break;
  }
 case 66:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36003) | 0;
   break;
  }
 case 67:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36011) | 0;
   break;
  }
 case 68:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36024) | 0;
   break;
  }
 case 69:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36032) | 0;
   break;
  }
 case 70:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36040) | 0;
   break;
  }
 case 71:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36047) | 0;
   break;
  }
 case 72:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36054) | 0;
   break;
  }
 case 73:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36061) | 0;
   break;
  }
 case 74:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36068) | 0;
   break;
  }
 case 75:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 36075) | 0;
   break;
  }
 default:
  _abort();
 } while (0);
 __ZN4wasm16PrintSExpression9incIndentEv(i2);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i2, HEAP32[i1 + 12 >> 2] | 0);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i2, HEAP32[i1 + 16 >> 2] | 0);
 __ZN4wasm16PrintSExpression9decIndentEv(i2);
 return;
}

function __ZN4wasm10PostWalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE4scanEPS4_PPNS_10ExpressionE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = HEAP32[i1 >> 2] | 0;
 L1 : do switch (HEAP32[i4 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 405, i1);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i4) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 406, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 407, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i4) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 408, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 409, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 32 | 0);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 410, i1);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 411, i1);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 412, i1);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 413, i1);
   break;
  }
 case 10:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 414, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 415, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 416, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 24 | 0);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 417, i1);
   break;
  }
 case 14:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 418, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 419, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 420, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 421, i1);
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 422, i1);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i4) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 404, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 423, i1);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i5, 424, i1);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc(i41, i35, i36, i39, i37, i40, i38, i1) {
 i41 = i41 | 0;
 i35 = i35 | 0;
 i36 = i36 | 0;
 i39 = i39 | 0;
 i37 = i37 | 0;
 i40 = i40 | 0;
 i38 = i38 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i42 = 0, i43 = 0, i44 = 0;
 i42 = STACKTOP;
 STACKTOP = STACKTOP + 144 | 0;
 i2 = i42 + 132 | 0;
 i1 = i42 + 116 | 0;
 i28 = i42 + 128 | 0;
 i13 = i42 + 124 | 0;
 i24 = i42 + 120 | 0;
 i29 = i42 + 112 | 0;
 i30 = i42 + 108 | 0;
 i31 = i42 + 104 | 0;
 i32 = i42 + 100 | 0;
 i33 = i42 + 96 | 0;
 i34 = i42 + 92 | 0;
 i3 = i42 + 88 | 0;
 i4 = i42 + 84 | 0;
 i5 = i42 + 80 | 0;
 i6 = i42 + 76 | 0;
 i7 = i42 + 72 | 0;
 i8 = i42 + 68 | 0;
 i9 = i42 + 64 | 0;
 i10 = i42 + 60 | 0;
 i11 = i42 + 56 | 0;
 i12 = i42 + 52 | 0;
 i14 = i42 + 48 | 0;
 i15 = i42 + 44 | 0;
 i16 = i42 + 40 | 0;
 i17 = i42 + 36 | 0;
 i18 = i42 + 32 | 0;
 i19 = i42 + 28 | 0;
 i20 = i42 + 24 | 0;
 i21 = i42 + 20 | 0;
 i22 = i42 + 16 | 0;
 i23 = i42 + 12 | 0;
 i25 = i42 + 8 | 0;
 i26 = i42 + 4 | 0;
 i27 = i42;
 HEAP32[i37 >> 2] = 0;
 i44 = __ZNKSt3__28ios_base6getlocEv(i39) | 0;
 HEAP32[i28 >> 2] = i44;
 i28 = __ZNKSt3__26locale9use_facetERNS0_2idE(i28, 61712) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i44) | 0;
 do switch (i38 << 24 >> 24 | 0) {
 case 65:
 case 97:
  {
   HEAP32[i13 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i13 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 24 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 104:
 case 66:
 case 98:
  {
   HEAP32[i24 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i24 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 16 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 99:
  {
   i38 = i41 + 8 | 0;
   i38 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i38 >> 2] | 0) + 12 >> 2] & 255](i38) | 0;
   HEAP32[i29 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i30 >> 2] = HEAP32[i36 >> 2];
   i43 = HEAP8[i38 + 8 + 3 >> 0] | 0;
   i36 = i43 << 24 >> 24 < 0;
   i44 = i36 ? HEAP32[i38 >> 2] | 0 : i38;
   i43 = i44 + ((i36 ? HEAP32[i38 + 4 >> 2] | 0 : i43 & 255) << 2) | 0;
   HEAP32[i1 >> 2] = HEAP32[i29 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i30 >> 2];
   i43 = __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i41, i1, i2, i39, i37, i40, i44, i43) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 101:
 case 100:
  {
   HEAP32[i31 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i31 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 12 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 68:
  {
   HEAP32[i32 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i33 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i32 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i33 >> 2];
   i43 = __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i41, i1, i2, i39, i37, i40, 13068, 13100) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 70:
  {
   HEAP32[i34 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i3 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i34 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
   i43 = __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i41, i1, i2, i39, i37, i40, 13100, 13132) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 72:
  {
   HEAP32[i4 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 8 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 73:
  {
   HEAP32[i5 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i5 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 8 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 106:
  {
   HEAP32[i6 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i6 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 28 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 109:
  {
   HEAP32[i7 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i7 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 16 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 77:
  {
   HEAP32[i8 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 4 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 116:
 case 110:
  {
   HEAP32[i9 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i9 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE(i41, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 112:
  {
   HEAP32[i10 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i10 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 8 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 114:
  {
   HEAP32[i11 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i12 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i12 >> 2];
   i43 = __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i41, i1, i2, i39, i37, i40, 13132, 13176) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 82:
  {
   HEAP32[i14 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i15 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i14 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i15 >> 2];
   i43 = __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i41, i1, i2, i39, i37, i40, 13176, 13196) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 83:
  {
   HEAP32[i16 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i16 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 84:
  {
   HEAP32[i17 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i18 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i17 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i18 >> 2];
   i43 = __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i41, i1, i2, i39, i37, i40, 13196, 13228) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 119:
  {
   HEAP32[i19 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i19 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 24 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 120:
  {
   i44 = HEAP32[(HEAP32[i41 >> 2] | 0) + 20 >> 2] | 0;
   HEAP32[i20 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i21 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i20 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i21 >> 2];
   i1 = FUNCTION_TABLE_iiiiiii[i44 & 63](i41, i1, i2, i39, i37, i40) | 0;
   break;
  }
 case 88:
  {
   i38 = i41 + 8 | 0;
   i38 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i38 >> 2] | 0) + 24 >> 2] & 255](i38) | 0;
   HEAP32[i22 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i23 >> 2] = HEAP32[i36 >> 2];
   i43 = HEAP8[i38 + 8 + 3 >> 0] | 0;
   i36 = i43 << 24 >> 24 < 0;
   i44 = i36 ? HEAP32[i38 >> 2] | 0 : i38;
   i43 = i44 + ((i36 ? HEAP32[i38 + 4 >> 2] | 0 : i43 & 255) << 2) | 0;
   HEAP32[i1 >> 2] = HEAP32[i22 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i23 >> 2];
   i43 = __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i41, i1, i2, i39, i37, i40, i44, i43) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 121:
  {
   HEAP32[i25 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i25 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 20 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 89:
  {
   HEAP32[i26 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i26 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE(i41, i40 + 20 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 37:
  {
   HEAP32[i27 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i27 >> 2];
   __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE(i41, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 default:
  {
   HEAP32[i37 >> 2] = HEAP32[i37 >> 2] | 4;
   i43 = 26;
  }
 } while (0);
 if ((i43 | 0) == 26) i1 = HEAP32[i35 >> 2] | 0;
 STACKTOP = i42;
 return i1 | 0;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc(i41, i35, i36, i39, i37, i40, i38, i1) {
 i41 = i41 | 0;
 i35 = i35 | 0;
 i36 = i36 | 0;
 i39 = i39 | 0;
 i37 = i37 | 0;
 i40 = i40 | 0;
 i38 = i38 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i42 = 0, i43 = 0, i44 = 0;
 i42 = STACKTOP;
 STACKTOP = STACKTOP + 144 | 0;
 i2 = i42 + 132 | 0;
 i1 = i42 + 116 | 0;
 i28 = i42 + 128 | 0;
 i13 = i42 + 124 | 0;
 i24 = i42 + 120 | 0;
 i29 = i42 + 112 | 0;
 i30 = i42 + 108 | 0;
 i31 = i42 + 104 | 0;
 i32 = i42 + 100 | 0;
 i33 = i42 + 96 | 0;
 i34 = i42 + 92 | 0;
 i3 = i42 + 88 | 0;
 i4 = i42 + 84 | 0;
 i5 = i42 + 80 | 0;
 i6 = i42 + 76 | 0;
 i7 = i42 + 72 | 0;
 i8 = i42 + 68 | 0;
 i9 = i42 + 64 | 0;
 i10 = i42 + 60 | 0;
 i11 = i42 + 56 | 0;
 i12 = i42 + 52 | 0;
 i14 = i42 + 48 | 0;
 i15 = i42 + 44 | 0;
 i16 = i42 + 40 | 0;
 i17 = i42 + 36 | 0;
 i18 = i42 + 32 | 0;
 i19 = i42 + 28 | 0;
 i20 = i42 + 24 | 0;
 i21 = i42 + 20 | 0;
 i22 = i42 + 16 | 0;
 i23 = i42 + 12 | 0;
 i25 = i42 + 8 | 0;
 i26 = i42 + 4 | 0;
 i27 = i42;
 HEAP32[i37 >> 2] = 0;
 i44 = __ZNKSt3__28ios_base6getlocEv(i39) | 0;
 HEAP32[i28 >> 2] = i44;
 i28 = __ZNKSt3__26locale9use_facetERNS0_2idE(i28, 61680) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i44) | 0;
 do switch (i38 << 24 >> 24 | 0) {
 case 65:
 case 97:
  {
   HEAP32[i13 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i13 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 24 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 104:
 case 66:
 case 98:
  {
   HEAP32[i24 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i24 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 16 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 99:
  {
   i38 = i41 + 8 | 0;
   i38 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i38 >> 2] | 0) + 12 >> 2] & 255](i38) | 0;
   HEAP32[i29 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i30 >> 2] = HEAP32[i36 >> 2];
   i43 = HEAP8[i38 + 11 >> 0] | 0;
   i36 = i43 << 24 >> 24 < 0;
   i44 = i36 ? HEAP32[i38 >> 2] | 0 : i38;
   i43 = i44 + (i36 ? HEAP32[i38 + 4 >> 2] | 0 : i43 & 255) | 0;
   HEAP32[i1 >> 2] = HEAP32[i29 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i30 >> 2];
   i43 = __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i41, i1, i2, i39, i37, i40, i44, i43) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 101:
 case 100:
  {
   HEAP32[i31 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i31 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 12 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 68:
  {
   HEAP32[i32 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i33 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i32 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i33 >> 2];
   i43 = __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i41, i1, i2, i39, i37, i40, 53723, 53731) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 70:
  {
   HEAP32[i34 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i3 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i34 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
   i43 = __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i41, i1, i2, i39, i37, i40, 53731, 53739) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 72:
  {
   HEAP32[i4 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 8 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 73:
  {
   HEAP32[i5 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i5 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 8 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 106:
  {
   HEAP32[i6 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i6 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 28 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 109:
  {
   HEAP32[i7 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i7 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 16 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 77:
  {
   HEAP32[i8 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 4 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 116:
 case 110:
  {
   HEAP32[i9 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i9 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE(i41, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 112:
  {
   HEAP32[i10 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i10 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 8 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 114:
  {
   HEAP32[i11 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i12 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i12 >> 2];
   i43 = __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i41, i1, i2, i39, i37, i40, 53739, 53750) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 82:
  {
   HEAP32[i14 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i15 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i14 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i15 >> 2];
   i43 = __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i41, i1, i2, i39, i37, i40, 53750, 53755) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 83:
  {
   HEAP32[i16 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i16 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 84:
  {
   HEAP32[i17 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i18 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i17 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i18 >> 2];
   i43 = __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i41, i1, i2, i39, i37, i40, 53755, 53763) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 119:
  {
   HEAP32[i19 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i19 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 24 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 120:
  {
   i44 = HEAP32[(HEAP32[i41 >> 2] | 0) + 20 >> 2] | 0;
   HEAP32[i20 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i21 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i20 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i21 >> 2];
   i1 = FUNCTION_TABLE_iiiiiii[i44 & 63](i41, i1, i2, i39, i37, i40) | 0;
   break;
  }
 case 88:
  {
   i38 = i41 + 8 | 0;
   i38 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i38 >> 2] | 0) + 24 >> 2] & 255](i38) | 0;
   HEAP32[i22 >> 2] = HEAP32[i35 >> 2];
   HEAP32[i23 >> 2] = HEAP32[i36 >> 2];
   i43 = HEAP8[i38 + 11 >> 0] | 0;
   i36 = i43 << 24 >> 24 < 0;
   i44 = i36 ? HEAP32[i38 >> 2] | 0 : i38;
   i43 = i44 + (i36 ? HEAP32[i38 + 4 >> 2] | 0 : i43 & 255) | 0;
   HEAP32[i1 >> 2] = HEAP32[i22 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i23 >> 2];
   i43 = __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i41, i1, i2, i39, i37, i40, i44, i43) | 0;
   HEAP32[i35 >> 2] = i43;
   i43 = 26;
   break;
  }
 case 121:
  {
   HEAP32[i25 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i25 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 20 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 89:
  {
   HEAP32[i26 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i26 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE(i41, i40 + 20 | 0, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 case 37:
  {
   HEAP32[i27 >> 2] = HEAP32[i36 >> 2];
   HEAP32[i2 >> 2] = HEAP32[i27 >> 2];
   __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE(i41, i35, i2, i37, i28);
   i43 = 26;
   break;
  }
 default:
  {
   HEAP32[i37 >> 2] = HEAP32[i37 >> 2] | 4;
   i43 = 26;
  }
 } while (0);
 if ((i43 | 0) == 26) i1 = HEAP32[i35 >> 2] | 0;
 STACKTOP = i42;
 return i1 | 0;
}

function _free(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 if (!i1) return;
 i3 = i1 + -8 | 0;
 i7 = HEAP32[15038] | 0;
 if (i3 >>> 0 < i7 >>> 0) _abort();
 i1 = HEAP32[i1 + -4 >> 2] | 0;
 i2 = i1 & 3;
 if ((i2 | 0) == 1) _abort();
 i4 = i1 & -8;
 i12 = i3 + i4 | 0;
 do if (!(i1 & 1)) {
  i1 = HEAP32[i3 >> 2] | 0;
  if (!i2) return;
  i10 = i3 + (0 - i1) | 0;
  i9 = i1 + i4 | 0;
  if (i10 >>> 0 < i7 >>> 0) _abort();
  if ((i10 | 0) == (HEAP32[15039] | 0)) {
   i1 = i12 + 4 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if ((i2 & 3 | 0) != 3) {
    i16 = i10;
    i6 = i9;
    break;
   }
   HEAP32[15036] = i9;
   HEAP32[i1 >> 2] = i2 & -2;
   HEAP32[i10 + 4 >> 2] = i9 | 1;
   HEAP32[i10 + i9 >> 2] = i9;
   return;
  }
  i4 = i1 >>> 3;
  if (i1 >>> 0 < 256) {
   i2 = HEAP32[i10 + 8 >> 2] | 0;
   i3 = HEAP32[i10 + 12 >> 2] | 0;
   i1 = 60176 + (i4 << 1 << 2) | 0;
   if ((i2 | 0) != (i1 | 0)) {
    if (i2 >>> 0 < i7 >>> 0) _abort();
    if ((HEAP32[i2 + 12 >> 2] | 0) != (i10 | 0)) _abort();
   }
   if ((i3 | 0) == (i2 | 0)) {
    HEAP32[15034] = HEAP32[15034] & ~(1 << i4);
    i16 = i10;
    i6 = i9;
    break;
   }
   if ((i3 | 0) != (i1 | 0)) {
    if (i3 >>> 0 < i7 >>> 0) _abort();
    i1 = i3 + 8 | 0;
    if ((HEAP32[i1 >> 2] | 0) == (i10 | 0)) i5 = i1; else _abort();
   } else i5 = i3 + 8 | 0;
   HEAP32[i2 + 12 >> 2] = i3;
   HEAP32[i5 >> 2] = i2;
   i16 = i10;
   i6 = i9;
   break;
  }
  i5 = HEAP32[i10 + 24 >> 2] | 0;
  i3 = HEAP32[i10 + 12 >> 2] | 0;
  do if ((i3 | 0) == (i10 | 0)) {
   i2 = i10 + 16 | 0;
   i3 = i2 + 4 | 0;
   i1 = HEAP32[i3 >> 2] | 0;
   if (!i1) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i8 = 0;
     break;
    }
   } else i2 = i3;
   while (1) {
    i3 = i1 + 20 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if (i4 | 0) {
     i1 = i4;
     i2 = i3;
     continue;
    }
    i3 = i1 + 16 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if (!i4) break; else {
     i1 = i4;
     i2 = i3;
    }
   }
   if (i2 >>> 0 < i7 >>> 0) _abort(); else {
    HEAP32[i2 >> 2] = 0;
    i8 = i1;
    break;
   }
  } else {
   i4 = HEAP32[i10 + 8 >> 2] | 0;
   if (i4 >>> 0 < i7 >>> 0) _abort();
   i1 = i4 + 12 | 0;
   if ((HEAP32[i1 >> 2] | 0) != (i10 | 0)) _abort();
   i2 = i3 + 8 | 0;
   if ((HEAP32[i2 >> 2] | 0) == (i10 | 0)) {
    HEAP32[i1 >> 2] = i3;
    HEAP32[i2 >> 2] = i4;
    i8 = i3;
    break;
   } else _abort();
  } while (0);
  if (i5) {
   i1 = HEAP32[i10 + 28 >> 2] | 0;
   i2 = 60440 + (i1 << 2) | 0;
   if ((i10 | 0) == (HEAP32[i2 >> 2] | 0)) {
    HEAP32[i2 >> 2] = i8;
    if (!i8) {
     HEAP32[15035] = HEAP32[15035] & ~(1 << i1);
     i16 = i10;
     i6 = i9;
     break;
    }
   } else {
    if (i5 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
    i1 = i5 + 16 | 0;
    if ((HEAP32[i1 >> 2] | 0) == (i10 | 0)) HEAP32[i1 >> 2] = i8; else HEAP32[i5 + 20 >> 2] = i8;
    if (!i8) {
     i16 = i10;
     i6 = i9;
     break;
    }
   }
   i3 = HEAP32[15038] | 0;
   if (i8 >>> 0 < i3 >>> 0) _abort();
   HEAP32[i8 + 24 >> 2] = i5;
   i1 = i10 + 16 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   do if (i2 | 0) if (i2 >>> 0 < i3 >>> 0) _abort(); else {
    HEAP32[i8 + 16 >> 2] = i2;
    HEAP32[i2 + 24 >> 2] = i8;
    break;
   } while (0);
   i1 = HEAP32[i1 + 4 >> 2] | 0;
   if (i1) if (i1 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
    HEAP32[i8 + 20 >> 2] = i1;
    HEAP32[i1 + 24 >> 2] = i8;
    i16 = i10;
    i6 = i9;
    break;
   } else {
    i16 = i10;
    i6 = i9;
   }
  } else {
   i16 = i10;
   i6 = i9;
  }
 } else {
  i16 = i3;
  i6 = i4;
 } while (0);
 if (i16 >>> 0 >= i12 >>> 0) _abort();
 i1 = i12 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if (!(i2 & 1)) _abort();
 if (!(i2 & 2)) {
  if ((i12 | 0) == (HEAP32[15040] | 0)) {
   i15 = (HEAP32[15037] | 0) + i6 | 0;
   HEAP32[15037] = i15;
   HEAP32[15040] = i16;
   HEAP32[i16 + 4 >> 2] = i15 | 1;
   if ((i16 | 0) != (HEAP32[15039] | 0)) return;
   HEAP32[15039] = 0;
   HEAP32[15036] = 0;
   return;
  }
  if ((i12 | 0) == (HEAP32[15039] | 0)) {
   i15 = (HEAP32[15036] | 0) + i6 | 0;
   HEAP32[15036] = i15;
   HEAP32[15039] = i16;
   HEAP32[i16 + 4 >> 2] = i15 | 1;
   HEAP32[i16 + i15 >> 2] = i15;
   return;
  }
  i6 = (i2 & -8) + i6 | 0;
  i4 = i2 >>> 3;
  do if (i2 >>> 0 >= 256) {
   i5 = HEAP32[i12 + 24 >> 2] | 0;
   i1 = HEAP32[i12 + 12 >> 2] | 0;
   do if ((i1 | 0) == (i12 | 0)) {
    i2 = i12 + 16 | 0;
    i3 = i2 + 4 | 0;
    i1 = HEAP32[i3 >> 2] | 0;
    if (!i1) {
     i1 = HEAP32[i2 >> 2] | 0;
     if (!i1) {
      i13 = 0;
      break;
     }
    } else i2 = i3;
    while (1) {
     i3 = i1 + 20 | 0;
     i4 = HEAP32[i3 >> 2] | 0;
     if (i4 | 0) {
      i1 = i4;
      i2 = i3;
      continue;
     }
     i3 = i1 + 16 | 0;
     i4 = HEAP32[i3 >> 2] | 0;
     if (!i4) break; else {
      i1 = i4;
      i2 = i3;
     }
    }
    if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
     HEAP32[i2 >> 2] = 0;
     i13 = i1;
     break;
    }
   } else {
    i2 = HEAP32[i12 + 8 >> 2] | 0;
    if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
    i3 = i2 + 12 | 0;
    if ((HEAP32[i3 >> 2] | 0) != (i12 | 0)) _abort();
    i4 = i1 + 8 | 0;
    if ((HEAP32[i4 >> 2] | 0) == (i12 | 0)) {
     HEAP32[i3 >> 2] = i1;
     HEAP32[i4 >> 2] = i2;
     i13 = i1;
     break;
    } else _abort();
   } while (0);
   if (i5 | 0) {
    i1 = HEAP32[i12 + 28 >> 2] | 0;
    i2 = 60440 + (i1 << 2) | 0;
    if ((i12 | 0) == (HEAP32[i2 >> 2] | 0)) {
     HEAP32[i2 >> 2] = i13;
     if (!i13) {
      HEAP32[15035] = HEAP32[15035] & ~(1 << i1);
      break;
     }
    } else {
     if (i5 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
     i1 = i5 + 16 | 0;
     if ((HEAP32[i1 >> 2] | 0) == (i12 | 0)) HEAP32[i1 >> 2] = i13; else HEAP32[i5 + 20 >> 2] = i13;
     if (!i13) break;
    }
    i3 = HEAP32[15038] | 0;
    if (i13 >>> 0 < i3 >>> 0) _abort();
    HEAP32[i13 + 24 >> 2] = i5;
    i1 = i12 + 16 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    do if (i2 | 0) if (i2 >>> 0 < i3 >>> 0) _abort(); else {
     HEAP32[i13 + 16 >> 2] = i2;
     HEAP32[i2 + 24 >> 2] = i13;
     break;
    } while (0);
    i1 = HEAP32[i1 + 4 >> 2] | 0;
    if (i1 | 0) if (i1 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
     HEAP32[i13 + 20 >> 2] = i1;
     HEAP32[i1 + 24 >> 2] = i13;
     break;
    }
   }
  } else {
   i2 = HEAP32[i12 + 8 >> 2] | 0;
   i3 = HEAP32[i12 + 12 >> 2] | 0;
   i1 = 60176 + (i4 << 1 << 2) | 0;
   if ((i2 | 0) != (i1 | 0)) {
    if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
    if ((HEAP32[i2 + 12 >> 2] | 0) != (i12 | 0)) _abort();
   }
   if ((i3 | 0) == (i2 | 0)) {
    HEAP32[15034] = HEAP32[15034] & ~(1 << i4);
    break;
   }
   if ((i3 | 0) != (i1 | 0)) {
    if (i3 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
    i1 = i3 + 8 | 0;
    if ((HEAP32[i1 >> 2] | 0) == (i12 | 0)) i11 = i1; else _abort();
   } else i11 = i3 + 8 | 0;
   HEAP32[i2 + 12 >> 2] = i3;
   HEAP32[i11 >> 2] = i2;
  } while (0);
  HEAP32[i16 + 4 >> 2] = i6 | 1;
  HEAP32[i16 + i6 >> 2] = i6;
  if ((i16 | 0) == (HEAP32[15039] | 0)) {
   HEAP32[15036] = i6;
   return;
  }
 } else {
  HEAP32[i1 >> 2] = i2 & -2;
  HEAP32[i16 + 4 >> 2] = i6 | 1;
  HEAP32[i16 + i6 >> 2] = i6;
 }
 i1 = i6 >>> 3;
 if (i6 >>> 0 < 256) {
  i3 = 60176 + (i1 << 1 << 2) | 0;
  i2 = HEAP32[15034] | 0;
  i1 = 1 << i1;
  if (i2 & i1) {
   i1 = i3 + 8 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
    i14 = i1;
    i15 = i2;
   }
  } else {
   HEAP32[15034] = i2 | i1;
   i14 = i3 + 8 | 0;
   i15 = i3;
  }
  HEAP32[i14 >> 2] = i16;
  HEAP32[i15 + 12 >> 2] = i16;
  HEAP32[i16 + 8 >> 2] = i15;
  HEAP32[i16 + 12 >> 2] = i3;
  return;
 }
 i1 = i6 >>> 8;
 if (i1) if (i6 >>> 0 > 16777215) i3 = 31; else {
  i14 = (i1 + 1048320 | 0) >>> 16 & 8;
  i15 = i1 << i14;
  i13 = (i15 + 520192 | 0) >>> 16 & 4;
  i15 = i15 << i13;
  i3 = (i15 + 245760 | 0) >>> 16 & 2;
  i3 = 14 - (i13 | i14 | i3) + (i15 << i3 >>> 15) | 0;
  i3 = i6 >>> (i3 + 7 | 0) & 1 | i3 << 1;
 } else i3 = 0;
 i4 = 60440 + (i3 << 2) | 0;
 HEAP32[i16 + 28 >> 2] = i3;
 HEAP32[i16 + 20 >> 2] = 0;
 HEAP32[i16 + 16 >> 2] = 0;
 i1 = HEAP32[15035] | 0;
 i2 = 1 << i3;
 do if (i1 & i2) {
  i5 = i6 << ((i3 | 0) == 31 ? 0 : 25 - (i3 >>> 1) | 0);
  i1 = HEAP32[i4 >> 2] | 0;
  while (1) {
   if ((HEAP32[i1 + 4 >> 2] & -8 | 0) == (i6 | 0)) {
    i3 = i1;
    i4 = 130;
    break;
   }
   i2 = i1 + 16 + (i5 >>> 31 << 2) | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   if (!i3) {
    i4 = 127;
    break;
   } else {
    i5 = i5 << 1;
    i1 = i3;
   }
  }
  if ((i4 | 0) == 127) if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
   HEAP32[i2 >> 2] = i16;
   HEAP32[i16 + 24 >> 2] = i1;
   HEAP32[i16 + 12 >> 2] = i16;
   HEAP32[i16 + 8 >> 2] = i16;
   break;
  } else if ((i4 | 0) == 130) {
   i1 = i3 + 8 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   i15 = HEAP32[15038] | 0;
   if (i2 >>> 0 >= i15 >>> 0 & i3 >>> 0 >= i15 >>> 0) {
    HEAP32[i2 + 12 >> 2] = i16;
    HEAP32[i1 >> 2] = i16;
    HEAP32[i16 + 8 >> 2] = i2;
    HEAP32[i16 + 12 >> 2] = i3;
    HEAP32[i16 + 24 >> 2] = 0;
    break;
   } else _abort();
  }
 } else {
  HEAP32[15035] = i1 | i2;
  HEAP32[i4 >> 2] = i16;
  HEAP32[i16 + 24 >> 2] = i4;
  HEAP32[i16 + 12 >> 2] = i16;
  HEAP32[i16 + 8 >> 2] = i16;
 } while (0);
 i16 = (HEAP32[15042] | 0) + -1 | 0;
 HEAP32[15042] = i16;
 if (!i16) i1 = 60592; else return;
 while (1) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (!i1) break; else i1 = i1 + 8 | 0;
 }
 HEAP32[15042] = -1;
 return;
}

function __ZN4wasm17WasmBinaryBuilder15maybeVisitUnaryERPNS_10ExpressionEh(i4, i3, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i5 = 0, i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i6;
 do switch (i1 & 255 | 0) {
 case 87:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 0;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 114:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 1;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 88:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 2;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 115:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 3;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 89:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 4;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 116:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 5;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 90:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 20;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 186:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 21;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 124:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 6;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 144:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 7;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 123:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 8;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 143:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 9;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 126:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 10;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 146:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 11;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 127:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 12;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 147:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 13;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 129:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 16;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 149:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 17;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 130:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 18;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 150:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 19;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 169:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 37;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 175:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 38;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 168:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 35;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 174:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 36;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 171:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 41;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 177:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 42;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 170:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 39;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 176:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 40;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 166:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 22;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 167:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 23;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 161:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 24;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 159:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 27;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 160:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 31;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 157:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 25;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 158:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 29;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 164:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 28;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 165:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 32;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 162:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 26;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 163:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 30;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 128:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 14;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 148:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 15;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 172:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 44;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 178:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 43;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 case 180:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 33;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 49;
   break;
  }
 case 181:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 34;
   HEAP32[i1 + 4 >> 2] = 2;
   i5 = 49;
   break;
  }
 case 173:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 45;
   HEAP32[i1 + 4 >> 2] = 3;
   i5 = 49;
   break;
  }
 case 179:
  {
   i1 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 46;
   HEAP32[i1 + 4 >> 2] = 4;
   i5 = 49;
   break;
  }
 default:
  i1 = 0;
 } while (0);
 if ((i5 | 0) == 49) {
  if (HEAP8[i4 + 12 >> 0] | 0) {
   i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24662) | 0;
   i7 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i2 >> 2] = i7;
   i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
   i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
   __ZNSt3__26localeD2Ev(i2);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i7) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  }
  i7 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i4) | 0;
  HEAP32[i1 + 12 >> 2] = i7;
  HEAP32[i3 >> 2] = i1;
  i1 = 1;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_120parse_template_paramINS0_2DbEEEPKcS4_S4_RT_(i18, i13, i20) {
 i18 = i18 | 0;
 i13 = i13 | 0;
 i20 = i20 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i19 = 0, i21 = 0;
 i21 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i19 = i21 + 64 | 0;
 i5 = i21 + 40 | 0;
 i16 = i21 + 16 | 0;
 i17 = i21;
 i15 = i18;
 L1 : do if ((i13 - i15 | 0) > 1 ? (HEAP8[i18 >> 0] | 0) == 84 : 0) {
  i12 = HEAP8[i18 + 1 >> 0] | 0;
  if (i12 << 24 >> 24 == 95) {
   i1 = HEAP32[i20 + 36 >> 2] | 0;
   if ((HEAP32[i20 + 32 >> 2] | 0) == (i1 | 0)) {
    i1 = i18;
    break;
   }
   i2 = HEAP32[i1 + -16 >> 2] | 0;
   if ((i2 | 0) != (HEAP32[i1 + -12 >> 2] | 0)) {
    i7 = HEAP32[i2 + 4 >> 2] | 0;
    i8 = i20 + 4 | 0;
    i9 = i20 + 8 | 0;
    i10 = i20 + 12 | 0;
    i11 = i19 + 8 | 0;
    i6 = HEAP32[i2 >> 2] | 0;
    while (1) {
     if ((i6 | 0) == (i7 | 0)) {
      i1 = 8;
      break;
     }
     i1 = HEAP32[i8 >> 2] | 0;
     i5 = HEAP32[i9 >> 2] | 0;
     i2 = i5;
     if ((i1 | 0) == (i5 | 0)) {
      i3 = HEAP32[i20 >> 2] | 0;
      i5 = (i1 - i3 | 0) / 24 | 0;
      i4 = i5 + 1 | 0;
      if (i4 >>> 0 > 178956970) {
       i1 = 12;
       break;
      }
      i1 = (i2 - i3 | 0) / 24 | 0;
      if (i1 >>> 0 < 89478485) {
       i1 = i1 << 1;
       i1 = i1 >>> 0 < i4 >>> 0 ? i4 : i1;
      } else i1 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i19, i1, i5, i10);
      i5 = HEAP32[i11 >> 2] | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i5, i6);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i5 + 12 | 0, i6 + 12 | 0);
      HEAP32[i11 >> 2] = i5 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i20, i19);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i19);
     } else {
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1, i6);
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1 + 12 | 0, i6 + 12 | 0);
      HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + 24;
     }
     i6 = i6 + 24 | 0;
    }
    if ((i1 | 0) == 8) {
     i1 = i18 + 2 | 0;
     break;
    } else if ((i1 | 0) == 12) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i20);
   } else {
    HEAP32[i5 >> 2] = 0;
    HEAP32[i5 + 4 >> 2] = 0;
    HEAP32[i5 + 8 >> 2] = 0;
    HEAP8[i5 + 11 >> 0] = 2;
    HEAP16[i5 >> 1] = 24404;
    HEAP8[i5 + 2 >> 0] = 0;
    i1 = i5 + 12 | 0;
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i1 = i20 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i17 = HEAP32[i20 + 8 >> 2] | 0;
    i3 = i17;
    if (i2 >>> 0 < i17 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i5);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i20 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i20);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i19, i1, i4, i20 + 12 | 0);
     i17 = i19 + 8 | 0;
     i16 = HEAP32[i17 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i16, i5);
     HEAP32[i17 >> 2] = i16 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i20, i19);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i19);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i5);
    HEAP8[i20 + 62 >> 0] = 1;
    i1 = i18 + 2 | 0;
    break;
   }
  }
  i1 = (i12 << 24 >> 24) + -48 | 0;
  if (i1 >>> 0 < 10) {
   i4 = i18 + 2 | 0;
   while (1) {
    if ((i4 | 0) == (i13 | 0)) {
     i1 = i18;
     break L1;
    }
    i2 = HEAP8[i4 >> 0] | 0;
    i3 = (i2 << 24 >> 24) + -48 | 0;
    if (i3 >>> 0 >= 10) break;
    i1 = i3 + (i1 * 10 | 0) | 0;
    i4 = i4 + 1 | 0;
   }
   if (i2 << 24 >> 24 == 95 ? (i14 = HEAP32[i20 + 36 >> 2] | 0, (HEAP32[i20 + 32 >> 2] | 0) != (i14 | 0)) : 0) {
    i1 = i1 + 1 | 0;
    i13 = HEAP32[i14 + -16 >> 2] | 0;
    i2 = i13;
    if (i1 >>> 0 < (HEAP32[i14 + -12 >> 2] | 0) - i13 >> 4 >>> 0) {
     i8 = HEAP32[i2 + (i1 << 4) + 4 >> 2] | 0;
     i9 = i20 + 4 | 0;
     i10 = i20 + 8 | 0;
     i11 = i20 + 12 | 0;
     i12 = i19 + 8 | 0;
     i7 = HEAP32[i2 + (i1 << 4) >> 2] | 0;
     while (1) {
      if ((i7 | 0) == (i8 | 0)) {
       i1 = 38;
       break;
      }
      i1 = HEAP32[i9 >> 2] | 0;
      i14 = HEAP32[i10 >> 2] | 0;
      i2 = i14;
      if ((i1 | 0) == (i14 | 0)) {
       i3 = HEAP32[i20 >> 2] | 0;
       i6 = (i1 - i3 | 0) / 24 | 0;
       i5 = i6 + 1 | 0;
       if (i5 >>> 0 > 178956970) {
        i1 = 42;
        break;
       }
       i1 = (i2 - i3 | 0) / 24 | 0;
       if (i1 >>> 0 < 89478485) {
        i1 = i1 << 1;
        i1 = i1 >>> 0 < i5 >>> 0 ? i5 : i1;
       } else i1 = 178956970;
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i19, i1, i6, i11);
       i14 = HEAP32[i12 >> 2] | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i14, i7);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i14 + 12 | 0, i7 + 12 | 0);
       HEAP32[i12 >> 2] = i14 + 24;
       __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i20, i19);
       __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i19);
      } else {
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1, i7);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1 + 12 | 0, i7 + 12 | 0);
       HEAP32[i9 >> 2] = (HEAP32[i9 >> 2] | 0) + 24;
      }
      i7 = i7 + 24 | 0;
     }
     if ((i1 | 0) == 38) {
      i1 = i4 + 1 | 0;
      break;
     } else if ((i1 | 0) == 42) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i20);
    }
    i1 = i4 + 1 | 0;
    HEAP32[i17 >> 2] = 0;
    HEAP32[i17 + 4 >> 2] = 0;
    HEAP32[i17 + 8 >> 2] = 0;
    i4 = i1 - i15 | 0;
    if (i4 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i17);
    if (i4 >>> 0 < 11) {
     HEAP8[i17 + 11 >> 0] = i4;
     i5 = i17;
    } else {
     i15 = i4 + 16 & -16;
     i5 = _malloc(i15) | 0;
     HEAP32[i17 >> 2] = i5;
     HEAP32[i17 + 8 >> 2] = i15 | -2147483648;
     HEAP32[i17 + 4 >> 2] = i4;
    }
    i2 = i18;
    i3 = i5;
    while (1) {
     if ((i2 | 0) == (i1 | 0)) break;
     HEAP8[i3 >> 0] = HEAP8[i2 >> 0] | 0;
     i2 = i2 + 1 | 0;
     i3 = i3 + 1 | 0;
    }
    HEAP8[i5 + i4 >> 0] = 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i16, i17);
    i2 = i20 + 4 | 0;
    i3 = HEAP32[i2 >> 2] | 0;
    i18 = HEAP32[i20 + 8 >> 2] | 0;
    i4 = i18;
    if (i3 >>> 0 < i18 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i16);
     HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
    } else {
     i2 = HEAP32[i20 >> 2] | 0;
     i5 = (i3 - i2 | 0) / 24 | 0;
     i3 = i5 + 1 | 0;
     if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i20);
     i2 = (i4 - i2 | 0) / 24 | 0;
     if (i2 >>> 0 < 89478485) {
      i2 = i2 << 1;
      i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
     } else i2 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i19, i2, i5, i20 + 12 | 0);
     i18 = i19 + 8 | 0;
     i15 = HEAP32[i18 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i15, i16);
     HEAP32[i18 >> 2] = i15 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i20, i19);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i19);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i16);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i17);
    HEAP8[i20 + 62 >> 0] = 1;
   } else i1 = i18;
  } else i1 = i18;
 } else i1 = i18; while (0);
 STACKTOP = i21;
 return i1 | 0;
}

function __ZN4wasm10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 186, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 187, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 188, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 189, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 190, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 191, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 192, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 193, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 194, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 195, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 196, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 197, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 198, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 199, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 200, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 201, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 202, i2);
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 203, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 185, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 204, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 205, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function _dispose_chunk(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0;
 i14 = i2 + i3 | 0;
 i1 = HEAP32[i2 + 4 >> 2] | 0;
 do if (!(i1 & 1)) {
  i5 = HEAP32[i2 >> 2] | 0;
  if (!(i1 & 3)) return;
  i11 = i2 + (0 - i5) | 0;
  i10 = i5 + i3 | 0;
  i8 = HEAP32[15038] | 0;
  if (i11 >>> 0 < i8 >>> 0) _abort();
  if ((i11 | 0) == (HEAP32[15039] | 0)) {
   i2 = i14 + 4 | 0;
   i1 = HEAP32[i2 >> 2] | 0;
   if ((i1 & 3 | 0) != 3) {
    i17 = i11;
    i6 = i10;
    break;
   }
   HEAP32[15036] = i10;
   HEAP32[i2 >> 2] = i1 & -2;
   HEAP32[i11 + 4 >> 2] = i10 | 1;
   HEAP32[i11 + i10 >> 2] = i10;
   return;
  }
  i4 = i5 >>> 3;
  if (i5 >>> 0 < 256) {
   i2 = HEAP32[i11 + 8 >> 2] | 0;
   i3 = HEAP32[i11 + 12 >> 2] | 0;
   i1 = 60176 + (i4 << 1 << 2) | 0;
   if ((i2 | 0) != (i1 | 0)) {
    if (i2 >>> 0 < i8 >>> 0) _abort();
    if ((HEAP32[i2 + 12 >> 2] | 0) != (i11 | 0)) _abort();
   }
   if ((i3 | 0) == (i2 | 0)) {
    HEAP32[15034] = HEAP32[15034] & ~(1 << i4);
    i17 = i11;
    i6 = i10;
    break;
   }
   if ((i3 | 0) != (i1 | 0)) {
    if (i3 >>> 0 < i8 >>> 0) _abort();
    i1 = i3 + 8 | 0;
    if ((HEAP32[i1 >> 2] | 0) == (i11 | 0)) i7 = i1; else _abort();
   } else i7 = i3 + 8 | 0;
   HEAP32[i2 + 12 >> 2] = i3;
   HEAP32[i7 >> 2] = i2;
   i17 = i11;
   i6 = i10;
   break;
  }
  i5 = HEAP32[i11 + 24 >> 2] | 0;
  i3 = HEAP32[i11 + 12 >> 2] | 0;
  do if ((i3 | 0) == (i11 | 0)) {
   i2 = i11 + 16 | 0;
   i3 = i2 + 4 | 0;
   i1 = HEAP32[i3 >> 2] | 0;
   if (!i1) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i9 = 0;
     break;
    }
   } else i2 = i3;
   while (1) {
    i3 = i1 + 20 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if (i4 | 0) {
     i1 = i4;
     i2 = i3;
     continue;
    }
    i3 = i1 + 16 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if (!i4) break; else {
     i1 = i4;
     i2 = i3;
    }
   }
   if (i2 >>> 0 < i8 >>> 0) _abort(); else {
    HEAP32[i2 >> 2] = 0;
    i9 = i1;
    break;
   }
  } else {
   i4 = HEAP32[i11 + 8 >> 2] | 0;
   if (i4 >>> 0 < i8 >>> 0) _abort();
   i1 = i4 + 12 | 0;
   if ((HEAP32[i1 >> 2] | 0) != (i11 | 0)) _abort();
   i2 = i3 + 8 | 0;
   if ((HEAP32[i2 >> 2] | 0) == (i11 | 0)) {
    HEAP32[i1 >> 2] = i3;
    HEAP32[i2 >> 2] = i4;
    i9 = i3;
    break;
   } else _abort();
  } while (0);
  if (i5) {
   i1 = HEAP32[i11 + 28 >> 2] | 0;
   i2 = 60440 + (i1 << 2) | 0;
   if ((i11 | 0) == (HEAP32[i2 >> 2] | 0)) {
    HEAP32[i2 >> 2] = i9;
    if (!i9) {
     HEAP32[15035] = HEAP32[15035] & ~(1 << i1);
     i17 = i11;
     i6 = i10;
     break;
    }
   } else {
    if (i5 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
    i1 = i5 + 16 | 0;
    if ((HEAP32[i1 >> 2] | 0) == (i11 | 0)) HEAP32[i1 >> 2] = i9; else HEAP32[i5 + 20 >> 2] = i9;
    if (!i9) {
     i17 = i11;
     i6 = i10;
     break;
    }
   }
   i3 = HEAP32[15038] | 0;
   if (i9 >>> 0 < i3 >>> 0) _abort();
   HEAP32[i9 + 24 >> 2] = i5;
   i1 = i11 + 16 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   do if (i2 | 0) if (i2 >>> 0 < i3 >>> 0) _abort(); else {
    HEAP32[i9 + 16 >> 2] = i2;
    HEAP32[i2 + 24 >> 2] = i9;
    break;
   } while (0);
   i1 = HEAP32[i1 + 4 >> 2] | 0;
   if (i1) if (i1 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
    HEAP32[i9 + 20 >> 2] = i1;
    HEAP32[i1 + 24 >> 2] = i9;
    i17 = i11;
    i6 = i10;
    break;
   } else {
    i17 = i11;
    i6 = i10;
   }
  } else {
   i17 = i11;
   i6 = i10;
  }
 } else {
  i17 = i2;
  i6 = i3;
 } while (0);
 i7 = HEAP32[15038] | 0;
 if (i14 >>> 0 < i7 >>> 0) _abort();
 i1 = i14 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if (!(i2 & 2)) {
  if ((i14 | 0) == (HEAP32[15040] | 0)) {
   i16 = (HEAP32[15037] | 0) + i6 | 0;
   HEAP32[15037] = i16;
   HEAP32[15040] = i17;
   HEAP32[i17 + 4 >> 2] = i16 | 1;
   if ((i17 | 0) != (HEAP32[15039] | 0)) return;
   HEAP32[15039] = 0;
   HEAP32[15036] = 0;
   return;
  }
  if ((i14 | 0) == (HEAP32[15039] | 0)) {
   i16 = (HEAP32[15036] | 0) + i6 | 0;
   HEAP32[15036] = i16;
   HEAP32[15039] = i17;
   HEAP32[i17 + 4 >> 2] = i16 | 1;
   HEAP32[i17 + i16 >> 2] = i16;
   return;
  }
  i6 = (i2 & -8) + i6 | 0;
  i4 = i2 >>> 3;
  do if (i2 >>> 0 >= 256) {
   i5 = HEAP32[i14 + 24 >> 2] | 0;
   i3 = HEAP32[i14 + 12 >> 2] | 0;
   do if ((i3 | 0) == (i14 | 0)) {
    i2 = i14 + 16 | 0;
    i3 = i2 + 4 | 0;
    i1 = HEAP32[i3 >> 2] | 0;
    if (!i1) {
     i1 = HEAP32[i2 >> 2] | 0;
     if (!i1) {
      i13 = 0;
      break;
     }
    } else i2 = i3;
    while (1) {
     i3 = i1 + 20 | 0;
     i4 = HEAP32[i3 >> 2] | 0;
     if (i4 | 0) {
      i1 = i4;
      i2 = i3;
      continue;
     }
     i3 = i1 + 16 | 0;
     i4 = HEAP32[i3 >> 2] | 0;
     if (!i4) break; else {
      i1 = i4;
      i2 = i3;
     }
    }
    if (i2 >>> 0 < i7 >>> 0) _abort(); else {
     HEAP32[i2 >> 2] = 0;
     i13 = i1;
     break;
    }
   } else {
    i4 = HEAP32[i14 + 8 >> 2] | 0;
    if (i4 >>> 0 < i7 >>> 0) _abort();
    i1 = i4 + 12 | 0;
    if ((HEAP32[i1 >> 2] | 0) != (i14 | 0)) _abort();
    i2 = i3 + 8 | 0;
    if ((HEAP32[i2 >> 2] | 0) == (i14 | 0)) {
     HEAP32[i1 >> 2] = i3;
     HEAP32[i2 >> 2] = i4;
     i13 = i3;
     break;
    } else _abort();
   } while (0);
   if (i5 | 0) {
    i1 = HEAP32[i14 + 28 >> 2] | 0;
    i2 = 60440 + (i1 << 2) | 0;
    if ((i14 | 0) == (HEAP32[i2 >> 2] | 0)) {
     HEAP32[i2 >> 2] = i13;
     if (!i13) {
      HEAP32[15035] = HEAP32[15035] & ~(1 << i1);
      break;
     }
    } else {
     if (i5 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
     i1 = i5 + 16 | 0;
     if ((HEAP32[i1 >> 2] | 0) == (i14 | 0)) HEAP32[i1 >> 2] = i13; else HEAP32[i5 + 20 >> 2] = i13;
     if (!i13) break;
    }
    i3 = HEAP32[15038] | 0;
    if (i13 >>> 0 < i3 >>> 0) _abort();
    HEAP32[i13 + 24 >> 2] = i5;
    i1 = i14 + 16 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    do if (i2 | 0) if (i2 >>> 0 < i3 >>> 0) _abort(); else {
     HEAP32[i13 + 16 >> 2] = i2;
     HEAP32[i2 + 24 >> 2] = i13;
     break;
    } while (0);
    i1 = HEAP32[i1 + 4 >> 2] | 0;
    if (i1 | 0) if (i1 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
     HEAP32[i13 + 20 >> 2] = i1;
     HEAP32[i1 + 24 >> 2] = i13;
     break;
    }
   }
  } else {
   i2 = HEAP32[i14 + 8 >> 2] | 0;
   i3 = HEAP32[i14 + 12 >> 2] | 0;
   i1 = 60176 + (i4 << 1 << 2) | 0;
   if ((i2 | 0) != (i1 | 0)) {
    if (i2 >>> 0 < i7 >>> 0) _abort();
    if ((HEAP32[i2 + 12 >> 2] | 0) != (i14 | 0)) _abort();
   }
   if ((i3 | 0) == (i2 | 0)) {
    HEAP32[15034] = HEAP32[15034] & ~(1 << i4);
    break;
   }
   if ((i3 | 0) != (i1 | 0)) {
    if (i3 >>> 0 < i7 >>> 0) _abort();
    i1 = i3 + 8 | 0;
    if ((HEAP32[i1 >> 2] | 0) == (i14 | 0)) i12 = i1; else _abort();
   } else i12 = i3 + 8 | 0;
   HEAP32[i2 + 12 >> 2] = i3;
   HEAP32[i12 >> 2] = i2;
  } while (0);
  HEAP32[i17 + 4 >> 2] = i6 | 1;
  HEAP32[i17 + i6 >> 2] = i6;
  if ((i17 | 0) == (HEAP32[15039] | 0)) {
   HEAP32[15036] = i6;
   return;
  }
 } else {
  HEAP32[i1 >> 2] = i2 & -2;
  HEAP32[i17 + 4 >> 2] = i6 | 1;
  HEAP32[i17 + i6 >> 2] = i6;
 }
 i1 = i6 >>> 3;
 if (i6 >>> 0 < 256) {
  i3 = 60176 + (i1 << 1 << 2) | 0;
  i2 = HEAP32[15034] | 0;
  i1 = 1 << i1;
  if (i2 & i1) {
   i1 = i3 + 8 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
    i15 = i1;
    i16 = i2;
   }
  } else {
   HEAP32[15034] = i2 | i1;
   i15 = i3 + 8 | 0;
   i16 = i3;
  }
  HEAP32[i15 >> 2] = i17;
  HEAP32[i16 + 12 >> 2] = i17;
  HEAP32[i17 + 8 >> 2] = i16;
  HEAP32[i17 + 12 >> 2] = i3;
  return;
 }
 i1 = i6 >>> 8;
 if (i1) if (i6 >>> 0 > 16777215) i3 = 31; else {
  i15 = (i1 + 1048320 | 0) >>> 16 & 8;
  i16 = i1 << i15;
  i14 = (i16 + 520192 | 0) >>> 16 & 4;
  i16 = i16 << i14;
  i3 = (i16 + 245760 | 0) >>> 16 & 2;
  i3 = 14 - (i14 | i15 | i3) + (i16 << i3 >>> 15) | 0;
  i3 = i6 >>> (i3 + 7 | 0) & 1 | i3 << 1;
 } else i3 = 0;
 i4 = 60440 + (i3 << 2) | 0;
 HEAP32[i17 + 28 >> 2] = i3;
 HEAP32[i17 + 20 >> 2] = 0;
 HEAP32[i17 + 16 >> 2] = 0;
 i1 = HEAP32[15035] | 0;
 i2 = 1 << i3;
 if (!(i1 & i2)) {
  HEAP32[15035] = i1 | i2;
  HEAP32[i4 >> 2] = i17;
  HEAP32[i17 + 24 >> 2] = i4;
  HEAP32[i17 + 12 >> 2] = i17;
  HEAP32[i17 + 8 >> 2] = i17;
  return;
 }
 i5 = i6 << ((i3 | 0) == 31 ? 0 : 25 - (i3 >>> 1) | 0);
 i1 = HEAP32[i4 >> 2] | 0;
 while (1) {
  if ((HEAP32[i1 + 4 >> 2] & -8 | 0) == (i6 | 0)) {
   i3 = i1;
   i4 = 127;
   break;
  }
  i2 = i1 + 16 + (i5 >>> 31 << 2) | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (!i3) {
   i4 = 124;
   break;
  } else {
   i5 = i5 << 1;
   i1 = i3;
  }
 }
 if ((i4 | 0) == 124) {
  if (i2 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
  HEAP32[i2 >> 2] = i17;
  HEAP32[i17 + 24 >> 2] = i1;
  HEAP32[i17 + 12 >> 2] = i17;
  HEAP32[i17 + 8 >> 2] = i17;
  return;
 } else if ((i4 | 0) == 127) {
  i1 = i3 + 8 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  i16 = HEAP32[15038] | 0;
  if (!(i2 >>> 0 >= i16 >>> 0 & i3 >>> 0 >= i16 >>> 0)) _abort();
  HEAP32[i2 + 12 >> 2] = i17;
  HEAP32[i1 >> 2] = i17;
  HEAP32[i17 + 8 >> 2] = i2;
  HEAP32[i17 + 12 >> 2] = i3;
  HEAP32[i17 + 24 >> 2] = 0;
  return;
 }
}

function __ZN4wasm10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 122, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 119, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 125, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 126, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 127, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 128, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 129, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 130, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 131, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 132, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 133, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 134, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 135, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 136, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 137, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 138, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 139, i2);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 140, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 141, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 142, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZNSt3__212__next_primeEj(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0;
 L1 : do if (i5 >>> 0 < 212) {
  i1 = 11628;
  i2 = 48;
  L2 : while (1) {
   while (1) {
    if (!i2) break L2;
    i3 = (i2 | 0) / 2 | 0;
    i4 = i1 + (i3 << 2) | 0;
    if ((HEAP32[i4 >> 2] | 0) >>> 0 < i5 >>> 0) {
     i1 = i4;
     break;
    } else i2 = i3;
   }
   i1 = i1 + 4 | 0;
   i2 = i2 + -1 - i3 | 0;
  }
  i1 = HEAP32[i1 >> 2] | 0;
 } else {
  i6 = (i5 >>> 0) / 210 | 0;
  i7 = i6 * 210 | 0;
  i5 = i5 - i7 | 0;
  i1 = 11820;
  i2 = 48;
  L10 : while (1) {
   while (1) {
    if (!i2) break L10;
    i3 = (i2 | 0) / 2 | 0;
    i4 = i1 + (i3 << 2) | 0;
    if ((HEAP32[i4 >> 2] | 0) >>> 0 < i5 >>> 0) {
     i1 = i4;
     break;
    } else i2 = i3;
   }
   i1 = i1 + 4 | 0;
   i2 = i2 + -1 - i3 | 0;
  }
  i1 = i1 - 11820 >> 2;
  i5 = i1;
  i1 = (HEAP32[11820 + (i1 << 2) >> 2] | 0) + i7 | 0;
  while (1) {
   i4 = 5;
   while (1) {
    if (i4 >>> 0 >= 47) {
     i4 = 211;
     i8 = 17;
     break;
    }
    i2 = HEAP32[11628 + (i4 << 2) >> 2] | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break; else i4 = i4 + 1 | 0;
   }
   L23 : do if ((i8 | 0) == 17) while (1) {
    i8 = 0;
    i2 = (i1 >>> 0) / (i4 >>> 0) | 0;
    if (i2 >>> 0 < i4 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i2, i4) | 0)) break L23;
    i2 = i4 + 10 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 12 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 16 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 18 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 22 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 28 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 30 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 36 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 40 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 42 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 46 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 52 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 58 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 60 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 66 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 70 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 72 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 78 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 82 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 88 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 96 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 100 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 102 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 106 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 108 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 112 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 120 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 126 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 130 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 136 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 138 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 142 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 148 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 150 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 156 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 162 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 166 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 168 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 172 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 178 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 180 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 186 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 190 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 192 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 196 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 198 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break L23;
    i2 = i4 + 208 | 0;
    i3 = (i1 >>> 0) / (i2 >>> 0) | 0;
    if (i3 >>> 0 < i2 >>> 0) break L1;
    if ((i1 | 0) == (Math_imul(i3, i2) | 0)) break; else {
     i4 = i4 + 210 | 0;
     i8 = 17;
    }
   } while (0);
   i7 = i5 + 1 | 0;
   i4 = (i7 | 0) == 48;
   i1 = (i4 & 1) + i6 | 0;
   i7 = i4 ? 0 : i7;
   i5 = i7;
   i6 = i1;
   i1 = (HEAP32[11820 + (i7 << 2) >> 2] | 0) + (i1 * 210 | 0) | 0;
  }
 } while (0);
 return i1 | 0;
}

function __ZN4wasm10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 273, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 274, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 275, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 276, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 277, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 278, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 279, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 280, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 281, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 282, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 283, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 284, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 285, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 286, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 287, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 288, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 289, i2);
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 290, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 272, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 291, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 292, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 363, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 364, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 365, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 366, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 367, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 368, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 369, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 370, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 371, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 372, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 373, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 374, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 375, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 376, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 377, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 378, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 379, i2);
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 380, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 362, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 381, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 382, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 211, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 208, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 212, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 213, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 214, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 215, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 216, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 217, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 218, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 219, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 220, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 221, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 222, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 223, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 224, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 225, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 226, i2);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 227, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 206, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 228, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 229, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 342, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 343, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 344, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 345, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 346, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 347, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 348, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 349, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 350, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 351, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 352, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 353, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 354, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 355, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 356, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 357, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 358, i2);
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 359, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 341, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 360, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 361, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 320, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 322, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 323, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 324, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 325, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 327, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 328, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 329, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 330, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 331, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 332, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 333, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 334, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 335, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 336, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 337, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 326, i2);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 338, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 339, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 340, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 294, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 295, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 296, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 297, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 298, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 299, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 300, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 301, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 302, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 303, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 304, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 305, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 306, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 307, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 308, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 309, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 310, i2);
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 311, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 293, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 312, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 313, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 471, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 473, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 477, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 480, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 482, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 486, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 487, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 488, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 489, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 490, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 491, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 492, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 493, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 494, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 495, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 496, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 484, i2);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 497, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 498, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 485, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 384, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 385, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 386, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 387, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 388, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 389, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 390, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 391, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 392, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 393, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 394, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 395, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 396, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 397, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 398, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 399, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 400, i2);
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 401, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 383, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 402, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 403, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm14CoalesceLocals12flowLivenessEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, d6 = 0.0, d7 = 0.0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0;
 i27 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i22 = i27 + 40 | 0;
 i23 = i27 + 36 | 0;
 i25 = i27 + 12 | 0;
 i16 = i27 + 32 | 0;
 i24 = i27;
 i3 = i5 + 116 | 0;
 i1 = HEAP32[i5 + 112 >> 2] | 0;
 __ZNSt3__26vectorIbNS_9allocatorIbEEE6resizeEjb(i3, Math_imul(i1, i1) | 0, 0);
 i3 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i5 + 120 >> 2] | 0;
 i4 = i3;
 i1 = (i4 + (i1 >>> 5 << 2) - i3 << 3) + (i1 & 31) | 0;
 i2 = 0;
 while (1) {
  if ((i1 | 0) <= 0) break;
  i20 = i3;
  HEAP32[i20 >> 2] = HEAP32[i20 >> 2] & ~(1 << i2);
  i20 = (i2 | 0) == 31;
  i21 = i4 + 4 | 0;
  i1 = i1 + -1 | 0;
  i2 = i20 ? 0 : i2 + 1 | 0;
  i3 = i20 ? i21 : i3;
  i4 = i20 ? i21 : i4;
 }
 i18 = i25 + 16 | 0;
 HEAP32[i25 >> 2] = 0;
 HEAP32[i25 + 4 >> 2] = 0;
 HEAP32[i25 + 8 >> 2] = 0;
 HEAP32[i25 + 12 >> 2] = 0;
 HEAPF32[i18 >> 2] = 1.0;
 i14 = HEAP32[i5 + 52 >> 2] | 0;
 i15 = i5 + 128 | 0;
 i19 = i25 + 4 | 0;
 i20 = i25 + 12 | 0;
 i21 = i25 + 8 | 0;
 i13 = HEAP32[i5 + 48 >> 2] | 0;
 while (1) {
  if ((i13 | 0) == (i14 | 0)) break;
  HEAP32[i16 >> 2] = HEAP32[i13 >> 2];
  if (__ZNKSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE4findIS9_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEERKT_(i15, i16) | 0) {
   i9 = HEAP32[i13 >> 2] | 0;
   HEAP32[i22 >> 2] = i9;
   i12 = __ZNSt3__221__murmur2_or_cityhashIjLj32EEclEPKvj(i23, i22, 4) | 0;
   i11 = HEAP32[i19 >> 2] | 0;
   i10 = (i11 | 0) == 0;
   i4 = i9;
   L10 : do if (!i10) {
    i5 = i11 + -1 | 0;
    i8 = (i5 & i11 | 0) == 0;
    if (i8) i1 = i5 & i12; else i1 = (i12 >>> 0) % (i11 >>> 0) | 0;
    i2 = HEAP32[(HEAP32[i25 >> 2] | 0) + (i1 << 2) >> 2] | 0;
    if (!i2) i26 = 19; else do {
     i2 = HEAP32[i2 >> 2] | 0;
     if (!i2) {
      i26 = 19;
      break L10;
     }
     i3 = HEAP32[i2 + 4 >> 2] | 0;
     if (i8) i3 = i3 & i5; else i3 = (i3 >>> 0) % (i11 >>> 0) | 0;
     if ((i3 | 0) != (i1 | 0)) {
      i26 = 19;
      break L10;
     }
    } while ((HEAP32[i2 + 8 >> 2] | 0) != (i4 | 0));
   } else {
    i1 = 0;
    i26 = 19;
   } while (0);
   if ((i26 | 0) == 19) {
    i26 = 0;
    i4 = __Znwj(12) | 0;
    HEAP32[i4 + 8 >> 2] = i9;
    HEAP32[i4 + 4 >> 2] = i12;
    HEAP32[i4 >> 2] = 0;
    d6 = +(((HEAP32[i20 >> 2] | 0) + 1 | 0) >>> 0);
    d7 = +HEAPF32[i18 >> 2];
    do if (i10 | d6 > +(i11 >>> 0) * d7) {
     if (i11 >>> 0 > 2) i1 = (i11 + -1 & i11 | 0) == 0; else i1 = 0;
     i1 = (i1 & 1 | i11 << 1) ^ 1;
     i2 = ~~+Math_ceil(+(d6 / d7)) >>> 0;
     __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6rehashEj(i25, i1 >>> 0 < i2 >>> 0 ? i2 : i1);
     i1 = HEAP32[i19 >> 2] | 0;
     i2 = i1 + -1 | 0;
     if (!(i2 & i1)) {
      i3 = i1;
      i1 = i2 & i12;
      break;
     } else {
      i3 = i1;
      i1 = (i12 >>> 0) % (i1 >>> 0) | 0;
      break;
     }
    } else i3 = i11; while (0);
    i1 = (HEAP32[i25 >> 2] | 0) + (i1 << 2) | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    if (!i2) {
     HEAP32[i4 >> 2] = HEAP32[i21 >> 2];
     HEAP32[i21 >> 2] = i4;
     HEAP32[i1 >> 2] = i21;
     i1 = HEAP32[i4 >> 2] | 0;
     if (i1 | 0) {
      i1 = HEAP32[i1 + 4 >> 2] | 0;
      i2 = i3 + -1 | 0;
      if (!(i2 & i3)) i1 = i1 & i2; else i1 = (i1 >>> 0) % (i3 >>> 0) | 0;
      HEAP32[(HEAP32[i25 >> 2] | 0) + (i1 << 2) >> 2] = i4;
     }
    } else {
     HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i2 >> 2] = i4;
    }
    HEAP32[i20 >> 2] = (HEAP32[i20 >> 2] | 0) + 1;
   }
   i17 = HEAP32[i13 >> 2] | 0;
   __ZN4wasm14CoalesceLocals26scanLivenessThroughActionsERNSt3__26vectorINS_6ActionENS1_9allocatorIS3_EEEERNS_8LocalSetE(0, i17 + 24 | 0, i17);
  }
  i13 = i13 + 4 | 0;
 }
 i15 = i25 + 8 | 0;
 i16 = i24 + 4 | 0;
 i17 = i24 + 8 | 0;
 L47 : while (1) {
  if (!(HEAP32[i20 >> 2] | 0)) {
   i26 = 75;
   break;
  }
  i1 = HEAP32[i15 >> 2] | 0;
  i8 = HEAP32[i1 + 8 >> 2] | 0;
  HEAP32[i23 >> 2] = i1;
  HEAP32[i22 >> 2] = HEAP32[i23 >> 2];
  __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE5eraseENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEE(i25, i22) | 0;
  HEAP32[i24 >> 2] = 0;
  HEAP32[i16 >> 2] = 0;
  HEAP32[i17 >> 2] = 0;
  i1 = i8 + 12 | 0;
  L50 : do if (__ZN4wasm14CoalesceLocals25mergeStartsAndCheckChangeERNSt3__26vectorIPNS_9CFGWalkerIS0_NS_7VisitorIS0_vEENS_8LivenessEE10BasicBlockENS1_9allocatorIS9_EEEERNS_8LocalSetESF_(0, i8 + 36 | 0, i1, i24) | 0) {
   if (((HEAP32[i8 + 16 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) | 0) >>> 0 >= ((HEAP32[i16 >> 2] | 0) - (HEAP32[i24 >> 2] | 0) | 0) >>> 0) {
    i26 = 38;
    break L47;
   }
   __ZN4wasm8LocalSetaSERKS0_(i1, i24) | 0;
   __ZN4wasm14CoalesceLocals26scanLivenessThroughActionsERNSt3__26vectorINS_6ActionENS1_9allocatorIS3_EEEERNS_8LocalSetE(0, i8 + 24 | 0, i24);
   i5 = HEAP32[i8 + 4 >> 2] | 0;
   i2 = HEAP32[i8 >> 2] | 0;
   i3 = i5 - i2 | 0;
   i1 = HEAP32[i24 >> 2] | 0;
   i4 = (HEAP32[i16 >> 2] | 0) - i1 | 0;
   L53 : do if ((i3 | 0) == (i4 | 0)) while (1) {
    if ((i2 | 0) == (i5 | 0)) break L50;
    if ((HEAP32[i2 >> 2] | 0) != (HEAP32[i1 >> 2] | 0)) break L53;
    i1 = i1 + 4 | 0;
    i2 = i2 + 4 | 0;
   } while (0);
   if (i3 >>> 0 >= i4 >>> 0) {
    i26 = 45;
    break L47;
   }
   __ZN4wasm8LocalSetaSERKS0_(i8, i24) | 0;
   i14 = HEAP32[i8 + 52 >> 2] | 0;
   i13 = HEAP32[i8 + 48 >> 2] | 0;
   while (1) {
    if ((i13 | 0) == (i14 | 0)) break L50;
    i9 = HEAP32[i13 >> 2] | 0;
    HEAP32[i22 >> 2] = i9;
    i12 = __ZNSt3__221__murmur2_or_cityhashIjLj32EEclEPKvj(i23, i22, 4) | 0;
    i11 = HEAP32[i19 >> 2] | 0;
    i10 = (i11 | 0) == 0;
    i4 = i9;
    L64 : do if (!i10) {
     i5 = i11 + -1 | 0;
     i8 = (i5 & i11 | 0) == 0;
     if (i8) i1 = i5 & i12; else i1 = (i12 >>> 0) % (i11 >>> 0) | 0;
     i2 = HEAP32[(HEAP32[i25 >> 2] | 0) + (i1 << 2) >> 2] | 0;
     if (!i2) i26 = 59; else do {
      i2 = HEAP32[i2 >> 2] | 0;
      if (!i2) {
       i26 = 59;
       break L64;
      }
      i3 = HEAP32[i2 + 4 >> 2] | 0;
      if (i8) i3 = i3 & i5; else i3 = (i3 >>> 0) % (i11 >>> 0) | 0;
      if ((i3 | 0) != (i1 | 0)) {
       i26 = 59;
       break L64;
      }
     } while ((HEAP32[i2 + 8 >> 2] | 0) != (i4 | 0));
    } else {
     i1 = 0;
     i26 = 59;
    } while (0);
    if ((i26 | 0) == 59) {
     i26 = 0;
     i4 = __Znwj(12) | 0;
     HEAP32[i4 + 8 >> 2] = i9;
     HEAP32[i4 + 4 >> 2] = i12;
     HEAP32[i4 >> 2] = 0;
     d6 = +(((HEAP32[i20 >> 2] | 0) + 1 | 0) >>> 0);
     d7 = +HEAPF32[i18 >> 2];
     do if (i10 | d6 > +(i11 >>> 0) * d7) {
      if (i11 >>> 0 > 2) i1 = (i11 + -1 & i11 | 0) == 0; else i1 = 0;
      i1 = (i1 & 1 | i11 << 1) ^ 1;
      i2 = ~~+Math_ceil(+(d6 / d7)) >>> 0;
      __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6rehashEj(i25, i1 >>> 0 < i2 >>> 0 ? i2 : i1);
      i1 = HEAP32[i19 >> 2] | 0;
      i2 = i1 + -1 | 0;
      if (!(i2 & i1)) {
       i3 = i1;
       i1 = i2 & i12;
       break;
      } else {
       i3 = i1;
       i1 = (i12 >>> 0) % (i1 >>> 0) | 0;
       break;
      }
     } else i3 = i11; while (0);
     i1 = (HEAP32[i25 >> 2] | 0) + (i1 << 2) | 0;
     i2 = HEAP32[i1 >> 2] | 0;
     if (!i2) {
      HEAP32[i4 >> 2] = HEAP32[i21 >> 2];
      HEAP32[i21 >> 2] = i4;
      HEAP32[i1 >> 2] = i21;
      i1 = HEAP32[i4 >> 2] | 0;
      if (i1 | 0) {
       i1 = HEAP32[i1 + 4 >> 2] | 0;
       i2 = i3 + -1 | 0;
       if (!(i2 & i3)) i1 = i1 & i2; else i1 = (i1 >>> 0) % (i3 >>> 0) | 0;
       HEAP32[(HEAP32[i25 >> 2] | 0) + (i1 << 2) >> 2] = i4;
      }
     } else {
      HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
      HEAP32[i2 >> 2] = i4;
     }
     HEAP32[i20 >> 2] = (HEAP32[i20 >> 2] | 0) + 1;
    }
    i13 = i13 + 4 | 0;
   }
  } while (0);
  __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i24);
 }
 if ((i26 | 0) == 38) ___assert_fail(46630, 46670, 270, 46700); else if ((i26 | 0) == 45) ___assert_fail(46713, 46670, 279, 46700); else if ((i26 | 0) == 75) {
  __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEED2Ev(i25);
  STACKTOP = i27;
  return;
 }
}

function __ZN4wasm10PostWalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 144, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 145, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 146, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 147, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 148, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 149, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 150, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 151, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 152, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 153, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 154, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 155, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 156, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 157, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 158, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 159, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 160, i2);
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 161, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 143, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 162, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 163, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm22SExpressionWasmBuilder13parseFunctionERNS_7ElementE(i34, i27) {
 i34 = i34 | 0;
 i27 = i27 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0;
 i38 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i19 = i38 + 100 | 0;
 i2 = i38 + 96 | 0;
 i1 = i38 + 92 | 0;
 i36 = i38 + 80 | 0;
 i35 = i38 + 68 | 0;
 i37 = i38 + 56 | 0;
 i33 = i38 + 52 | 0;
 i32 = i38 + 32 | 0;
 i28 = i38 + 20 | 0;
 i20 = i38 + 28 | 0;
 i21 = i38 + 24 | 0;
 i22 = i38 + 8 | 0;
 i23 = i38 + 4 | 0;
 i25 = i38;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i1 >> 2] = 0;
 i3 = __ZN4wasm22SExpressionWasmBuilder18parseFunctionNamesERNS_7ElementERNS_4NameES4_(i34, i27, i2, i1) | 0;
 if (!(HEAP32[i2 >> 2] | 0)) {
  i31 = __ZN4wasm4Name7fromIntEj(HEAP32[i34 + 20 >> 2] | 0) | 0;
  HEAP32[i2 >> 2] = i31;
 }
 i1 = HEAP32[i1 >> 2] | 0;
 if (!i1) i31 = i34; else {
  i31 = __ZN4wasm11make_uniqueINS_6ExportEJEEENSt3__210unique_ptrIT_NS2_14default_deleteIS4_EEEEDpOT0_() | 0;
  HEAP32[i31 >> 2] = i1;
  HEAP32[i31 + 4 >> 2] = HEAP32[i2 >> 2];
  __ZN4wasm6Module9addExportEPNS_6ExportE(HEAP32[i34 >> 2] | 0, i31);
  i31 = i34;
 }
 i15 = i34 + 20 | 0;
 HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + 1;
 i15 = i34 + 56 | 0;
 HEAP32[i15 >> 2] = 0;
 HEAP32[i34 + 60 >> 2] = 0;
 HEAP32[i36 >> 2] = 0;
 i16 = i36 + 4 | 0;
 HEAP32[i16 >> 2] = 0;
 HEAP32[i36 + 8 >> 2] = 0;
 HEAP32[i35 >> 2] = 0;
 i17 = i35 + 4 | 0;
 HEAP32[i17 >> 2] = 0;
 HEAP32[i35 + 8 >> 2] = 0;
 HEAP32[i37 >> 2] = 0;
 i18 = i37 + 4 | 0;
 HEAP32[i18 >> 2] = 0;
 HEAP32[i37 + 8 >> 2] = 0;
 HEAP32[i33 >> 2] = 0;
 HEAP32[i32 >> 2] = i34;
 HEAP32[i32 + 4 >> 2] = i2;
 HEAP32[i32 + 8 >> 2] = i35;
 HEAP32[i32 + 12 >> 2] = i33;
 HEAP32[i32 + 16 >> 2] = i37;
 i11 = i36 + 8 | 0;
 i12 = i34 + 44 | 0;
 i29 = i34 + 40 | 0;
 i24 = i34 + 4 | 0;
 i13 = i35 + 8 | 0;
 i14 = i37 + 8 | 0;
 i2 = 0;
 i1 = 0;
 i10 = i3;
 i3 = 0;
 L8 : while (1) {
  i9 = (__ZN4wasm7Element4listEv(i27) | 0) + 8 | 0;
  if (i10 >>> 0 >= (HEAP32[i9 >> 2] | 0) >>> 0) break;
  i9 = __ZN4wasm7ElementixEj(i27, i10) | 0;
  i7 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i9, 0) | 0) | 0;
  L11 : do if (!((i7 | 0) == (HEAP32[14975] | 0) | (i7 | 0) == (HEAP32[14982] | 0))) {
   if ((i7 | 0) == (HEAP32[14976] | 0)) {
    i9 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i34, __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i9, 1) | 0) | 0, 0, 0) | 0;
    HEAP32[i33 >> 2] = i9;
    break;
   }
   if ((i7 | 0) == (HEAP32[14983] | 0)) {
    i3 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i9, 1) | 0) | 0;
    i9 = HEAP32[i31 >> 2] | 0;
    HEAP32[i21 >> 2] = i3;
    HEAP32[i19 >> 2] = HEAP32[i21 >> 2];
    if (!(__ZN4wasm6Module17checkFunctionTypeENS_4NameE(i9, i19) | 0)) {
     i30 = 26;
     break L8;
    }
    i5 = HEAP32[i31 >> 2] | 0;
    HEAP32[i23 >> 2] = i3;
    HEAP32[i19 >> 2] = HEAP32[i23 >> 2];
    i5 = __ZN4wasm6Module15getFunctionTypeENS_4NameE(i5, i19) | 0;
    HEAP32[i33 >> 2] = HEAP32[i5 + 4 >> 2];
    i4 = i5 + 8 | 0;
    i5 = i5 + 12 | 0;
    i9 = 0;
    while (1) {
     if (i9 >>> 0 >= (HEAP32[i5 >> 2] | 0) - (HEAP32[i4 >> 2] | 0) >> 2 >>> 0) break L11;
     i8 = __ZN4wasm4Name7fromIntEj(i9) | 0;
     HEAP32[i19 >> 2] = i8;
     i6 = HEAP32[(HEAP32[i4 >> 2] | 0) + (i9 << 2) >> 2] | 0;
     HEAP32[i28 >> 2] = i6;
     i7 = HEAP32[i16 >> 2] | 0;
     if (i7 >>> 0 < (HEAP32[i11 >> 2] | 0) >>> 0) {
      HEAP32[i7 >> 2] = i8;
      HEAP32[i7 + 4 >> 2] = i6;
      HEAP32[i16 >> 2] = (HEAP32[i16 >> 2] | 0) + 8;
     } else __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRN6cashew7IStringERNS1_8WasmTypeEEEEvDpOT_(i36, i19, i28);
     HEAP32[i25 >> 2] = i8;
     i8 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixEOS2_(i12, i25) | 0;
     HEAP32[i8 >> 2] = i6;
     i9 = i9 + 1 | 0;
    }
   }
   i7 = HEAP32[i16 >> 2] | 0;
   i8 = HEAP32[i36 >> 2] | 0;
   i4 = i8;
   i5 = i7;
   if ((i7 | 0) != (i8 | 0) ? (HEAP32[i17 >> 2] | 0) == (HEAP32[i35 >> 2] | 0) : 0) __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_(i35, i4, i5);
   if (!(HEAP32[i29 >> 2] | 0)) __ZZN4wasm22SExpressionWasmBuilder13parseFunctionERNS_7ElementEENKUlvE_clEv(i32);
   i4 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i34, i9) | 0;
   if (!i1) i1 = i4; else {
    if (!i2) {
     i9 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i24 >> 2] | 0) | 0;
     __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i9 + 12 | 0, i1);
     i2 = i9;
     i1 = i9;
    }
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2 + 12 | 0, i4);
    __ZN4wasm5Block8finalizeEv(i2);
   }
  } else {
   i4 = 1;
   while (1) {
    i8 = (__ZN4wasm7Element4listEv(i9) | 0) + 8 | 0;
    if (i4 >>> 0 >= (HEAP32[i8 >> 2] | 0) >>> 0) break L11;
    HEAP32[i19 >> 2] = 0;
    HEAP32[i28 >> 2] = 0;
    i8 = (__ZN4wasm7ElementixEj(i9, i4) | 0) + 24 | 0;
    if ((HEAP8[i8 >> 0] | 0) == 0 ? (i26 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i34, __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i9, i4) | 0) | 0, 1, 0) | 0, HEAP32[i28 >> 2] = i26, (i26 | 0) != 0) : 0) {
     i5 = __ZN4wasm4Name7fromIntEj(HEAP32[i15 >> 2] | 0) | 0;
     HEAP32[i19 >> 2] = i5;
     i8 = i26;
    } else {
     i5 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i9, i4) | 0) | 0;
     HEAP32[i19 >> 2] = i5;
     i4 = i4 + 1 | 0;
     i8 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i34, __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i9, i4) | 0) | 0, 0, 0) | 0;
     HEAP32[i28 >> 2] = i8;
    }
    i4 = i4 + 1 | 0;
    do if ((i7 | 0) == (HEAP32[14975] | 0)) {
     i6 = HEAP32[i17 >> 2] | 0;
     if (i6 >>> 0 < (HEAP32[i13 >> 2] | 0) >>> 0) {
      HEAP32[i6 >> 2] = i5;
      HEAP32[i6 + 4 >> 2] = i8;
      HEAP32[i17 >> 2] = (HEAP32[i17 >> 2] | 0) + 8;
      break;
     } else {
      __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRN6cashew7IStringERNS1_8WasmTypeEEEEvDpOT_(i35, i19, i28);
      break;
     }
    } else {
     i6 = HEAP32[i18 >> 2] | 0;
     if (i6 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
      HEAP32[i6 >> 2] = i5;
      HEAP32[i6 + 4 >> 2] = i8;
      HEAP32[i18 >> 2] = (HEAP32[i18 >> 2] | 0) + 8;
      break;
     } else {
      __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRN6cashew7IStringERNS1_8WasmTypeEEEEvDpOT_(i37, i19, i28);
      break;
     }
    } while (0);
    HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + 1;
    HEAP32[i20 >> 2] = i5;
    i6 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixEOS2_(i12, i20) | 0;
    HEAP32[i6 >> 2] = i8;
   }
  } while (0);
  i10 = i10 + 1 | 0;
 }
 if ((i30 | 0) == 26) {
  i38 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i22 >> 2] = 0;
  HEAP32[i22 + 4 >> 2] = 0;
  HEAP32[i22 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i22, 21659, 16);
  __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i38, i22);
  ___cxa_throw(i38 | 0, 64, 279);
 }
 i2 = HEAP32[i29 >> 2] | 0;
 if (!i2) {
  __ZZN4wasm22SExpressionWasmBuilder13parseFunctionERNS_7ElementEENKUlvE_clEv(i32);
  i1 = __ZN10MixedArena5allocIN4wasm3NopEEEPT_v(HEAP32[i24 >> 2] | 0) | 0;
  i2 = HEAP32[i29 >> 2] | 0;
 }
 if ((HEAP32[i2 + 4 >> 2] | 0) != (HEAP32[i33 >> 2] | 0)) ___assert_fail(21901, 21446, 486, 21932);
 HEAP32[i2 + 36 >> 2] = i1;
 HEAP32[(HEAP32[i29 >> 2] | 0) + 32 >> 2] = i3;
 i1 = HEAP32[i31 >> 2] | 0;
 i3 = HEAP32[i29 >> 2] | 0;
 HEAP32[i29 >> 2] = 0;
 __ZN4wasm6Module11addFunctionEPNS_8FunctionE(i1, i3);
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE5clearEv(i34 + 44 | 0);
 i3 = HEAP32[i34 + 64 >> 2] | 0;
 i1 = i34 + 68 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i3 | 0)) break;
  i34 = i2 + -4 | 0;
  HEAP32[i1 >> 2] = i34;
  i2 = i34;
 }
 __ZNSt3__213__vector_baseIN4wasm8NameTypeENS_9allocatorIS2_EEED2Ev(i37);
 __ZNSt3__213__vector_baseIN4wasm8NameTypeENS_9allocatorIS2_EEED2Ev(i35);
 __ZNSt3__213__vector_baseIN4wasm8NameTypeENS_9allocatorIS2_EEED2Ev(i36);
 STACKTOP = i38;
 return;
}

function __ZN4wasm10PostWalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = HEAP32[i1 >> 2] | 0;
 L1 : do switch (HEAP32[i4 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 449, i1);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i4) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 450, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 451, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i4) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 452, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 453, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 454, i1);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 455, i1);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 456, i1);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 457, i1);
   break;
  }
 case 10:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 458, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 459, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 460, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 461, i1);
   break;
  }
 case 14:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 462, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 463, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 464, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 465, i1);
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 466, i1);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i4) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 448, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 467, i1);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 468, i1);
   break;
  }
 default:
  {}
 } while (0);
 return;
}
function __ZN4wasm16PrintSExpression11visitModuleEPNS_6ModuleE(i17, i15) {
 i17 = i17 | 0;
 i15 = i15 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i16 = 0, i18 = 0, i19 = 0;
 i18 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i12 = i18 + 8 | 0;
 i13 = i18;
 __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i17 >> 2] | 0, 49074, 1) | 0;
 __ZN4wasm16PrintSExpression9incIndentEv(i17);
 i16 = i17 + 4 | 0;
 __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i17 >> 2] | 0, HEAP32[i16 >> 2] | 0) | 0;
 i1 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i17 >> 2] | 0, 49105, 0) | 0, 58055) | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i1, HEAP32[i15 + 60 >> 2] | 0) | 0;
 i1 = i15 + 64 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) < 65535) switch (i2 | 0) {
 case 0:
  break;
 default:
  i3 = 2;
 } else switch (i2 | 0) {
 case 65535:
  break;
 default:
  i3 = 2;
 }
 if ((i3 | 0) == 2) {
  i14 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 58055) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i14, HEAP32[i1 >> 2] | 0) | 0;
 }
 i3 = i15 + 68 | 0;
 i4 = i15 + 72 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 i14 = i17 + 16 | 0;
 i6 = i17 + 8 | 0;
 i7 = i12 + 4 | 0;
 i8 = i12 + 8 | 0;
 i9 = i12 + 4 | 0;
 i10 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i10 | 0) == (i5 | 0)) break;
  __ZN4wasm6Memory7SegmentC2ERKS1_(i12, i10);
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
  i11 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP8[i6 >> 0] | 0 ? 67717 : 34504) | 0, 34509) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i11, HEAP32[i12 >> 2] | 0) | 0, 34519) | 0;
  i11 = 0;
  while (1) {
   i1 = HEAP32[i7 >> 2] | 0;
   if (i11 >>> 0 >= ((HEAP32[i8 >> 2] | 0) - i1 | 0) >>> 0) break;
   i1 = HEAP8[i1 + i11 >> 0] | 0;
   L13 : do switch (i1 & 255 | 0) {
   case 10:
    {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 34525) | 0;
     break;
    }
   case 13:
    {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 34528) | 0;
     break;
    }
   case 9:
    {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 34532) | 0;
     break;
    }
   case 12:
    {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 34535) | 0;
     break;
    }
   case 8:
    {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 34539) | 0;
     break;
    }
   case 92:
    {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 34543) | 0;
     break;
    }
   case 34:
    {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 34546) | 0;
     break;
    }
   case 39:
    {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 34549) | 0;
     break;
    }
   default:
    {
     i2 = HEAP32[i17 >> 2] | 0;
     if ((i1 + -32 & 255) < 95) {
      __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_h(i2, i1) | 0;
      break L13;
     } else {
      i19 = i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
      HEAP32[i19 >> 2] = HEAP32[i19 >> 2] & -75 | 8;
      i2 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i2, 92) | 0, (i1 & 255) >>> 4 & 255) | 0, i1 & 15) | 0;
      i2 = i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
      HEAP32[i2 >> 2] = HEAP32[i2 >> 2] & -75 | 2;
      break L13;
     }
    }
   } while (0);
   i11 = i11 + 1 | 0;
  }
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, 34522) | 0;
  __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i9);
  i10 = i10 + 16 | 0;
 }
 if ((HEAP32[i4 >> 2] | 0) == (HEAP32[i3 >> 2] | 0)) i1 = 67717; else i1 = HEAP8[i6 >> 0] | 0 ? 67717 : 34552;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, i1) | 0, 56966) | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
 i1 = i15 + 80 | 0;
 if (HEAP32[i1 >> 2] | 0) {
  __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i17 >> 2] | 0, HEAP32[i16 >> 2] | 0) | 0;
  __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i17 >> 2] | 0, 34556, 0) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__Z9printTextRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i17 >> 2] | 0, HEAP32[i1 >> 2] | 0) | 0, 34570) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
 }
 i1 = i15 + 84 | 0;
 if (HEAP32[i1 >> 2] | 0) {
  __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i17 >> 2] | 0, HEAP32[i16 >> 2] | 0) | 0;
  i19 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i17 >> 2] | 0, 49081, 0) | 0, 58055) | 0;
  HEAP32[i13 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i12 >> 2] = HEAP32[i13 >> 2];
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i19, i12) | 0, 56966) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
 }
 i1 = HEAP32[i15 + 4 >> 2] | 0;
 i2 = HEAP32[i15 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i17 >> 2] | 0, HEAP32[i16 >> 2] | 0) | 0;
  __ZN4wasm16PrintSExpression17visitFunctionTypeEPNS_12FunctionTypeEb(i17, HEAP32[i2 >> 2] | 0, 1);
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
  i2 = i2 + 4 | 0;
 }
 i1 = HEAP32[i15 + 16 >> 2] | 0;
 i2 = HEAP32[i15 + 12 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i17 >> 2] | 0, HEAP32[i16 >> 2] | 0) | 0;
  __ZN4wasm16PrintSExpression11visitImportEPNS_6ImportE(i17, HEAP32[i2 >> 2] | 0);
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
  i2 = i2 + 4 | 0;
 }
 i1 = HEAP32[i15 + 28 >> 2] | 0;
 i2 = HEAP32[i15 + 24 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i17 >> 2] | 0, HEAP32[i16 >> 2] | 0) | 0;
  __ZN4wasm16PrintSExpression11visitExportEPNS_6ExportE(i17, HEAP32[i2 >> 2] | 0);
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
  i2 = i2 + 4 | 0;
 }
 i1 = i15 + 48 | 0;
 if ((HEAP32[i15 + 52 >> 2] | 0) != (HEAP32[i1 >> 2] | 0)) {
  __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i17 >> 2] | 0, HEAP32[i16 >> 2] | 0) | 0;
  __ZN4wasm16PrintSExpression10visitTableEPNS_5TableE(i17, i1);
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
 }
 i2 = HEAP32[i15 + 40 >> 2] | 0;
 i1 = HEAP32[i15 + 36 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i17 >> 2] | 0, HEAP32[i16 >> 2] | 0) | 0;
  __ZN4wasm16PrintSExpression13visitFunctionEPNS_8FunctionE(i17, HEAP32[i1 >> 2] | 0);
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
  i1 = i1 + 4 | 0;
 }
 __ZN4wasm16PrintSExpression9decIndentEv(i17);
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i17 >> 2] | 0, HEAP32[i14 >> 2] | 0) | 0;
 STACKTOP = i18;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_typeINS0_2DbEEEPKcS4_S4_RT_(i6, i2, i12) {
 i6 = i6 | 0;
 i2 = i2 | 0;
 i12 = i12 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i11 = i13 + 72 | 0;
 i10 = i13 + 56 | 0;
 i7 = i13 + 48 | 0;
 i8 = i13 + 32 | 0;
 i3 = i13 + 24 | 0;
 i9 = i13 + 8 | 0;
 i4 = i13;
 L1 : do if ((i6 | 0) == (i2 | 0)) i1 = i6; else switch (HEAP8[i6 >> 0] | 0) {
 case 84:
  {
   i5 = i12 + 4 | 0;
   i4 = ((HEAP32[i5 >> 2] | 0) - (HEAP32[i12 >> 2] | 0) | 0) / 24 | 0;
   i1 = __ZN10__cxxabiv112_GLOBAL__N_120parse_template_paramINS0_2DbEEEPKcS4_S4_RT_(i6, i2, i12) | 0;
   i2 = HEAP32[i5 >> 2] | 0;
   i3 = (i2 - (HEAP32[i12 >> 2] | 0) | 0) / 24 | 0;
   if (!((i1 | 0) != (i6 | 0) & (i3 | 0) == (i4 + 1 | 0))) {
    i1 = i2;
    while (1) {
     if ((i3 | 0) == (i4 | 0)) {
      i1 = i6;
      break L1;
     }
     i2 = i1 + -24 | 0;
     while (1) {
      if ((i1 | 0) == (i2 | 0)) break;
      i12 = i1 + -24 | 0;
      HEAP32[i5 >> 2] = i12;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i12);
      i1 = HEAP32[i5 >> 2] | 0;
     }
     i1 = i2;
     i3 = i3 + -1 | 0;
    }
   }
   i6 = i12 + 16 | 0;
   HEAP32[i7 >> 2] = HEAP32[i12 + 12 >> 2];
   __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i10, i2 + -24 | 0, i7);
   i2 = i12 + 20 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i9 = HEAP32[i12 + 24 >> 2] | 0;
   i4 = i9;
   if (i3 >>> 0 < i9 >>> 0) {
    HEAP32[i3 + 12 >> 2] = HEAP32[i10 + 12 >> 2];
    HEAP32[i3 >> 2] = HEAP32[i10 >> 2];
    i12 = i10 + 4 | 0;
    HEAP32[i3 + 4 >> 2] = HEAP32[i12 >> 2];
    i11 = i10 + 8 | 0;
    HEAP32[i3 + 8 >> 2] = HEAP32[i11 >> 2];
    HEAP32[i11 >> 2] = 0;
    HEAP32[i12 >> 2] = 0;
    HEAP32[i10 >> 2] = 0;
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
   } else {
    i2 = HEAP32[i6 >> 2] | 0;
    i5 = i3 - i2 >> 4;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
    i2 = i4 - i2 | 0;
    if (i2 >> 4 >>> 0 < 134217727) {
     i2 = i2 >> 3;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 268435455;
    __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i11, i2, i5, i12 + 28 | 0);
    i12 = i11 + 8 | 0;
    i9 = HEAP32[i12 >> 2] | 0;
    HEAP32[i9 + 12 >> 2] = HEAP32[i10 + 12 >> 2];
    HEAP32[i9 >> 2] = HEAP32[i10 >> 2];
    i8 = i10 + 4 | 0;
    HEAP32[i9 + 4 >> 2] = HEAP32[i8 >> 2];
    i7 = i10 + 8 | 0;
    HEAP32[i9 + 8 >> 2] = HEAP32[i7 >> 2];
    HEAP32[i7 >> 2] = 0;
    HEAP32[i8 >> 2] = 0;
    HEAP32[i10 >> 2] = 0;
    HEAP32[i12 >> 2] = i9 + 16;
    __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i11);
    __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i11);
   }
   __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i10);
   break L1;
  }
 case 68:
  {
   i1 = __ZN10__cxxabiv112_GLOBAL__N_114parse_decltypeINS0_2DbEEEPKcS4_S4_RT_(i6, i2, i12) | 0;
   if ((i1 | 0) == (i6 | 0)) {
    i1 = i6;
    break L1;
   }
   i2 = HEAP32[i12 + 4 >> 2] | 0;
   if ((HEAP32[i12 >> 2] | 0) == (i2 | 0)) {
    i1 = i6;
    break L1;
   }
   i6 = i12 + 16 | 0;
   HEAP32[i3 >> 2] = HEAP32[i12 + 12 >> 2];
   __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i8, i2 + -24 | 0, i3);
   i2 = i12 + 20 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i10 = HEAP32[i12 + 24 >> 2] | 0;
   i5 = i10;
   if (i3 >>> 0 < i10 >>> 0) {
    HEAP32[i3 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
    HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
    i12 = i8 + 4 | 0;
    HEAP32[i3 + 4 >> 2] = HEAP32[i12 >> 2];
    i11 = i8 + 8 | 0;
    HEAP32[i3 + 8 >> 2] = HEAP32[i11 >> 2];
    HEAP32[i11 >> 2] = 0;
    HEAP32[i12 >> 2] = 0;
    HEAP32[i8 >> 2] = 0;
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
   } else {
    i2 = HEAP32[i6 >> 2] | 0;
    i4 = i3 - i2 >> 4;
    i3 = i4 + 1 | 0;
    if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
    i2 = i5 - i2 | 0;
    if (i2 >> 4 >>> 0 < 134217727) {
     i2 = i2 >> 3;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 268435455;
    __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i11, i2, i4, i12 + 28 | 0);
    i12 = i11 + 8 | 0;
    i10 = HEAP32[i12 >> 2] | 0;
    HEAP32[i10 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
    HEAP32[i10 >> 2] = HEAP32[i8 >> 2];
    i9 = i8 + 4 | 0;
    HEAP32[i10 + 4 >> 2] = HEAP32[i9 >> 2];
    i7 = i8 + 8 | 0;
    HEAP32[i10 + 8 >> 2] = HEAP32[i7 >> 2];
    HEAP32[i7 >> 2] = 0;
    HEAP32[i9 >> 2] = 0;
    HEAP32[i8 >> 2] = 0;
    HEAP32[i12 >> 2] = i10 + 16;
    __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i11);
    __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i11);
   }
   __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i8);
   break L1;
  }
 case 83:
  {
   i1 = __ZN10__cxxabiv112_GLOBAL__N_118parse_substitutionINS0_2DbEEEPKcS4_S4_RT_(i6, i2, i12) | 0;
   if ((i1 | 0) != (i6 | 0)) break L1;
   if ((i2 - i6 | 0) <= 2) {
    i1 = i6;
    break L1;
   }
   if ((HEAP8[i6 + 1 >> 0] | 0) != 116) {
    i1 = i6;
    break L1;
   }
   i10 = i6 + 2 | 0;
   i1 = __ZN10__cxxabiv112_GLOBAL__N_122parse_unqualified_nameINS0_2DbEEEPKcS4_S4_RT_(i10, i2, i12) | 0;
   if ((i1 | 0) == (i10 | 0)) {
    i1 = i6;
    break L1;
   }
   i3 = i12 + 4 | 0;
   i2 = HEAP32[i3 >> 2] | 0;
   if ((HEAP32[i12 >> 2] | 0) == (i2 | 0)) {
    i1 = i6;
    break L1;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 57996) | 0;
   i6 = i12 + 16 | 0;
   i2 = (HEAP32[i3 >> 2] | 0) + -24 | 0;
   HEAP32[i4 >> 2] = HEAP32[i12 + 12 >> 2];
   __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i9, i2, i4);
   i2 = i12 + 20 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i10 = HEAP32[i12 + 24 >> 2] | 0;
   i4 = i10;
   if (i3 >>> 0 < i10 >>> 0) {
    HEAP32[i3 + 12 >> 2] = HEAP32[i9 + 12 >> 2];
    HEAP32[i3 >> 2] = HEAP32[i9 >> 2];
    i12 = i9 + 4 | 0;
    HEAP32[i3 + 4 >> 2] = HEAP32[i12 >> 2];
    i11 = i9 + 8 | 0;
    HEAP32[i3 + 8 >> 2] = HEAP32[i11 >> 2];
    HEAP32[i11 >> 2] = 0;
    HEAP32[i12 >> 2] = 0;
    HEAP32[i9 >> 2] = 0;
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
   } else {
    i2 = HEAP32[i6 >> 2] | 0;
    i5 = i3 - i2 >> 4;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i6);
    i2 = i4 - i2 | 0;
    if (i2 >> 4 >>> 0 < 134217727) {
     i2 = i2 >> 3;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 268435455;
    __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i11, i2, i5, i12 + 28 | 0);
    i12 = i11 + 8 | 0;
    i10 = HEAP32[i12 >> 2] | 0;
    HEAP32[i10 + 12 >> 2] = HEAP32[i9 + 12 >> 2];
    HEAP32[i10 >> 2] = HEAP32[i9 >> 2];
    i8 = i9 + 4 | 0;
    HEAP32[i10 + 4 >> 2] = HEAP32[i8 >> 2];
    i7 = i9 + 8 | 0;
    HEAP32[i10 + 8 >> 2] = HEAP32[i7 >> 2];
    HEAP32[i7 >> 2] = 0;
    HEAP32[i8 >> 2] = 0;
    HEAP32[i9 >> 2] = 0;
    HEAP32[i12 >> 2] = i10 + 16;
    __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i11);
    __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i11);
   }
   __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i9);
   break L1;
  }
 default:
  {
   i1 = i6;
   break L1;
  }
 } while (0);
 STACKTOP = i13;
 return i1 | 0;
}

function __ZN4wasm10PostWalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = HEAP32[i1 >> 2] | 0;
 L1 : do switch (HEAP32[i4 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 165, i1);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i4) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 166, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 167, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i4) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 168, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 169, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 170, i1);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 171, i1);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 172, i1);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 173, i1);
   break;
  }
 case 10:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 174, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 175, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 176, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 177, i1);
   break;
  }
 case 14:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 178, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 179, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 180, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 181, i1);
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 182, i1);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i4) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 164, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 183, i1);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 184, i1);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_6VacuumENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i2 >> 2] | 0;
 L1 : do switch (HEAP32[i5 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 428, i2);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i5) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 429, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 430, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i5) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 431, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 432, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 433, i2);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 434, i2);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 435, i2);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i5) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 436, i2);
   break;
  }
 case 10:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 437, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 438, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 439, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i5) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 440, i2);
   break;
  }
 case 14:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 441, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 442, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i5) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 443, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 444, i2);
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i5) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 445, i2);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i5) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 425, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 446, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1 + 16 | 0, 447, i2);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = HEAP32[i1 >> 2] | 0;
 L1 : do switch (HEAP32[i4 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 77, i1);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i4) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 78, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 79, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i4) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 80, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 81, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 82, i1);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 83, i1);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 84, i1);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 85, i1);
   break;
  }
 case 10:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 86, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 87, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 88, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 89, i1);
   break;
  }
 case 14:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 90, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 91, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 92, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 93, i1);
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 94, i1);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i4) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 76, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 95, i1);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 96, i1);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = HEAP32[i1 >> 2] | 0;
 L1 : do switch (HEAP32[i4 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 98, i1);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i4) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 99, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 100, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i4) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 101, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 102, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 103, i1);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 104, i1);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 105, i1);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 106, i1);
   break;
  }
 case 10:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 107, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 108, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 109, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 110, i1);
   break;
  }
 case 14:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 111, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 112, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 113, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 114, i1);
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 115, i1);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i4) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 97, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 116, i1);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 117, i1);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZN4wasm10PostWalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = HEAP32[i1 >> 2] | 0;
 L1 : do switch (HEAP32[i4 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 500, i1);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i4) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 501, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 502, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i4) | 0) + 16 | 0);
   break;
  }
 case 4:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 503, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 504, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 6:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 505, i1);
   i3 = __ZN4wasm10Expression4castINS_4CallEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 7:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 506, i1);
   i3 = __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 8:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 507, i1);
   i3 = __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0;
   i1 = i3 + 8 | 0;
   i3 = HEAP32[i3 + 16 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i4) | 0) + 28 | 0);
   break;
  }
 case 9:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 508, i1);
   break;
  }
 case 10:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 509, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 11:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 510, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 12:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 511, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 24 | 0);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_5StoreEEEPT_v(i4) | 0) + 20 | 0);
   break;
  }
 case 13:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 512, i1);
   break;
  }
 case 14:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 513, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 15:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 514, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i4) | 0) + 12 | 0);
   break;
  }
 case 16:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 515, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_6SelectEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 17:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 516, i1);
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i4) | 0) + 8 | 0);
   break;
  }
 case 18:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 517, i1);
   i3 = __ZN4wasm10Expression4castINS_4HostEEEPT_v(i4) | 0;
   i1 = i3 + 16 | 0;
   i3 = HEAP32[i3 + 24 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 499, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 19:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 518, i1);
   break;
  }
 case 20:
  {
   __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i5, 519, i1);
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri(i1, i7, i2, i8, i18, i19, i20, i21, i15, i22) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i8 = i8 | 0;
 i18 = i18 | 0;
 i19 = i19 | 0;
 i20 = i20 | 0;
 i21 = i21 | 0;
 i15 = i15 | 0;
 i22 = i22 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i16 = 0, i17 = 0, i23 = 0;
 i23 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i3 = i23 + 108 | 0;
 i9 = i23 + 96 | 0;
 i4 = i23 + 92 | 0;
 i10 = i23 + 80 | 0;
 i14 = i23 + 68 | 0;
 i17 = i23 + 56 | 0;
 i5 = i23 + 52 | 0;
 i11 = i23 + 40 | 0;
 i6 = i23 + 36 | 0;
 i12 = i23 + 24 | 0;
 i13 = i23 + 12 | 0;
 i16 = i23;
 if (i1) {
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 63400) | 0;
  i1 = HEAP32[i5 >> 2] | 0;
  if (i7) {
   FUNCTION_TABLE_vii[HEAP32[i1 + 44 >> 2] & 1023](i3, i5);
   i1 = HEAP32[i3 >> 2] | 0;
   HEAP8[i8 >> 0] = i1;
   HEAP8[i8 + 1 >> 0] = i1 >> 8;
   HEAP8[i8 + 2 >> 0] = i1 >> 16;
   HEAP8[i8 + 3 >> 0] = i1 >> 24;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i5 >> 2] | 0) + 32 >> 2] & 1023](i9, i5);
   i1 = i15 + 11 | 0;
   if ((HEAP8[i1 >> 0] | 0) < 0) {
    HEAP8[HEAP32[i15 >> 2] >> 0] = 0;
    HEAP32[i15 + 4 >> 2] = 0;
    i1 = i15;
   } else {
    HEAP8[i15 >> 0] = 0;
    HEAP8[i1 >> 0] = 0;
    i1 = i15;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i15, 0);
   HEAP32[i1 >> 2] = HEAP32[i9 >> 2];
   HEAP32[i1 + 4 >> 2] = HEAP32[i9 + 4 >> 2];
   HEAP32[i1 + 8 >> 2] = HEAP32[i9 + 8 >> 2];
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break;
    HEAP32[i9 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i9);
   i2 = i5;
  } else {
   FUNCTION_TABLE_vii[HEAP32[i1 + 40 >> 2] & 1023](i4, i5);
   i1 = HEAP32[i4 >> 2] | 0;
   HEAP8[i8 >> 0] = i1;
   HEAP8[i8 + 1 >> 0] = i1 >> 8;
   HEAP8[i8 + 2 >> 0] = i1 >> 16;
   HEAP8[i8 + 3 >> 0] = i1 >> 24;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 1023](i10, i5);
   i1 = i15 + 11 | 0;
   if ((HEAP8[i1 >> 0] | 0) < 0) {
    HEAP8[HEAP32[i15 >> 2] >> 0] = 0;
    HEAP32[i15 + 4 >> 2] = 0;
    i1 = i15;
   } else {
    HEAP8[i15 >> 0] = 0;
    HEAP8[i1 >> 0] = 0;
    i1 = i15;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i15, 0);
   HEAP32[i1 >> 2] = HEAP32[i10 >> 2];
   HEAP32[i1 + 4 >> 2] = HEAP32[i10 + 4 >> 2];
   HEAP32[i1 + 8 >> 2] = HEAP32[i10 + 8 >> 2];
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break;
    HEAP32[i10 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i10);
   i2 = i5;
  }
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 12 >> 2] & 255](i5) | 0;
  HEAP8[i18 >> 0] = i1;
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 16 >> 2] & 255](i5) | 0;
  HEAP8[i19 >> 0] = i1;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i14, i5);
  i1 = i20 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i20 >> 2] >> 0] = 0;
   HEAP32[i20 + 4 >> 2] = 0;
   i1 = i20;
  } else {
   HEAP8[i20 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i20;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i20, 0);
  HEAP32[i1 >> 2] = HEAP32[i14 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i14 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i14 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i14 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i14);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 1023](i17, i5);
  i1 = i21 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i21 >> 2] >> 0] = 0;
   HEAP32[i21 + 4 >> 2] = 0;
   i1 = i21;
  } else {
   HEAP8[i21 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i21;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i21, 0);
  HEAP32[i1 >> 2] = HEAP32[i17 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i17 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i17 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i17 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i17);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0;
 } else {
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 63392) | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  if (i7) {
   FUNCTION_TABLE_vii[HEAP32[i1 + 44 >> 2] & 1023](i5, i3);
   i1 = HEAP32[i5 >> 2] | 0;
   HEAP8[i8 >> 0] = i1;
   HEAP8[i8 + 1 >> 0] = i1 >> 8;
   HEAP8[i8 + 2 >> 0] = i1 >> 16;
   HEAP8[i8 + 3 >> 0] = i1 >> 24;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i3 >> 2] | 0) + 32 >> 2] & 1023](i11, i3);
   i1 = i15 + 11 | 0;
   if ((HEAP8[i1 >> 0] | 0) < 0) {
    HEAP8[HEAP32[i15 >> 2] >> 0] = 0;
    HEAP32[i15 + 4 >> 2] = 0;
    i1 = i15;
   } else {
    HEAP8[i15 >> 0] = 0;
    HEAP8[i1 >> 0] = 0;
    i1 = i15;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i15, 0);
   HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
   HEAP32[i1 + 4 >> 2] = HEAP32[i11 + 4 >> 2];
   HEAP32[i1 + 8 >> 2] = HEAP32[i11 + 8 >> 2];
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break;
    HEAP32[i11 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i11);
   i2 = i3;
  } else {
   FUNCTION_TABLE_vii[HEAP32[i1 + 40 >> 2] & 1023](i6, i3);
   i1 = HEAP32[i6 >> 2] | 0;
   HEAP8[i8 >> 0] = i1;
   HEAP8[i8 + 1 >> 0] = i1 >> 8;
   HEAP8[i8 + 2 >> 0] = i1 >> 16;
   HEAP8[i8 + 3 >> 0] = i1 >> 24;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 1023](i12, i3);
   i1 = i15 + 11 | 0;
   if ((HEAP8[i1 >> 0] | 0) < 0) {
    HEAP8[HEAP32[i15 >> 2] >> 0] = 0;
    HEAP32[i15 + 4 >> 2] = 0;
    i1 = i15;
   } else {
    HEAP8[i15 >> 0] = 0;
    HEAP8[i1 >> 0] = 0;
    i1 = i15;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i15, 0);
   HEAP32[i1 >> 2] = HEAP32[i12 >> 2];
   HEAP32[i1 + 4 >> 2] = HEAP32[i12 + 4 >> 2];
   HEAP32[i1 + 8 >> 2] = HEAP32[i12 + 8 >> 2];
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break;
    HEAP32[i12 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i12);
   i2 = i3;
  }
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 12 >> 2] & 255](i3) | 0;
  HEAP8[i18 >> 0] = i1;
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 255](i3) | 0;
  HEAP8[i19 >> 0] = i1;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i13, i3);
  i1 = i20 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i20 >> 2] >> 0] = 0;
   HEAP32[i20 + 4 >> 2] = 0;
   i1 = i20;
  } else {
   HEAP8[i20 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i20;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i20, 0);
  HEAP32[i1 >> 2] = HEAP32[i13 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i13 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i13 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i13 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i13);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 1023](i16, i3);
  i1 = i21 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i21 >> 2] >> 0] = 0;
   HEAP32[i21 + 4 >> 2] = 0;
   i1 = i21;
  } else {
   HEAP8[i21 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i21;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i21, 0);
  HEAP32[i1 >> 2] = HEAP32[i16 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i16 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i16 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i16 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i16);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0;
 }
 HEAP32[i22 >> 2] = i1;
 STACKTOP = i23;
 return;
}

function _strstr(i1, i17) {
 i1 = i1 | 0;
 i17 = i17 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0;
 i19 = STACKTOP;
 STACKTOP = STACKTOP + 1056 | 0;
 i16 = i19 + 1024 | 0;
 i18 = i19;
 i6 = HEAP8[i17 >> 0] | 0;
 do if (i6 << 24 >> 24) {
  i15 = _strchr(i1, i6 << 24 >> 24) | 0;
  if (i15) {
   i5 = HEAP8[i17 + 1 >> 0] | 0;
   if (i5 << 24 >> 24) {
    i2 = i15 + 1 | 0;
    i8 = HEAP8[i2 >> 0] | 0;
    if (i8 << 24 >> 24) {
     i4 = HEAP8[i17 + 2 >> 0] | 0;
     if (!(i4 << 24 >> 24)) {
      i5 = i5 & 255 | (i6 & 255) << 8;
      i1 = i8;
      i3 = HEAPU8[i15 >> 0] << 8 | i8 & 255;
      while (1) {
       i3 = i3 & 65535;
       if ((i3 | 0) == (i5 | 0)) break;
       i2 = i2 + 1 | 0;
       i4 = HEAP8[i2 >> 0] | 0;
       if (!(i4 << 24 >> 24)) {
        i1 = 0;
        break;
       } else {
        i1 = i4;
        i3 = i4 & 255 | i3 << 8;
       }
      }
      i1 = i1 << 24 >> 24 ? i2 + -1 | 0 : 0;
      break;
     }
     i2 = i15 + 2 | 0;
     i1 = HEAP8[i2 >> 0] | 0;
     if (i1 << 24 >> 24) {
      i3 = HEAP8[i17 + 3 >> 0] | 0;
      if (!(i3 << 24 >> 24)) {
       i4 = (i5 & 255) << 16 | (i6 & 255) << 24 | (i4 & 255) << 8;
       i3 = (i1 & 255) << 8 | (i8 & 255) << 16 | HEAPU8[i15 >> 0] << 24;
       if ((i3 | 0) != (i4 | 0)) do {
        i2 = i2 + 1 | 0;
        i1 = HEAP8[i2 >> 0] | 0;
        i3 = (i1 & 255 | i3) << 8;
       } while (!(i1 << 24 >> 24 == 0 | (i3 | 0) == (i4 | 0)));
       i1 = i1 << 24 >> 24 ? i2 + -2 | 0 : 0;
       break;
      }
      i2 = i15 + 3 | 0;
      i7 = HEAP8[i2 >> 0] | 0;
      if (i7 << 24 >> 24) {
       if (!(HEAP8[i17 + 4 >> 0] | 0)) {
        i4 = (i5 & 255) << 16 | (i6 & 255) << 24 | (i4 & 255) << 8 | i3 & 255;
        i1 = (i1 & 255) << 8 | (i8 & 255) << 16 | i7 & 255 | HEAPU8[i15 >> 0] << 24;
        if ((i1 | 0) == (i4 | 0)) i1 = i7; else {
         i3 = i1;
         do {
          i2 = i2 + 1 | 0;
          i1 = HEAP8[i2 >> 0] | 0;
          i3 = i1 & 255 | i3 << 8;
         } while (!(i1 << 24 >> 24 == 0 | (i3 | 0) == (i4 | 0)));
        }
        i1 = i1 << 24 >> 24 ? i2 + -3 | 0 : 0;
        break;
       };
       HEAP32[i16 >> 2] = 0;
       HEAP32[i16 + 4 >> 2] = 0;
       HEAP32[i16 + 8 >> 2] = 0;
       HEAP32[i16 + 12 >> 2] = 0;
       HEAP32[i16 + 16 >> 2] = 0;
       HEAP32[i16 + 20 >> 2] = 0;
       HEAP32[i16 + 24 >> 2] = 0;
       HEAP32[i16 + 28 >> 2] = 0;
       i1 = i6;
       i3 = 0;
       while (1) {
        if (!(HEAP8[i15 + i3 >> 0] | 0)) {
         i1 = 0;
         break;
        }
        i2 = i16 + (((i1 & 255) >>> 5 & 255) << 2) | 0;
        HEAP32[i2 >> 2] = HEAP32[i2 >> 2] | 1 << (i1 & 31);
        i2 = i3 + 1 | 0;
        HEAP32[i18 + ((i1 & 255) << 2) >> 2] = i2;
        i1 = HEAP8[i17 + i2 >> 0] | 0;
        if (!(i1 << 24 >> 24)) {
         i9 = 23;
         break;
        } else i3 = i2;
       }
       L32 : do if ((i9 | 0) == 23) {
        L34 : do if (i2 >>> 0 > 1) {
         i4 = 1;
         i9 = -1;
         i1 = 0;
         L35 : while (1) {
          i8 = 1;
          while (1) {
           L39 : while (1) {
            i5 = 1;
            while (1) {
             i6 = HEAP8[i17 + (i5 + i9) >> 0] | 0;
             i7 = HEAP8[i17 + i4 >> 0] | 0;
             if (i6 << 24 >> 24 != i7 << 24 >> 24) {
              i8 = i4;
              i5 = i6;
              i4 = i7;
              break L39;
             }
             if ((i5 | 0) == (i8 | 0)) break;
             i5 = i5 + 1 | 0;
             i4 = i5 + i1 | 0;
             if (i4 >>> 0 >= i2 >>> 0) {
              i1 = i9;
              i11 = i8;
              break L35;
             }
            }
            i1 = i1 + i8 | 0;
            i4 = i1 + 1 | 0;
            if (i4 >>> 0 >= i2 >>> 0) {
             i1 = i9;
             i11 = i8;
             break L35;
            }
           }
           i6 = i8 - i9 | 0;
           if ((i5 & 255) <= (i4 & 255)) break;
           i1 = i8 + 1 | 0;
           if (i1 >>> 0 < i2 >>> 0) {
            i4 = i1;
            i1 = i8;
            i8 = i6;
           } else {
            i1 = i9;
            i11 = i6;
            break L35;
           }
          }
          i4 = i1 + 2 | 0;
          if (i4 >>> 0 >= i2 >>> 0) {
           i11 = 1;
           break;
          } else {
           i9 = i1;
           i1 = i1 + 1 | 0;
          }
         }
         i5 = 1;
         i6 = -1;
         i4 = 0;
         while (1) {
          i7 = i4;
          i4 = 1;
          while (1) {
           i10 = i7;
           L54 : while (1) {
            i7 = 1;
            while (1) {
             i9 = HEAP8[i17 + (i7 + i6) >> 0] | 0;
             i8 = HEAP8[i17 + i5 >> 0] | 0;
             if (i9 << 24 >> 24 != i8 << 24 >> 24) {
              i7 = i5;
              i5 = i10;
              break L54;
             }
             if ((i7 | 0) == (i4 | 0)) break;
             i7 = i7 + 1 | 0;
             i5 = i7 + i10 | 0;
             if (i5 >>> 0 >= i2 >>> 0) {
              i5 = i11;
              break L34;
             }
            }
            i10 = i10 + i4 | 0;
            i5 = i10 + 1 | 0;
            if (i5 >>> 0 >= i2 >>> 0) {
             i5 = i11;
             break L34;
            }
           }
           i4 = i7 - i6 | 0;
           if ((i9 & 255) >= (i8 & 255)) {
            i4 = i5;
            break;
           }
           i5 = i7 + 1 | 0;
           if (i5 >>> 0 >= i2 >>> 0) {
            i5 = i11;
            break L34;
           }
          }
          i5 = i4 + 2 | 0;
          if (i5 >>> 0 >= i2 >>> 0) {
           i6 = i4;
           i5 = i11;
           i4 = 1;
           break;
          } else {
           i6 = i4;
           i4 = i4 + 1 | 0;
          }
         }
        } else {
         i1 = -1;
         i6 = -1;
         i5 = 1;
         i4 = 1;
        } while (0);
        i13 = (i6 + 1 | 0) >>> 0 > (i1 + 1 | 0) >>> 0;
        i4 = i13 ? i4 : i5;
        i13 = i13 ? i6 : i1;
        i12 = i13 + 1 | 0;
        if (!(_memcmp(i17, i17 + i4 | 0, i12) | 0)) i14 = i2 - i4 | 0; else {
         i4 = i2 - i13 + -1 | 0;
         i14 = 0;
         i4 = (i13 >>> 0 > i4 >>> 0 ? i13 : i4) + 1 | 0;
        }
        i9 = i2 | 63;
        i10 = (i14 | 0) != 0;
        i11 = i2 - i4 | 0;
        i1 = i15;
        i8 = 0;
        i7 = i15;
        L69 : while (1) {
         i5 = i1;
         do if ((i7 - i5 | 0) >>> 0 < i2 >>> 0) {
          i6 = _memchr(i7, 0, i9) | 0;
          if (i6) if ((i6 - i5 | 0) >>> 0 < i2 >>> 0) {
           i1 = 0;
           break L32;
          } else break; else {
           i6 = i7 + i9 | 0;
           break;
          }
         } else i6 = i7; while (0);
         i5 = HEAP8[i1 + i3 >> 0] | 0;
         if (!(1 << (i5 & 31) & HEAP32[i16 + (((i5 & 255) >>> 5 & 255) << 2) >> 2])) {
          i1 = i1 + i2 | 0;
          i8 = 0;
          i7 = i6;
          continue;
         }
         i15 = HEAP32[i18 + ((i5 & 255) << 2) >> 2] | 0;
         i5 = i2 - i15 | 0;
         if ((i2 | 0) != (i15 | 0)) {
          i1 = i1 + (i10 & (i8 | 0) != 0 & i5 >>> 0 < i4 >>> 0 ? i11 : i5) | 0;
          i8 = 0;
          i7 = i6;
          continue;
         }
         i5 = i12 >>> 0 > i8 >>> 0 ? i12 : i8;
         i7 = HEAP8[i17 + i5 >> 0] | 0;
         L83 : do if (!(i7 << 24 >> 24)) i5 = i12; else {
          while (1) {
           if (i7 << 24 >> 24 != (HEAP8[i1 + i5 >> 0] | 0)) break;
           i5 = i5 + 1 | 0;
           i7 = HEAP8[i17 + i5 >> 0] | 0;
           if (!(i7 << 24 >> 24)) {
            i5 = i12;
            break L83;
           }
          }
          i1 = i1 + (i5 - i13) | 0;
          i8 = 0;
          i7 = i6;
          continue L69;
         } while (0);
         do {
          if (i5 >>> 0 <= i8 >>> 0) break L32;
          i5 = i5 + -1 | 0;
         } while ((HEAP8[i17 + i5 >> 0] | 0) == (HEAP8[i1 + i5 >> 0] | 0));
         i1 = i1 + i4 | 0;
         i8 = i14;
         i7 = i6;
        }
       } while (0);
      } else i1 = 0;
     } else i1 = 0;
    } else i1 = 0;
   } else i1 = i15;
  } else i1 = 0;
 } while (0);
 STACKTOP = i19;
 return i1 | 0;
}

function __ZNSt3__26__sortIRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEvT0_SL_T_(i2, i1, i18) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i18 = i18 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, d9 = 0.0, i10 = 0, d11 = 0.0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i19 = 0;
 i8 = i1;
 L1 : while (1) {
  i15 = i8;
  i1 = i8 + -4 | 0;
  L3 : while (1) {
   i14 = i2;
   i3 = i15 - i14 | 0;
   i4 = i3 >> 2;
   switch (i4 | 0) {
   case 1:
   case 0:
    break L1;
   case 2:
    {
     i4 = i2;
     i2 = i1;
     i3 = i1;
     i19 = 4;
     break L1;
    }
   case 3:
    {
     i19 = 6;
     break L1;
    }
   case 4:
    {
     i19 = 7;
     break L1;
    }
   case 5:
    {
     i19 = 8;
     break L1;
    }
   default:
    {}
   }
   if ((i3 | 0) < 28) {
    i19 = 10;
    break L1;
   }
   i7 = i2 + (((i4 | 0) / 2 | 0) << 2) | 0;
   if ((i3 | 0) > 3996) {
    i3 = (i4 | 0) / 4 | 0;
    i3 = __ZNSt3__27__sort5IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_SL_SL_T_(i2, i2 + (i3 << 2) | 0, i7, i7 + (i3 << 2) | 0, i1, i18) | 0;
   } else i3 = __ZNSt3__27__sort3IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_T_(i2, i7, i1, i18) | 0;
   i6 = HEAP32[i2 >> 2] | 0;
   d11 = +HEAPF64[i6 + 16 >> 3];
   d9 = +HEAPF64[(HEAP32[i7 >> 2] | 0) + 16 >> 3];
   do if (d11 > d9) i5 = i1; else {
    i5 = i1;
    while (1) {
     i5 = i5 + -4 | 0;
     if ((i2 | 0) == (i5 | 0)) break;
     i4 = HEAP32[i5 >> 2] | 0;
     if (+HEAPF64[i4 + 16 >> 3] > d9) {
      i19 = 39;
      break;
     }
    }
    if ((i19 | 0) == 39) {
     i19 = 0;
     HEAP32[i2 >> 2] = i4;
     HEAP32[i5 >> 2] = i6;
     i3 = i3 + 1 | 0;
     break;
    }
    i3 = i2 + 4 | 0;
    i14 = HEAP32[i1 >> 2] | 0;
    i5 = i14;
    if (!(d11 > +HEAPF64[i14 + 16 >> 3])) {
     while (1) {
      if ((i3 | 0) == (i1 | 0)) break L1;
      i4 = HEAP32[i3 >> 2] | 0;
      if (d11 > +HEAPF64[i4 + 16 >> 3]) break;
      i3 = i3 + 4 | 0;
     }
     HEAP32[i3 >> 2] = i5;
     HEAP32[i1 >> 2] = i4;
     i3 = i3 + 4 | 0;
    }
    if ((i3 | 0) == (i1 | 0)) break L1; else i5 = i1;
    while (1) {
     d9 = +HEAPF64[(HEAP32[i2 >> 2] | 0) + 16 >> 3];
     i6 = i3;
     while (1) {
      i4 = HEAP32[i6 >> 2] | 0;
      i3 = i6 + 4 | 0;
      if (d9 > +HEAPF64[i4 + 16 >> 3]) break; else i6 = i3;
     }
     i7 = i4;
     i4 = i5;
     while (1) {
      i5 = i4 + -4 | 0;
      i4 = HEAP32[i5 >> 2] | 0;
      if (d9 > +HEAPF64[i4 + 16 >> 3]) i4 = i5; else break;
     }
     if (i6 >>> 0 >= i5 >>> 0) {
      i2 = i6;
      continue L3;
     }
     HEAP32[i6 >> 2] = i4;
     HEAP32[i5 >> 2] = i7;
    }
   } while (0);
   i4 = i2 + 4 | 0;
   L35 : do if (i4 >>> 0 < i5 >>> 0) {
    i13 = i7;
    while (1) {
     d9 = +HEAPF64[(HEAP32[i13 >> 2] | 0) + 16 >> 3];
     i7 = i4;
     while (1) {
      i6 = HEAP32[i7 >> 2] | 0;
      i4 = i7 + 4 | 0;
      if (+HEAPF64[i6 + 16 >> 3] > d9) i7 = i4; else {
       i12 = i7;
       break;
      }
     }
     do {
      i5 = i5 + -4 | 0;
      i7 = HEAP32[i5 >> 2] | 0;
     } while (!(+HEAPF64[i7 + 16 >> 3] > d9));
     i10 = i5;
     i5 = i7;
     if (i12 >>> 0 > i10 >>> 0) {
      i5 = i12;
      i4 = i13;
      break L35;
     }
     HEAP32[i12 >> 2] = i5;
     HEAP32[i10 >> 2] = i6;
     i5 = i10;
     i13 = (i13 | 0) == (i12 | 0) ? i10 : i13;
     i3 = i3 + 1 | 0;
    }
   } else {
    i5 = i4;
    i4 = i7;
   } while (0);
   if ((i5 | 0) != (i4 | 0) ? (i16 = HEAP32[i4 >> 2] | 0, i17 = HEAP32[i5 >> 2] | 0, +HEAPF64[i16 + 16 >> 3] > +HEAPF64[i17 + 16 >> 3]) : 0) {
    HEAP32[i5 >> 2] = i16;
    HEAP32[i4 >> 2] = i17;
    i3 = i3 + 1 | 0;
   }
   if (!i3) {
    i3 = __ZNSt3__227__insertion_sort_incompleteIRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEbT0_SL_T_(i2, i5, i18) | 0;
    i4 = i5 + 4 | 0;
    if (__ZNSt3__227__insertion_sort_incompleteIRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEbT0_SL_T_(i4, i8, i18) | 0) {
     i19 = 56;
     break;
    }
    if (i3) {
     i2 = i4;
     continue;
    }
   }
   i13 = i5;
   if ((i13 - i14 | 0) >= (i15 - i13 | 0)) {
    i1 = i5;
    i19 = 55;
    break;
   }
   __ZNSt3__26__sortIRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEvT0_SL_T_(i2, i5, i18);
   i2 = i5 + 4 | 0;
  }
  if ((i19 | 0) == 55) {
   i19 = 0;
   __ZNSt3__26__sortIRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEvT0_SL_T_(i1 + 4 | 0, i8, i18);
   i8 = i1;
   continue;
  } else if ((i19 | 0) == 56) {
   i19 = 0;
   if (i3) break; else {
    i8 = i5;
    continue;
   }
  }
 }
 L58 : do if ((i19 | 0) == 4) {
  i1 = HEAP32[i2 >> 2] | 0;
  i2 = HEAP32[i4 >> 2] | 0;
  if (+HEAPF64[i1 + 16 >> 3] > +HEAPF64[i2 + 16 >> 3]) {
   HEAP32[i4 >> 2] = i1;
   HEAP32[i3 >> 2] = i2;
  }
 } else if ((i19 | 0) == 6) __ZNSt3__27__sort3IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_T_(i2, i2 + 4 | 0, i1, i18) | 0; else if ((i19 | 0) == 7) __ZNSt3__27__sort4IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_SL_T_(i2, i2 + 4 | 0, i2 + 8 | 0, i1, i18) | 0; else if ((i19 | 0) == 8) __ZNSt3__27__sort5IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_SL_SL_T_(i2, i2 + 4 | 0, i2 + 8 | 0, i2 + 12 | 0, i1, i18) | 0; else if ((i19 | 0) == 10) {
  i1 = i2 + 8 | 0;
  __ZNSt3__27__sort3IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_T_(i2, i2 + 4 | 0, i1, i18) | 0;
  i7 = i2 + 12 | 0;
  while (1) {
   if ((i7 | 0) == (i8 | 0)) break L58;
   i6 = HEAP32[i7 >> 2] | 0;
   i4 = i6 + 16 | 0;
   if (+HEAPF64[i4 >> 3] > +HEAPF64[(HEAP32[i1 >> 2] | 0) + 16 >> 3]) {
    HEAP32[i7 >> 2] = 0;
    i3 = i7;
    i5 = i1;
    while (1) {
     i19 = HEAP32[i5 >> 2] | 0;
     HEAP32[i5 >> 2] = 0;
     i1 = HEAP32[i3 >> 2] | 0;
     HEAP32[i3 >> 2] = i19;
     if (i1 | 0) {
      __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1);
      __ZdlPv(i1);
     }
     if ((i5 | 0) == (i2 | 0)) {
      i1 = i5;
      i3 = i5;
      break;
     }
     i1 = i5 + -4 | 0;
     if (+HEAPF64[i4 >> 3] > +HEAPF64[(HEAP32[i1 >> 2] | 0) + 16 >> 3]) {
      i3 = i5;
      i5 = i1;
     } else {
      i1 = i5;
      i3 = i5;
      break;
     }
    }
    i1 = HEAP32[i1 >> 2] | 0;
    HEAP32[i3 >> 2] = i6;
    if (i1 | 0) {
     __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1);
     __ZdlPv(i1);
    }
   }
   i1 = i7;
   i7 = i7 + 4 | 0;
  }
 } while (0);
 return;
}

function __ZN4wasm17WasmBinaryBuilder14readExpressionERPNS_10ExpressionE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0, i10 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i8;
 i3 = i7 + 16 | 0;
 if ((HEAP32[i3 >> 2] | 0) != (HEAP32[i7 + 68 >> 2] | 0)) {
  i5 = i7 + 12 | 0;
  if (HEAP8[i5 >> 0] | 0) {
   i1 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23914) | 0;
   i9 = i7 + 124 | 0;
   i4 = (HEAP32[i9 >> 2] | 0) + 1 | 0;
   HEAP32[i9 >> 2] = i4;
   i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(i1, i4) | 0, 23931) | 0;
   i4 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i4, HEAP32[i3 >> 2] | 0) | 0;
   i1 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i2 >> 2] = i1;
   i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
   i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 10) | 0;
   __ZNSt3__26localeD2Ev(i2);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i1) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  }
  i4 = __ZN4wasm17WasmBinaryBuilder7getInt8Ev(i7) | 0;
  if (!(HEAP8[i5 >> 0] | 0)) i1 = i4 & 255; else {
   i1 = i4 & 255;
   i9 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23936) | 0, i1) | 0;
   i10 = __ZNKSt3__28ios_base6getlocEv(i9 + (HEAP32[(HEAP32[i9 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i2 >> 2] = i10;
   i10 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
   i10 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i10 >> 2] | 0) + 28 >> 2] & 63](i10, 10) | 0;
   __ZNSt3__26localeD2Ev(i2);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i9, i10) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i9) | 0;
  }
  do switch (i1 | 0) {
  case 1:
   {
    i10 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder10visitBlockEPNS_5BlockE(i7, __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i10) | 0);
    break;
   }
  case 3:
   {
    i10 = __ZN10MixedArena5allocIN4wasm2IfEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder7visitIfEPNS_2IfE(i7, __ZN4wasm10Expression4castINS_2IfEEEPT_v(i10) | 0);
    break;
   }
  case 2:
   {
    i10 = __ZN10MixedArena5allocIN4wasm4LoopEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder9visitLoopEPNS_4LoopE(i7, __ZN4wasm10Expression4castINS_4LoopEEEPT_v(i10) | 0);
    break;
   }
  case 7:
  case 6:
   {
    i10 = __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder10visitBreakEPNS_5BreakEh(i7, __ZN4wasm10Expression4castINS_5BreakEEEPT_v(i10) | 0, i4);
    break;
   }
  case 8:
   {
    i10 = __ZN10MixedArena5allocIN4wasm6SwitchEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder11visitSwitchEPNS_6SwitchE(i7, __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i10) | 0);
    break;
   }
  case 22:
   {
    i10 = __ZN10MixedArena5allocIN4wasm4CallEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder9visitCallEPNS_4CallE(i7, __ZN4wasm10Expression4castINS_4CallEEEPT_v(i10) | 0);
    break;
   }
  case 24:
   {
    i10 = __ZN10MixedArena5allocIN4wasm10CallImportEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder15visitCallImportEPNS_10CallImportE(i7, __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i10) | 0);
    break;
   }
  case 23:
   {
    i10 = __ZN10MixedArena5allocIN4wasm12CallIndirectEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder17visitCallIndirectEPNS_12CallIndirectE(i7, __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i10) | 0);
    break;
   }
  case 20:
   {
    i10 = __ZN10MixedArena5allocIN4wasm8GetLocalEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder13visitGetLocalEPNS_8GetLocalE(i7, __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(i10) | 0);
    break;
   }
  case 21:
   {
    i10 = __ZN10MixedArena5allocIN4wasm8SetLocalEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder13visitSetLocalEPNS_8SetLocalE(i7, __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i10) | 0);
    break;
   }
  case 5:
   {
    i10 = __ZN10MixedArena5allocIN4wasm6SelectEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder11visitSelectEPNS_6SelectE(i7, __ZN4wasm10Expression4castINS_6SelectEEEPT_v(i10) | 0);
    break;
   }
  case 9:
   {
    i10 = __ZN10MixedArena5allocIN4wasm6ReturnEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder11visitReturnEPNS_6ReturnE(i7, __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i10) | 0);
    break;
   }
  case 0:
   {
    i10 = __ZN10MixedArena5allocIN4wasm3NopEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder8visitNopEPNS_3NopE(i7, __ZN4wasm10Expression4castINS_3NopEEEPT_v(i10) | 0);
    break;
   }
  case 10:
   {
    i10 = __ZN10MixedArena5allocIN4wasm11UnreachableEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
    HEAP32[i6 >> 2] = i10;
    __ZN4wasm17WasmBinaryBuilder16visitUnreachableEPNS_11UnreachableE(i7, __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(i10) | 0);
    break;
   }
  case 4:
  case 15:
   {
    HEAP32[i6 >> 2] = 0;
    break;
   }
  default:
   if (((((!(__ZN4wasm17WasmBinaryBuilder16maybeVisitBinaryERPNS_10ExpressionEh(i7, i6, i4) | 0) ? !(__ZN4wasm17WasmBinaryBuilder15maybeVisitUnaryERPNS_10ExpressionEh(i7, i6, i4) | 0) : 0) ? !(__ZN4wasm17WasmBinaryBuilder15maybeVisitConstERPNS_10ExpressionEh(i7, i6, i4) | 0) : 0) ? !(__ZN4wasm17WasmBinaryBuilder14maybeVisitLoadERPNS_10ExpressionEh(i7, i6, i4) | 0) : 0) ? !(__ZN4wasm17WasmBinaryBuilder15maybeVisitStoreERPNS_10ExpressionEh(i7, i6, i4) | 0) : 0) ? !(__ZN4wasm17WasmBinaryBuilder14maybeVisitHostERPNS_10ExpressionEh(i7, i6, i4) | 0) : 0) {
    i10 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23959) | 0;
    i9 = i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
    HEAP32[i9 >> 2] = HEAP32[i9 >> 2] & -75 | 8;
    i10 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(i10, i1) | 0;
    i9 = __ZNKSt3__28ios_base6getlocEv(i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
    HEAP32[i2 >> 2] = i9;
    i9 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
    i9 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i9 >> 2] | 0) + 28 >> 2] & 63](i9, 10) | 0;
    __ZNSt3__26localeD2Ev(i2);
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i10, i9) | 0;
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i10) | 0;
    _abort();
   }
  } while (0);
  if (HEAP8[i5 >> 0] | 0) {
   i9 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23971) | 0;
   i7 = i7 + 124 | 0;
   i10 = HEAP32[i7 >> 2] | 0;
   HEAP32[i7 >> 2] = i10 + -1;
   i10 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(i9, i10) | 0, 23931) | 0;
   i10 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i10, HEAP32[i3 >> 2] | 0) | 0;
   i9 = __ZNKSt3__28ios_base6getlocEv(i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i2 >> 2] = i9;
   i9 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
   i9 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i9 >> 2] | 0) + 28 >> 2] & 63](i9, 10) | 0;
   __ZNSt3__26localeD2Ev(i2);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i10, i9) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i10) | 0;
  }
 } else {
  HEAP32[i6 >> 2] = 0;
  i1 = 15;
 }
 STACKTOP = i8;
 return i1 | 0;
}

function __ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri(i1, i11, i2, i12, i18, i19, i20, i21, i13, i22) {
 i1 = i1 | 0;
 i11 = i11 | 0;
 i2 = i2 | 0;
 i12 = i12 | 0;
 i18 = i18 | 0;
 i19 = i19 | 0;
 i20 = i20 | 0;
 i21 = i21 | 0;
 i13 = i13 | 0;
 i22 = i22 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i23 = 0;
 i23 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i3 = i23 + 108 | 0;
 i7 = i23 + 96 | 0;
 i4 = i23 + 92 | 0;
 i8 = i23 + 80 | 0;
 i15 = i23 + 68 | 0;
 i17 = i23 + 56 | 0;
 i5 = i23 + 52 | 0;
 i9 = i23 + 40 | 0;
 i6 = i23 + 36 | 0;
 i10 = i23 + 24 | 0;
 i14 = i23 + 12 | 0;
 i16 = i23;
 if (i1) {
  i2 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 63416) | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if (i11) {
   FUNCTION_TABLE_vii[HEAP32[i1 + 44 >> 2] & 1023](i3, i2);
   i1 = HEAP32[i3 >> 2] | 0;
   HEAP8[i12 >> 0] = i1;
   HEAP8[i12 + 1 >> 0] = i1 >> 8;
   HEAP8[i12 + 2 >> 0] = i1 >> 16;
   HEAP8[i12 + 3 >> 0] = i1 >> 24;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 32 >> 2] & 1023](i7, i2);
   i1 = i13 + 8 + 3 | 0;
   if ((HEAP8[i1 >> 0] | 0) < 0) {
    HEAP32[HEAP32[i13 >> 2] >> 2] = 0;
    HEAP32[i13 + 4 >> 2] = 0;
   } else {
    HEAP32[i13 >> 2] = 0;
    HEAP8[i1 >> 0] = 0;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i13, 0);
   HEAP32[i13 >> 2] = HEAP32[i7 >> 2];
   HEAP32[i13 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
   HEAP32[i13 + 8 >> 2] = HEAP32[i7 + 8 >> 2];
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break;
    HEAP32[i7 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i7);
  } else {
   FUNCTION_TABLE_vii[HEAP32[i1 + 40 >> 2] & 1023](i4, i2);
   i1 = HEAP32[i4 >> 2] | 0;
   HEAP8[i12 >> 0] = i1;
   HEAP8[i12 + 1 >> 0] = i1 >> 8;
   HEAP8[i12 + 2 >> 0] = i1 >> 16;
   HEAP8[i12 + 3 >> 0] = i1 >> 24;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 28 >> 2] & 1023](i8, i2);
   i1 = i13 + 8 + 3 | 0;
   if ((HEAP8[i1 >> 0] | 0) < 0) {
    HEAP32[HEAP32[i13 >> 2] >> 2] = 0;
    HEAP32[i13 + 4 >> 2] = 0;
   } else {
    HEAP32[i13 >> 2] = 0;
    HEAP8[i1 >> 0] = 0;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i13, 0);
   HEAP32[i13 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i13 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
   HEAP32[i13 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break;
    HEAP32[i8 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i8);
  }
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 255](i2) | 0;
  HEAP32[i18 >> 2] = i1;
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 16 >> 2] & 255](i2) | 0;
  HEAP32[i19 >> 2] = i1;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i15, i2);
  i1 = i20 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i20 >> 2] >> 0] = 0;
   HEAP32[i20 + 4 >> 2] = 0;
   i1 = i20;
  } else {
   HEAP8[i20 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i20;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i20, 0);
  HEAP32[i1 >> 2] = HEAP32[i15 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i15 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i15 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i15 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i15);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 1023](i17, i2);
  i1 = i21 + 8 + 3 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP32[HEAP32[i21 >> 2] >> 2] = 0;
   HEAP32[i21 + 4 >> 2] = 0;
  } else {
   HEAP32[i21 >> 2] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i21, 0);
  HEAP32[i21 >> 2] = HEAP32[i17 >> 2];
  HEAP32[i21 + 4 >> 2] = HEAP32[i17 + 4 >> 2];
  HEAP32[i21 + 8 >> 2] = HEAP32[i17 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i17 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i17);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0;
 } else {
  i2 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 63408) | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if (i11) {
   FUNCTION_TABLE_vii[HEAP32[i1 + 44 >> 2] & 1023](i5, i2);
   i1 = HEAP32[i5 >> 2] | 0;
   HEAP8[i12 >> 0] = i1;
   HEAP8[i12 + 1 >> 0] = i1 >> 8;
   HEAP8[i12 + 2 >> 0] = i1 >> 16;
   HEAP8[i12 + 3 >> 0] = i1 >> 24;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 32 >> 2] & 1023](i9, i2);
   i1 = i13 + 8 + 3 | 0;
   if ((HEAP8[i1 >> 0] | 0) < 0) {
    HEAP32[HEAP32[i13 >> 2] >> 2] = 0;
    HEAP32[i13 + 4 >> 2] = 0;
   } else {
    HEAP32[i13 >> 2] = 0;
    HEAP8[i1 >> 0] = 0;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i13, 0);
   HEAP32[i13 >> 2] = HEAP32[i9 >> 2];
   HEAP32[i13 + 4 >> 2] = HEAP32[i9 + 4 >> 2];
   HEAP32[i13 + 8 >> 2] = HEAP32[i9 + 8 >> 2];
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break;
    HEAP32[i9 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i9);
  } else {
   FUNCTION_TABLE_vii[HEAP32[i1 + 40 >> 2] & 1023](i6, i2);
   i1 = HEAP32[i6 >> 2] | 0;
   HEAP8[i12 >> 0] = i1;
   HEAP8[i12 + 1 >> 0] = i1 >> 8;
   HEAP8[i12 + 2 >> 0] = i1 >> 16;
   HEAP8[i12 + 3 >> 0] = i1 >> 24;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 28 >> 2] & 1023](i10, i2);
   i1 = i13 + 8 + 3 | 0;
   if ((HEAP8[i1 >> 0] | 0) < 0) {
    HEAP32[HEAP32[i13 >> 2] >> 2] = 0;
    HEAP32[i13 + 4 >> 2] = 0;
   } else {
    HEAP32[i13 >> 2] = 0;
    HEAP8[i1 >> 0] = 0;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i13, 0);
   HEAP32[i13 >> 2] = HEAP32[i10 >> 2];
   HEAP32[i13 + 4 >> 2] = HEAP32[i10 + 4 >> 2];
   HEAP32[i13 + 8 >> 2] = HEAP32[i10 + 8 >> 2];
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break;
    HEAP32[i10 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i10);
  }
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 255](i2) | 0;
  HEAP32[i18 >> 2] = i1;
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 16 >> 2] & 255](i2) | 0;
  HEAP32[i19 >> 2] = i1;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i14, i2);
  i1 = i20 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i20 >> 2] >> 0] = 0;
   HEAP32[i20 + 4 >> 2] = 0;
   i1 = i20;
  } else {
   HEAP8[i20 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i20;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i20, 0);
  HEAP32[i1 >> 2] = HEAP32[i14 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i14 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i14 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i14 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i14);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 1023](i16, i2);
  i1 = i21 + 8 + 3 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP32[HEAP32[i21 >> 2] >> 2] = 0;
   HEAP32[i21 + 4 >> 2] = 0;
  } else {
   HEAP32[i21 >> 2] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i21, 0);
  HEAP32[i21 >> 2] = HEAP32[i16 >> 2];
  HEAP32[i21 + 4 >> 2] = HEAP32[i16 + 4 >> 2];
  HEAP32[i21 + 8 >> 2] = HEAP32[i16 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i16 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i16);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0;
 }
 HEAP32[i22 >> 2] = i1;
 STACKTOP = i23;
 return;
}

function ___intscan(i13, i3, i6, i1, i2) {
 i13 = i13 | 0;
 i3 = i3 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i15 = 0;
 L1 : do if (i3 >>> 0 > 36) {
  i2 = ___errno_location() | 0;
  HEAP32[i2 >> 2] = 22;
  i2 = 0;
  i1 = 0;
 } else {
  i15 = i13 + 4 | 0;
  i14 = i13 + 100 | 0;
  do {
   i4 = HEAP32[i15 >> 2] | 0;
   if (i4 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
    HEAP32[i15 >> 2] = i4 + 1;
    i4 = HEAPU8[i4 >> 0] | 0;
   } else i4 = ___shgetc(i13) | 0;
  } while ((_isspace(i4) | 0) != 0);
  L11 : do switch (i4 | 0) {
  case 43:
  case 45:
   {
    i5 = ((i4 | 0) == 45) << 31 >> 31;
    i4 = HEAP32[i15 >> 2] | 0;
    if (i4 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
     HEAP32[i15 >> 2] = i4 + 1;
     i4 = HEAPU8[i4 >> 0] | 0;
     i12 = i5;
     break L11;
    } else {
     i4 = ___shgetc(i13) | 0;
     i12 = i5;
     break L11;
    }
   }
  default:
   i12 = 0;
  } while (0);
  i5 = (i3 | 0) == 0;
  do if ((i3 | 16 | 0) == 16 & (i4 | 0) == 48) {
   i4 = HEAP32[i15 >> 2] | 0;
   if (i4 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
    HEAP32[i15 >> 2] = i4 + 1;
    i4 = HEAPU8[i4 >> 0] | 0;
   } else i4 = ___shgetc(i13) | 0;
   if ((i4 | 32 | 0) != 120) if (i5) {
    i3 = 8;
    i10 = 46;
    break;
   } else {
    i10 = 32;
    break;
   }
   i3 = HEAP32[i15 >> 2] | 0;
   if (i3 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
    HEAP32[i15 >> 2] = i3 + 1;
    i4 = HEAPU8[i3 >> 0] | 0;
   } else i4 = ___shgetc(i13) | 0;
   if ((HEAPU8[49681 + i4 >> 0] | 0) > 15) {
    i1 = (HEAP32[i14 >> 2] | 0) == 0;
    if (!i1) HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + -1;
    if (!i6) {
     ___shlim(i13, 0);
     i2 = 0;
     i1 = 0;
     break L1;
    }
    if (i1) {
     i2 = 0;
     i1 = 0;
     break L1;
    }
    HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + -1;
    i2 = 0;
    i1 = 0;
    break L1;
   } else {
    i3 = 16;
    i10 = 46;
   }
  } else {
   i3 = i5 ? 10 : i3;
   if ((HEAPU8[49681 + i4 >> 0] | 0) >>> 0 < i3 >>> 0) i10 = 32; else {
    if (HEAP32[i14 >> 2] | 0) HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + -1;
    ___shlim(i13, 0);
    i2 = ___errno_location() | 0;
    HEAP32[i2 >> 2] = 22;
    i2 = 0;
    i1 = 0;
    break L1;
   }
  } while (0);
  if ((i10 | 0) == 32) if ((i3 | 0) == 10) {
   i3 = i4 + -48 | 0;
   if (i3 >>> 0 < 10) {
    i4 = 0;
    while (1) {
     i5 = (i4 * 10 | 0) + i3 | 0;
     i3 = HEAP32[i15 >> 2] | 0;
     if (i3 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
      HEAP32[i15 >> 2] = i3 + 1;
      i4 = HEAPU8[i3 >> 0] | 0;
     } else i4 = ___shgetc(i13) | 0;
     i3 = i4 + -48 | 0;
     if (!(i3 >>> 0 < 10 & i5 >>> 0 < 429496729)) {
      i3 = i5;
      break;
     } else i4 = i5;
    }
    i5 = 0;
   } else {
    i3 = 0;
    i5 = 0;
   }
   i6 = i4 + -48 | 0;
   if (i6 >>> 0 < 10) {
    while (1) {
     i7 = ___muldi3(i3 | 0, i5 | 0, 10, 0) | 0;
     i8 = tempRet0;
     i9 = ((i6 | 0) < 0) << 31 >> 31;
     i11 = ~i9;
     if (i8 >>> 0 > i11 >>> 0 | (i8 | 0) == (i11 | 0) & i7 >>> 0 > ~i6 >>> 0) {
      i7 = i3;
      break;
     }
     i3 = _i64Add(i7 | 0, i8 | 0, i6 | 0, i9 | 0) | 0;
     i5 = tempRet0;
     i4 = HEAP32[i15 >> 2] | 0;
     if (i4 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
      HEAP32[i15 >> 2] = i4 + 1;
      i4 = HEAPU8[i4 >> 0] | 0;
     } else i4 = ___shgetc(i13) | 0;
     i6 = i4 + -48 | 0;
     if (!(i6 >>> 0 < 10 & (i5 >>> 0 < 429496729 | (i5 | 0) == 429496729 & i3 >>> 0 < 2576980378))) {
      i7 = i3;
      break;
     }
    }
    if (i6 >>> 0 > 9) {
     i4 = i7;
     i3 = i12;
    } else {
     i3 = 10;
     i10 = 72;
    }
   } else {
    i4 = i3;
    i3 = i12;
   }
  } else i10 = 46;
  L63 : do if ((i10 | 0) == 46) {
   if (!(i3 + -1 & i3)) {
    i10 = HEAP8[49937 + ((i3 * 23 | 0) >>> 5 & 7) >> 0] | 0;
    i5 = HEAP8[49681 + i4 >> 0] | 0;
    i6 = i5 & 255;
    if (i6 >>> 0 < i3 >>> 0) {
     i4 = 0;
     while (1) {
      i7 = i6 | i4 << i10;
      i4 = HEAP32[i15 >> 2] | 0;
      if (i4 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
       HEAP32[i15 >> 2] = i4 + 1;
       i4 = HEAPU8[i4 >> 0] | 0;
      } else i4 = ___shgetc(i13) | 0;
      i5 = HEAP8[49681 + i4 >> 0] | 0;
      i6 = i5 & 255;
      if (!(i7 >>> 0 < 134217728 & i6 >>> 0 < i3 >>> 0)) break; else i4 = i7;
     }
     i6 = 0;
    } else {
     i6 = 0;
     i7 = 0;
    }
    i8 = _bitshift64Lshr(-1, -1, i10 | 0) | 0;
    i9 = tempRet0;
    if ((i5 & 255) >>> 0 >= i3 >>> 0 | (i6 >>> 0 > i9 >>> 0 | (i6 | 0) == (i9 | 0) & i7 >>> 0 > i8 >>> 0)) {
     i5 = i6;
     i10 = 72;
     break;
    } else i4 = i6;
    while (1) {
     i7 = _bitshift64Shl(i7 | 0, i4 | 0, i10 | 0) | 0;
     i6 = tempRet0;
     i7 = i5 & 255 | i7;
     i4 = HEAP32[i15 >> 2] | 0;
     if (i4 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
      HEAP32[i15 >> 2] = i4 + 1;
      i4 = HEAPU8[i4 >> 0] | 0;
     } else i4 = ___shgetc(i13) | 0;
     i5 = HEAP8[49681 + i4 >> 0] | 0;
     if ((i5 & 255) >>> 0 >= i3 >>> 0 | (i6 >>> 0 > i9 >>> 0 | (i6 | 0) == (i9 | 0) & i7 >>> 0 > i8 >>> 0)) {
      i5 = i6;
      i10 = 72;
      break L63;
     } else i4 = i6;
    }
   }
   i5 = HEAP8[49681 + i4 >> 0] | 0;
   i6 = i5 & 255;
   if (i6 >>> 0 < i3 >>> 0) {
    i4 = 0;
    while (1) {
     i7 = i6 + (Math_imul(i4, i3) | 0) | 0;
     i4 = HEAP32[i15 >> 2] | 0;
     if (i4 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
      HEAP32[i15 >> 2] = i4 + 1;
      i4 = HEAPU8[i4 >> 0] | 0;
     } else i4 = ___shgetc(i13) | 0;
     i5 = HEAP8[49681 + i4 >> 0] | 0;
     i6 = i5 & 255;
     if (!(i7 >>> 0 < 119304647 & i6 >>> 0 < i3 >>> 0)) break; else i4 = i7;
    }
    i6 = 0;
   } else {
    i7 = 0;
    i6 = 0;
   }
   if ((i5 & 255) >>> 0 < i3 >>> 0) {
    i10 = ___udivdi3(-1, -1, i3 | 0, 0) | 0;
    i11 = tempRet0;
    i9 = i6;
    while (1) {
     if (i9 >>> 0 > i11 >>> 0 | (i9 | 0) == (i11 | 0) & i7 >>> 0 > i10 >>> 0) {
      i5 = i9;
      i10 = 72;
      break L63;
     }
     i6 = ___muldi3(i7 | 0, i9 | 0, i3 | 0, 0) | 0;
     i8 = tempRet0;
     i5 = i5 & 255;
     if (i8 >>> 0 > 4294967295 | (i8 | 0) == -1 & i6 >>> 0 > ~i5 >>> 0) {
      i5 = i9;
      i10 = 72;
      break L63;
     }
     i7 = _i64Add(i5 | 0, 0, i6 | 0, i8 | 0) | 0;
     i6 = tempRet0;
     i4 = HEAP32[i15 >> 2] | 0;
     if (i4 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
      HEAP32[i15 >> 2] = i4 + 1;
      i4 = HEAPU8[i4 >> 0] | 0;
     } else i4 = ___shgetc(i13) | 0;
     i5 = HEAP8[49681 + i4 >> 0] | 0;
     if ((i5 & 255) >>> 0 >= i3 >>> 0) {
      i5 = i6;
      i10 = 72;
      break;
     } else i9 = i6;
    }
   } else {
    i5 = i6;
    i10 = 72;
   }
  } while (0);
  if ((i10 | 0) == 72) if ((HEAPU8[49681 + i4 >> 0] | 0) >>> 0 < i3 >>> 0) {
   do {
    i4 = HEAP32[i15 >> 2] | 0;
    if (i4 >>> 0 < (HEAP32[i14 >> 2] | 0) >>> 0) {
     HEAP32[i15 >> 2] = i4 + 1;
     i4 = HEAPU8[i4 >> 0] | 0;
    } else i4 = ___shgetc(i13) | 0;
   } while ((HEAPU8[49681 + i4 >> 0] | 0) >>> 0 < i3 >>> 0);
   i5 = ___errno_location() | 0;
   HEAP32[i5 >> 2] = 34;
   i5 = i2;
   i4 = i1;
   i3 = (i1 & 1 | 0) == 0 & 0 == 0 ? i12 : 0;
  } else {
   i4 = i7;
   i3 = i12;
  }
  if (HEAP32[i14 >> 2] | 0) HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + -1;
  if (!(i5 >>> 0 < i2 >>> 0 | (i5 | 0) == (i2 | 0) & i4 >>> 0 < i1 >>> 0)) {
   if (!((i1 & 1 | 0) != 0 | 0 != 0 | (i3 | 0) != 0)) {
    i15 = ___errno_location() | 0;
    HEAP32[i15 >> 2] = 34;
    i1 = _i64Add(i1 | 0, i2 | 0, -1, -1) | 0;
    i2 = tempRet0;
    break;
   }
   if (i5 >>> 0 > i2 >>> 0 | (i5 | 0) == (i2 | 0) & i4 >>> 0 > i1 >>> 0) {
    i15 = ___errno_location() | 0;
    HEAP32[i15 >> 2] = 34;
    break;
   }
  }
  i1 = ((i3 | 0) < 0) << 31 >> 31;
  i1 = _i64Subtract(i4 ^ i3 | 0, i5 ^ i1 | 0, i3 | 0, i1 | 0) | 0;
  i2 = tempRet0;
 } while (0);
 tempRet0 = i2;
 return i1 | 0;
}

function __ZN4wasm28DuplicateFunctionElimination3runEPNS_10PassRunnerEPNS_6ModuleE(i51, i1, i50) {
 i51 = i51 | 0;
 i1 = i1 | 0;
 i50 = i50 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i39 = 0, i40 = 0, i41 = 0, i42 = 0, i43 = 0, i44 = 0, i45 = 0, i46 = 0, i47 = 0, i48 = 0, i49 = 0;
 i48 = STACKTOP;
 STACKTOP = STACKTOP + 144 | 0;
 i9 = i48 + 112 | 0;
 i8 = i48 + 108 | 0;
 i7 = i48 + 100 | 0;
 i10 = i48 + 104 | 0;
 i46 = i48 + 60 | 0;
 i45 = i48 + 44 | 0;
 i11 = i48 + 96 | 0;
 i22 = i48 + 56 | 0;
 i47 = i48 + 32 | 0;
 i44 = i48 + 20 | 0;
 i33 = i48 + 16 | 0;
 i38 = i48 + 12 | 0;
 i39 = i48 + 8 | 0;
 i40 = i48 + 4 | 0;
 i41 = i48;
 i42 = i51 + 16 | 0;
 i43 = i50 + 36 | 0;
 i12 = i50 + 40 | 0;
 i13 = i46 + 4 | 0;
 i14 = i46 + 32 | 0;
 i15 = i46 + 28 | 0;
 i16 = i46 + 24 | 0;
 i17 = i45 + 4 | 0;
 i18 = i45 + 8 | 0;
 i19 = i45 + 4 | 0;
 i20 = i47 + 4 | 0;
 i21 = i47 + 8 | 0;
 i23 = i47 + 4 | 0;
 i24 = i44 + 4 | 0;
 i25 = i44 + 8 | 0;
 i26 = i44 + 4 | 0;
 i27 = i9 + 4 | 0;
 i28 = i9 + 28 | 0;
 i29 = i9 + 24 | 0;
 i30 = i50 + 48 | 0;
 i31 = i50 + 52 | 0;
 i32 = i50 + 84 | 0;
 i34 = i50 + 24 | 0;
 i35 = i50 + 28 | 0;
 i36 = i9 + 8 | 0;
 i37 = i46 + 8 | 0;
 while (1) {
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE5clearEv(i42);
  i1 = HEAP32[i12 >> 2] | 0;
  i2 = HEAP32[i43 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i1 | 0)) break;
   HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
   i6 = __ZNSt3__23mapIPN4wasm8FunctionEjNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_jEEEEEixEOS3_(i42, i10) | 0;
   HEAP32[i6 >> 2] = 0;
   i2 = i2 + 4 | 0;
  }
  HEAP32[i13 >> 2] = 0;
  HEAP32[i13 + 4 >> 2] = 0;
  HEAP32[i13 + 8 >> 2] = 0;
  HEAP32[i13 + 12 >> 2] = 0;
  HEAP32[i13 + 16 >> 2] = 0;
  HEAP32[i46 >> 2] = 7396;
  HEAP32[i14 >> 2] = 0;
  HEAP32[i15 >> 2] = i42;
  HEAP32[i16 >> 2] = i50;
  __ZN4wasm6WalkerINS_14FunctionHasherENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i46, i50);
  HEAP32[i17 >> 2] = 0;
  HEAP32[i18 >> 2] = 0;
  HEAP32[i45 >> 2] = i19;
  i1 = HEAP32[i12 >> 2] | 0;
  i6 = HEAP32[i43 >> 2] | 0;
  while (1) {
   if ((i6 | 0) == (i1 | 0)) break;
   HEAP32[i11 >> 2] = HEAP32[i6 >> 2];
   i2 = __ZNSt3__23mapIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS4_EEEENS_4lessIjEENS5_INS_4pairIKjS7_EEEEEixERSB_(i45, __ZNSt3__23mapIPN4wasm8FunctionEjNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_jEEEEEixEOS3_(i42, i11) | 0) | 0;
   i3 = HEAP32[i6 >> 2] | 0;
   HEAP32[i22 >> 2] = i3;
   i4 = i2 + 4 | 0;
   i5 = HEAP32[i4 >> 2] | 0;
   if (i5 >>> 0 < (HEAP32[i2 + 8 >> 2] | 0) >>> 0) {
    HEAP32[i5 >> 2] = i3;
    HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 4;
   } else __ZNSt3__26vectorIPN4wasm8FunctionENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i2, i22);
   i6 = i6 + 4 | 0;
  }
  HEAP32[i20 >> 2] = 0;
  HEAP32[i21 >> 2] = 0;
  HEAP32[i47 >> 2] = i23;
  HEAP32[i24 >> 2] = 0;
  HEAP32[i25 >> 2] = 0;
  HEAP32[i44 >> 2] = i26;
  i5 = HEAP32[i45 >> 2] | 0;
  while (1) {
   if ((i5 | 0) == (i19 | 0)) break;
   i4 = HEAP32[i5 + 24 >> 2] | 0;
   i6 = HEAP32[i5 + 20 >> 2] | 0;
   i1 = i6;
   i3 = i4;
   L18 : do if ((i4 - i6 | 0) != 4) {
    i4 = HEAP32[i1 >> 2] | 0;
    while (1) {
     if ((i1 | 0) == (i3 | 0)) break L18;
     i2 = HEAP32[i1 >> 2] | 0;
     if ((i2 | 0) != (i4 | 0) ? __ZN4wasm28DuplicateFunctionElimination5equalEPNS_8FunctionES2_(i51, i2, i4) | 0 : 0) {
      i6 = __ZNSt3__23mapIN4wasm4NameES2_NS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S2_EEEEEixERS7_(i47, i2) | 0;
      HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
      __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i9, i44, i2, i2);
     }
     i1 = i1 + 4 | 0;
    }
   } while (0);
   i5 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i5) | 0;
  }
  if (!(HEAP32[i21 >> 2] | 0)) break;
  HEAP32[i38 >> 2] = HEAP32[i43 >> 2];
  HEAP32[i39 >> 2] = HEAP32[i12 >> 2];
  HEAP32[i40 >> 2] = i44;
  HEAP32[i7 >> 2] = HEAP32[i38 >> 2];
  HEAP32[i8 >> 2] = HEAP32[i39 >> 2];
  HEAP32[i9 >> 2] = HEAP32[i40 >> 2];
  i1 = __ZNSt3__29remove_ifINS_11__wrap_iterIPNS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS4_EEEEEEZNS3_28DuplicateFunctionElimination3runEPNS3_10PassRunnerEPNS3_6ModuleEEUlRKS7_E_EET_SI_SI_T0_(i7, i8, i9) | 0;
  HEAP32[i33 >> 2] = i1;
  HEAP32[i41 >> 2] = HEAP32[i12 >> 2];
  HEAP32[i8 >> 2] = HEAP32[i33 >> 2];
  HEAP32[i9 >> 2] = HEAP32[i41 >> 2];
  __ZNSt3__26vectorINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE5eraseENS_11__wrap_iterIPKS6_EESD_(i43, i8, i9) | 0;
  __ZN4wasm6Module18updateFunctionsMapEv(i50);
  HEAP32[i27 >> 2] = 0;
  HEAP32[i27 + 4 >> 2] = 0;
  HEAP32[i27 + 8 >> 2] = 0;
  HEAP32[i27 + 12 >> 2] = 0;
  HEAP32[i27 + 16 >> 2] = 0;
  HEAP32[i9 >> 2] = 7464;
  HEAP32[i28 >> 2] = i47;
  HEAP32[i29 >> 2] = i50;
  __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i9, i50);
  i1 = HEAP32[i31 >> 2] | 0;
  i3 = HEAP32[i30 >> 2] | 0;
  while (1) {
   if ((i3 | 0) == (i1 | 0)) break;
   i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_(i47, i3) | 0;
   if ((i2 | 0) != (i23 | 0)) HEAP32[i3 >> 2] = HEAP32[i2 + 20 >> 2];
   i3 = i3 + 4 | 0;
  }
  if (HEAP32[i32 >> 2] | 0 ? (i49 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_(i47, i32) | 0, (i49 | 0) != (i23 | 0)) : 0) HEAP32[i32 >> 2] = HEAP32[i49 + 20 >> 2];
  i2 = HEAP32[i35 >> 2] | 0;
  i4 = HEAP32[i34 >> 2] | 0;
  while (1) {
   if ((i4 | 0) == (i2 | 0)) break;
   i3 = (HEAP32[i4 >> 2] | 0) + 4 | 0;
   i1 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_(i47, i3) | 0;
   if ((i1 | 0) != (i23 | 0)) HEAP32[i3 >> 2] = HEAP32[i1 + 20 >> 2];
   i4 = i4 + 4 | 0;
  }
  HEAP32[i9 >> 2] = 7520;
  __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i36);
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEED2Ev(i44);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i47);
  __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEED2Ev(i45);
  HEAP32[i46 >> 2] = 7452;
  __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14FunctionHasherENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i37);
 }
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEED2Ev(i44);
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i47);
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEED2Ev(i45);
 HEAP32[i46 >> 2] = 7452;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14FunctionHasherENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i37);
 STACKTOP = i48;
 return;
}

function __ZN4wasm17WasmBinaryBuilder13readFunctionsEv(i39) {
 i39 = i39 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0, i31 = 0, i32 = 0, i33 = 0, i34 = 0, i35 = 0, i36 = 0, i37 = 0, i38 = 0, i40 = 0, i41 = 0;
 i41 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i8 = i41 + 52 | 0;
 i37 = i41 + 44 | 0;
 i34 = i41 + 36 | 0;
 i38 = i41 + 24 | 0;
 i40 = i41 + 8 | 0;
 i9 = i41 + 48 | 0;
 i10 = i41 + 40 | 0;
 i35 = i41;
 i13 = i41 + 20 | 0;
 i24 = i41 + 4 | 0;
 i33 = i39 + 12 | 0;
 if (HEAP8[i33 >> 0] | 0) {
  i36 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23751) | 0;
  i32 = __ZNKSt3__28ios_base6getlocEv(i36 + (HEAP32[(HEAP32[i36 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i8 >> 2] = i32;
  i32 = __ZNKSt3__26locale9use_facetERNS0_2idE(i8, 61680) | 0;
  i32 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i32 >> 2] | 0) + 28 >> 2] & 63](i32, 10) | 0;
  __ZNSt3__26localeD2Ev(i8);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i36, i32) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i36) | 0;
 }
 i11 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i39) | 0;
 i12 = i39 + 16 | 0;
 i14 = i39 + 68 | 0;
 i15 = i39 + 24 | 0;
 i16 = i38 + 4 | 0;
 i17 = i38 + 8 | 0;
 i18 = i40 + 4 | 0;
 i19 = i40 + 8 | 0;
 i20 = i38 + 8 | 0;
 i21 = i40 + 8 | 0;
 i22 = i39 + 64 | 0;
 i23 = i39 + 36 | 0;
 i25 = i39 + 84 | 0;
 i26 = i39 + 88 | 0;
 i27 = i39 + 96 | 0;
 i28 = i39 + 100 | 0;
 i29 = i39 + 124 | 0;
 i30 = i39 + 44 | 0;
 i31 = i39 + 48 | 0;
 i32 = i39 + 40 | 0;
 i36 = 0;
 while (1) {
  if (i36 >>> 0 >= i11 >>> 0) {
   i1 = 5;
   break;
  }
  if (HEAP8[i33 >> 0] | 0) {
   i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23768) | 0;
   i7 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i7, HEAP32[i12 >> 2] | 0) | 0;
   i6 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i8 >> 2] = i6;
   i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i8, 61680) | 0;
   i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
   __ZNSt3__26localeD2Ev(i8);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i6) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
  }
  i1 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i39) | 0;
  if (!i1) {
   i1 = 9;
   break;
  }
  HEAP32[i14 >> 2] = (HEAP32[i12 >> 2] | 0) + i1;
  i7 = HEAP32[(HEAP32[i15 >> 2] | 0) + (i36 << 2) >> 2] | 0;
  if (HEAP8[i33 >> 0] | 0) {
   i6 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23804) | 0, i36) | 0;
   i5 = __ZNKSt3__28ios_base6getlocEv(i6 + (HEAP32[(HEAP32[i6 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i8 >> 2] = i5;
   i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i8, 61680) | 0;
   i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
   __ZNSt3__26localeD2Ev(i8);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i6, i5) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i6) | 0;
  }
  HEAP32[i37 >> 2] = 0;
  HEAP32[i34 >> 2] = i37;
  HEAP32[i38 >> 2] = 0;
  HEAP32[i16 >> 2] = 0;
  HEAP32[i17 >> 2] = 0;
  HEAP32[i40 >> 2] = 0;
  HEAP32[i18 >> 2] = 0;
  HEAP32[i19 >> 2] = 0;
  i1 = i7 + 8 | 0;
  i2 = i7 + 12 | 0;
  i6 = 0;
  while (1) {
   if (i6 >>> 0 >= (HEAP32[i2 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) >> 2 >>> 0) break;
   i3 = __ZZN4wasm17WasmBinaryBuilder13readFunctionsEvENKUlvE_clEv(i34) | 0;
   HEAP32[i9 >> 2] = i3;
   i4 = (HEAP32[i1 >> 2] | 0) + (i6 << 2) | 0;
   i5 = HEAP32[i16 >> 2] | 0;
   if (i5 >>> 0 < (HEAP32[i20 >> 2] | 0) >>> 0) {
    i4 = HEAP32[i4 >> 2] | 0;
    HEAP32[i5 >> 2] = i3;
    HEAP32[i5 + 4 >> 2] = i4;
    HEAP32[i16 >> 2] = (HEAP32[i16 >> 2] | 0) + 8;
   } else __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJNS1_4NameERNS1_8WasmTypeEEEEvDpOT_(i38, i9, i4);
   i6 = i6 + 1 | 0;
  }
  i4 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i39) | 0;
  i6 = 0;
  while (1) {
   if (i6 >>> 0 >= i4 >>> 0) break;
   i5 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i39) | 0;
   i1 = __ZN4wasm17WasmBinaryBuilder11getWasmTypeEv(i39) | 0;
   HEAP32[i8 >> 2] = i1;
   while (1) {
    if (!i5) break;
    i2 = __ZZN4wasm17WasmBinaryBuilder13readFunctionsEvENKUlvE_clEv(i34) | 0;
    HEAP32[i10 >> 2] = i2;
    i3 = HEAP32[i18 >> 2] | 0;
    if (i3 >>> 0 < (HEAP32[i21 >> 2] | 0) >>> 0) {
     HEAP32[i3 >> 2] = i2;
     HEAP32[i3 + 4 >> 2] = i1;
     HEAP32[i18 >> 2] = (HEAP32[i18 >> 2] | 0) + 8;
    } else __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJNS1_4NameERNS1_8WasmTypeEEEEvDpOT_(i40, i10, i8);
    i5 = i5 + -1 | 0;
   }
   i6 = i6 + 1 | 0;
  }
  HEAP32[i13 >> 2] = (HEAP32[i39 >> 2] | 0) + 88;
  i1 = __ZN4wasm4Name7fromIntEj(i36) | 0;
  HEAP32[i24 >> 2] = i1;
  i1 = HEAP32[i7 + 4 >> 2] | 0;
  HEAP32[i8 >> 2] = HEAP32[i24 >> 2];
  i1 = __ZN4wasm7Builder12makeFunctionENS_4NameEONSt3__26vectorINS_8NameTypeENS2_9allocatorIS4_EEEENS_8WasmTypeES8_PNS_10ExpressionE(i13, i8, i38, i1, i40, 0) | 0;
  HEAP32[i35 >> 2] = i1;
  HEAP32[i1 + 32 >> 2] = HEAP32[i7 >> 2];
  i2 = i1;
  HEAP32[i22 >> 2] = i2;
  if (HEAP8[i33 >> 0] | 0) {
   i7 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23812) | 0, i36) | 0;
   i6 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i8 >> 2] = i6;
   i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i8, 61680) | 0;
   i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
   __ZNSt3__26localeD2Ev(i8);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i6) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
  }
  HEAP32[i23 >> 2] = 0;
  if ((HEAP32[i25 >> 2] | 0) != (HEAP32[i26 >> 2] | 0)) {
   i1 = 30;
   break;
  }
  if ((HEAP32[i27 >> 2] | 0) != (HEAP32[i28 >> 2] | 0)) {
   i1 = 32;
   break;
  }
  HEAP32[i29 >> 2] = 0;
  i7 = __ZN4wasm17WasmBinaryBuilder13getMaybeBlockEv(i39) | 0;
  HEAP32[i1 + 36 >> 2] = i7;
  if (HEAP32[i29 >> 2] | 0) {
   i1 = 34;
   break;
  }
  if ((HEAP32[i25 >> 2] | 0) != (HEAP32[i26 >> 2] | 0)) {
   i1 = 36;
   break;
  }
  if ((HEAP32[i27 >> 2] | 0) != (HEAP32[i28 >> 2] | 0)) {
   i1 = 38;
   break;
  }
  if ((HEAP32[i12 >> 2] | 0) != (HEAP32[i14 >> 2] | 0)) {
   i1 = 40;
   break;
  }
  HEAP32[i22 >> 2] = 0;
  i1 = HEAP32[i30 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i31 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm8FunctionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i32, i35); else {
   HEAP32[i1 >> 2] = i2;
   HEAP32[i30 >> 2] = (HEAP32[i30 >> 2] | 0) + 4;
  }
  __ZNSt3__213__vector_baseIN4wasm8NameTypeENS_9allocatorIS2_EEED2Ev(i40);
  __ZNSt3__213__vector_baseIN4wasm8NameTypeENS_9allocatorIS2_EEED2Ev(i38);
  i36 = i36 + 1 | 0;
 }
 if ((i1 | 0) == 5) {
  STACKTOP = i41;
  return;
 } else if ((i1 | 0) == 9) ___assert_fail(23781, 22948, 1485, 23790); else if ((i1 | 0) == 30) ___assert_fail(23834, 22948, 1520, 23790); else if ((i1 | 0) == 32) ___assert_fail(23853, 22948, 1521, 23790); else if ((i1 | 0) == 34) ___assert_fail(23877, 22948, 1524, 23790); else if ((i1 | 0) == 36) ___assert_fail(23834, 22948, 1525, 23790); else if ((i1 | 0) == 38) ___assert_fail(23853, 22948, 1526, 23790); else if ((i1 | 0) == 40) ___assert_fail(23888, 22948, 1527, 23790);
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE14findLiveBlocksEv(i26, i1) {
 i26 = i26 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, d5 = 0.0, d6 = 0.0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i27 = 0, i28 = 0, i29 = 0, i30 = 0;
 i30 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i22 = i30 + 28 | 0;
 i23 = i30 + 24 | 0;
 i28 = i30 + 4 | 0;
 i27 = i30;
 i24 = i26 + 16 | 0;
 HEAP32[i26 >> 2] = 0;
 HEAP32[i26 + 4 >> 2] = 0;
 HEAP32[i26 + 8 >> 2] = 0;
 HEAP32[i26 + 12 >> 2] = 0;
 HEAPF32[i24 >> 2] = 1.0;
 i25 = i28 + 16 | 0;
 HEAP32[i28 >> 2] = 0;
 HEAP32[i28 + 4 >> 2] = 0;
 HEAP32[i28 + 8 >> 2] = 0;
 HEAP32[i28 + 12 >> 2] = 0;
 HEAPF32[i25 >> 2] = 1.0;
 i20 = HEAP32[i1 + 28 >> 2] | 0;
 HEAP32[i22 >> 2] = i20;
 i2 = __ZNSt3__221__murmur2_or_cityhashIjLj32EEclEPKvj(i23, i22, 4) | 0;
 i21 = i28 + 4 | 0;
 i4 = __Znwj(12) | 0;
 HEAP32[i4 + 8 >> 2] = i20;
 HEAP32[i4 + 4 >> 2] = i2;
 HEAP32[i4 >> 2] = 0;
 i20 = i28 + 12 | 0;
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6rehashEj(i28, 1);
 i3 = HEAP32[i21 >> 2] | 0;
 i1 = i3 + -1 | 0;
 if (!(i1 & i3)) i1 = i1 & i2; else i1 = (i2 >>> 0) % (i3 >>> 0) | 0;
 i1 = (HEAP32[i28 >> 2] | 0) + (i1 << 2) | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if (!i2) {
  i19 = i28 + 8 | 0;
  HEAP32[i4 >> 2] = HEAP32[i19 >> 2];
  HEAP32[i19 >> 2] = i4;
  HEAP32[i1 >> 2] = i19;
  i1 = HEAP32[i4 >> 2] | 0;
  if (i1 | 0) {
   i1 = HEAP32[i1 + 4 >> 2] | 0;
   i2 = i3 + -1 | 0;
   if (!(i2 & i3)) i1 = i1 & i2; else i1 = (i1 >>> 0) % (i3 >>> 0) | 0;
   HEAP32[(HEAP32[i28 >> 2] | 0) + (i1 << 2) >> 2] = i4;
  }
 } else {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i2 >> 2] = i4;
 }
 i1 = (HEAP32[i20 >> 2] | 0) + 1 | 0;
 HEAP32[i20 >> 2] = i1;
 i15 = i28 + 8 | 0;
 i16 = i26 + 4 | 0;
 i17 = i26 + 12 | 0;
 i18 = i26 + 8 | 0;
 i19 = i28 + 8 | 0;
 while (1) {
  if (!i1) break;
  i11 = HEAP32[i15 >> 2] | 0;
  i8 = HEAP32[i11 + 8 >> 2] | 0;
  HEAP32[i23 >> 2] = i11;
  HEAP32[i22 >> 2] = HEAP32[i23 >> 2];
  __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE5eraseENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEE(i28, i22) | 0;
  HEAP32[i22 >> 2] = i8;
  i11 = __ZNSt3__221__murmur2_or_cityhashIjLj32EEclEPKvj(i23, i22, 4) | 0;
  i10 = HEAP32[i16 >> 2] | 0;
  i9 = (i10 | 0) == 0;
  i12 = i8;
  L17 : do if (!i9) {
   i4 = i10 + -1 | 0;
   i7 = (i4 & i10 | 0) == 0;
   if (i7) i1 = i4 & i11; else i1 = (i11 >>> 0) % (i10 >>> 0) | 0;
   i2 = HEAP32[(HEAP32[i26 >> 2] | 0) + (i1 << 2) >> 2] | 0;
   if (!i2) i29 = 25; else do {
    i2 = HEAP32[i2 >> 2] | 0;
    if (!i2) {
     i29 = 25;
     break L17;
    }
    i3 = HEAP32[i2 + 4 >> 2] | 0;
    if (i7) i3 = i3 & i4; else i3 = (i3 >>> 0) % (i10 >>> 0) | 0;
    if ((i3 | 0) != (i1 | 0)) {
     i29 = 25;
     break L17;
    }
   } while ((HEAP32[i2 + 8 >> 2] | 0) != (i12 | 0));
  } else {
   i1 = 0;
   i29 = 25;
  } while (0);
  if ((i29 | 0) == 25) {
   i29 = 0;
   i4 = __Znwj(12) | 0;
   HEAP32[i4 + 8 >> 2] = i8;
   HEAP32[i4 + 4 >> 2] = i11;
   HEAP32[i4 >> 2] = 0;
   d5 = +(((HEAP32[i17 >> 2] | 0) + 1 | 0) >>> 0);
   d6 = +HEAPF32[i24 >> 2];
   do if (i9 | d5 > +(i10 >>> 0) * d6) {
    if (i10 >>> 0 > 2) i1 = (i10 + -1 & i10 | 0) == 0; else i1 = 0;
    i1 = (i1 & 1 | i10 << 1) ^ 1;
    i2 = ~~+Math_ceil(+(d5 / d6)) >>> 0;
    __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6rehashEj(i26, i1 >>> 0 < i2 >>> 0 ? i2 : i1);
    i1 = HEAP32[i16 >> 2] | 0;
    i2 = i1 + -1 | 0;
    if (!(i2 & i1)) {
     i3 = i1;
     i1 = i2 & i11;
     break;
    } else {
     i3 = i1;
     i1 = (i11 >>> 0) % (i1 >>> 0) | 0;
     break;
    }
   } else i3 = i10; while (0);
   i1 = (HEAP32[i26 >> 2] | 0) + (i1 << 2) | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if (!i2) {
    HEAP32[i4 >> 2] = HEAP32[i18 >> 2];
    HEAP32[i18 >> 2] = i4;
    HEAP32[i1 >> 2] = i18;
    i1 = HEAP32[i4 >> 2] | 0;
    if (i1 | 0) {
     i1 = HEAP32[i1 + 4 >> 2] | 0;
     i2 = i3 + -1 | 0;
     if (!(i2 & i3)) i1 = i1 & i2; else i1 = (i1 >>> 0) % (i3 >>> 0) | 0;
     HEAP32[(HEAP32[i26 >> 2] | 0) + (i1 << 2) >> 2] = i4;
    }
   } else {
    HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i2 >> 2] = i4;
   }
   HEAP32[i17 >> 2] = (HEAP32[i17 >> 2] | 0) + 1;
  }
  i14 = HEAP32[i12 + 40 >> 2] | 0;
  i13 = HEAP32[i12 + 36 >> 2] | 0;
  while (1) {
   if ((i13 | 0) == (i14 | 0)) break;
   i9 = HEAP32[i13 >> 2] | 0;
   HEAP32[i27 >> 2] = i9;
   L55 : do if (!(__ZNKSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE4findIS9_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEERKT_(i26, i27) | 0)) {
    HEAP32[i22 >> 2] = i9;
    i12 = __ZNSt3__221__murmur2_or_cityhashIjLj32EEclEPKvj(i23, i22, 4) | 0;
    i11 = HEAP32[i21 >> 2] | 0;
    i10 = (i11 | 0) == 0;
    i4 = i9;
    L57 : do if (!i10) {
     i7 = i11 + -1 | 0;
     i8 = (i7 & i11 | 0) == 0;
     if (i8) i1 = i7 & i12; else i1 = (i12 >>> 0) % (i11 >>> 0) | 0;
     i2 = HEAP32[(HEAP32[i28 >> 2] | 0) + (i1 << 2) >> 2] | 0;
     if (i2) while (1) {
      i2 = HEAP32[i2 >> 2] | 0;
      if (!i2) break L57;
      i3 = HEAP32[i2 + 4 >> 2] | 0;
      if (i8) i3 = i3 & i7; else i3 = (i3 >>> 0) % (i11 >>> 0) | 0;
      if ((i3 | 0) != (i1 | 0)) break L57;
      if ((HEAP32[i2 + 8 >> 2] | 0) == (i4 | 0)) break L55;
     }
    } else i1 = 0; while (0);
    i4 = __Znwj(12) | 0;
    HEAP32[i4 + 8 >> 2] = i9;
    HEAP32[i4 + 4 >> 2] = i12;
    HEAP32[i4 >> 2] = 0;
    d5 = +(((HEAP32[i20 >> 2] | 0) + 1 | 0) >>> 0);
    d6 = +HEAPF32[i25 >> 2];
    do if (i10 | d5 > +(i11 >>> 0) * d6) {
     if (i11 >>> 0 > 2) i1 = (i11 + -1 & i11 | 0) == 0; else i1 = 0;
     i1 = (i1 & 1 | i11 << 1) ^ 1;
     i2 = ~~+Math_ceil(+(d5 / d6)) >>> 0;
     __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6rehashEj(i28, i1 >>> 0 < i2 >>> 0 ? i2 : i1);
     i1 = HEAP32[i21 >> 2] | 0;
     i2 = i1 + -1 | 0;
     if (!(i2 & i1)) {
      i3 = i1;
      i1 = i2 & i12;
      break;
     } else {
      i3 = i1;
      i1 = (i12 >>> 0) % (i1 >>> 0) | 0;
      break;
     }
    } else i3 = i11; while (0);
    i1 = (HEAP32[i28 >> 2] | 0) + (i1 << 2) | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    if (!i2) {
     HEAP32[i4 >> 2] = HEAP32[i19 >> 2];
     HEAP32[i19 >> 2] = i4;
     HEAP32[i1 >> 2] = i19;
     i1 = HEAP32[i4 >> 2] | 0;
     if (i1 | 0) {
      i1 = HEAP32[i1 + 4 >> 2] | 0;
      i2 = i3 + -1 | 0;
      if (!(i2 & i3)) i1 = i1 & i2; else i1 = (i1 >>> 0) % (i3 >>> 0) | 0;
      HEAP32[(HEAP32[i28 >> 2] | 0) + (i1 << 2) >> 2] = i4;
     }
    } else {
     HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i2 >> 2] = i4;
    }
    HEAP32[i20 >> 2] = (HEAP32[i20 >> 2] | 0) + 1;
   } while (0);
   i13 = i13 + 4 | 0;
  }
  i1 = HEAP32[i20 >> 2] | 0;
 }
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEED2Ev(i28);
 STACKTOP = i30;
 return;
}

function __ZNSt3__211__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri(i1, i2, i5, i16, i17, i18, i19, i13, i8, i20) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 i16 = i16 | 0;
 i17 = i17 | 0;
 i18 = i18 | 0;
 i19 = i19 | 0;
 i13 = i13 | 0;
 i8 = i8 | 0;
 i20 = i20 | 0;
 var i3 = 0, i4 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i15 = 0, i21 = 0;
 i21 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i3 = i21 + 100 | 0;
 i6 = i21 + 88 | 0;
 i9 = i21 + 76 | 0;
 i11 = i21 + 64 | 0;
 i14 = i21 + 52 | 0;
 i4 = i21 + 48 | 0;
 i7 = i21 + 36 | 0;
 i10 = i21 + 24 | 0;
 i12 = i21 + 12 | 0;
 i15 = i21;
 if (i1) {
  i2 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 63400) | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 44 >> 2] & 1023](i3, i2);
  i1 = HEAP32[i3 >> 2] | 0;
  HEAP8[i5 >> 0] = i1;
  HEAP8[i5 + 1 >> 0] = i1 >> 8;
  HEAP8[i5 + 2 >> 0] = i1 >> 16;
  HEAP8[i5 + 3 >> 0] = i1 >> 24;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 32 >> 2] & 1023](i6, i2);
  i1 = i8 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i8 >> 2] >> 0] = 0;
   HEAP32[i8 + 4 >> 2] = 0;
   i1 = i8;
  } else {
   HEAP8[i8 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i8;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i8, 0);
  HEAP32[i1 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i6 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i6);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 28 >> 2] & 1023](i9, i2);
  i1 = i13 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i13 >> 2] >> 0] = 0;
   HEAP32[i13 + 4 >> 2] = 0;
   i1 = i13;
  } else {
   HEAP8[i13 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i13;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i13, 0);
  HEAP32[i1 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i9 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i9 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i9 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i9);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 255](i2) | 0;
  HEAP8[i16 >> 0] = i1;
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 16 >> 2] & 255](i2) | 0;
  HEAP8[i17 >> 0] = i1;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i11, i2);
  i1 = i18 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i18 >> 2] >> 0] = 0;
   HEAP32[i18 + 4 >> 2] = 0;
   i1 = i18;
  } else {
   HEAP8[i18 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i18;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i18, 0);
  HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i11 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i11 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i11 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i11);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 1023](i14, i2);
  i1 = i19 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i19 >> 2] >> 0] = 0;
   HEAP32[i19 + 4 >> 2] = 0;
   i1 = i19;
  } else {
   HEAP8[i19 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i19;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i19, 0);
  HEAP32[i1 >> 2] = HEAP32[i14 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i14 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i14 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i14 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i14);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0;
 } else {
  i2 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 63392) | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 44 >> 2] & 1023](i4, i2);
  i1 = HEAP32[i4 >> 2] | 0;
  HEAP8[i5 >> 0] = i1;
  HEAP8[i5 + 1 >> 0] = i1 >> 8;
  HEAP8[i5 + 2 >> 0] = i1 >> 16;
  HEAP8[i5 + 3 >> 0] = i1 >> 24;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 32 >> 2] & 1023](i7, i2);
  i1 = i8 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i8 >> 2] >> 0] = 0;
   HEAP32[i8 + 4 >> 2] = 0;
   i1 = i8;
  } else {
   HEAP8[i8 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i8;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i8, 0);
  HEAP32[i1 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i7 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i7 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i7);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 28 >> 2] & 1023](i10, i2);
  i1 = i13 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i13 >> 2] >> 0] = 0;
   HEAP32[i13 + 4 >> 2] = 0;
   i1 = i13;
  } else {
   HEAP8[i13 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i13;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i13, 0);
  HEAP32[i1 >> 2] = HEAP32[i10 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i10 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i10 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i10 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i10);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 255](i2) | 0;
  HEAP8[i16 >> 0] = i1;
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 16 >> 2] & 255](i2) | 0;
  HEAP8[i17 >> 0] = i1;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i12, i2);
  i1 = i18 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i18 >> 2] >> 0] = 0;
   HEAP32[i18 + 4 >> 2] = 0;
   i1 = i18;
  } else {
   HEAP8[i18 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i18;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i18, 0);
  HEAP32[i1 >> 2] = HEAP32[i12 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i12 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i12 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i12 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i12);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 1023](i15, i2);
  i1 = i19 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i19 >> 2] >> 0] = 0;
   HEAP32[i19 + 4 >> 2] = 0;
   i1 = i19;
  } else {
   HEAP8[i19 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i19;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i19, 0);
  HEAP32[i1 >> 2] = HEAP32[i15 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i15 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i15 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i15 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i15);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0;
 }
 HEAP32[i20 >> 2] = i1;
 STACKTOP = i21;
 return;
}

function __ZNSt3__211__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri(i1, i2, i5, i16, i17, i18, i19, i13, i8, i20) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 i16 = i16 | 0;
 i17 = i17 | 0;
 i18 = i18 | 0;
 i19 = i19 | 0;
 i13 = i13 | 0;
 i8 = i8 | 0;
 i20 = i20 | 0;
 var i3 = 0, i4 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i15 = 0, i21 = 0;
 i21 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i3 = i21 + 100 | 0;
 i6 = i21 + 88 | 0;
 i9 = i21 + 76 | 0;
 i11 = i21 + 64 | 0;
 i14 = i21 + 52 | 0;
 i4 = i21 + 48 | 0;
 i7 = i21 + 36 | 0;
 i10 = i21 + 24 | 0;
 i12 = i21 + 12 | 0;
 i15 = i21;
 if (i1) {
  i2 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 63416) | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 44 >> 2] & 1023](i3, i2);
  i1 = HEAP32[i3 >> 2] | 0;
  HEAP8[i5 >> 0] = i1;
  HEAP8[i5 + 1 >> 0] = i1 >> 8;
  HEAP8[i5 + 2 >> 0] = i1 >> 16;
  HEAP8[i5 + 3 >> 0] = i1 >> 24;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 32 >> 2] & 1023](i6, i2);
  i1 = i8 + 8 + 3 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP32[HEAP32[i8 >> 2] >> 2] = 0;
   HEAP32[i8 + 4 >> 2] = 0;
  } else {
   HEAP32[i8 >> 2] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i8, 0);
  HEAP32[i8 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i8 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
  HEAP32[i8 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i6 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i6);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 28 >> 2] & 1023](i9, i2);
  i1 = i13 + 8 + 3 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP32[HEAP32[i13 >> 2] >> 2] = 0;
   HEAP32[i13 + 4 >> 2] = 0;
  } else {
   HEAP32[i13 >> 2] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i13, 0);
  HEAP32[i13 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i13 + 4 >> 2] = HEAP32[i9 + 4 >> 2];
  HEAP32[i13 + 8 >> 2] = HEAP32[i9 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i9 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i9);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 255](i2) | 0;
  HEAP32[i16 >> 2] = i1;
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 16 >> 2] & 255](i2) | 0;
  HEAP32[i17 >> 2] = i1;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i11, i2);
  i1 = i18 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i18 >> 2] >> 0] = 0;
   HEAP32[i18 + 4 >> 2] = 0;
   i1 = i18;
  } else {
   HEAP8[i18 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i18;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i18, 0);
  HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i11 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i11 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i11 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i11);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 1023](i14, i2);
  i1 = i19 + 8 + 3 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP32[HEAP32[i19 >> 2] >> 2] = 0;
   HEAP32[i19 + 4 >> 2] = 0;
  } else {
   HEAP32[i19 >> 2] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i19, 0);
  HEAP32[i19 >> 2] = HEAP32[i14 >> 2];
  HEAP32[i19 + 4 >> 2] = HEAP32[i14 + 4 >> 2];
  HEAP32[i19 + 8 >> 2] = HEAP32[i14 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i14 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i14);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0;
 } else {
  i2 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 63408) | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 44 >> 2] & 1023](i4, i2);
  i1 = HEAP32[i4 >> 2] | 0;
  HEAP8[i5 >> 0] = i1;
  HEAP8[i5 + 1 >> 0] = i1 >> 8;
  HEAP8[i5 + 2 >> 0] = i1 >> 16;
  HEAP8[i5 + 3 >> 0] = i1 >> 24;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 32 >> 2] & 1023](i7, i2);
  i1 = i8 + 8 + 3 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP32[HEAP32[i8 >> 2] >> 2] = 0;
   HEAP32[i8 + 4 >> 2] = 0;
  } else {
   HEAP32[i8 >> 2] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i8, 0);
  HEAP32[i8 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i8 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
  HEAP32[i8 + 8 >> 2] = HEAP32[i7 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i7 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i7);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 28 >> 2] & 1023](i10, i2);
  i1 = i13 + 8 + 3 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP32[HEAP32[i13 >> 2] >> 2] = 0;
   HEAP32[i13 + 4 >> 2] = 0;
  } else {
   HEAP32[i13 >> 2] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i13, 0);
  HEAP32[i13 >> 2] = HEAP32[i10 >> 2];
  HEAP32[i13 + 4 >> 2] = HEAP32[i10 + 4 >> 2];
  HEAP32[i13 + 8 >> 2] = HEAP32[i10 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i10 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i10);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 255](i2) | 0;
  HEAP32[i16 >> 2] = i1;
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 16 >> 2] & 255](i2) | 0;
  HEAP32[i17 >> 2] = i1;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i12, i2);
  i1 = i18 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i18 >> 2] >> 0] = 0;
   HEAP32[i18 + 4 >> 2] = 0;
   i1 = i18;
  } else {
   HEAP8[i18 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
   i1 = i18;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i18, 0);
  HEAP32[i1 >> 2] = HEAP32[i12 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i12 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i12 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i12 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i12);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 1023](i15, i2);
  i1 = i19 + 8 + 3 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP32[HEAP32[i19 >> 2] >> 2] = 0;
   HEAP32[i19 + 4 >> 2] = 0;
  } else {
   HEAP32[i19 >> 2] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i19, 0);
  HEAP32[i19 >> 2] = HEAP32[i15 >> 2];
  HEAP32[i19 + 4 >> 2] = HEAP32[i15 + 4 >> 2];
  HEAP32[i19 + 8 >> 2] = HEAP32[i15 + 8 >> 2];
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i15 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i15);
  i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0;
 }
 HEAP32[i20 >> 2] = i1;
 STACKTOP = i21;
 return;
}

function __ZN6cashew4InitC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0, i29 = 0;
 i29 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i1 = i29 + 68 | 0;
 i2 = i29 + 48 | 0;
 i4 = i29 + 67 | 0;
 i5 = i29 + 44 | 0;
 i6 = i29 + 66 | 0;
 i7 = i29 + 40 | 0;
 i8 = i29 + 65 | 0;
 i9 = i29 + 36 | 0;
 i10 = i29 + 64 | 0;
 i11 = i29 + 32 | 0;
 i12 = i29 + 63 | 0;
 i13 = i29 + 28 | 0;
 i14 = i29 + 62 | 0;
 i15 = i29 + 24 | 0;
 i16 = i29 + 61 | 0;
 i17 = i29 + 20 | 0;
 i18 = i29 + 60 | 0;
 i19 = i29 + 16 | 0;
 i20 = i29 + 59 | 0;
 i21 = i29 + 12 | 0;
 i22 = i29 + 58 | 0;
 i23 = i29 + 8 | 0;
 i24 = i29 + 57 | 0;
 i25 = i29 + 4 | 0;
 i26 = i29 + 56 | 0;
 i27 = i29;
 i28 = i29 + 52 | 0;
 HEAP8[i1 >> 0] = 0;
 HEAP32[i2 >> 2] = 0;
 i3 = HEAP32[14913] | 0;
 if (i3 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i3, 58005);
  HEAP8[i3 + 32 >> 0] = 0;
  HEAP32[i3 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA2_KcbNS2_4TypeEEEEvDpOT_(59648, 58005, i1, i2);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i4 >> 0] = 1;
 HEAP32[i5 >> 2] = 1;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 48125);
  HEAP8[i1 + 32 >> 0] = 1;
  HEAP32[i1 + 36 >> 2] = 1;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA8_KcbNS2_4TypeEEEEvDpOT_(59648, 48125, i4, i5);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i6 >> 0] = 0;
 HEAP32[i7 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 48133);
  HEAP8[i1 + 32 >> 0] = 0;
  HEAP32[i1 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA6_KcbNS2_4TypeEEEEvDpOT_(59648, 48133, i6, i7);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i8 >> 0] = 0;
 HEAP32[i9 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 48139);
  HEAP8[i1 + 32 >> 0] = 0;
  HEAP32[i1 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA4_KcbNS2_4TypeEEEEvDpOT_(59648, 48139, i8, i9);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i10 >> 0] = 0;
 HEAP32[i11 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 48143);
  HEAP8[i1 + 32 >> 0] = 0;
  HEAP32[i1 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA10_KcbNS2_4TypeEEEEvDpOT_(59648, 48143, i10, i11);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i12 >> 0] = 0;
 HEAP32[i13 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 48153);
  HEAP8[i1 + 32 >> 0] = 0;
  HEAP32[i1 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA10_KcbNS2_4TypeEEEEvDpOT_(59648, 48153, i12, i13);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i14 >> 0] = 0;
 HEAP32[i15 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 48163);
  HEAP8[i1 + 32 >> 0] = 0;
  HEAP32[i1 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA6_KcbNS2_4TypeEEEEvDpOT_(59648, 48163, i14, i15);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i16 >> 0] = 0;
 HEAP32[i17 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 57019);
  HEAP8[i1 + 32 >> 0] = 0;
  HEAP32[i1 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA2_KcbNS2_4TypeEEEEvDpOT_(59648, 57019, i16, i17);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i18 >> 0] = 0;
 HEAP32[i19 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 58012);
  HEAP8[i1 + 32 >> 0] = 0;
  HEAP32[i1 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA2_KcbNS2_4TypeEEEEvDpOT_(59648, 58012, i18, i19);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i20 >> 0] = 0;
 HEAP32[i21 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 58076);
  HEAP8[i1 + 32 >> 0] = 0;
  HEAP32[i1 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA2_KcbNS2_4TypeEEEEvDpOT_(59648, 58076, i20, i21);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i22 >> 0] = 1;
 HEAP32[i23 >> 2] = 3;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 48169);
  HEAP8[i1 + 32 >> 0] = 1;
  HEAP32[i1 + 36 >> 2] = 3;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA4_KcbNS2_4TypeEEEEvDpOT_(59648, 48169, i22, i23);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i24 >> 0] = 1;
 HEAP32[i25 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 57024);
  HEAP8[i1 + 32 >> 0] = 1;
  HEAP32[i1 + 36 >> 2] = 0;
  i1 = (HEAP32[14913] | 0) + 40 | 0;
  HEAP32[14913] = i1;
 } else {
  __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA2_KcbNS2_4TypeEEEEvDpOT_(59648, 57024, i24, i25);
  i1 = HEAP32[14913] | 0;
 }
 HEAP8[i26 >> 0] = 1;
 HEAP32[i27 >> 2] = 0;
 if (i1 >>> 0 < (HEAP32[14914] | 0) >>> 0) {
  __ZN6cashew10IStringSetC2EPKc(i1, 57051);
  HEAP8[i1 + 32 >> 0] = 1;
  HEAP32[i1 + 36 >> 2] = 0;
  HEAP32[14913] = (HEAP32[14913] | 0) + 40;
 } else __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA2_KcbNS2_4TypeEEEEvDpOT_(59648, 57051, i26, i27);
 __ZNSt3__26vectorINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEE6resizeEj(59660, 4);
 i2 = 0;
 while (1) {
  i1 = HEAP32[14912] | 0;
  if (i2 >>> 0 >= (((HEAP32[14913] | 0) - i1 | 0) / 40 | 0) >>> 0) break;
  i1 = i1 + (i2 * 40 | 0) + 8 | 0;
  while (1) {
   i1 = HEAP32[i1 >> 2] | 0;
   if (!i1) break;
   HEAP32[i28 >> 2] = HEAP32[i1 + 8 >> 2];
   i27 = __ZNSt3__213unordered_mapIN6cashew7IStringEiNS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorINS_4pairIKS2_iEEEEEixERS9_((HEAP32[14915] | 0) + ((HEAP32[(HEAP32[14912] | 0) + (i2 * 40 | 0) + 36 >> 2] | 0) * 20 | 0) | 0, i28) | 0;
   HEAP32[i27 >> 2] = i2;
  }
  i2 = i2 + 1 | 0;
 }
 STACKTOP = i29;
 return;
}

function __ZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEE(i28, i26) {
 i28 = i28 | 0;
 i26 = i26 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, d21 = 0.0, i22 = 0, i23 = 0, i24 = 0, i25 = 0, i27 = 0, i29 = 0, d30 = 0.0;
 i29 = STACKTOP;
 STACKTOP = STACKTOP + 5072 | 0;
 i25 = i29;
 i24 = i29 + 5048 | 0;
 i4 = i29 + 2540 | 0;
 i27 = i29 + 24 | 0;
 i1 = HEAP32[i28 + 36 >> 2] | 0;
 i1 = (HEAP32[i1 + 24 >> 2] | 0) - (HEAP32[i1 + 20 >> 2] | 0) >> 2;
 do if (i1 >>> 0 >= 2) {
  i1 = Math_imul(i1 + -1 | 0, i1) | 0;
  i1 = i1 >>> 0 > 20 ? 20 : i1;
  HEAP32[i4 >> 2] = i28;
  __ZNSt3__223mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EE4seedEj(i4 + 4 | 0, 42);
  HEAP8[i4 + 2504 >> 0] = 1;
  HEAP32[i27 >> 2] = i4;
  i22 = i27 + 4 | 0;
  HEAP32[i22 >> 2] = 0;
  i23 = i27 + 8 | 0;
  HEAP32[i23 >> 2] = 0;
  HEAP32[i27 + 12 >> 2] = 0;
  __ZNSt3__223mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EE4seedEj(i27 + 16 | 0, 1337);
  __ZNSt3__26vectorINS_10unique_ptrIZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNS0_IjNS_9allocatorIjEEEEE5OrderNS_14default_deleteIS8_EEEENS4_ISB_EEE6resizeEj(i22, i1);
  i3 = 0;
  while (1) {
   if (i3 >>> 0 >= i1 >>> 0) break;
   i20 = (HEAP32[i22 >> 2] | 0) + (i3 << 2) | 0;
   i19 = __ZZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEEEN9Generator10makeRandomEv(i4) | 0;
   i2 = HEAP32[i20 >> 2] | 0;
   HEAP32[i20 >> 2] = i19;
   if (i2 | 0) {
    __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i2);
    __ZdlPv(i2);
   }
   i3 = i3 + 1 | 0;
  }
  __ZN4wasm14GeneticLearnerIZNS_26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS2_9allocatorIjEEEEE5OrderdZNS1_11pickIndicesES7_E9GeneratorE4sortEv(i27);
  i16 = i27 + 4 | 0;
  i15 = HEAP32[i16 >> 2] | 0;
  i17 = i24 + 4 | 0;
  i18 = i24 + 8 | 0;
  i19 = i25 + 4 | 0;
  i20 = i25 + 8 | 0;
  i2 = i15;
  d21 = +HEAPF64[(HEAP32[i15 >> 2] | 0) + 16 >> 3];
  L11 : while (1) {
   i15 = (HEAP32[i23 >> 2] | 0) - i2 >> 2;
   i13 = ((i15 * 25 | 0) >>> 0) / 100 | 0;
   i14 = ((i15 * 50 | 0) >>> 0) / 100 | 0;
   HEAP32[i24 >> 2] = 0;
   HEAP32[i17 >> 2] = 0;
   HEAP32[i18 >> 2] = 0;
   __ZNSt3__26vectorINS_10unique_ptrIZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNS0_IjNS_9allocatorIjEEEEE5OrderNS_14default_deleteIS8_EEEENS4_ISB_EEE6resizeEj(i24, i14);
   i12 = 0;
   while (1) {
    if (i12 >>> 0 >= i14 >>> 0) {
     i1 = 0;
     break;
    }
    i11 = (HEAP32[i24 >> 2] | 0) + (i12 << 2) | 0;
    i10 = HEAP32[i27 >> 2] | 0;
    i4 = __ZN4wasm14GeneticLearnerIZNS_26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS2_9allocatorIjEEEEE5OrderdZNS1_11pickIndicesES7_E9GeneratorE11randomIndexEv(i27) | 0;
    i4 = HEAP32[(HEAP32[i22 >> 2] | 0) + (i4 << 2) >> 2] | 0;
    i1 = __ZN4wasm14GeneticLearnerIZNS_26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS2_9allocatorIjEEEEE5OrderdZNS1_11pickIndicesES7_E9GeneratorE11randomIndexEv(i27) | 0;
    i1 = HEAP32[(HEAP32[i22 >> 2] | 0) + (i1 << 2) >> 2] | 0;
    i5 = i4 + 4 | 0;
    i6 = (HEAP32[i5 >> 2] | 0) - (HEAP32[i4 >> 2] | 0) >> 2;
    HEAP32[i25 >> 2] = 0;
    HEAP32[i19 >> 2] = 0;
    HEAP32[i20 >> 2] = 0;
    __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i25, i6);
    i2 = HEAP32[i25 >> 2] | 0;
    i3 = 0;
    while (1) {
     if ((i3 | 0) == (i6 | 0)) break;
     HEAP32[i2 + (HEAP32[(HEAP32[i1 >> 2] | 0) + (i3 << 2) >> 2] << 2) >> 2] = i3;
     i3 = i3 + 1 | 0;
    }
    i9 = __Znwj(24) | 0;
    HEAP32[i9 >> 2] = 0;
    HEAP32[i9 + 4 >> 2] = 0;
    HEAP32[i9 + 8 >> 2] = 0;
    if ((i9 | 0) != (i4 | 0)) __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_(i9, HEAP32[i4 >> 2] | 0, HEAP32[i5 >> 2] | 0);
    HEAPF64[i9 + 16 >> 3] = +HEAPF64[i4 + 16 >> 3];
    if (!i6) {
     i2 = 17;
     break L11;
    }
    i5 = HEAP32[(HEAP32[i10 >> 2] | 0) + 36 >> 2] | 0;
    i7 = i6 + -1 | 0;
    i8 = HEAP32[i25 >> 2] | 0;
    i6 = (HEAP32[i5 + 12 >> 2] | 0) - (HEAP32[i5 + 8 >> 2] | 0) >> 2;
    while (1) {
     if (i6 >>> 0 >= i7 >>> 0) break;
     i4 = HEAP32[i9 >> 2] | 0;
     i2 = i4 + (i6 << 2) | 0;
     i3 = HEAP32[i2 >> 2] | 0;
     i1 = i6 + 1 | 0;
     i4 = i4 + (i1 << 2) | 0;
     i5 = HEAP32[i4 >> 2] | 0;
     if ((HEAP32[i8 + (i3 << 2) >> 2] | 0) >>> 0 > (HEAP32[i8 + (i5 << 2) >> 2] | 0) >>> 0) {
      HEAP32[i2 >> 2] = i5;
      HEAP32[i4 >> 2] = i3;
     } else i1 = i6;
     i6 = i1 + 1 | 0;
    }
    __ZZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEEEN9Generator16calculateFitnessEPZNS0_11pickIndicesES6_E5Order(i10, i9);
    __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i25);
    i1 = HEAP32[i11 >> 2] | 0;
    HEAP32[i11 >> 2] = i9;
    if (i1 | 0) {
     __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1);
     __ZdlPv(i1);
    }
    i12 = i12 + 1 | 0;
   }
   while (1) {
    if (i1 >>> 0 >= i14 >>> 0) break;
    i10 = (HEAP32[i22 >> 2] | 0) + (i1 + i13 << 2) | 0;
    i12 = (HEAP32[i24 >> 2] | 0) + (i1 << 2) | 0;
    i11 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = HEAP32[i12 >> 2];
    HEAP32[i12 >> 2] = i11;
    i1 = i1 + 1 | 0;
   }
   i2 = i13 + i14 | 0;
   while (1) {
    if (i2 >>> 0 >= i15 >>> 0) break;
    i14 = (HEAP32[i22 >> 2] | 0) + (i2 << 2) | 0;
    i13 = __ZZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEEEN9Generator10makeRandomEv(HEAP32[i27 >> 2] | 0) | 0;
    i1 = HEAP32[i14 >> 2] | 0;
    HEAP32[i14 >> 2] = i13;
    if (i1 | 0) {
     __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1);
     __ZdlPv(i1);
    }
    i2 = i2 + 1 | 0;
   }
   __ZN4wasm14GeneticLearnerIZNS_26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS2_9allocatorIjEEEEE5OrderdZNS1_11pickIndicesES7_E9GeneratorE4sortEv(i27);
   __ZNSt3__213__vector_baseINS_10unique_ptrIZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderNS_14default_deleteIS9_EEEENS5_ISC_EEED2Ev(i24);
   i2 = HEAP32[i16 >> 2] | 0;
   i1 = HEAP32[i2 >> 2] | 0;
   d30 = d21;
   d21 = +HEAPF64[i1 + 16 >> 3];
   if (d21 == d30) {
    i2 = 34;
    break;
   }
  }
  if ((i2 | 0) == 17) ___assert_fail(47030, 46670, 540, 47040); else if ((i2 | 0) == 34) {
   __ZN4wasm14CoalesceLocals20pickIndicesFromOrderERNSt3__26vectorIjNS1_9allocatorIjEEEES6_(i28, i1, i26);
   __ZNSt3__213__vector_baseINS_10unique_ptrIZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderNS_14default_deleteIS9_EEEENS5_ISC_EEED2Ev(i27 + 4 | 0);
   break;
  }
 } else __ZN4wasm14CoalesceLocals11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEE(i28, i26); while (0);
 STACKTOP = i29;
 return;
}

function __ZN6cashew5Value9stringifyERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEb(i1, i8, i7) {
 i1 = i1 | 0;
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i9;
 L1 : do switch (HEAP32[i1 >> 2] | 0) {
 case 0:
  {
   i1 = i1 + 8 | 0;
   if (!(HEAP32[i1 >> 2] | 0)) {
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 20866) | 0;
    break L1;
   } else {
    i8 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i8, 34) | 0;
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, HEAP32[i1 >> 2] | 0) | 0, 34) | 0;
    break L1;
   }
  }
 case 1:
  {
   HEAP32[i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) + 8 >> 2] = 17;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd(i8, +HEAPF64[i1 + 8 >> 3]) | 0;
   break;
  }
 case 2:
  {
   i1 = i1 + 8 | 0;
   i5 = HEAP32[i1 >> 2] | 0;
   if ((HEAP32[i5 + 4 >> 2] | 0) == (HEAP32[i5 >> 2] | 0)) {
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 20875) | 0;
    break L1;
   }
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i8, 91) | 0;
   if (i7) {
    i5 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
    HEAP32[i6 >> 2] = i5;
    i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61680) | 0;
    i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
    __ZNSt3__26localeD2Ev(i6);
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i5) | 0;
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
    HEAP32[14816] = (HEAP32[14816] | 0) + 1;
   }
   i2 = 0;
   while (1) {
    i5 = HEAP32[i1 >> 2] | 0;
    if (i2 >>> 0 >= (HEAP32[i5 + 4 >> 2] | 0) - (HEAP32[i5 >> 2] | 0) >> 2 >>> 0) break;
    do if (i2) if (i7) {
     i3 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 57051) | 0;
     i5 = __ZNKSt3__28ios_base6getlocEv(i3 + (HEAP32[(HEAP32[i3 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
     HEAP32[i6 >> 2] = i5;
     i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61680) | 0;
     i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
     __ZNSt3__26localeD2Ev(i6);
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i3, i5) | 0;
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i3) | 0;
     i3 = 0;
     break;
    } else {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 57598) | 0;
     i3 = 0;
     break;
    } else i3 = 0; while (0);
    while (1) {
     if ((i3 | 0) >= (HEAP32[14816] | 0)) break;
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 34501) | 0;
     i3 = i3 + 1 | 0;
    }
    __ZN6cashew5Value9stringifyERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEb(HEAP32[(HEAP32[HEAP32[i1 >> 2] >> 2] | 0) + (i2 << 2) >> 2] | 0, i8, i7);
    i2 = i2 + 1 | 0;
   }
   if (i7) {
    i1 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
    HEAP32[i6 >> 2] = i1;
    i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61680) | 0;
    i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 10) | 0;
    __ZNSt3__26localeD2Ev(i6);
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i1) | 0;
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
    HEAP32[14816] = (HEAP32[14816] | 0) + -1;
    i1 = 0;
   } else i1 = 0;
   while (1) {
    if ((i1 | 0) >= (HEAP32[14816] | 0)) break;
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 34501) | 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i8, 93) | 0;
   break;
  }
 case 3:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 20878) | 0;
   break;
  }
 case 4:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, HEAP8[i1 + 8 >> 0] | 0 ? 56974 : 56968) | 0;
   break;
  }
 case 5:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i8, 123) | 0;
   if (i7) {
    i5 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
    HEAP32[i6 >> 2] = i5;
    i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61680) | 0;
    i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
    __ZNSt3__26localeD2Ev(i6);
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i5) | 0;
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
    HEAP32[14816] = (HEAP32[14816] | 0) + 1;
    i5 = i8;
   } else i5 = i8;
   i1 = (HEAP32[i1 + 8 >> 2] | 0) + 8 | 0;
   i2 = 1;
   while (1) {
    i1 = HEAP32[i1 >> 2] | 0;
    if (!i1) break;
    i4 = i1;
    i3 = HEAP32[i4 + 8 >> 2] | 0;
    i4 = HEAP32[i4 + 12 >> 2] | 0;
    if (!i2 ? (__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 57598) | 0, i7) : 0) {
     i2 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
     HEAP32[i6 >> 2] = i2;
     i2 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61680) | 0;
     i2 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i2 >> 2] | 0) + 28 >> 2] & 63](i2, 10) | 0;
     __ZNSt3__26localeD2Ev(i6);
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i2) | 0;
     __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
     i2 = 0;
    } else i2 = 0;
    while (1) {
     if ((i2 | 0) >= (HEAP32[14816] | 0)) break;
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 34501) | 0;
     i2 = i2 + 1 | 0;
    }
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i8, 34) | 0, i3) | 0, 20883) | 0;
    __ZN6cashew5Value9stringifyERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEb(i4, i8, i7);
    i2 = 0;
   }
   if (i7) {
    i1 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
    HEAP32[i6 >> 2] = i1;
    i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61680) | 0;
    i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 10) | 0;
    __ZNSt3__26localeD2Ev(i6);
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i1) | 0;
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
    HEAP32[14816] = (HEAP32[14816] | 0) + -1;
    i1 = 0;
   } else i1 = 0;
   while (1) {
    if ((i1 | 0) >= (HEAP32[14816] | 0)) break;
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i8, 34501) | 0;
    i1 = i1 + 1 | 0;
   }
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i8, 125) | 0;
   break;
  }
 default:
  {}
 } while (0);
 STACKTOP = i9;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i17, i18, i19, i15, i20, i16, i1, i14) {
 i17 = i17 | 0;
 i18 = i18 | 0;
 i19 = i19 | 0;
 i15 = i15 | 0;
 i20 = i20 | 0;
 i16 = i16 | 0;
 i1 = i1 | 0;
 i14 = i14 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i21 = 0, i22 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i10 = i22 + 16 | 0;
 i9 = i22 + 12 | 0;
 i13 = i22 + 8 | 0;
 i11 = i22 + 4 | 0;
 i12 = i22;
 i2 = __ZNKSt3__28ios_base6getlocEv(i15) | 0;
 HEAP32[i13 >> 2] = i2;
 i13 = __ZNKSt3__26locale9use_facetERNS0_2idE(i13, 61712) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i2) | 0;
 HEAP32[i20 >> 2] = 0;
 i2 = i1;
 i1 = 0;
 L1 : while (1) {
  i8 = (i2 | 0) != (i14 | 0);
  i3 = i1;
  while (1) {
   i1 = HEAP32[i18 >> 2] | 0;
   if (!(i8 & (i3 | 0) == 0)) break L1;
   i4 = i1;
   if (i1) {
    i3 = HEAP32[i1 + 12 >> 2] | 0;
    if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i3 = HEAP32[i3 >> 2] | 0;
    if ((i3 | 0) == -1) {
     HEAP32[i18 >> 2] = 0;
     i1 = 0;
     i4 = 0;
     i7 = 1;
    } else i7 = 0;
   } else {
    i1 = 0;
    i7 = 1;
   }
   i6 = HEAP32[i19 >> 2] | 0;
   i3 = i6;
   do if (i6) {
    i5 = HEAP32[i6 + 12 >> 2] | 0;
    if ((i5 | 0) == (HEAP32[i6 + 16 >> 2] | 0)) i5 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 36 >> 2] & 255](i6) | 0; else i5 = HEAP32[i5 >> 2] | 0;
    if ((i5 | 0) != -1) if (i7) {
     i5 = i6;
     break;
    } else {
     i21 = 18;
     break L1;
    } else {
     HEAP32[i19 >> 2] = 0;
     i3 = 0;
     i21 = 16;
     break;
    }
   } else i21 = 16; while (0);
   if ((i21 | 0) == 16) {
    i21 = 0;
    if (i7) {
     i21 = 18;
     break L1;
    } else i5 = 0;
   }
   if ((FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i13 >> 2] | 0) + 52 >> 2] & 31](i13, HEAP32[i2 >> 2] | 0, 0) | 0) << 24 >> 24 == 37) {
    i7 = i3;
    i21 = 20;
    break;
   }
   if (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i13 >> 2] | 0) + 12 >> 2] & 31](i13, 8192, HEAP32[i2 >> 2] | 0) | 0) {
    i4 = i5;
    i21 = 28;
    break;
   }
   i5 = i1 + 12 | 0;
   i4 = HEAP32[i5 >> 2] | 0;
   i3 = i1 + 16 | 0;
   if ((i4 | 0) == (HEAP32[i3 >> 2] | 0)) i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i4 = HEAP32[i4 >> 2] | 0;
   i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 28 >> 2] & 63](i13, i4) | 0;
   if ((i7 | 0) == (FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 28 >> 2] & 63](i13, HEAP32[i2 >> 2] | 0) | 0)) {
    i21 = 57;
    break;
   }
   HEAP32[i20 >> 2] = 4;
   i3 = 4;
  }
  L33 : do if ((i21 | 0) == 20) {
   i21 = 0;
   i3 = i2 + 4 | 0;
   if ((i3 | 0) == (i14 | 0)) {
    i21 = 21;
    break L1;
   }
   i6 = FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i13 >> 2] | 0) + 52 >> 2] & 31](i13, HEAP32[i3 >> 2] | 0, 0) | 0;
   switch (i6 << 24 >> 24) {
   case 48:
   case 69:
    {
     i5 = i2 + 8 | 0;
     if ((i5 | 0) == (i14 | 0)) {
      i21 = 26;
      break L1;
     }
     i2 = i3;
     i3 = FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i13 >> 2] | 0) + 52 >> 2] & 31](i13, HEAP32[i5 >> 2] | 0, 0) | 0;
     i1 = i6;
     break;
    }
   default:
    {
     i3 = i6;
     i1 = 0;
    }
   }
   i8 = HEAP32[(HEAP32[i17 >> 2] | 0) + 36 >> 2] | 0;
   HEAP32[i11 >> 2] = i4;
   HEAP32[i12 >> 2] = i7;
   HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
   HEAP32[i10 >> 2] = HEAP32[i12 >> 2];
   i1 = FUNCTION_TABLE_iiiiiiiii[i8 & 15](i17, i9, i10, i15, i20, i16, i3, i1) | 0;
   HEAP32[i18 >> 2] = i1;
   i1 = i2 + 8 | 0;
  } else if ((i21 | 0) == 28) {
   i21 = 0;
   do {
    i2 = i2 + 4 | 0;
    if ((i2 | 0) == (i14 | 0)) {
     i2 = i14;
     break;
    }
   } while (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i13 >> 2] | 0) + 12 >> 2] & 31](i13, 8192, HEAP32[i2 >> 2] | 0) | 0);
   i3 = i4;
   i6 = i4;
   while (1) {
    if (i1) {
     i4 = HEAP32[i1 + 12 >> 2] | 0;
     if ((i4 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i4 = HEAP32[i4 >> 2] | 0;
     if ((i4 | 0) == -1) {
      HEAP32[i18 >> 2] = 0;
      i1 = 0;
      i5 = 1;
     } else i5 = 0;
    } else {
     i1 = 0;
     i5 = 1;
    }
    do if (i6) {
     i4 = HEAP32[i6 + 12 >> 2] | 0;
     if ((i4 | 0) == (HEAP32[i6 + 16 >> 2] | 0)) i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 36 >> 2] & 255](i6) | 0; else i4 = HEAP32[i4 >> 2] | 0;
     if ((i4 | 0) != -1) if (i5 ^ (i3 | 0) == 0) {
      i7 = i3;
      i6 = i3;
      break;
     } else {
      i1 = i2;
      break L33;
     } else {
      HEAP32[i19 >> 2] = 0;
      i3 = 0;
      i21 = 44;
      break;
     }
    } else i21 = 44; while (0);
    if ((i21 | 0) == 44) {
     i21 = 0;
     if (i5) {
      i1 = i2;
      break L33;
     } else {
      i7 = i3;
      i6 = 0;
     }
    }
    i5 = i1 + 12 | 0;
    i3 = HEAP32[i5 >> 2] | 0;
    i4 = i1 + 16 | 0;
    if ((i3 | 0) == (HEAP32[i4 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i3 = HEAP32[i3 >> 2] | 0;
    if (!(FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i13 >> 2] | 0) + 12 >> 2] & 31](i13, 8192, i3) | 0)) {
     i1 = i2;
     break L33;
    }
    i3 = HEAP32[i5 >> 2] | 0;
    if ((i3 | 0) == (HEAP32[i4 >> 2] | 0)) {
     FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
     i3 = i7;
     continue;
    } else {
     HEAP32[i5 >> 2] = i3 + 4;
     i3 = i7;
     continue;
    }
   }
  } else if ((i21 | 0) == 57) {
   i21 = 0;
   i4 = HEAP32[i5 >> 2] | 0;
   if ((i4 | 0) == (HEAP32[i3 >> 2] | 0)) FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0; else HEAP32[i5 >> 2] = i4 + 4;
   i1 = i2 + 4 | 0;
  } while (0);
  i2 = i1;
  i1 = HEAP32[i20 >> 2] | 0;
 }
 if ((i21 | 0) == 18) HEAP32[i20 >> 2] = 4; else if ((i21 | 0) == 21) HEAP32[i20 >> 2] = 4; else if ((i21 | 0) == 26) HEAP32[i20 >> 2] = 4;
 if (i1) {
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAP32[i2 >> 2] | 0;
  if ((i2 | 0) == -1) {
   HEAP32[i18 >> 2] = 0;
   i1 = 0;
   i4 = 1;
  } else i4 = 0;
 } else {
  i1 = 0;
  i4 = 1;
 }
 i2 = HEAP32[i19 >> 2] | 0;
 do if (i2) {
  i3 = HEAP32[i2 + 12 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i2 = HEAP32[i3 >> 2] | 0;
  if ((i2 | 0) != -1) if (i4) break; else {
   i21 = 77;
   break;
  } else {
   HEAP32[i19 >> 2] = 0;
   i21 = 75;
   break;
  }
 } else i21 = 75; while (0);
 if ((i21 | 0) == 75 ? i4 : 0) i21 = 77;
 if ((i21 | 0) == 77) HEAP32[i20 >> 2] = HEAP32[i20 >> 2] | 2;
 STACKTOP = i22;
 return i1 | 0;
}

function __ZN4wasm16PrintSExpression10visitUnaryEPNS_5UnaryE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i2 >> 2] | 0, 40) | 0;
 __Z12prepareColorRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE(HEAP32[i2 >> 2] | 0) | 0;
 do switch (HEAP32[i1 + 8 >> 2] | 0) {
 case 0:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34806) | 0;
   break;
  }
 case 2:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34814) | 0;
   break;
  }
 case 4:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34822) | 0;
   break;
  }
 case 20:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34833) | 0;
   break;
  }
 case 1:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34841) | 0;
   break;
  }
 case 3:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34849) | 0;
   break;
  }
 case 5:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34857) | 0;
   break;
  }
 case 21:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34868) | 0;
   break;
  }
 case 6:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34876) | 0;
   break;
  }
 case 8:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34884) | 0;
   break;
  }
 case 10:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34892) | 0;
   break;
  }
 case 12:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34901) | 0;
   break;
  }
 case 14:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34911) | 0;
   break;
  }
 case 16:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34921) | 0;
   break;
  }
 case 18:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34933) | 0;
   break;
  }
 case 7:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34942) | 0;
   break;
  }
 case 9:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34950) | 0;
   break;
  }
 case 11:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34958) | 0;
   break;
  }
 case 13:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34967) | 0;
   break;
  }
 case 15:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34977) | 0;
   break;
  }
 case 17:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34987) | 0;
   break;
  }
 case 19:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 34999) | 0;
   break;
  }
 case 22:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35008) | 0;
   break;
  }
 case 23:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35025) | 0;
   break;
  }
 case 24:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35042) | 0;
   break;
  }
 case 25:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35055) | 0;
   break;
  }
 case 26:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35071) | 0;
   break;
  }
 case 27:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35087) | 0;
   break;
  }
 case 28:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35103) | 0;
   break;
  }
 case 29:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35119) | 0;
   break;
  }
 case 30:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35135) | 0;
   break;
  }
 case 31:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35151) | 0;
   break;
  }
 case 32:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35167) | 0;
   break;
  }
 case 33:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35183) | 0;
   break;
  }
 case 34:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35203) | 0;
   break;
  }
 case 37:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35223) | 0;
   break;
  }
 case 38:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35241) | 0;
   break;
  }
 case 35:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35259) | 0;
   break;
  }
 case 36:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35277) | 0;
   break;
  }
 case 41:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35295) | 0;
   break;
  }
 case 42:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35313) | 0;
   break;
  }
 case 39:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35331) | 0;
   break;
  }
 case 40:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35349) | 0;
   break;
  }
 case 43:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35367) | 0;
   break;
  }
 case 44:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35383) | 0;
   break;
  }
 case 45:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35398) | 0;
   break;
  }
 case 46:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 35418) | 0;
   break;
  }
 default:
  _abort();
 } while (0);
 __ZN4wasm16PrintSExpression9incIndentEv(i2);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i2, HEAP32[i1 + 12 >> 2] | 0);
 __ZN4wasm16PrintSExpression9decIndentEv(i2);
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_120parse_function_paramINS0_2DbEEEPKcS4_S4_RT_(i1, i4, i14) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 i14 = i14 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 128 | 0;
 i13 = i15 + 104 | 0;
 i3 = i15 + 72 | 0;
 i10 = i15 + 80 | 0;
 i11 = i15 + 60 | 0;
 i12 = i15 + 48 | 0;
 i6 = i15 + 24 | 0;
 i7 = i15 + 12 | 0;
 i8 = i15;
 L1 : do if ((i4 - i1 | 0) > 2 ? (HEAP8[i1 >> 0] | 0) == 102 : 0) {
  switch (HEAP8[i1 + 1 >> 0] | 0) {
  case 112:
   {
    i2 = __ZN10__cxxabiv112_GLOBAL__N_119parse_cv_qualifiersEPKcS2_Rj(i1 + 2 | 0, i4, i3) | 0;
    i5 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i2, i4) | 0;
    if ((i5 | 0) != (i4 | 0) ? (HEAP8[i5 >> 0] | 0) == 95 : 0) {
     HEAP32[i12 >> 2] = 0;
     HEAP32[i12 + 4 >> 2] = 0;
     HEAP32[i12 + 8 >> 2] = 0;
     i3 = i5 - i2 | 0;
     if (i3 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i12);
     if (i3 >>> 0 < 11) {
      HEAP8[i12 + 11 >> 0] = i3;
      i4 = i12;
     } else {
      i9 = i3 + 16 & -16;
      i4 = _malloc(i9) | 0;
      HEAP32[i12 >> 2] = i4;
      HEAP32[i12 + 8 >> 2] = i9 | -2147483648;
      HEAP32[i12 + 4 >> 2] = i3;
     }
     i1 = i2;
     i2 = i4;
     while (1) {
      if ((i1 | 0) == (i5 | 0)) break;
      HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
      i1 = i1 + 1 | 0;
      i2 = i2 + 1 | 0;
     }
     HEAP8[i4 + i3 >> 0] = 0;
     i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i12, 0, 57005) | 0;
     HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
     HEAP32[i11 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
     HEAP32[i11 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i1 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i10, i11);
     i1 = i14 + 4 | 0;
     i2 = HEAP32[i1 >> 2] | 0;
     i9 = HEAP32[i14 + 8 >> 2] | 0;
     i3 = i9;
     if (i2 >>> 0 < i9 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i10);
      HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
     } else {
      i1 = HEAP32[i14 >> 2] | 0;
      i4 = (i2 - i1 | 0) / 24 | 0;
      i2 = i4 + 1 | 0;
      if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i14);
      i1 = (i3 - i1 | 0) / 24 | 0;
      if (i1 >>> 0 < 89478485) {
       i1 = i1 << 1;
       i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
      } else i1 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i13, i1, i4, i14 + 12 | 0);
      i9 = i13 + 8 | 0;
      i8 = HEAP32[i9 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i8, i10);
      HEAP32[i9 >> 2] = i8 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i14, i13);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i13);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i10);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i11);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i12);
     i1 = i5 + 1 | 0;
    }
    break L1;
   }
  case 76:
   break;
  default:
   break L1;
  }
  i2 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i1 + 2 | 0, i4) | 0;
  if ((((i2 | 0) != (i4 | 0) ? (HEAP8[i2 >> 0] | 0) == 112 : 0) ? (i5 = __ZN10__cxxabiv112_GLOBAL__N_119parse_cv_qualifiersEPKcS2_Rj(i2 + 1 | 0, i4, i3) | 0, i9 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i5, i4) | 0, (i9 | 0) != (i4 | 0)) : 0) ? (HEAP8[i9 >> 0] | 0) == 95 : 0) {
   HEAP32[i8 >> 2] = 0;
   HEAP32[i8 + 4 >> 2] = 0;
   HEAP32[i8 + 8 >> 2] = 0;
   i3 = i9 - i5 | 0;
   if (i3 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i8);
   if (i3 >>> 0 < 11) {
    HEAP8[i8 + 11 >> 0] = i3;
    i4 = i8;
   } else {
    i12 = i3 + 16 & -16;
    i4 = _malloc(i12) | 0;
    HEAP32[i8 >> 2] = i4;
    HEAP32[i8 + 8 >> 2] = i12 | -2147483648;
    HEAP32[i8 + 4 >> 2] = i3;
   }
   i1 = i5;
   i2 = i4;
   while (1) {
    if ((i1 | 0) == (i9 | 0)) break;
    HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
    i1 = i1 + 1 | 0;
    i2 = i2 + 1 | 0;
   }
   HEAP8[i4 + i3 >> 0] = 0;
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i8, 0, 57005) | 0;
   HEAP32[i7 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i7 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i7 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i6, i7);
   i1 = i14 + 4 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   i12 = HEAP32[i14 + 8 >> 2] | 0;
   i3 = i12;
   if (i2 >>> 0 < i12 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i6);
    HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
   } else {
    i1 = HEAP32[i14 >> 2] | 0;
    i4 = (i2 - i1 | 0) / 24 | 0;
    i2 = i4 + 1 | 0;
    if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i14);
    i1 = (i3 - i1 | 0) / 24 | 0;
    if (i1 >>> 0 < 89478485) {
     i1 = i1 << 1;
     i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
    } else i1 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i13, i1, i4, i14 + 12 | 0);
    i12 = i13 + 8 | 0;
    i11 = HEAP32[i12 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i11, i6);
    HEAP32[i12 >> 2] = i11 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i14, i13);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i13);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i7);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
   i1 = i9 + 1 | 0;
  }
 } while (0);
 STACKTOP = i15;
 return i1 | 0;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i18, i19, i20, i16, i21, i17, i1, i15) {
 i18 = i18 | 0;
 i19 = i19 | 0;
 i20 = i20 | 0;
 i16 = i16 | 0;
 i21 = i21 | 0;
 i17 = i17 | 0;
 i1 = i1 | 0;
 i15 = i15 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i22 = 0, i23 = 0;
 i23 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i9 = i23 + 16 | 0;
 i8 = i23 + 12 | 0;
 i12 = i23 + 8 | 0;
 i10 = i23 + 4 | 0;
 i11 = i23;
 i13 = __ZNKSt3__28ios_base6getlocEv(i16) | 0;
 HEAP32[i12 >> 2] = i13;
 i12 = __ZNKSt3__26locale9use_facetERNS0_2idE(i12, 61680) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i13) | 0;
 HEAP32[i21 >> 2] = 0;
 i13 = i12 + 8 | 0;
 i2 = i1;
 i1 = 0;
 L1 : while (1) {
  i7 = (i2 | 0) != (i15 | 0);
  i3 = i1;
  while (1) {
   i1 = HEAP32[i19 >> 2] | 0;
   if (!(i7 & (i3 | 0) == 0)) break L1;
   i3 = i1;
   if (i1) {
    if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
     HEAP32[i19 >> 2] = 0;
     i3 = 0;
     i1 = 0;
    }
   } else i1 = 0;
   i6 = (i1 | 0) == 0;
   i5 = HEAP32[i20 >> 2] | 0;
   i4 = i5;
   do if (i5) {
    if ((HEAP32[i5 + 12 >> 2] | 0) == (HEAP32[i5 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0) == -1 : 0) {
     HEAP32[i20 >> 2] = 0;
     i4 = 0;
     i22 = 13;
     break;
    }
    if (!i6) {
     i22 = 14;
     break L1;
    }
   } else i22 = 13; while (0);
   if ((i22 | 0) == 13) {
    i22 = 0;
    if (i6) {
     i22 = 14;
     break L1;
    } else i5 = 0;
   }
   if ((FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i12 >> 2] | 0) + 36 >> 2] & 31](i12, HEAP8[i2 >> 0] | 0, 0) | 0) << 24 >> 24 == 37) {
    i7 = i4;
    i22 = 16;
    break;
   }
   i3 = HEAP8[i2 >> 0] | 0;
   if (i3 << 24 >> 24 > -1 ? (i14 = HEAP32[i13 >> 2] | 0, HEAP16[i14 + (i3 << 24 >> 24 << 1) >> 1] & 8192) : 0) {
    i4 = i14;
    i22 = 25;
    break;
   }
   i5 = i1 + 12 | 0;
   i4 = HEAP32[i5 >> 2] | 0;
   i3 = i1 + 16 | 0;
   if ((i4 | 0) == (HEAP32[i3 >> 2] | 0)) i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i4 = HEAPU8[i4 >> 0] | 0;
   i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i12 >> 2] | 0) + 12 >> 2] & 63](i12, i4 & 255) | 0;
   if (i6 << 24 >> 24 == (FUNCTION_TABLE_iii[HEAP32[(HEAP32[i12 >> 2] | 0) + 12 >> 2] & 63](i12, HEAP8[i2 >> 0] | 0) | 0) << 24 >> 24) {
    i22 = 53;
    break;
   }
   HEAP32[i21 >> 2] = 4;
   i3 = 4;
  }
  L29 : do if ((i22 | 0) == 16) {
   i22 = 0;
   i4 = i2 + 1 | 0;
   if ((i4 | 0) == (i15 | 0)) {
    i22 = 17;
    break L1;
   }
   i6 = FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i12 >> 2] | 0) + 36 >> 2] & 31](i12, HEAP8[i4 >> 0] | 0, 0) | 0;
   switch (i6 << 24 >> 24) {
   case 48:
   case 69:
    {
     i5 = i2 + 2 | 0;
     if ((i5 | 0) == (i15 | 0)) {
      i22 = 22;
      break L1;
     }
     i2 = i4;
     i4 = FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i12 >> 2] | 0) + 36 >> 2] & 31](i12, HEAP8[i5 >> 0] | 0, 0) | 0;
     i1 = i6;
     break;
    }
   default:
    {
     i4 = i6;
     i1 = 0;
    }
   }
   i6 = HEAP32[(HEAP32[i18 >> 2] | 0) + 36 >> 2] | 0;
   HEAP32[i10 >> 2] = i3;
   HEAP32[i11 >> 2] = i7;
   HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
   HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
   i1 = FUNCTION_TABLE_iiiiiiiii[i6 & 15](i18, i8, i9, i16, i21, i17, i4, i1) | 0;
   HEAP32[i19 >> 2] = i1;
   i1 = i2 + 2 | 0;
  } else if ((i22 | 0) == 25) {
   i22 = 0;
   do {
    i2 = i2 + 1 | 0;
    if ((i2 | 0) == (i15 | 0)) {
     i2 = i15;
     break;
    }
    i3 = HEAP8[i2 >> 0] | 0;
    if (i3 << 24 >> 24 <= -1) break;
   } while ((HEAP16[i4 + (i3 << 24 >> 24 << 1) >> 1] & 8192) != 0);
   i3 = i5;
   while (1) {
    if (i1) {
     if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
      HEAP32[i19 >> 2] = 0;
      i1 = 0;
     }
    } else i1 = 0;
    i4 = (i1 | 0) == 0;
    do if (i5) {
     if ((HEAP32[i5 + 12 >> 2] | 0) != (HEAP32[i5 + 16 >> 2] | 0)) if (i4) {
      i7 = i3;
      break;
     } else {
      i1 = i2;
      break L29;
     }
     if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0) != -1) if (i4 ^ (i3 | 0) == 0) {
      i7 = i3;
      i5 = i3;
      break;
     } else {
      i1 = i2;
      break L29;
     } else {
      HEAP32[i20 >> 2] = 0;
      i3 = 0;
      i22 = 39;
      break;
     }
    } else i22 = 39; while (0);
    if ((i22 | 0) == 39) {
     i22 = 0;
     if (i4) {
      i1 = i2;
      break L29;
     } else {
      i7 = i3;
      i5 = 0;
     }
    }
    i4 = i1 + 12 | 0;
    i3 = HEAP32[i4 >> 2] | 0;
    i6 = i1 + 16 | 0;
    if ((i3 | 0) == (HEAP32[i6 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i3 = HEAPU8[i3 >> 0] | 0;
    if ((i3 & 255) << 24 >> 24 <= -1) {
     i1 = i2;
     break L29;
    }
    if (!(HEAP16[(HEAP32[i13 >> 2] | 0) + (i3 << 24 >> 24 << 1) >> 1] & 8192)) {
     i1 = i2;
     break L29;
    }
    i3 = HEAP32[i4 >> 2] | 0;
    if ((i3 | 0) == (HEAP32[i6 >> 2] | 0)) {
     FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
     i3 = i7;
     continue;
    } else {
     HEAP32[i4 >> 2] = i3 + 1;
     i3 = i7;
     continue;
    }
   }
  } else if ((i22 | 0) == 53) {
   i22 = 0;
   i4 = HEAP32[i5 >> 2] | 0;
   if ((i4 | 0) == (HEAP32[i3 >> 2] | 0)) FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0; else HEAP32[i5 >> 2] = i4 + 1;
   i1 = i2 + 1 | 0;
  } while (0);
  i2 = i1;
  i1 = HEAP32[i21 >> 2] | 0;
 }
 if ((i22 | 0) == 14) HEAP32[i21 >> 2] = 4; else if ((i22 | 0) == 17) HEAP32[i21 >> 2] = 4; else if ((i22 | 0) == 22) HEAP32[i21 >> 2] = 4;
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i19 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i2 = (i1 | 0) == 0;
 i3 = HEAP32[i20 >> 2] | 0;
 do if (i3) {
  if ((HEAP32[i3 + 12 >> 2] | 0) == (HEAP32[i3 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0) == -1 : 0) {
   HEAP32[i20 >> 2] = 0;
   i22 = 68;
   break;
  }
  if (!i2) i22 = 69;
 } else i22 = 68; while (0);
 if ((i22 | 0) == 68 ? i2 : 0) i22 = 69;
 if ((i22 | 0) == 69) HEAP32[i21 >> 2] = HEAP32[i21 >> 2] | 2;
 STACKTOP = i23;
 return i1 | 0;
}

function __Z10detectTypeN6cashew3RefEP7AsmDatabNS_7IStringE(i15, i13, i14, i17) {
 i15 = i15 | 0;
 i13 = i13 | 0;
 i14 = i14 | 0;
 i17 = i17 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0;
 i19 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i2 = i19 + 40 | 0;
 i1 = i19 + 36 | 0;
 i3 = i19 + 32 | 0;
 i4 = i19 + 28 | 0;
 i5 = i19 + 24 | 0;
 i7 = i19 + 20 | 0;
 i8 = i19 + 16 | 0;
 i9 = i19 + 12 | 0;
 i10 = i19 + 8 | 0;
 i11 = i19 + 4 | 0;
 i12 = i19;
 i20 = __ZN6cashew3RefixEj(i15, 0) | 0;
 i20 = __ZN6cashew5Value10getCStringEv(HEAP32[i20 >> 2] | 0) | 0;
 L1 : do switch (HEAP8[i20 >> 0] | 0) {
 case 110:
  {
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 0) | 0, 59348) | 0) {
    i16 = __ZN6cashew3RefixEj(i15, 1) | 0;
    i16 = __ZN6cashew5Value9getNumberEv(HEAP32[i16 >> 2] | 0) | 0;
    i16 = (__ZN4wasm9isIntegerEd(+HEAPF64[i16 >> 3]) | 0) & 1 ^ 1;
    break L1;
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 0) | 0, 59292) | 0) {
    if (i13 | 0 ? (i6 = __ZN6cashew3RefixEj(i15, 1) | 0, __ZN6cashew7IStringC2EPKcb(i3, __ZN6cashew5Value10getCStringEv(HEAP32[i6 >> 2] | 0) | 0, 1), i6 = __ZN7AsmData7getTypeERKN6cashew7IStringE(i13, i3) | 0, (i6 | 0) != 8) : 0) {
     i16 = i6;
     break L1;
    }
    if (!i14) {
     if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 1) | 0, 59372) | 0) {
      i16 = 1;
      break L1;
     }
     if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 1) | 0, 59376) | 0) {
      i16 = 1;
      break L1;
     }
     i16 = __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 1) | 0, 59380) | 0;
     i16 = i16 ? 0 : 8;
     break L1;
    }
    i20 = (HEAP32[14934] | 0) == 0;
    i1 = __ZN6cashew3RefixEj(i15, 1) | 0;
    if (i20) {
     i16 = __ZN6cashew5Value10getIStringEv(HEAP32[i1 >> 2] | 0) | 0;
     HEAP32[14934] = HEAP32[i16 >> 2];
     i16 = 2;
     break L1;
    }
    if (__ZN6cashew3RefeqERKNS_7IStringE(i1, 59736) | 0) i16 = 2; else ___assert_fail(48409, 48435, 73, 48481);
   } else i18 = 40;
   break;
  }
 case 117:
  {
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 0) | 0, 59396) | 0) {
    i20 = __ZN6cashew3RefixEj(i15, 1) | 0;
    i20 = __ZN6cashew5Value10getCStringEv(HEAP32[i20 >> 2] | 0) | 0;
    switch (HEAP8[i20 >> 0] | 0) {
    case 43:
     {
      i16 = 1;
      break L1;
     }
    case 45:
     {
      i16 = __ZN6cashew3RefixEj(i15, 2) | 0;
      HEAP32[i4 >> 2] = HEAP32[i16 >> 2];
      HEAP32[i5 >> 2] = HEAP32[i17 >> 2];
      HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
      HEAP32[i2 >> 2] = HEAP32[i5 >> 2];
      i16 = __Z10detectTypeN6cashew3RefEP7AsmDatabNS_7IStringE(i1, i13, i14, i2) | 0;
      break L1;
     }
    case 126:
    case 33:
     {
      i16 = 0;
      break L1;
     }
    default:
     {
      i18 = 40;
      break L1;
     }
    }
   } else i18 = 40;
   break;
  }
 case 99:
  {
   if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 0) | 0, 59344) | 0)) {
    if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 0) | 0, 59304) | 0)) {
     i18 = 40;
     break L1;
    }
    i16 = __ZN6cashew3RefixEj(i15, 2) | 0;
    HEAP32[i7 >> 2] = HEAP32[i16 >> 2];
    HEAP32[i8 >> 2] = HEAP32[i17 >> 2];
    HEAP32[i1 >> 2] = HEAP32[i7 >> 2];
    HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
    i16 = __Z10detectTypeN6cashew3RefEP7AsmDatabNS_7IStringE(i1, i13, i14, i2) | 0;
    break L1;
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i15, 1) | 0, 0) | 0, 59292) | 0) {
    i1 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i15, 1) | 0, 1) | 0;
    i1 = __ZN6cashew5Value10getIStringEv(HEAP32[i1 >> 2] | 0) | 0;
    i1 = HEAP32[i1 >> 2] | 0;
    if ((i1 | 0) == (HEAP32[14851] | 0)) {
     i16 = 2;
     break L1;
    }
    if ((i1 | 0) == (HEAP32[i17 >> 2] | 0)) {
     i16 = 2;
     break L1;
    }
    if ((i1 | 0) == (HEAP32[14852] | 0) | (i1 | 0) == (HEAP32[14938] | 0)) {
     i16 = 3;
     break L1;
    }
    if ((i1 | 0) == (HEAP32[14853] | 0) | (i1 | 0) == (HEAP32[14939] | 0)) {
     i16 = 4;
     break L1;
    }
    if ((i1 | 0) == (HEAP32[14854] | 0) | (i1 | 0) == (HEAP32[14935] | 0)) {
     i16 = 5;
     break L1;
    }
    if ((i1 | 0) == (HEAP32[14855] | 0) | (i1 | 0) == (HEAP32[14936] | 0)) {
     i16 = 6;
     break L1;
    }
    if ((i1 | 0) == (HEAP32[14856] | 0) | (i1 | 0) == (HEAP32[14937] | 0)) {
     i16 = 7;
     break L1;
    }
   }
   i16 = 8;
   break;
  }
 case 98:
  {
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 0) | 0, 59308) | 0) {
    i20 = __ZN6cashew3RefixEj(i15, 1) | 0;
    i20 = __ZN6cashew5Value10getCStringEv(HEAP32[i20 >> 2] | 0) | 0;
    switch (HEAP8[i20 >> 0] | 0) {
    case 33:
    case 61:
    case 62:
    case 60:
    case 94:
    case 38:
    case 124:
     {
      i16 = 0;
      break L1;
     }
    case 37:
    case 47:
    case 42:
    case 45:
    case 43:
     break;
    default:
     {
      i18 = 40;
      break L1;
     }
    }
    i16 = __ZN6cashew3RefixEj(i15, 2) | 0;
    HEAP32[i9 >> 2] = HEAP32[i16 >> 2];
    HEAP32[i10 >> 2] = HEAP32[i17 >> 2];
    HEAP32[i1 >> 2] = HEAP32[i9 >> 2];
    HEAP32[i2 >> 2] = HEAP32[i10 >> 2];
    i16 = __Z10detectTypeN6cashew3RefEP7AsmDatabNS_7IStringE(i1, i13, i14, i2) | 0;
   } else i18 = 40;
   break;
  }
 case 115:
  {
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 0) | 0, 59336) | 0) {
    i16 = __ZN6cashew3RefixEj(i15, 2) | 0;
    HEAP32[i11 >> 2] = HEAP32[i16 >> 2];
    HEAP32[i12 >> 2] = HEAP32[i17 >> 2];
    HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
    HEAP32[i2 >> 2] = HEAP32[i12 >> 2];
    i16 = __Z10detectTypeN6cashew3RefEP7AsmDatabNS_7IStringE(i1, i13, i14, i2) | 0;
    break L1;
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i15, 0) | 0, 59340) | 0) if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i15, 1) | 0, 0) | 0, 59292) | 0) {
    i16 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i15, 1) | 0, 1) | 0;
    __Z9parseHeapPKc(i2, __ZN6cashew5Value10getCStringEv(HEAP32[i16 >> 2] | 0) | 0);
    i16 = HEAP32[i2 >> 2] | 0;
    i16 = (i16 & 255) << 24 >> 24 == 0 ? i16 >>> 16 & 255 : 8;
    break L1;
   } else ___assert_fail(48492, 48435, 123, 48481); else i18 = 40;
   break;
  }
 default:
  i18 = 40;
 } while (0);
 if ((i18 | 0) == 40) i16 = 8;
 STACKTOP = i19;
 return i16 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i10, i9) {
 i10 = i10 | 0;
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, d3 = 0.0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i11;
 HEAP32[i7 >> 2] = i9;
 L1 : do if (!(__ZN6cashew11isIdentInitEc(HEAP8[i9 >> 0] | 0) | 0)) {
  i6 = HEAP8[i9 >> 0] | 0;
  L10 : do if ((i6 + -48 & 255) < 10) if (i6 << 24 >> 24 == 48) {
   switch (HEAP8[i9 + 1 >> 0] | 0) {
   case 88:
   case 120:
    break;
   default:
    {
     i8 = 20;
     break L10;
    }
   }
   i1 = i9 + 2 | 0;
   HEAP32[i7 >> 2] = i1;
   HEAPF64[i10 >> 3] = 0.0;
   d3 = 0.0;
   while (1) {
    i2 = HEAP8[i1 >> 0] | 0;
    do if ((i2 + -48 & 255) < 10) {
     d3 = d3 * 16.0;
     HEAPF64[i10 >> 3] = d3;
     d3 = d3 + +((HEAP8[i1 >> 0] | 0) + -48 | 0);
     HEAPF64[i10 >> 3] = d3;
    } else {
     if ((i2 + -97 & 255) < 6) {
      d3 = d3 * 16.0;
      HEAPF64[i10 >> 3] = d3;
      d3 = d3 + +((HEAP8[i1 >> 0] | 0) + -87 | 0);
      HEAPF64[i10 >> 3] = d3;
      break;
     }
     if ((i2 + -65 & 255) >= 6) break L10;
     d3 = d3 * 16.0;
     HEAPF64[i10 >> 3] = d3;
     d3 = d3 + +((HEAP8[i1 >> 0] | 0) + -55 | 0);
     HEAPF64[i10 >> 3] = d3;
    } while (0);
    i6 = i1 + 1 | 0;
    HEAP32[i7 >> 2] = i6;
    i1 = i6;
   }
  } else i8 = 20; else {
   if (i6 << 24 >> 24 == 46 ? ((HEAP8[i9 + 1 >> 0] | 0) + -48 & 255) < 10 : 0) {
    i8 = 20;
    break;
   }
   i2 = HEAP32[1953] | 0;
   while (1) {
    i4 = HEAP8[i2 >> 0] | 0;
    if (!(i4 << 24 >> 24)) {
     i8 = 56;
     break;
    }
    if (i4 << 24 >> 24 == i6 << 24 >> 24) break; else i2 = i2 + 1 | 0;
   }
   if ((i8 | 0) == 56) {
    i2 = HEAP32[1954] | 0;
    while (1) {
     i4 = HEAP8[i2 >> 0] | 0;
     if (!(i4 << 24 >> 24)) break;
     if (i4 << 24 >> 24 == i6 << 24 >> 24) {
      i8 = 59;
      break;
     } else i2 = i2 + 1 | 0;
    }
    if ((i8 | 0) == 59) {
     HEAP32[i10 + 12 >> 2] = 6;
     i1 = i9 + 1 | 0;
     i6 = HEAP8[i1 >> 0] | 0;
     HEAP8[i1 >> 0] = 0;
     __ZN6cashew7IString3setEPKcb(i10, i9, 0);
     HEAP8[i1 >> 0] = i6;
     HEAP32[i7 >> 2] = i1;
     i8 = 63;
     break L1;
    }
    switch (i6 << 24 >> 24) {
    case 39:
    case 34:
     {
      i8 = i9 + 1 | 0;
      i1 = _strchr(i8, i6 << 24 >> 24) | 0;
      HEAP8[i1 >> 0] = 0;
      __ZN6cashew7IString3setEPKcb(i10, i8, 1);
      i1 = i1 + 1 | 0;
      HEAP32[i7 >> 2] = i1;
      HEAP32[i10 + 12 >> 2] = 3;
      i8 = 63;
      break L1;
     }
    default:
     {
      __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4dumpEPKcPc(31240, i9);
      _abort();
     }
    }
   }
   do switch (i6 << 24 >> 24 | 0) {
   case 33:
    {
     i5 = (HEAP8[i9 + 1 >> 0] | 0) == 61 ? HEAP32[14869] | 0 : HEAP32[14862] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 37:
    {
     i5 = HEAP32[14871] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 38:
    {
     i5 = HEAP32[14860] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 42:
    {
     i5 = HEAP32[14872] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 43:
    {
     i5 = HEAP32[14857] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 44:
    {
     i5 = HEAP32[14892] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 45:
    {
     i5 = HEAP32[14858] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 46:
    {
     i5 = HEAP32[14898] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 47:
    {
     i5 = HEAP32[14870] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 58:
    {
     i5 = HEAP32[14894] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 60:
    {
     i5 = HEAP8[i9 + 1 >> 0] | 0;
     i5 = HEAP32[(i5 << 24 >> 24 == 60 ? 59496 : i5 << 24 >> 24 == 61 ? 59464 : 59456) >> 2] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 61:
    {
     i5 = (HEAP8[i9 + 1 >> 0] | 0) == 61 ? HEAP32[14868] | 0 : HEAP32[14903] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 62:
    {
     i2 = HEAP8[i9 + 1 >> 0] | 0;
     if (i2 << 24 >> 24 == 62) i2 = (HEAP8[i9 + 2 >> 0] | 0) == 62 ? 59500 : 59492; else i2 = i2 << 24 >> 24 == 61 ? 59460 : 59468;
     i5 = HEAP32[i2 >> 2] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 63:
    {
     i5 = HEAP32[14893] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 94:
    {
     i5 = HEAP32[14861] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 124:
    {
     i5 = HEAP32[14859] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   case 126:
    {
     i5 = HEAP32[14863] | 0;
     HEAP32[i10 >> 2] = i5;
     break;
    }
   default:
    _abort();
   } while (0);
   i7 = _strlen(i5) | 0;
   i2 = i10 + 8 | 0;
   HEAP32[i2 >> 2] = i7;
   i7 = i9 + i7 | 0;
   i4 = HEAP8[i7 >> 0] | 0;
   HEAP8[i7 >> 0] = 0;
   if (!(_strcmp(HEAP32[i10 >> 2] | 0, i9) | 0)) {
    HEAP8[i9 + (HEAP32[i2 >> 2] | 0) >> 0] = i4;
    HEAP32[i10 + 12 >> 2] = 1;
    break L1;
   } else ___assert_fail(31212, 31173, 282, 31207);
  } while (0);
  if ((i8 | 0) == 20) {
   d3 = +_strtod(i9, i7);
   HEAPF64[i10 >> 3] = d3;
   i1 = HEAP32[i7 >> 2] | 0;
  }
  i2 = i9;
  while (1) {
   if ((i2 | 0) == (i1 | 0)) {
    i8 = 24;
    break;
   }
   if ((HEAP8[i2 >> 0] | 0) == 46) {
    i2 = 5;
    break;
   } else i2 = i2 + 1 | 0;
  }
  if ((i8 | 0) == 24) if (__ZN4wasm12isSInteger32Ed(d3) | 0) i2 = 4; else {
   i2 = __ZN4wasm12isUInteger32Ed(+HEAPF64[i10 >> 3]) | 0;
   i2 = i2 ? 4 : 5;
  }
  HEAP32[i10 + 12 >> 2] = i2;
  if (i1 >>> 0 > i9 >>> 0) i8 = 63; else ___assert_fail(31161, 31173, 256, 31207);
 } else {
  i1 = i9;
  do {
   i1 = i1 + 1 | 0;
   HEAP32[i7 >> 2] = i1;
  } while (__ZN6cashew11isIdentPartEc(HEAP8[i1 >> 0] | 0) | 0);
  i2 = HEAP8[i1 >> 0] | 0;
  if (!(i2 << 24 >> 24)) {
   __ZN6cashew7IString3setEPKcb(i10, i9, 1);
   i2 = i10;
  } else {
   HEAP8[i1 >> 0] = 0;
   __ZN6cashew7IString3setEPKcb(i10, i9, 0);
   i1 = HEAP32[i7 >> 2] | 0;
   HEAP8[i1 >> 0] = i2;
   i2 = i10;
  }
  i8 = (__ZNKSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE4findIS2_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS2_PvEEEERKT_(59616, i2) | 0) != 0;
  HEAP32[i10 + 12 >> 2] = i8 ? 0 : 2;
  i8 = 63;
 } while (0);
 if ((i8 | 0) == 63) HEAP32[i10 + 8 >> 2] = i1 - i9;
 STACKTOP = i11;
 return;
}

function __ZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionE(i9, i14) {
 i9 = i9 | 0;
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0;
 i23 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i15 = i23;
 i13 = i23 + 108 | 0;
 i17 = i23 + 96 | 0;
 i21 = i23 + 84 | 0;
 i20 = i23 + 72 | 0;
 i22 = i23 + 36 | 0;
 i19 = i23 + 24 | 0;
 i18 = i23 + 12 | 0;
 i8 = __ZN4wasm8Function12getNumLocalsEv(i14) | 0;
 HEAP32[i17 >> 2] = 0;
 i16 = i17 + 4 | 0;
 HEAP32[i16 >> 2] = 0;
 HEAP32[i17 + 8 >> 2] = 0;
 i2 = i17 + 8 | 0;
 i3 = 0;
 while (1) {
  HEAP32[i15 >> 2] = i3;
  if (i3 >>> 0 >= i8 >>> 0) break;
  i1 = HEAP32[i16 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i2 >> 2] | 0)) __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIRKjEEvOT_(i17, i15); else {
   HEAP32[i1 >> 2] = i3;
   HEAP32[i16 >> 2] = i1 + 4;
  }
  i3 = i3 + 1 | 0;
 }
 i12 = HEAP32[i17 >> 2] | 0;
 i11 = HEAP32[i16 >> 2] | 0;
 HEAP32[i15 >> 2] = i9;
 HEAP32[i15 + 4 >> 2] = i14;
 HEAP32[i15 + 8 >> 2] = i17;
 __ZNSt3__26__sortIRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEvT0_S8_T_(i12, i11, i15);
 i11 = i14 + 8 | 0;
 i12 = i14 + 12 | 0;
 i1 = (HEAP32[i12 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2;
 i2 = HEAP32[i17 >> 2] | 0;
 i3 = 0;
 while (1) {
  if (i3 >>> 0 >= i1 >>> 0) {
   i4 = 0;
   break;
  }
  if ((HEAP32[i2 + (i3 << 2) >> 2] | 0) >>> 0 < i1 >>> 0) i3 = i3 + 1 | 0; else {
   i10 = 10;
   break;
  }
 }
 if ((i10 | 0) == 10) ___assert_fail(43538, 43572, 57, 43601);
 while (1) {
  if ((i4 | 0) == (i1 | 0)) break;
  HEAP32[i2 + (i4 << 2) >> 2] = i4;
  i4 = i4 + 1 | 0;
 }
 i6 = i14 + 20 | 0;
 __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEEC2ERKS5_(i21, i6);
 i1 = HEAP32[i6 >> 2] | 0;
 i7 = i14 + 24 | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  i5 = i2 + -4 | 0;
  HEAP32[i7 >> 2] = i5;
  i2 = i5;
 }
 i4 = i9 + 44 | 0;
 i5 = i14 + 28 | 0;
 i1 = (HEAP32[i12 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2;
 while (1) {
  i2 = HEAP32[i17 >> 2] | 0;
  if (i1 >>> 0 >= (HEAP32[i16 >> 2] | 0) - i2 >> 2 >>> 0) break;
  HEAP32[i15 >> 2] = HEAP32[i2 + (i1 << 2) >> 2];
  i3 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i4, i15) | 0;
  if (!(HEAP32[i3 >> 2] | 0)) {
   i10 = 22;
   break;
  }
  i2 = (HEAP32[i21 >> 2] | 0) + ((HEAP32[i15 >> 2] | 0) - ((HEAP32[i12 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2) << 2) | 0;
  i3 = HEAP32[i7 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i5 >> 2] | 0)) __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i6, i2); else {
   HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i7 >> 2] = i3 + 4;
  }
  i1 = i1 + 1 | 0;
 }
 if ((i10 | 0) == 22) __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i17, i1);
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE5clearEv(i9 + 44 | 0);
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i20, i8);
 i1 = HEAP32[i17 >> 2] | 0;
 i2 = (HEAP32[i16 >> 2] | 0) - i1 >> 2;
 i3 = HEAP32[i20 >> 2] | 0;
 i4 = 0;
 while (1) {
  if ((i4 | 0) == (i2 | 0)) break;
  if ((HEAP32[i12 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2 >>> 0 > i4 >>> 0) HEAP32[i3 + (i4 << 2) >> 2] = i4; else HEAP32[i3 + (HEAP32[i1 + (i4 << 2) >> 2] << 2) >> 2] = i4;
  i4 = i4 + 1 | 0;
 }
 i5 = i22 + 4 | 0;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP32[i5 + 8 >> 2] = 0;
 HEAP32[i5 + 12 >> 2] = 0;
 HEAP32[i5 + 16 >> 2] = 0;
 HEAP32[i5 + 20 >> 2] = 0;
 HEAP32[i22 >> 2] = 7080;
 HEAP32[i22 + 28 >> 2] = i14;
 HEAP32[i22 + 32 >> 2] = i20;
 __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE4walkERPNS_10ExpressionE(i22, i14 + 36 | 0);
 i5 = i14 + 40 | 0;
 __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEEC2ERKS5_(i19, i5);
 i6 = i14 + 52 | 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i3 = i18 + 4 | 0;
 HEAP32[i18 >> 2] = i3;
 i4 = HEAP32[i6 >> 2] | 0;
 i2 = i14 + 56 | 0;
 i1 = i4;
 while (1) {
  if ((i4 | 0) == (i2 | 0)) break;
  i12 = i4 + 16 | 0;
  HEAP32[i13 >> 2] = i3;
  HEAP32[i15 >> 2] = HEAP32[i13 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE30__emplace_hint_unique_key_argsIS3_JRKNS_4pairIKS3_jEEEEENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEENS_21__tree_const_iteratorIS4_SM_iEERKT_DpOT0_(i18, i15, i12, i12) | 0;
  i12 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i1) | 0;
  i1 = i12;
  i4 = i12;
 }
 i3 = HEAP32[i5 >> 2] | 0;
 i1 = i14 + 44 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i3 | 0)) break;
  i14 = i2 + -4 | 0;
  HEAP32[i1 >> 2] = i14;
  i2 = i14;
 }
 __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE6resizeEj(i5, (HEAP32[i16 >> 2] | 0) - (HEAP32[i17 >> 2] | 0) >> 2);
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE5clearEv(i6);
 i3 = i19 + 4 | 0;
 i4 = 0;
 while (1) {
  i1 = HEAP32[i17 >> 2] | 0;
  if (i4 >>> 0 >= (HEAP32[i16 >> 2] | 0) - i1 >> 2 >>> 0) break;
  i1 = HEAP32[i1 + (i4 << 2) >> 2] | 0;
  i2 = HEAP32[i19 >> 2] | 0;
  if (i1 >>> 0 < (HEAP32[i3 >> 2] | 0) - i2 >> 2 >>> 0) {
   i14 = HEAP32[i2 + (i1 << 2) >> 2] | 0;
   HEAP32[i15 >> 2] = i14;
   HEAP32[(HEAP32[i5 >> 2] | 0) + (i4 << 2) >> 2] = i14;
   i14 = __ZNSt3__23mapIN4wasm4NameEjNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_jEEEEEixERS7_(i6, i15) | 0;
   HEAP32[i14 >> 2] = i4;
  }
  i4 = i4 + 1 | 0;
 }
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i18);
 __ZNSt3__213__vector_baseIN4wasm4NameENS_9allocatorIS2_EEED2Ev(i19);
 HEAP32[i22 >> 2] = 7092;
 __ZNSt3__213__vector_baseIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEED2Ev(i22 + 8 | 0);
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i20);
 __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i21);
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i17);
 STACKTOP = i23;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_123parse_binary_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i4, i1, i13, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i13 = i13 | 0;
 i3 = i3 | 0;
 var i2 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i15 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i15 = i16 + 84 | 0;
 i14 = i16 + 72 | 0;
 i7 = i16 + 60 | 0;
 i8 = i16 + 48 | 0;
 i9 = i16 + 36 | 0;
 i10 = i16 + 24 | 0;
 i11 = i16 + 12 | 0;
 i12 = i16;
 i2 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i4, i1, i3) | 0;
 L1 : do if ((i2 | 0) != (i4 | 0)) {
  i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i2, i1, i3) | 0;
  i5 = i3 + 4 | 0;
  if ((i1 | 0) == (i2 | 0)) {
   i2 = HEAP32[i5 >> 2] | 0;
   i1 = i2 + -24 | 0;
   while (1) {
    if ((i2 | 0) == (i1 | 0)) {
     i1 = i4;
     break L1;
    }
    i15 = i2 + -24 | 0;
    HEAP32[i5 >> 2] = i15;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i15);
    i2 = HEAP32[i5 >> 2] | 0;
   }
  }
  i2 = HEAP32[i5 >> 2] | 0;
  if (((i2 - (HEAP32[i3 >> 2] | 0) | 0) / 24 | 0) >>> 0 >= 2) {
   __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i15, i2 + -24 | 0);
   i2 = HEAP32[i5 >> 2] | 0;
   i3 = i2 + -24 | 0;
   i4 = i2;
   while (1) {
    if ((i4 | 0) == (i3 | 0)) break;
    i6 = i4 + -24 | 0;
    HEAP32[i5 >> 2] = i6;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
    i4 = HEAP32[i5 >> 2] | 0;
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i14, i2 + -48 | 0);
   i2 = HEAP32[i5 >> 2] | 0;
   i6 = i2 + -24 | 0;
   i3 = i6 + 11 | 0;
   if ((HEAP8[i3 >> 0] | 0) < 0) {
    HEAP8[HEAP32[i6 >> 2] >> 0] = 0;
    HEAP32[i2 + -20 >> 2] = 0;
   } else {
    HEAP8[i6 >> 0] = 0;
    HEAP8[i3 >> 0] = 0;
   }
   i4 = i13 + 11 | 0;
   i3 = HEAP8[i4 >> 0] | 0;
   i2 = i3 << 24 >> 24 < 0;
   i5 = i13 + 4 | 0;
   if (((i2 ? HEAP32[i5 >> 2] | 0 : i3 & 255) | 0) == 1 ? (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2 ? HEAP32[i13 >> 2] | 0 : i13, 57011, 1) | 0) == 0 : 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9push_backEc(i6, 40);
   __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i12, 56964, i14);
   i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i12, 57013) | 0;
   HEAP32[i11 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i11 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   HEAP32[i11 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   i2 = HEAP8[i4 >> 0] | 0;
   i3 = i2 << 24 >> 24 < 0;
   i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i11, i3 ? HEAP32[i13 >> 2] | 0 : i13, i3 ? HEAP32[i5 >> 2] | 0 : i2 & 255) | 0;
   HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i10 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   HEAP32[i10 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i10, 57016) | 0;
   HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i9 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   HEAP32[i9 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   i2 = HEAP8[i15 + 11 >> 0] | 0;
   i3 = i2 << 24 >> 24 < 0;
   i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i9, i3 ? HEAP32[i15 >> 2] | 0 : i15, i3 ? HEAP32[i15 + 4 >> 2] | 0 : i2 & 255) | 0;
   HEAP32[i8 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i8 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   HEAP32[i8 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i8, 56966) | 0;
   HEAP32[i7 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i7 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   HEAP32[i7 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   i2 = HEAP8[i7 + 11 >> 0] | 0;
   i3 = i2 << 24 >> 24 < 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i6, i3 ? HEAP32[i7 >> 2] | 0 : i7, i3 ? HEAP32[i7 + 4 >> 2] | 0 : i2 & 255) | 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i7);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i9);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i10);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i11);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i12);
   i12 = HEAP8[i4 >> 0] | 0;
   i2 = i12 << 24 >> 24 < 0;
   if (((i2 ? HEAP32[i5 >> 2] | 0 : i12 & 255) | 0) == 1 ? (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2 ? HEAP32[i13 >> 2] | 0 : i13, 57011, 1) | 0) == 0 : 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9push_backEc(i6, 41);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i14);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
  } else i1 = i4;
 } else i1 = i4; while (0);
 STACKTOP = i16;
 return i1 | 0;
}

function __ZNSt3__26__sortIRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEvT0_S8_T_(i2, i1, i12) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i12 = i12 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0;
 L1 : while (1) {
  i10 = i1;
  i11 = i1 + -4 | 0;
  L3 : while (1) {
   i9 = i2;
   i3 = i10 - i9 | 0;
   i4 = i3 >> 2;
   switch (i4 | 0) {
   case 1:
   case 0:
    break L1;
   case 2:
    {
     i1 = i11;
     i13 = 4;
     break L1;
    }
   case 3:
    {
     i1 = i11;
     i13 = 6;
     break L1;
    }
   case 4:
    {
     i1 = i11;
     i13 = 7;
     break L1;
    }
   case 5:
    {
     i1 = i11;
     i13 = 8;
     break L1;
    }
   default:
    {}
   }
   if ((i3 | 0) < 124) {
    i13 = 10;
    break L1;
   }
   i5 = i2 + (((i4 | 0) / 2 | 0) << 2) | 0;
   if ((i3 | 0) > 3996) {
    i4 = (i4 | 0) / 4 | 0;
    i4 = __ZNSt3__27__sort5IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_S8_S8_T_(i2, i2 + (i4 << 2) | 0, i5, i5 + (i4 << 2) | 0, i11, i12) | 0;
   } else i4 = __ZNSt3__27__sort3IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_T_(i2, i5, i11, i12) | 0;
   do if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i2 >> 2] | 0, HEAP32[i5 >> 2] | 0) | 0) i6 = i11; else {
    i3 = i11;
    while (1) {
     i3 = i3 + -4 | 0;
     if ((i2 | 0) == (i3 | 0)) break;
     if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i3 >> 2] | 0, HEAP32[i5 >> 2] | 0) | 0) {
      i13 = 29;
      break;
     }
    }
    if ((i13 | 0) == 29) {
     i13 = 0;
     i6 = HEAP32[i2 >> 2] | 0;
     HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
     HEAP32[i3 >> 2] = i6;
     i6 = i3;
     i4 = i4 + 1 | 0;
     break;
    }
    i3 = i2 + 4 | 0;
    if (!(__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i2 >> 2] | 0, HEAP32[i11 >> 2] | 0) | 0)) {
     while (1) {
      if ((i3 | 0) == (i11 | 0)) break L1;
      if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i2 >> 2] | 0, HEAP32[i3 >> 2] | 0) | 0) break;
      i3 = i3 + 4 | 0;
     }
     i9 = HEAP32[i3 >> 2] | 0;
     HEAP32[i3 >> 2] = HEAP32[i11 >> 2];
     HEAP32[i11 >> 2] = i9;
     i3 = i3 + 4 | 0;
    }
    if ((i3 | 0) == (i11 | 0)) break L1; else i4 = i11;
    while (1) {
     i5 = i3;
     while (1) {
      i3 = i5 + 4 | 0;
      if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i2 >> 2] | 0, HEAP32[i5 >> 2] | 0) | 0) break; else i5 = i3;
     }
     do i4 = i4 + -4 | 0; while (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i2 >> 2] | 0, HEAP32[i4 >> 2] | 0) | 0);
     if (i5 >>> 0 >= i4 >>> 0) {
      i2 = i5;
      continue L3;
     }
     i9 = HEAP32[i5 >> 2] | 0;
     HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
     HEAP32[i4 >> 2] = i9;
    }
   } while (0);
   i3 = i2 + 4 | 0;
   L35 : do if (i3 >>> 0 < i6 >>> 0) {
    i8 = i5;
    while (1) {
     i5 = i3;
     while (1) {
      i3 = i5 + 4 | 0;
      if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i5 >> 2] | 0, HEAP32[i8 >> 2] | 0) | 0) i5 = i3; else {
       i7 = i5;
       break;
      }
     }
     i5 = i6;
     do i5 = i5 + -4 | 0; while (!(__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i5 >> 2] | 0, HEAP32[i8 >> 2] | 0) | 0));
     if (i7 >>> 0 > i5 >>> 0) {
      i3 = i7;
      i5 = i8;
      break L35;
     }
     i6 = HEAP32[i7 >> 2] | 0;
     HEAP32[i7 >> 2] = HEAP32[i5 >> 2];
     HEAP32[i5 >> 2] = i6;
     i6 = i5;
     i8 = (i8 | 0) == (i7 | 0) ? i5 : i8;
     i4 = i4 + 1 | 0;
    }
   } while (0);
   if ((i3 | 0) != (i5 | 0) ? __ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i5 >> 2] | 0, HEAP32[i3 >> 2] | 0) | 0 : 0) {
    i8 = HEAP32[i3 >> 2] | 0;
    HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
    HEAP32[i5 >> 2] = i8;
    i4 = i4 + 1 | 0;
   }
   if (!i4) {
    i4 = __ZNSt3__227__insertion_sort_incompleteIRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEbT0_S8_T_(i2, i3, i12) | 0;
    i5 = i3 + 4 | 0;
    if (__ZNSt3__227__insertion_sort_incompleteIRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEbT0_S8_T_(i5, i1, i12) | 0) {
     i13 = 46;
     break;
    }
    if (i4) {
     i2 = i5;
     continue;
    }
   }
   i8 = i3;
   if ((i8 - i9 | 0) >= (i10 - i8 | 0)) {
    i13 = 45;
    break;
   }
   __ZNSt3__26__sortIRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEvT0_S8_T_(i2, i3, i12);
   i2 = i3 + 4 | 0;
  }
  if ((i13 | 0) == 45) {
   i13 = 0;
   __ZNSt3__26__sortIRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEvT0_S8_T_(i3 + 4 | 0, i1, i12);
   i1 = i3;
   continue;
  } else if ((i13 | 0) == 46) {
   i13 = 0;
   if (i4) break; else {
    i1 = i3;
    continue;
   }
  }
 }
 if ((i13 | 0) == 4) {
  if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i12, HEAP32[i1 >> 2] | 0, HEAP32[i2 >> 2] | 0) | 0) {
   i13 = HEAP32[i2 >> 2] | 0;
   HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i1 >> 2] = i13;
  }
 } else if ((i13 | 0) == 6) __ZNSt3__27__sort3IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_T_(i2, i2 + 4 | 0, i1, i12) | 0; else if ((i13 | 0) == 7) __ZNSt3__27__sort4IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_S8_T_(i2, i2 + 4 | 0, i2 + 8 | 0, i1, i12) | 0; else if ((i13 | 0) == 8) __ZNSt3__27__sort5IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_S8_S8_T_(i2, i2 + 4 | 0, i2 + 8 | 0, i2 + 12 | 0, i1, i12) | 0; else if ((i13 | 0) == 10) __ZNSt3__218__insertion_sort_3IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEvT0_S8_T_(i2, i1, i12);
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_117parse_source_nameINS0_2DbEEEPKcS4_S4_RT_(i1, i5, i14) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i14 = i14 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i13 = i16 + 88 | 0;
 i15 = i16 + 64 | 0;
 i6 = i16 + 76 | 0;
 i9 = i16 + 40 | 0;
 i7 = i16 + 16 | 0;
 i8 = i16;
 L1 : do if (((i1 | 0) != (i5 | 0) ? (i3 = (HEAP8[i1 >> 0] | 0) + -48 | 0, i3 >>> 0 < 10) : 0) ? (i2 = i1 + 1 | 0, (i2 | 0) != (i5 | 0)) : 0) {
  while (1) {
   i4 = (HEAP8[i2 >> 0] | 0) + -48 | 0;
   if (i4 >>> 0 >= 10) {
    i12 = i2;
    i11 = i3;
    break;
   }
   i2 = i2 + 1 | 0;
   if ((i2 | 0) == (i5 | 0)) break L1;
   i3 = i4 + (i3 * 10 | 0) | 0;
  }
  if ((i5 - i12 | 0) >>> 0 >= i11 >>> 0) {
   HEAP32[i15 >> 2] = 0;
   HEAP32[i15 + 4 >> 2] = 0;
   HEAP32[i15 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i15, i12, i11);
   HEAP32[i6 >> 2] = 0;
   HEAP32[i6 + 4 >> 2] = 0;
   HEAP32[i6 + 8 >> 2] = 0;
   i5 = HEAP8[i15 + 11 >> 0] | 0;
   i1 = i5 << 24 >> 24 < 0;
   i5 = i1 ? HEAP32[i15 + 4 >> 2] | 0 : i5 & 255;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i6, i1 ? HEAP32[i15 >> 2] | 0 : i15, i5 >>> 0 < 10 ? i5 : 10);
   i5 = HEAP8[i6 + 11 >> 0] | 0;
   i1 = i5 << 24 >> 24 < 0;
   if (((i1 ? HEAP32[i6 + 4 >> 2] | 0 : i5 & 255) | 0) == 10) {
    i5 = (__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i1 ? HEAP32[i6 >> 2] | 0 : i6, 56843, 10) | 0) == 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i6);
    if (i5) {
     HEAP32[i9 >> 2] = 0;
     i1 = _malloc(32) | 0;
     HEAP32[i9 >> 2] = i1;
     HEAP32[i9 + 8 >> 2] = -2147483616;
     HEAP32[i9 + 4 >> 2] = 21;
     i2 = i1;
     i3 = 56854;
     i4 = i2 + 21 | 0;
     do {
      HEAP8[i2 >> 0] = HEAP8[i3 >> 0] | 0;
      i2 = i2 + 1 | 0;
      i3 = i3 + 1 | 0;
     } while ((i2 | 0) < (i4 | 0));
     HEAP8[i1 + 21 >> 0] = 0;
     i1 = i9 + 12 | 0;
     HEAP32[i1 >> 2] = 0;
     HEAP32[i1 + 4 >> 2] = 0;
     HEAP32[i1 + 8 >> 2] = 0;
     i2 = 0;
     while (1) {
      if ((i2 | 0) == 3) break;
      HEAP32[i1 + (i2 << 2) >> 2] = 0;
      i2 = i2 + 1 | 0;
     }
     i1 = i14 + 4 | 0;
     i2 = HEAP32[i1 >> 2] | 0;
     i8 = HEAP32[i14 + 8 >> 2] | 0;
     i3 = i8;
     if (i2 >>> 0 < i8 >>> 0) {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i9);
      HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
     } else {
      i1 = HEAP32[i14 >> 2] | 0;
      i4 = (i2 - i1 | 0) / 24 | 0;
      i2 = i4 + 1 | 0;
      if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i14);
      i1 = (i3 - i1 | 0) / 24 | 0;
      if (i1 >>> 0 < 89478485) {
       i1 = i1 << 1;
       i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
      } else i1 = 178956970;
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i13, i1, i4, i14 + 12 | 0);
      i8 = i13 + 8 | 0;
      i7 = HEAP32[i8 >> 2] | 0;
      __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i7, i9);
      HEAP32[i8 >> 2] = i7 + 24;
      __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i14, i13);
      __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i13);
     }
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i9);
    } else {
     i5 = i14;
     i10 = 22;
    }
   } else {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i6);
    i5 = i14;
    i10 = 22;
   }
   if ((i10 | 0) == 22) {
    HEAP32[i8 >> 2] = HEAP32[i15 >> 2];
    HEAP32[i8 + 4 >> 2] = HEAP32[i15 + 4 >> 2];
    HEAP32[i8 + 8 >> 2] = HEAP32[i15 + 8 >> 2];
    i1 = 0;
    while (1) {
     if ((i1 | 0) == 3) break;
     HEAP32[i15 + (i1 << 2) >> 2] = 0;
     i1 = i1 + 1 | 0;
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i7, i8);
    i1 = i14 + 4 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    i10 = HEAP32[i14 + 8 >> 2] | 0;
    i3 = i10;
    if (i2 >>> 0 < i10 >>> 0) {
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i2, i7);
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 24;
    } else {
     i1 = HEAP32[i5 >> 2] | 0;
     i4 = (i2 - i1 | 0) / 24 | 0;
     i2 = i4 + 1 | 0;
     if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i5);
     i1 = (i3 - i1 | 0) / 24 | 0;
     if (i1 >>> 0 < 89478485) {
      i1 = i1 << 1;
      i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
     } else i1 = 178956970;
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i13, i1, i4, i14 + 12 | 0);
     i14 = i13 + 8 | 0;
     i10 = HEAP32[i14 >> 2] | 0;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i10, i7);
     HEAP32[i14 >> 2] = i10 + 24;
     __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i5, i13);
     __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i13);
    }
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i7);
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
   }
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i15);
   i1 = i12 + i11 | 0;
  }
 } while (0);
 STACKTOP = i16;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_121parse_integer_literalINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i1, i2, i14, i10) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i14 = i14 | 0;
 i10 = i10 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i9 = i15 + 48 | 0;
 i6 = i15 + 24 | 0;
 i7 = i15 + 12 | 0;
 i8 = i15;
 i13 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i1, i2) | 0;
 if (!((i13 | 0) == (i1 | 0) | (i13 | 0) == (i2 | 0)) ? (HEAP8[i13 >> 0] | 0) == 69 : 0) {
  i11 = i14 + 11 | 0;
  i5 = HEAP8[i11 >> 0] | 0;
  i12 = i14 + 4 | 0;
  do if ((i5 << 24 >> 24 < 0 ? HEAP32[i12 >> 2] | 0 : i5 & 255) >>> 0 > 3) {
   __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i8, 56964, i14);
   i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i8, 56966) | 0;
   HEAP32[i7 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i7 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   HEAP32[i7 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i6, i7);
   i2 = i10 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   i5 = HEAP32[i10 + 8 >> 2] | 0;
   i4 = i5;
   if (i3 >>> 0 < i5 >>> 0) {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i6);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 24;
   } else {
    i2 = HEAP32[i10 >> 2] | 0;
    i5 = (i3 - i2 | 0) / 24 | 0;
    i3 = i5 + 1 | 0;
    if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i10);
    i2 = (i4 - i2 | 0) / 24 | 0;
    if (i2 >>> 0 < 89478485) {
     i2 = i2 << 1;
     i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
    } else i2 = 178956970;
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i9, i2, i5, i10 + 12 | 0);
    i5 = i9 + 8 | 0;
    i4 = HEAP32[i5 >> 2] | 0;
    __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i4, i6);
    HEAP32[i5 >> 2] = i4 + 24;
    __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i10, i9);
    __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i9);
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i7);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
  } else {
   i4 = i10 + 4 | 0;
   i3 = HEAP32[i4 >> 2] | 0;
   i8 = HEAP32[i10 + 8 >> 2] | 0;
   i5 = i8;
   if (i3 >>> 0 < i8 >>> 0) {
    HEAP32[i3 >> 2] = 0;
    HEAP32[i3 + 4 >> 2] = 0;
    HEAP32[i3 + 8 >> 2] = 0;
    HEAP32[i3 + 12 >> 2] = 0;
    HEAP32[i3 + 16 >> 2] = 0;
    HEAP32[i3 + 20 >> 2] = 0;
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i3 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i2 = i3 + 12 | 0;
    HEAP32[i2 >> 2] = 0;
    HEAP32[i2 + 4 >> 2] = 0;
    HEAP32[i2 + 8 >> 2] = 0;
    i3 = 0;
    while (1) {
     if ((i3 | 0) == 3) break;
     HEAP32[i2 + (i3 << 2) >> 2] = 0;
     i3 = i3 + 1 | 0;
    }
    HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 24;
    break;
   }
   i2 = HEAP32[i10 >> 2] | 0;
   i4 = (i3 - i2 | 0) / 24 | 0;
   i3 = i4 + 1 | 0;
   if (i3 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i10);
   i2 = (i5 - i2 | 0) / 24 | 0;
   if (i2 >>> 0 < 89478485) {
    i2 = i2 << 1;
    i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
   } else i2 = 178956970;
   __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i9, i2, i4, i10 + 12 | 0);
   i4 = i9 + 8 | 0;
   i5 = HEAP32[i4 >> 2] | 0;
   HEAP32[i5 >> 2] = 0;
   HEAP32[i5 + 4 >> 2] = 0;
   HEAP32[i5 + 8 >> 2] = 0;
   HEAP32[i5 + 12 >> 2] = 0;
   HEAP32[i5 + 16 >> 2] = 0;
   HEAP32[i5 + 20 >> 2] = 0;
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i5 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   i2 = i5 + 12 | 0;
   HEAP32[i2 >> 2] = 0;
   HEAP32[i2 + 4 >> 2] = 0;
   HEAP32[i2 + 8 >> 2] = 0;
   i3 = 0;
   while (1) {
    if ((i3 | 0) == 3) break;
    HEAP32[i2 + (i3 << 2) >> 2] = 0;
    i3 = i3 + 1 | 0;
   }
   HEAP32[i4 >> 2] = i5 + 24;
   __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i10, i9);
   __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i9);
  } while (0);
  i3 = i10 + 4 | 0;
  if ((HEAP8[i1 >> 0] | 0) == 110) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9push_backEc((HEAP32[i3 >> 2] | 0) + -24 | 0, 45);
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendIPKcEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorISC_EE5valueERS7_E4typeESC_SC_((HEAP32[i3 >> 2] | 0) + -24 | 0, i1, i13);
  i1 = HEAP8[i11 >> 0] | 0;
  i2 = i1 << 24 >> 24 < 0;
  i1 = i2 ? HEAP32[i12 >> 2] | 0 : i1 & 255;
  if (i1 >>> 0 < 4) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj((HEAP32[i3 >> 2] | 0) + -24 | 0, i2 ? HEAP32[i14 >> 2] | 0 : i14, i1) | 0;
  i1 = i13 + 1 | 0;
 }
 STACKTOP = i15;
 return i1 | 0;
}

function __ZZN4wasm15Asm2WasmBuilder10processAsmEN6cashew3RefEENK3__0clENS1_7IStringES2_NS_8WasmTypeE(i2, i8, i7, i1) {
 i2 = i2 | 0;
 i8 = i8 | 0;
 i7 = i7 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i12 = i16 + 28 | 0;
 i11 = i16 + 24 | 0;
 i10 = i16 + 20 | 0;
 i4 = i16 + 16 | 0;
 i3 = i16 + 12 | 0;
 i13 = i16 + 8 | 0;
 i14 = i16 + 4 | 0;
 i15 = i16;
 i9 = HEAP32[i2 >> 2] | 0;
 if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 0) | 0, 59588) | 0)) ___assert_fail(18813, 16311, 450, 57137);
 i5 = __ZN6cashew3RefixEj(i7, 1) | 0;
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 do if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 0) | 0, 59588) | 0)) {
  if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 0) | 0, 59292) | 0)) ___assert_fail(18989, 16311, 492, 57137);
  i2 = __ZN6cashew3RefixEj(i4, 1) | 0;
  i2 = __ZN6cashew5Value10getIStringEv(HEAP32[i2 >> 2] | 0) | 0;
  i2 = HEAP32[i2 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[14997] | 0)) {
   i3 = __ZN6cashew3RefixEj(i7, 2) | 0;
   i3 = __ZN6cashew5Value10getIStringEv(HEAP32[i3 >> 2] | 0) | 0;
   i3 = HEAP32[i3 >> 2] | 0;
   if ((i3 | 0) == (HEAP32[14876] | 0)) {
    i4 = i9 + 104 | 0;
    if (!(HEAP32[i4 >> 2] | 0)) {
     HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
     i5 = i2;
     i6 = 47;
     break;
    } else ___assert_fail(19007, 16311, 497, 57137);
   }
   if ((i3 | 0) == (HEAP32[14847] | 0)) {
    i1 = i9 + 100 | 0;
    if (!(HEAP32[i1 >> 2] | 0)) {
     HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
     break;
    } else ___assert_fail(19030, 16311, 501, 57137);
   } else {
    i5 = i2;
    i6 = 47;
   }
  } else {
   i5 = i2;
   i6 = 47;
  }
 } else {
  if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 1) | 0, 0) | 0, 59292) | 0)) ___assert_fail(18832, 16311, 455, 57137);
  if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 2) | 0, 59824) | 0) {
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 2) | 0, 59828) | 0) {
    i2 = i9 + 72 | 0;
    if (!(HEAP32[i2 >> 2] | 0)) {
     HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
     break;
    } else ___assert_fail(18853, 16311, 458, 57137);
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 2) | 0, 59832) | 0) {
    i2 = i9 + 76 | 0;
    if (!(HEAP32[i2 >> 2] | 0)) {
     HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
     break;
    } else ___assert_fail(18872, 16311, 462, 57137);
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 2) | 0, 59836) | 0) {
    i2 = i9 + 80 | 0;
    if (!(HEAP32[i2 >> 2] | 0)) {
     HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
     break;
    } else ___assert_fail(18892, 16311, 466, 57137);
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 2) | 0, 59856) | 0) {
    i2 = i9 + 84 | 0;
    if (!(HEAP32[i2 >> 2] | 0)) {
     HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
     break;
    } else ___assert_fail(18913, 16311, 470, 57137);
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 2) | 0, 59860) | 0) {
    i2 = i9 + 88 | 0;
    if (!(HEAP32[i2 >> 2] | 0)) {
     HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
     break;
    } else ___assert_fail(18931, 16311, 474, 57137);
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 2) | 0, 59864) | 0) {
    i2 = i9 + 92 | 0;
    if (!(HEAP32[i2 >> 2] | 0)) {
     HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
     break;
    } else ___assert_fail(18951, 16311, 478, 57137);
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 2) | 0, 59868) | 0) {
    i2 = i9 + 96 | 0;
    if (!(HEAP32[i2 >> 2] | 0)) {
     HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
     break;
    } else ___assert_fail(18970, 16311, 482, 57137);
   }
  }
  i5 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 1) | 0, 1) | 0;
  i5 = __ZN6cashew5Value10getCStringEv(HEAP32[i5 >> 2] | 0) | 0;
  HEAP32[i12 >> 2] = 0;
  HEAP32[i12 + 4 >> 2] = 0;
  HEAP32[i12 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i12, i5, _strlen(i5) | 0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i12, 46);
  i5 = __ZN6cashew3RefixEj(i4, 2) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i12, __ZN6cashew5Value10getCStringEv(HEAP32[i5 >> 2] | 0) | 0) | 0;
  __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i12 + 11 >> 0] | 0) < 0 ? HEAP32[i12 >> 2] | 0 : i12, 0);
  i5 = HEAP32[i3 >> 2] | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i12);
  i6 = 47;
 } while (0);
 do if ((i6 | 0) == 47) {
  i4 = __Znwj(16) | 0;
  HEAP32[i4 >> 2] = 0;
  HEAP32[i4 + 4 >> 2] = 0;
  HEAP32[i4 + 8 >> 2] = 0;
  HEAP32[i4 + 12 >> 2] = 0;
  i3 = HEAP32[i8 >> 2] | 0;
  HEAP32[i4 >> 2] = i3;
  HEAP32[i4 + 4 >> 2] = i5;
  i2 = __ZN6cashew3RefixEj(i7, 2) | 0;
  i2 = __ZN6cashew5Value10getIStringEv(HEAP32[i2 >> 2] | 0) | 0;
  i2 = HEAP32[i2 >> 2] | 0;
  HEAP32[i4 + 8 >> 2] = i2;
  i8 = i2;
  if ((i5 | 0) == (HEAP32[14941] | 0) ? (i8 | 0) == (HEAP32[14942] | 0) | (i8 | 0) == (HEAP32[14943] | 0) : 0) i1 = 4; else if (!i1) {
   __ZN4wasm6Module9addImportEPNS_6ImportE(HEAP32[i9 >> 2] | 0, i4);
   break;
  }
  HEAP32[i13 >> 2] = i3;
  HEAP32[i14 >> 2] = i5;
  HEAP32[i15 >> 2] = i2;
  HEAP32[i10 >> 2] = HEAP32[i13 >> 2];
  HEAP32[i11 >> 2] = HEAP32[i14 >> 2];
  HEAP32[i12 >> 2] = HEAP32[i15 >> 2];
  __ZN4wasm15Asm2WasmBuilder14allocateGlobalEN6cashew7IStringENS_8WasmTypeEbS2_S2_(i9, i10, i1, 1, i11, i12);
  __ZdlPv(i4);
 } while (0);
 STACKTOP = i16;
 return;
}

function __ZN4wasm10PassRunner28addDefaultOptimizationPassesEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 176 | 0;
 i16 = i2 + 156 | 0;
 i15 = i2 + 144 | 0;
 i14 = i2 + 132 | 0;
 i13 = i2 + 120 | 0;
 i12 = i2 + 108 | 0;
 i11 = i2 + 96 | 0;
 i10 = i2 + 84 | 0;
 i9 = i2 + 72 | 0;
 i8 = i2 + 60 | 0;
 i7 = i2 + 48 | 0;
 i6 = i2 + 36 | 0;
 i5 = i2 + 24 | 0;
 i4 = i2 + 12 | 0;
 i3 = i2;
 HEAP32[i16 >> 2] = 0;
 HEAP32[i16 + 4 >> 2] = 0;
 HEAP32[i16 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i16, 44768, 30);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i16);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i16);
 HEAP32[i15 >> 2] = 0;
 HEAP32[i15 + 4 >> 2] = 0;
 HEAP32[i15 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i15, 32485, 3);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i15);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i15);
 HEAP32[i14 >> 2] = 0;
 HEAP32[i14 + 4 >> 2] = 0;
 HEAP32[i14 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i14, 37649, 17);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i14);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i14);
 HEAP32[i13 >> 2] = 0;
 HEAP32[i13 + 4 >> 2] = 0;
 HEAP32[i13 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i13, 39468, 19);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i13);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i13);
 HEAP32[i12 >> 2] = 0;
 HEAP32[i12 + 4 >> 2] = 0;
 HEAP32[i12 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i12, 36849, 21);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i12);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i12);
 HEAP32[i11 >> 2] = 0;
 HEAP32[i11 + 4 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i11, 41084, 15);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i11);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i11);
 HEAP32[i10 >> 2] = 0;
 HEAP32[i10 + 4 >> 2] = 0;
 HEAP32[i10 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i10, 44121, 6);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i10);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i10);
 HEAP32[i9 >> 2] = 0;
 HEAP32[i9 + 4 >> 2] = 0;
 HEAP32[i9 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i9, 47052, 15);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i9);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i9);
 HEAP32[i8 >> 2] = 0;
 HEAP32[i8 + 4 >> 2] = 0;
 HEAP32[i8 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i8, 44121, 6);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i8);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i8);
 HEAP32[i7 >> 2] = 0;
 HEAP32[i7 + 4 >> 2] = 0;
 HEAP32[i7 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i7, 42978, 14);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i7);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i7);
 HEAP32[i6 >> 2] = 0;
 HEAP32[i6 + 4 >> 2] = 0;
 HEAP32[i6 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i6, 33465, 12);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i6);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i6);
 HEAP32[i5 >> 2] = 0;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP32[i5 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i5, 36849, 21);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i5);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i4, 44121, 6);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i4);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
 HEAP32[i3 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i3, 44768, 30);
 __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i1, i3);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i3);
 STACKTOP = i2;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE11parseSwitchERPcPKc(i24, i27, i1) {
 i24 = i24 | 0;
 i27 = i27 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i25 = 0, i26 = 0;
 i26 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i10 = i26 + 92 | 0;
 i9 = i26 + 88 | 0;
 i23 = i26 + 84 | 0;
 i20 = i26 + 32 | 0;
 i21 = i26 + 16 | 0;
 i22 = i26;
 i11 = i26 + 80 | 0;
 i12 = i26 + 76 | 0;
 i13 = i26 + 72 | 0;
 i14 = i26 + 68 | 0;
 i15 = i26 + 64 | 0;
 i16 = i26 + 60 | 0;
 i17 = i26 + 56 | 0;
 i18 = i26 + 52 | 0;
 i19 = i26 + 48 | 0;
 i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseParennedERPc(i24, i27) | 0;
 HEAP32[i23 >> 2] = i1;
 HEAP32[i10 >> 2] = HEAP32[i23 >> 2];
 i23 = __ZN6cashew12ValueBuilder10makeSwitchENS_3RefE(i10) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i27);
 i1 = HEAP32[i27 >> 2] | 0;
 if ((HEAP8[i1 >> 0] | 0) != 123) ___assert_fail(31389, 31173, 536, 31601);
 HEAP32[i27 >> 2] = i1 + 1;
 i3 = i20 + 12 | 0;
 i4 = i20 + 8 | 0;
 i5 = i21 + 12 | 0;
 i6 = i21 + 8 | 0;
 i7 = i22 + 12 | 0;
 i8 = i22 + 8 | 0;
 L4 : while (1) {
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i27);
  i1 = HEAP32[i27 >> 2] | 0;
  if ((HEAP8[i1 >> 0] | 0) == 125) {
   i25 = 28;
   break;
  }
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i20, i1);
  do if (!(HEAP32[i3 >> 2] | 0)) {
   i1 = HEAP32[i20 >> 2] | 0;
   if ((i1 | 0) != (HEAP32[14895] | 0)) {
    if ((i1 | 0) != (HEAP32[14896] | 0)) {
     i25 = 23;
     break;
    }
    HEAP32[i27 >> 2] = (HEAP32[i27 >> 2] | 0) + (HEAP32[i4 >> 2] | 0);
    HEAP32[i15 >> 2] = i23;
    HEAP32[i10 >> 2] = HEAP32[i15 >> 2];
    __ZN6cashew12ValueBuilder21appendDefaultToSwitchENS_3RefE(i10);
    __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i27);
    i1 = HEAP32[i27 >> 2] | 0;
    if ((HEAP8[i1 >> 0] | 0) != 58) {
     i25 = 21;
     break L4;
    }
    HEAP32[i27 >> 2] = i1 + 1;
    break;
   }
   HEAP32[i27 >> 2] = (HEAP32[i27 >> 2] | 0) + (HEAP32[i4 >> 2] | 0);
   __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i27);
   __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i21, HEAP32[i27 >> 2] | 0);
   i1 = HEAP32[i5 >> 2] | 0;
   if ((i1 | 1 | 0) == 5) {
    i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseFragERNS3_4FragE(i24, i21) | 0;
    HEAP32[i27 >> 2] = (HEAP32[i27 >> 2] | 0) + (HEAP32[i6 >> 2] | 0);
   } else {
    if ((i1 | 0) != 1) {
     i25 = 10;
     break L4;
    }
    if ((HEAP32[i21 >> 2] | 0) != (HEAP32[14858] | 0)) {
     i25 = 12;
     break L4;
    }
    HEAP32[i27 >> 2] = (HEAP32[i27 >> 2] | 0) + (HEAP32[i6 >> 2] | 0);
    __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i27);
    __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i22, HEAP32[i27 >> 2] | 0);
    if ((HEAP32[i7 >> 2] | 1 | 0) != 5) {
     i25 = 14;
     break L4;
    }
    HEAP32[i11 >> 2] = HEAP32[14858];
    i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseFragERNS3_4FragE(i24, i22) | 0;
    HEAP32[i12 >> 2] = i1;
    HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
    HEAP32[i10 >> 2] = HEAP32[i12 >> 2];
    i1 = __ZN6cashew12ValueBuilder10makePrefixENS_7IStringENS_3RefE(i9, i10) | 0;
    HEAP32[i27 >> 2] = (HEAP32[i27 >> 2] | 0) + (HEAP32[i8 >> 2] | 0);
   }
   HEAP32[i13 >> 2] = i23;
   HEAP32[i14 >> 2] = i1;
   HEAP32[i9 >> 2] = HEAP32[i13 >> 2];
   HEAP32[i10 >> 2] = HEAP32[i14 >> 2];
   __ZN6cashew12ValueBuilder18appendCaseToSwitchENS_3RefES1_(i9, i10);
   __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i27);
   i1 = HEAP32[i27 >> 2] | 0;
   if ((HEAP8[i1 >> 0] | 0) != 58) {
    i25 = 17;
    break L4;
   }
   HEAP32[i27 >> 2] = i1 + 1;
  } else i25 = 23; while (0);
  if ((i25 | 0) == 23) {
   i25 = 0;
   __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i27);
   i1 = (HEAP8[HEAP32[i27 >> 2] >> 0] | 0) == 123;
   if (i1) i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseBracketedBlockERPc(i24, i27) | 0; else {
    HEAP32[i16 >> 2] = HEAP32[14895];
    HEAP32[i17 >> 2] = HEAP32[14896];
    HEAP32[i9 >> 2] = HEAP32[i16 >> 2];
    HEAP32[i10 >> 2] = HEAP32[i17 >> 2];
    i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10parseBlockERPcPKcNS_7IStringES8_(i24, i27, 31421, i9, i10) | 0;
   }
   HEAP32[i18 >> 2] = i23;
   HEAP32[i19 >> 2] = i2;
   HEAP32[i9 >> 2] = HEAP32[i18 >> 2];
   HEAP32[i10 >> 2] = HEAP32[i19 >> 2];
   __ZN6cashew12ValueBuilder18appendCodeToSwitchENS_3RefES1_b(i9, i10, i1);
  }
 }
 if ((i25 | 0) == 10) ___assert_fail(31613, 31173, 553, 31601); else if ((i25 | 0) == 12) ___assert_fail(31636, 31173, 554, 31601); else if ((i25 | 0) == 14) ___assert_fail(31655, 31173, 558, 31601); else if ((i25 | 0) == 17) ___assert_fail(31673, 31173, 564, 31601); else if ((i25 | 0) == 21) ___assert_fail(31673, 31173, 571, 31601); else if ((i25 | 0) == 28) {
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i27);
  i1 = HEAP32[i27 >> 2] | 0;
  if ((HEAP8[i1 >> 0] | 0) == 125) {
   HEAP32[i27 >> 2] = i1 + 1;
   STACKTOP = i26;
   return i23 | 0;
  } else ___assert_fail(31424, 31173, 584, 31601);
 }
 return 0;
}

function __ZN4wasm22SExpressionWasmBuilder11parseImportERNS_7ElementE(i15, i12) {
 i15 = i15 | 0;
 i12 = i12 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i4 = i16 + 60 | 0;
 i2 = i16 + 48 | 0;
 i9 = i16 + 44 | 0;
 i5 = i16 + 40 | 0;
 i6 = i16 + 28 | 0;
 i7 = i16 + 24 | 0;
 i3 = i16 + 12 | 0;
 i13 = i16;
 i14 = __ZN4wasm11make_uniqueINS_6ImportEJEEENSt3__210unique_ptrIT_NS2_14default_deleteIS4_EEEEDpOT0_() | 0;
 i11 = (__ZN4wasm7Element4listEv(i12) | 0) + 8 | 0;
 if ((HEAP32[i11 >> 2] | 0) >>> 0 > 3 ? (i11 = __ZN4wasm7ElementixEj(i12, 3) | 0, (HEAP8[i11 >> 0] | 0) == 0) : 0) {
  i1 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i12, 1) | 0) | 0;
  HEAP32[i14 >> 2] = i1;
  i1 = i15 + 24 | 0;
  i11 = 2;
 } else {
  i1 = i15 + 24 | 0;
  i11 = __ZN4wasm4Name7fromIntEj(HEAP32[i1 >> 2] | 0) | 0;
  HEAP32[i14 >> 2] = i11;
  i11 = 1;
 }
 HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 1;
 i1 = i11 + 1 | 0;
 i10 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i12, i11) | 0) | 0;
 HEAP32[i14 + 4 >> 2] = i10;
 i10 = __ZN4wasm7ElementixEj(i12, i1) | 0;
 if (HEAP8[i10 >> 0] | 0) {
  i16 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i2 >> 2] = 0;
  HEAP32[i2 + 4 >> 2] = 0;
  HEAP32[i2 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i2, 21752, 18);
  __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i16, i2);
  ___cxa_throw(i16 | 0, 64, 279);
 }
 i2 = i11 + 2 | 0;
 i10 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i12, i1) | 0) | 0;
 HEAP32[i14 + 8 >> 2] = i10;
 i10 = __ZN4wasm11make_uniqueINS_12FunctionTypeEJEEENSt3__210unique_ptrIT_NS2_14default_deleteIS4_EEEEDpOT0_() | 0;
 i8 = (__ZN4wasm7Element4listEv(i12) | 0) + 8 | 0;
 do if ((HEAP32[i8 >> 2] | 0) >>> 0 > i2 >>> 0) {
  i8 = __ZN4wasm7ElementixEj(i12, i2) | 0;
  i1 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i8, 0) | 0) | 0;
  L12 : do if ((i1 | 0) != (HEAP32[14975] | 0)) {
   if ((i1 | 0) == (HEAP32[14976] | 0)) {
    i9 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i15, __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i8, 1) | 0) | 0, 0, 0) | 0;
    HEAP32[i10 + 4 >> 2] = i9;
    break;
   }
   if ((i1 | 0) != (HEAP32[14983] | 0)) {
    i16 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i3 >> 2] = 0;
    HEAP32[i3 + 4 >> 2] = 0;
    HEAP32[i3 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i3, 21800, 18);
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i16, i3);
    ___cxa_throw(i16 | 0, 64, 279);
   }
   i1 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i8, 1) | 0) | 0;
   i9 = HEAP32[i15 >> 2] | 0;
   HEAP32[i5 >> 2] = i1;
   HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
   if (!(__ZN4wasm6Module17checkFunctionTypeENS_4NameE(i9, i4) | 0)) {
    i16 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i6 >> 2] = 0;
    HEAP32[i6 + 4 >> 2] = 0;
    HEAP32[i6 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i6, 21771, 28);
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i16, i6);
    ___cxa_throw(i16 | 0, 64, 279);
   } else {
    i9 = HEAP32[i15 >> 2] | 0;
    HEAP32[i7 >> 2] = i1;
    HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
    __ZN4wasm12FunctionTypeaSERKS0_(i10, __ZN4wasm6Module15getFunctionTypeENS_4NameE(i9, i4) | 0) | 0;
    break;
   }
  } else {
   i1 = i10 + 8 | 0;
   i2 = i10 + 12 | 0;
   i3 = i10 + 16 | 0;
   i6 = 1;
   while (1) {
    i7 = (__ZN4wasm7Element4listEv(i8) | 0) + 8 | 0;
    if (i6 >>> 0 >= (HEAP32[i7 >> 2] | 0) >>> 0) break L12;
    i4 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i15, __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i8, i6) | 0) | 0, 0, 0) | 0;
    HEAP32[i9 >> 2] = i4;
    i5 = HEAP32[i2 >> 2] | 0;
    if (i5 >>> 0 < (HEAP32[i3 >> 2] | 0) >>> 0) {
     HEAP32[i5 >> 2] = i4;
     HEAP32[i2 >> 2] = i5 + 4;
    } else __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i1, i9);
    i6 = i6 + 1 | 0;
   }
  } while (0);
  i9 = (__ZN4wasm7Element4listEv(i12) | 0) + 8 | 0;
  i1 = i11 + 3 | 0;
  if ((HEAP32[i9 >> 2] | 0) >>> 0 > i1 >>> 0) {
   i1 = __ZN4wasm7ElementixEj(i12, i1) | 0;
   i12 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 0) | 0) | 0;
   if ((i12 | 0) == (HEAP32[14976] | 0)) {
    i12 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i15, __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 1) | 0) | 0, 0, 0) | 0;
    HEAP32[i10 + 4 >> 2] = i12;
    break;
   } else ___assert_fail(21819, 21446, 1277, 21846);
  }
 } while (0);
 __ZN4wasm6getSigEPNS_12FunctionTypeE(i13, i10);
 i12 = __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i13, HEAP32[i15 >> 2] | 0) | 0;
 HEAP32[i14 + 12 >> 2] = i12;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i13);
 __ZN4wasm6Module9addImportEPNS_6ImportE(HEAP32[i15 >> 2] | 0, i14);
 if (i10 | 0) {
  __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i10 + 8 | 0);
  __ZdlPv(i10);
 }
 STACKTOP = i16;
 return;
}

function __ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i(i31, i33, i32, i30, i1, i20, i19, i24, i25, i21, i27, i23, i26, i29, i22) {
 i31 = i31 | 0;
 i33 = i33 | 0;
 i32 = i32 | 0;
 i30 = i30 | 0;
 i1 = i1 | 0;
 i20 = i20 | 0;
 i19 = i19 | 0;
 i24 = i24 | 0;
 i25 = i25 | 0;
 i21 = i21 | 0;
 i27 = i27 | 0;
 i23 = i23 | 0;
 i26 = i26 | 0;
 i29 = i29 | 0;
 i22 = i22 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i28 = 0, i34 = 0;
 HEAP32[i32 >> 2] = i31;
 i12 = i29 + 8 + 3 | 0;
 i28 = i29 + 4 | 0;
 i14 = i26 + 8 + 3 | 0;
 i15 = i26 + 4 | 0;
 i16 = (i30 & 512 | 0) == 0;
 i17 = (i22 | 0) > 0;
 i18 = i23 + 11 | 0;
 i13 = i23 + 4 | 0;
 i11 = 0;
 while (1) {
  if ((i11 | 0) == 4) break;
  L4 : do switch (HEAP8[i25 + i11 >> 0] | 0) {
  case 0:
   {
    HEAP32[i33 >> 2] = HEAP32[i32 >> 2];
    break;
   }
  case 1:
   {
    HEAP32[i33 >> 2] = HEAP32[i32 >> 2];
    i9 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i19 >> 2] | 0) + 44 >> 2] & 63](i19, 32) | 0;
    i10 = HEAP32[i32 >> 2] | 0;
    HEAP32[i32 >> 2] = i10 + 4;
    HEAP32[i10 >> 2] = i9;
    break;
   }
  case 3:
   {
    i10 = HEAP8[i12 >> 0] | 0;
    i2 = i10 << 24 >> 24 < 0;
    if ((i2 ? HEAP32[i28 >> 2] | 0 : i10 & 255) | 0) {
     i9 = HEAP32[(i2 ? HEAP32[i29 >> 2] | 0 : i29) >> 2] | 0;
     i10 = HEAP32[i32 >> 2] | 0;
     HEAP32[i32 >> 2] = i10 + 4;
     HEAP32[i10 >> 2] = i9;
    }
    break;
   }
  case 2:
   {
    i6 = HEAP8[i14 >> 0] | 0;
    i2 = i6 << 24 >> 24 < 0;
    i6 = i2 ? HEAP32[i15 >> 2] | 0 : i6 & 255;
    if (!(i16 | (i6 | 0) == 0)) {
     i5 = i2 ? HEAP32[i26 >> 2] | 0 : i26;
     i3 = i5 + (i6 << 2) | 0;
     i4 = HEAP32[i32 >> 2] | 0;
     i2 = i4;
     while (1) {
      if ((i5 | 0) == (i3 | 0)) break;
      HEAP32[i2 >> 2] = HEAP32[i5 >> 2];
      i2 = i2 + 4 | 0;
      i5 = i5 + 4 | 0;
     }
     HEAP32[i32 >> 2] = i4 + (i6 << 2);
    }
    break;
   }
  case 4:
   {
    i3 = HEAP32[i32 >> 2] | 0;
    i1 = i24 ? i1 + 4 | 0 : i1;
    i2 = i1;
    while (1) {
     if (i2 >>> 0 >= i20 >>> 0) break;
     if (!(FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i19 >> 2] | 0) + 12 >> 2] & 31](i19, 2048, HEAP32[i2 >> 2] | 0) | 0)) break;
     i2 = i2 + 4 | 0;
    }
    if (i17) {
     i6 = i22;
     while (1) {
      i4 = (i6 | 0) > 0;
      if (!(i2 >>> 0 > i1 >>> 0 & i4)) break;
      i10 = i2 + -4 | 0;
      i8 = HEAP32[i10 >> 2] | 0;
      i9 = HEAP32[i32 >> 2] | 0;
      HEAP32[i32 >> 2] = i9 + 4;
      HEAP32[i9 >> 2] = i8;
      i2 = i10;
      i6 = i6 + -1 | 0;
     }
     if (i4) i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i19 >> 2] | 0) + 44 >> 2] & 63](i19, 48) | 0; else i7 = 0;
     i5 = HEAP32[i32 >> 2] | 0;
     while (1) {
      i4 = i5 + 4 | 0;
      if ((i6 | 0) <= 0) break;
      HEAP32[i5 >> 2] = i7;
      i5 = i4;
      i6 = i6 + -1 | 0;
     }
     HEAP32[i32 >> 2] = i4;
     HEAP32[i5 >> 2] = i21;
    }
    if ((i2 | 0) == (i1 | 0)) {
     i9 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i19 >> 2] | 0) + 44 >> 2] & 63](i19, 48) | 0;
     i10 = HEAP32[i32 >> 2] | 0;
     i2 = i10 + 4 | 0;
     HEAP32[i32 >> 2] = i2;
     HEAP32[i10 >> 2] = i9;
    } else {
     i10 = HEAP8[i18 >> 0] | 0;
     i9 = i10 << 24 >> 24 < 0;
     i10 = i9 ? HEAP32[i13 >> 2] | 0 : i10 & 255;
     if (!i10) {
      i7 = -1;
      i5 = 0;
      i8 = 0;
     } else {
      i7 = HEAP8[(i9 ? HEAP32[i23 >> 2] | 0 : i23) >> 0] | 0;
      i5 = 0;
      i8 = 0;
     }
     while (1) {
      if ((i2 | 0) == (i1 | 0)) break;
      i6 = HEAP32[i32 >> 2] | 0;
      if ((i8 | 0) == (i7 | 0)) {
       i4 = i6 + 4 | 0;
       HEAP32[i32 >> 2] = i4;
       HEAP32[i6 >> 2] = i27;
       i5 = i5 + 1 | 0;
       if (i5 >>> 0 < i10 >>> 0) {
        i7 = HEAP8[(i9 ? HEAP32[i23 >> 2] | 0 : i23) + i5 >> 0] | 0;
        i7 = i7 << 24 >> 24 == 127 ? -1 : i7 << 24 >> 24;
        i6 = 0;
       } else {
        i7 = i8;
        i6 = 0;
       }
      } else {
       i4 = i6;
       i6 = i8;
      }
      i8 = i2 + -4 | 0;
      i34 = HEAP32[i8 >> 2] | 0;
      HEAP32[i32 >> 2] = i4 + 4;
      HEAP32[i4 >> 2] = i34;
      i2 = i8;
      i8 = i6 + 1 | 0;
     }
     i2 = HEAP32[i32 >> 2] | 0;
    }
    if ((i3 | 0) != (i2 | 0)) while (1) {
     i2 = i2 + -4 | 0;
     if (i3 >>> 0 >= i2 >>> 0) break L4;
     i34 = HEAP32[i3 >> 2] | 0;
     HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
     HEAP32[i2 >> 2] = i34;
     i3 = i3 + 4 | 0;
    }
    break;
   }
  default:
   {}
  } while (0);
  i11 = i11 + 1 | 0;
 }
 i1 = HEAP8[i12 >> 0] | 0;
 i2 = i1 << 24 >> 24 < 0;
 i1 = i2 ? HEAP32[i28 >> 2] | 0 : i1 & 255;
 if (i1 >>> 0 > 1) {
  i2 = i2 ? HEAP32[i29 >> 2] | 0 : i29;
  i5 = i2 + 4 | 0;
  i2 = i2 + (i1 << 2) | 0;
  i3 = HEAP32[i32 >> 2] | 0;
  i4 = i2 - i5 | 0;
  i1 = i3;
  while (1) {
   if ((i5 | 0) == (i2 | 0)) break;
   HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
   i1 = i1 + 4 | 0;
   i5 = i5 + 4 | 0;
  }
  HEAP32[i32 >> 2] = i3 + (i4 >>> 2 << 2);
 }
 switch (i30 & 176 | 0) {
 case 32:
  {
   HEAP32[i33 >> 2] = HEAP32[i32 >> 2];
   break;
  }
 case 16:
  break;
 default:
  HEAP32[i33 >> 2] = i31;
 }
 return;
}

function __ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i(i28, i30, i29, i27, i1, i17, i16, i21, i22, i18, i24, i20, i23, i26, i19) {
 i28 = i28 | 0;
 i30 = i30 | 0;
 i29 = i29 | 0;
 i27 = i27 | 0;
 i1 = i1 | 0;
 i17 = i17 | 0;
 i16 = i16 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i18 = i18 | 0;
 i24 = i24 | 0;
 i20 = i20 | 0;
 i23 = i23 | 0;
 i26 = i26 | 0;
 i19 = i19 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i25 = 0, i31 = 0, i32 = 0, i33 = 0;
 HEAP32[i29 >> 2] = i28;
 i8 = i26 + 11 | 0;
 i25 = i26 + 4 | 0;
 i9 = i23 + 11 | 0;
 i10 = i23 + 4 | 0;
 i11 = (i27 & 512 | 0) == 0;
 i12 = i16 + 8 | 0;
 i13 = (i19 | 0) > 0;
 i14 = i20 + 11 | 0;
 i15 = i20 + 4 | 0;
 i7 = 0;
 while (1) {
  if ((i7 | 0) == 4) break;
  L4 : do switch (HEAP8[i22 + i7 >> 0] | 0) {
  case 0:
   {
    HEAP32[i30 >> 2] = HEAP32[i29 >> 2];
    break;
   }
  case 1:
   {
    HEAP32[i30 >> 2] = HEAP32[i29 >> 2];
    i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i16 >> 2] | 0) + 28 >> 2] & 63](i16, 32) | 0;
    i6 = HEAP32[i29 >> 2] | 0;
    HEAP32[i29 >> 2] = i6 + 1;
    HEAP8[i6 >> 0] = i5;
    break;
   }
  case 3:
   {
    i6 = HEAP8[i8 >> 0] | 0;
    i2 = i6 << 24 >> 24 < 0;
    if ((i2 ? HEAP32[i25 >> 2] | 0 : i6 & 255) | 0) {
     i5 = HEAP8[(i2 ? HEAP32[i26 >> 2] | 0 : i26) >> 0] | 0;
     i6 = HEAP32[i29 >> 2] | 0;
     HEAP32[i29 >> 2] = i6 + 1;
     HEAP8[i6 >> 0] = i5;
    }
    break;
   }
  case 2:
   {
    i3 = HEAP8[i9 >> 0] | 0;
    i2 = i3 << 24 >> 24 < 0;
    i3 = i2 ? HEAP32[i10 >> 2] | 0 : i3 & 255;
    if (!(i11 | (i3 | 0) == 0)) {
     i6 = i2 ? HEAP32[i23 >> 2] | 0 : i23;
     i4 = i6 + i3 | 0;
     i2 = HEAP32[i29 >> 2] | 0;
     i3 = i6;
     while (1) {
      if ((i3 | 0) == (i4 | 0)) break;
      HEAP8[i2 >> 0] = HEAP8[i3 >> 0] | 0;
      i2 = i2 + 1 | 0;
      i3 = i3 + 1 | 0;
     }
     HEAP32[i29 >> 2] = i2;
    }
    break;
   }
  case 4:
   {
    i3 = HEAP32[i29 >> 2] | 0;
    i1 = i21 ? i1 + 1 | 0 : i1;
    i2 = i1;
    while (1) {
     if (i2 >>> 0 >= i17 >>> 0) break;
     i4 = HEAP8[i2 >> 0] | 0;
     if (i4 << 24 >> 24 <= -1) break;
     if (!(HEAP16[(HEAP32[i12 >> 2] | 0) + (i4 << 24 >> 24 << 1) >> 1] & 2048)) break;
     i2 = i2 + 1 | 0;
    }
    if (i13) {
     i5 = i19;
     while (1) {
      i4 = (i5 | 0) > 0;
      if (!(i2 >>> 0 > i1 >>> 0 & i4)) break;
      i6 = i2 + -1 | 0;
      i31 = HEAP8[i6 >> 0] | 0;
      i4 = HEAP32[i29 >> 2] | 0;
      HEAP32[i29 >> 2] = i4 + 1;
      HEAP8[i4 >> 0] = i31;
      i2 = i6;
      i5 = i5 + -1 | 0;
     }
     if (i4) i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i16 >> 2] | 0) + 28 >> 2] & 63](i16, 48) | 0; else i6 = 0;
     while (1) {
      i4 = HEAP32[i29 >> 2] | 0;
      HEAP32[i29 >> 2] = i4 + 1;
      if ((i5 | 0) <= 0) break;
      HEAP8[i4 >> 0] = i6;
      i5 = i5 + -1 | 0;
     }
     HEAP8[i4 >> 0] = i18;
    }
    L35 : do if ((i2 | 0) == (i1 | 0)) {
     i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i16 >> 2] | 0) + 28 >> 2] & 63](i16, 48) | 0;
     i31 = HEAP32[i29 >> 2] | 0;
     HEAP32[i29 >> 2] = i31 + 1;
     HEAP8[i31 >> 0] = i6;
    } else {
     i31 = HEAP8[i14 >> 0] | 0;
     i4 = i31 << 24 >> 24 < 0;
     if (!((i4 ? HEAP32[i15 >> 2] | 0 : i31 & 255) | 0)) {
      i4 = -1;
      i5 = 0;
      i6 = 0;
     } else {
      i4 = HEAP8[(i4 ? HEAP32[i20 >> 2] | 0 : i20) >> 0] | 0;
      i5 = 0;
      i6 = 0;
     }
     while (1) {
      if ((i2 | 0) == (i1 | 0)) break L35;
      if ((i6 | 0) == (i4 | 0)) {
       i31 = HEAP32[i29 >> 2] | 0;
       HEAP32[i29 >> 2] = i31 + 1;
       HEAP8[i31 >> 0] = i24;
       i5 = i5 + 1 | 0;
       i31 = HEAP8[i14 >> 0] | 0;
       i4 = i31 << 24 >> 24 < 0;
       if (i5 >>> 0 < (i4 ? HEAP32[i15 >> 2] | 0 : i31 & 255) >>> 0) {
        i4 = HEAP8[(i4 ? HEAP32[i20 >> 2] | 0 : i20) + i5 >> 0] | 0;
        i4 = i4 << 24 >> 24 == 127 ? -1 : i4 << 24 >> 24;
        i6 = 0;
       } else {
        i4 = i6;
        i6 = 0;
       }
      }
      i31 = i2 + -1 | 0;
      i33 = HEAP8[i31 >> 0] | 0;
      i32 = HEAP32[i29 >> 2] | 0;
      HEAP32[i29 >> 2] = i32 + 1;
      HEAP8[i32 >> 0] = i33;
      i2 = i31;
      i6 = i6 + 1 | 0;
     }
    } while (0);
    i2 = HEAP32[i29 >> 2] | 0;
    if ((i3 | 0) != (i2 | 0)) while (1) {
     i2 = i2 + -1 | 0;
     if (i3 >>> 0 >= i2 >>> 0) break L4;
     i33 = HEAP8[i3 >> 0] | 0;
     HEAP8[i3 >> 0] = HEAP8[i2 >> 0] | 0;
     HEAP8[i2 >> 0] = i33;
     i3 = i3 + 1 | 0;
    }
    break;
   }
  default:
   {}
  } while (0);
  i7 = i7 + 1 | 0;
 }
 i1 = HEAP8[i8 >> 0] | 0;
 i2 = i1 << 24 >> 24 < 0;
 i1 = i2 ? HEAP32[i25 >> 2] | 0 : i1 & 255;
 if (i1 >>> 0 > 1) {
  i2 = i2 ? HEAP32[i26 >> 2] | 0 : i26;
  i3 = i2 + i1 | 0;
  i1 = HEAP32[i29 >> 2] | 0;
  while (1) {
   i2 = i2 + 1 | 0;
   if ((i2 | 0) == (i3 | 0)) break;
   HEAP8[i1 >> 0] = HEAP8[i2 >> 0] | 0;
   i1 = i1 + 1 | 0;
  }
  HEAP32[i29 >> 2] = i1;
 }
 switch (i27 & 176 | 0) {
 case 32:
  {
   HEAP32[i30 >> 2] = HEAP32[i29 >> 2];
   break;
  }
 case 16:
  break;
 default:
  HEAP32[i30 >> 2] = i28;
 }
 return;
}

function __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_(i1, i11) {
 i1 = i1 | 0;
 i11 = i11 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0;
 i2 = HEAP32[i11 >> 2] | 0;
 do if (i2) if (HEAP32[i11 + 4 >> 2] | 0) {
  i3 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i11) | 0;
  i2 = HEAP32[i3 >> 2] | 0;
  if (!i2) {
   i4 = i3;
   i6 = 6;
   break;
  } else {
   i5 = i3;
   i4 = i3;
   i6 = 8;
   break;
  }
 } else {
  i5 = i11;
  i4 = i11;
  i6 = 8;
  break;
 } else {
  i4 = i11;
  i3 = i11;
  i6 = 6;
 } while (0);
 if ((i6 | 0) == 6) {
  i2 = HEAP32[i3 + 4 >> 2] | 0;
  if (!i2) {
   i9 = i3 + 8 | 0;
   i10 = 0;
   i2 = 0;
   i8 = i4;
  } else {
   i5 = i3;
   i6 = 8;
  }
 }
 if ((i6 | 0) == 8) {
  i9 = i5 + 8 | 0;
  HEAP32[i2 + 8 >> 2] = HEAP32[i9 >> 2];
  i10 = 1;
  i3 = i5;
  i8 = i4;
 }
 i4 = HEAP32[i9 >> 2] | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 if ((i5 | 0) == (i3 | 0)) {
  HEAP32[i4 >> 2] = i2;
  if ((i3 | 0) == (i1 | 0)) {
   i1 = i2;
   i5 = 0;
  } else i5 = HEAP32[i4 + 4 >> 2] | 0;
 } else HEAP32[i4 + 4 >> 2] = i2;
 i6 = i3 + 12 | 0;
 i7 = (HEAP8[i6 >> 0] | 0) != 0;
 if ((i3 | 0) != (i11 | 0)) {
  i12 = i11 + 8 | 0;
  i4 = HEAP32[i12 >> 2] | 0;
  HEAP32[i9 >> 2] = i4;
  if ((HEAP32[HEAP32[i12 >> 2] >> 2] | 0) == (i11 | 0)) HEAP32[i4 >> 2] = i3; else HEAP32[i4 + 4 >> 2] = i3;
  i4 = HEAP32[i11 >> 2] | 0;
  HEAP32[i8 >> 2] = i4;
  HEAP32[i4 + 8 >> 2] = i3;
  i4 = HEAP32[i11 + 4 >> 2] | 0;
  HEAP32[i3 + 4 >> 2] = i4;
  if (i4 | 0) HEAP32[i4 + 8 >> 2] = i3;
  HEAP8[i6 >> 0] = HEAP8[i11 + 12 >> 0] | 0;
  i1 = (i1 | 0) == (i11 | 0) ? i3 : i1;
 }
 do if (i7 & (i1 | 0) != 0) {
  if (i10) {
   HEAP8[i2 + 12 >> 0] = 1;
   break;
  }
  while (1) {
   i2 = HEAP32[i5 + 8 >> 2] | 0;
   i3 = i5 + 12 | 0;
   i4 = (HEAP8[i3 >> 0] | 0) != 0;
   if ((HEAP32[i2 >> 2] | 0) == (i5 | 0)) {
    if (i4) {
     i4 = i1;
     i1 = i5;
    } else {
     HEAP8[i3 >> 0] = 1;
     HEAP8[i2 + 12 >> 0] = 0;
     __ZNSt3__219__tree_right_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i2);
     i12 = HEAP32[i5 + 4 >> 2] | 0;
     i4 = (i1 | 0) == (i12 | 0) ? i5 : i1;
     i1 = HEAP32[i12 >> 2] | 0;
    }
    i2 = HEAP32[i1 >> 2] | 0;
    i3 = (i2 | 0) == 0;
    if (!i3 ? (HEAP8[i2 + 12 >> 0] | 0) == 0 : 0) {
     i6 = 49;
     break;
    }
    i12 = HEAP32[i1 + 4 >> 2] | 0;
    if (i12 | 0 ? (HEAP8[i12 + 12 >> 0] | 0) == 0 : 0) {
     i6 = 48;
     break;
    }
    HEAP8[i1 + 12 >> 0] = 0;
    i2 = HEAP32[i1 + 8 >> 2] | 0;
    i1 = i2 + 12 | 0;
    if ((i2 | 0) == (i4 | 0) | (HEAP8[i1 >> 0] | 0) == 0) {
     i6 = 45;
     break;
    }
    i12 = HEAP32[i2 + 8 >> 2] | 0;
    i1 = i4;
    i2 = (HEAP32[i12 >> 2] | 0) == (i2 | 0) ? i12 + 4 | 0 : i12;
   } else {
    if (!i4) {
     HEAP8[i3 >> 0] = 1;
     HEAP8[i2 + 12 >> 0] = 0;
     __ZNSt3__218__tree_left_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i2);
     i12 = HEAP32[i5 >> 2] | 0;
     i1 = (i1 | 0) == (i12 | 0) ? i5 : i1;
     i5 = HEAP32[i12 + 4 >> 2] | 0;
    }
    i3 = HEAP32[i5 >> 2] | 0;
    if (i3 | 0 ? (HEAP8[i3 + 12 >> 0] | 0) == 0 : 0) {
     i1 = i5;
     i6 = 34;
     break;
    }
    i2 = HEAP32[i5 + 4 >> 2] | 0;
    if (i2 | 0 ? (HEAP8[i2 + 12 >> 0] | 0) == 0 : 0) {
     i1 = i5;
     i6 = 35;
     break;
    }
    HEAP8[i5 + 12 >> 0] = 0;
    i2 = HEAP32[i5 + 8 >> 2] | 0;
    if ((i2 | 0) == (i1 | 0)) {
     i6 = 32;
     break;
    }
    if (!(HEAP8[i2 + 12 >> 0] | 0)) {
     i1 = i2;
     i6 = 32;
     break;
    }
    i12 = HEAP32[i2 + 8 >> 2] | 0;
    i2 = (HEAP32[i12 >> 2] | 0) == (i2 | 0) ? i12 + 4 | 0 : i12;
   }
   i5 = HEAP32[i2 >> 2] | 0;
  }
  if ((i6 | 0) == 32) {
   HEAP8[i1 + 12 >> 0] = 1;
   break;
  } else if ((i6 | 0) == 34) {
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   if (!i2) i6 = 36; else i6 = 35;
  } else if ((i6 | 0) == 45) {
   HEAP8[i1 >> 0] = 1;
   break;
  } else if ((i6 | 0) == 48) if (i3) i6 = 50; else i6 = 49;
  if ((i6 | 0) == 35) if (!(HEAP8[i2 + 12 >> 0] | 0)) i6 = 37; else i6 = 36; else if ((i6 | 0) == 49) if (!(HEAP8[i2 + 12 >> 0] | 0)) i6 = 51; else i6 = 50;
  if ((i6 | 0) == 36) {
   HEAP8[i3 + 12 >> 0] = 1;
   HEAP8[i1 + 12 >> 0] = 0;
   __ZNSt3__219__tree_right_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i1);
   i1 = HEAP32[i1 + 8 >> 2] | 0;
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   i6 = 37;
  } else if ((i6 | 0) == 50) {
   HEAP8[(HEAP32[i1 + 4 >> 2] | 0) + 12 >> 0] = 1;
   HEAP8[i1 + 12 >> 0] = 0;
   __ZNSt3__218__tree_left_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i1);
   i1 = HEAP32[i1 + 8 >> 2] | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   i6 = 51;
  }
  if ((i6 | 0) == 37) {
   i12 = HEAP32[i1 + 8 >> 2] | 0;
   i11 = i12 + 12 | 0;
   HEAP8[i1 + 12 >> 0] = HEAP8[i11 >> 0] | 0;
   HEAP8[i11 >> 0] = 1;
   HEAP8[i2 + 12 >> 0] = 1;
   __ZNSt3__218__tree_left_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i12);
   break;
  } else if ((i6 | 0) == 51) {
   i12 = HEAP32[i1 + 8 >> 2] | 0;
   i11 = i12 + 12 | 0;
   HEAP8[i1 + 12 >> 0] = HEAP8[i11 >> 0] | 0;
   HEAP8[i11 >> 0] = 1;
   HEAP8[i2 + 12 >> 0] = 1;
   __ZNSt3__219__tree_right_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i12);
   break;
  }
 } while (0);
 return;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 304 | 0;
 i11 = i20 + 200 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i2;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP32[i3 >> 2] | 0;
 i3 = HEAP32[i21 >> 2] | 0;
 L13 : while (1) {
  if (i3) {
   i1 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i21 >> 2] = 0;
    i3 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i3 = 0;
   i5 = 1;
  }
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   i1 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i5) {
    i6 = i4;
    break;
   } else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 23;
    break;
   }
  } else i24 = 23; while (0);
  if ((i24 | 0) == 23) {
   i24 = 0;
   if (i5) {
    i4 = 0;
    break;
   } else i6 = 0;
  }
  i4 = HEAP8[i9 >> 0] | 0;
  i4 = i4 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i4 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i2 + i4 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i4 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
   i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i2 + i4;
  }
  i4 = i3 + 12 | 0;
  i1 = HEAP32[i4 >> 2] | 0;
  i5 = i3 + 16 | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw(i1, i14, i2, i15, i12, i7, i19, i16, i13, i11) | 0) {
   i4 = i6;
   break;
  }
  i1 = HEAP32[i4 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   continue;
  } else {
   HEAP32[i4 >> 2] = i1 + 4;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i1 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i1 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i1 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i1 >> 2] = i11;
  i1 = i12;
 }
 i15 = __ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji(i2, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 HEAP32[i17 + 4 >> 2] = tempRet0;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i1, i23);
 if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i21 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i4) {
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i24 = 53;
   break;
  } else {
   HEAP32[i22 >> 2] = 0;
   i24 = 51;
   break;
  }
 } else i24 = 51; while (0);
 if ((i24 | 0) == 51 ? i2 : 0) i24 = 53;
 if ((i24 | 0) == 53) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 304 | 0;
 i11 = i20 + 200 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i2;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP32[i3 >> 2] | 0;
 i3 = HEAP32[i21 >> 2] | 0;
 L13 : while (1) {
  if (i3) {
   i1 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i21 >> 2] = 0;
    i3 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i3 = 0;
   i5 = 1;
  }
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   i1 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i5) {
    i6 = i4;
    break;
   } else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 23;
    break;
   }
  } else i24 = 23; while (0);
  if ((i24 | 0) == 23) {
   i24 = 0;
   if (i5) {
    i4 = 0;
    break;
   } else i6 = 0;
  }
  i4 = HEAP8[i9 >> 0] | 0;
  i4 = i4 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i4 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i2 + i4 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i4 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
   i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i2 + i4;
  }
  i4 = i3 + 12 | 0;
  i1 = HEAP32[i4 >> 2] | 0;
  i5 = i3 + 16 | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw(i1, i14, i2, i15, i12, i7, i19, i16, i13, i11) | 0) {
   i4 = i6;
   break;
  }
  i1 = HEAP32[i4 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   continue;
  } else {
   HEAP32[i4 >> 2] = i1 + 4;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i1 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i1 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i1 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i1 >> 2] = i11;
  i1 = i12;
 }
 i15 = __ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji(i2, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 HEAP32[i17 + 4 >> 2] = tempRet0;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i1, i23);
 if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i21 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i4) {
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i24 = 53;
   break;
  } else {
   HEAP32[i22 >> 2] = 0;
   i24 = 51;
   break;
  }
 } else i24 = 51; while (0);
 if ((i24 | 0) == 51 ? i2 : 0) i24 = 53;
 if ((i24 | 0) == 53) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb(i16, i17, i1, i19, i15, i18, i14) {
 i16 = i16 | 0;
 i17 = i17 | 0;
 i1 = i1 | 0;
 i19 = i19 | 0;
 i15 = i15 | 0;
 i18 = i18 | 0;
 i14 = i14 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i20 = 0, i21 = 0, i22 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i2 = i22;
 i4 = (i19 - i1 | 0) / 12 | 0;
 if (i4 >>> 0 > 100) {
  i2 = _malloc(i4) | 0;
  if (!i2) {
   i20 = 0;
   i2 = 0;
  } else i20 = i2;
 } else i20 = 0;
 i7 = i1;
 i3 = 0;
 i6 = i2;
 while (1) {
  if ((i7 | 0) == (i19 | 0)) break;
  i5 = HEAP8[i7 + 8 + 3 >> 0] | 0;
  if (i5 << 24 >> 24 < 0) i5 = HEAP32[i7 + 4 >> 2] | 0; else i5 = i5 & 255;
  if (!i5) {
   HEAP8[i6 >> 0] = 2;
   i3 = i3 + 1 | 0;
   i4 = i4 + -1 | 0;
  } else HEAP8[i6 >> 0] = 1;
  i7 = i7 + 12 | 0;
  i6 = i6 + 1 | 0;
 }
 i13 = 0;
 i10 = i3;
 i8 = i4;
 L17 : while (1) {
  i3 = HEAP32[i16 >> 2] | 0;
  do if (i3) {
   i4 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i4 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i3 = HEAP32[i4 >> 2] | 0;
   if ((i3 | 0) == -1) {
    HEAP32[i16 >> 2] = 0;
    i6 = 1;
    break;
   } else {
    i6 = (HEAP32[i16 >> 2] | 0) == 0;
    break;
   }
  } else i6 = 1; while (0);
  i5 = HEAP32[i17 >> 2] | 0;
  if (i5) {
   i3 = HEAP32[i5 + 12 >> 2] | 0;
   if ((i3 | 0) == (HEAP32[i5 + 16 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0; else i3 = HEAP32[i3 >> 2] | 0;
   if ((i3 | 0) == -1) {
    HEAP32[i17 >> 2] = 0;
    i5 = 0;
    i3 = 1;
   } else i3 = 0;
  } else {
   i5 = 0;
   i3 = 1;
  }
  i4 = HEAP32[i16 >> 2] | 0;
  if (!((i8 | 0) != 0 & (i6 ^ i3))) break;
  i3 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i3 = HEAP32[i3 >> 2] | 0;
  if (!i14) i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i15 >> 2] | 0) + 28 >> 2] & 63](i15, i3) | 0;
  i12 = i13 + 1 | 0;
  i7 = 0;
  i9 = i1;
  i11 = i8;
  i8 = i2;
  while (1) {
   if ((i9 | 0) == (i19 | 0)) break;
   do if ((HEAP8[i8 >> 0] | 0) == 1) {
    i5 = i9 + 8 + 3 | 0;
    if ((HEAP8[i5 >> 0] | 0) < 0) i4 = HEAP32[i9 >> 2] | 0; else i4 = i9;
    i4 = HEAP32[i4 + (i13 << 2) >> 2] | 0;
    if (!i14) i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i15 >> 2] | 0) + 28 >> 2] & 63](i15, i4) | 0;
    if ((i3 | 0) != (i4 | 0)) {
     HEAP8[i8 >> 0] = 0;
     i4 = i7;
     i5 = i10;
     i6 = i11 + -1 | 0;
     break;
    }
    i4 = HEAP8[i5 >> 0] | 0;
    if (i4 << 24 >> 24 < 0) i4 = HEAP32[i9 + 4 >> 2] | 0; else i4 = i4 & 255;
    if ((i4 | 0) == (i12 | 0)) {
     HEAP8[i8 >> 0] = 2;
     i4 = 1;
     i5 = i10 + 1 | 0;
     i6 = i11 + -1 | 0;
    } else {
     i4 = 1;
     i5 = i10;
     i6 = i11;
    }
   } else {
    i4 = i7;
    i5 = i10;
    i6 = i11;
   } while (0);
   i7 = i4;
   i9 = i9 + 12 | 0;
   i10 = i5;
   i11 = i6;
   i8 = i8 + 1 | 0;
  }
  if (!i7) {
   i13 = i12;
   i8 = i11;
   continue;
  }
  i3 = HEAP32[i16 >> 2] | 0;
  i4 = i3 + 12 | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  if ((i5 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0; else HEAP32[i4 >> 2] = i5 + 4;
  if ((i10 + i11 | 0) >>> 0 > 1) {
   i6 = i1;
   i3 = i10;
   i5 = i2;
  } else {
   i13 = i12;
   i8 = i11;
   continue;
  }
  while (1) {
   if ((i6 | 0) == (i19 | 0)) {
    i13 = i12;
    i10 = i3;
    i8 = i11;
    continue L17;
   }
   if ((HEAP8[i5 >> 0] | 0) == 2) {
    i4 = HEAP8[i6 + 8 + 3 >> 0] | 0;
    if (i4 << 24 >> 24 < 0) i4 = HEAP32[i6 + 4 >> 2] | 0; else i4 = i4 & 255;
    if ((i4 | 0) != (i12 | 0)) {
     HEAP8[i5 >> 0] = 0;
     i3 = i3 + -1 | 0;
    }
   }
   i6 = i6 + 12 | 0;
   i5 = i5 + 1 | 0;
  }
 }
 do if (i4) {
  i3 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i3 = HEAP32[i3 >> 2] | 0;
  if ((i3 | 0) == -1) {
   HEAP32[i16 >> 2] = 0;
   i4 = 1;
   break;
  } else {
   i4 = (HEAP32[i16 >> 2] | 0) == 0;
   break;
  }
 } else i4 = 1; while (0);
 do if (i5) {
  i3 = HEAP32[i5 + 12 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i5 + 16 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0; else i3 = HEAP32[i3 >> 2] | 0;
  if ((i3 | 0) != -1) if (i4) break; else {
   i21 = 77;
   break;
  } else {
   HEAP32[i17 >> 2] = 0;
   i21 = 41;
   break;
  }
 } else i21 = 41; while (0);
 if ((i21 | 0) == 41) if (i4) i21 = 77;
 if ((i21 | 0) == 77) HEAP32[i18 >> 2] = HEAP32[i18 >> 2] | 2;
 while (1) {
  if ((i1 | 0) == (i19 | 0)) {
   i21 = 81;
   break;
  }
  if ((HEAP8[i2 >> 0] | 0) == 2) break;
  i1 = i1 + 12 | 0;
  i2 = i2 + 1 | 0;
 }
 if ((i21 | 0) == 81) {
  HEAP32[i18 >> 2] = HEAP32[i18 >> 2] | 4;
  i1 = i19;
 }
 _free(i20);
 STACKTOP = i22;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_18demangleINS0_2DbEEEvPKcS4_RT_Ri(i1, i10, i9, i11) {
 i1 = i1 | 0;
 i10 = i10 | 0;
 i9 = i9 | 0;
 i11 = i11 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i6 = i12 + 24 | 0;
 i7 = i12 + 12 | 0;
 i8 = i12;
 L1 : do if (i1 >>> 0 < i10 >>> 0) {
  L3 : do if ((HEAP8[i1 >> 0] | 0) != 95) {
   if ((__ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i1, i10, i9) | 0) != (i10 | 0)) {
    HEAP32[i11 >> 2] = -2;
    break L1;
   }
  } else {
   i3 = i10;
   if ((i3 - i1 | 0) <= 3) {
    HEAP32[i11 >> 2] = -2;
    break L1;
   }
   switch (HEAP8[i1 + 1 >> 0] | 0) {
   case 90:
    {
     i5 = i1 + 2 | 0;
     i1 = __ZN10__cxxabiv112_GLOBAL__N_114parse_encodingINS0_2DbEEEPKcS4_S4_RT_(i5, i10, i9) | 0;
     if (!((i1 | 0) == (i5 | 0) | (i1 | 0) == (i10 | 0)) ? (HEAP8[i1 >> 0] | 0) == 46 : 0) {
      i2 = HEAP32[i9 + 4 >> 2] | 0;
      if ((HEAP32[i9 >> 2] | 0) != (i2 | 0)) {
       i5 = i2 + -24 | 0;
       HEAP32[i8 >> 2] = 0;
       HEAP32[i8 + 4 >> 2] = 0;
       HEAP32[i8 + 8 >> 2] = 0;
       i3 = i3 - i1 | 0;
       if (i3 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i8);
       if (i3 >>> 0 < 11) {
        HEAP8[i8 + 11 >> 0] = i3;
        i4 = i8;
       } else {
        i2 = i3 + 16 & -16;
        i4 = _malloc(i2) | 0;
        HEAP32[i8 >> 2] = i4;
        HEAP32[i8 + 8 >> 2] = i2 | -2147483648;
        HEAP32[i8 + 4 >> 2] = i3;
       }
       i2 = i4;
       while (1) {
        if ((i1 | 0) == (i10 | 0)) break;
        HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
        i1 = i1 + 1 | 0;
        i2 = i2 + 1 | 0;
       }
       HEAP8[i4 + i3 >> 0] = 0;
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i8, 0, 57016) | 0;
       HEAP32[i7 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i7 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i7 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i7, 56966) | 0;
       HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i6 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
       HEAP32[i6 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
       i2 = 0;
       while (1) {
        if ((i2 | 0) == 3) break;
        HEAP32[i1 + (i2 << 2) >> 2] = 0;
        i2 = i2 + 1 | 0;
       }
       i1 = HEAP8[i6 + 11 >> 0] | 0;
       i4 = i1 << 24 >> 24 < 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i5, i4 ? HEAP32[i6 >> 2] | 0 : i6, i4 ? HEAP32[i6 + 4 >> 2] | 0 : i1 & 255) | 0;
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i6);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i7);
       __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
       i1 = i10;
      }
     }
     if ((i1 | 0) == (i10 | 0)) break L3;
     HEAP32[i11 >> 2] = -2;
     break L1;
    }
   case 95:
    {
     if ((HEAP8[i1 + 2 >> 0] | 0) == 95 ? (HEAP8[i1 + 3 >> 0] | 0) == 90 : 0) {
      i8 = i1 + 4 | 0;
      i1 = __ZN10__cxxabiv112_GLOBAL__N_114parse_encodingINS0_2DbEEEPKcS4_S4_RT_(i8, i10, i9) | 0;
      if ((i1 | 0) == (i8 | 0) | (i1 | 0) == (i10 | 0)) {
       HEAP32[i11 >> 2] = -2;
       break L1;
      }
      L43 : do if ((i3 - i1 | 0) > 12) {
       i3 = 0;
       i2 = i1;
       while (1) {
        if ((i3 | 0) >= 13) break;
        if ((HEAP8[i2 >> 0] | 0) != (HEAP8[58493 + i3 >> 0] | 0)) break L43;
        i3 = i3 + 1 | 0;
        i2 = i2 + 1 | 0;
       }
       L49 : do if ((i2 | 0) == (i10 | 0)) i2 = i10; else {
        if ((HEAP8[i2 >> 0] | 0) == 95) {
         i3 = i2 + 1 | 0;
         if ((i3 | 0) == (i10 | 0)) break L43;
         if (((HEAP8[i3 >> 0] | 0) + -48 | 0) >>> 0 >= 10) break L43;
         i2 = i2 + 2 | 0;
        }
        while (1) {
         if ((i2 | 0) == (i10 | 0)) {
          i2 = i10;
          break L49;
         }
         if (((HEAP8[i2 >> 0] | 0) + -48 | 0) >>> 0 >= 10) break L49;
         i2 = i2 + 1 | 0;
        }
       } while (0);
       i3 = HEAP32[i9 + 4 >> 2] | 0;
       if ((HEAP32[i9 >> 2] | 0) != (i3 | 0)) {
        __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i3 + -24 | 0, 0, 58507) | 0;
        i1 = i2;
       }
      } while (0);
      if ((i1 | 0) == (i10 | 0)) break L3;
      HEAP32[i11 >> 2] = -2;
      break L1;
     }
     break;
    }
   default:
    {}
   }
   HEAP32[i11 >> 2] = -2;
   break L1;
  } while (0);
  if ((HEAP32[i11 >> 2] | 0) == 0 ? (HEAP32[i9 >> 2] | 0) == (HEAP32[i9 + 4 >> 2] | 0) : 0) HEAP32[i11 >> 2] = -2;
 } else HEAP32[i11 >> 2] = -2; while (0);
 STACKTOP = i12;
 return;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 304 | 0;
 i11 = i20 + 200 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i2;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP32[i3 >> 2] | 0;
 i3 = HEAP32[i21 >> 2] | 0;
 L13 : while (1) {
  if (i3) {
   i1 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i21 >> 2] = 0;
    i3 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i3 = 0;
   i5 = 1;
  }
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   i1 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i5) {
    i6 = i4;
    break;
   } else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 23;
    break;
   }
  } else i24 = 23; while (0);
  if ((i24 | 0) == 23) {
   i24 = 0;
   if (i5) {
    i4 = 0;
    break;
   } else i6 = 0;
  }
  i4 = HEAP8[i9 >> 0] | 0;
  i4 = i4 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i4 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i2 + i4 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i4 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
   i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i2 + i4;
  }
  i4 = i3 + 12 | 0;
  i1 = HEAP32[i4 >> 2] | 0;
  i5 = i3 + 16 | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw(i1, i14, i2, i15, i12, i7, i19, i16, i13, i11) | 0) {
   i4 = i6;
   break;
  }
  i1 = HEAP32[i4 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   continue;
  } else {
   HEAP32[i4 >> 2] = i1 + 4;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i1 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i1 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i1 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i1 >> 2] = i11;
  i1 = i12;
 }
 i15 = __ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji(i2, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP16[i17 >> 1] = i15;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i1, i23);
 if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i21 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i4) {
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i24 = 53;
   break;
  } else {
   HEAP32[i22 >> 2] = 0;
   i24 = 51;
   break;
  }
 } else i24 = 51; while (0);
 if ((i24 | 0) == 51 ? i2 : 0) i24 = 53;
 if ((i24 | 0) == 53) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 304 | 0;
 i11 = i20 + 200 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i2;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP32[i3 >> 2] | 0;
 i3 = HEAP32[i21 >> 2] | 0;
 L13 : while (1) {
  if (i3) {
   i1 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i21 >> 2] = 0;
    i3 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i3 = 0;
   i5 = 1;
  }
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   i1 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i5) {
    i6 = i4;
    break;
   } else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 23;
    break;
   }
  } else i24 = 23; while (0);
  if ((i24 | 0) == 23) {
   i24 = 0;
   if (i5) {
    i4 = 0;
    break;
   } else i6 = 0;
  }
  i4 = HEAP8[i9 >> 0] | 0;
  i4 = i4 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i4 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i2 + i4 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i4 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
   i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i2 + i4;
  }
  i4 = i3 + 12 | 0;
  i1 = HEAP32[i4 >> 2] | 0;
  i5 = i3 + 16 | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw(i1, i14, i2, i15, i12, i7, i19, i16, i13, i11) | 0) {
   i4 = i6;
   break;
  }
  i1 = HEAP32[i4 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   continue;
  } else {
   HEAP32[i4 >> 2] = i1 + 4;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i1 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i1 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i1 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i1 >> 2] = i11;
  i1 = i12;
 }
 i15 = __ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji(i2, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i1, i23);
 if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i21 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i4) {
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i24 = 53;
   break;
  } else {
   HEAP32[i22 >> 2] = 0;
   i24 = 51;
   break;
  }
 } else i24 = 51; while (0);
 if ((i24 | 0) == 51 ? i2 : 0) i24 = 53;
 if ((i24 | 0) == 53) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 304 | 0;
 i11 = i20 + 200 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i2;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP32[i3 >> 2] | 0;
 i3 = HEAP32[i21 >> 2] | 0;
 L13 : while (1) {
  if (i3) {
   i1 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i21 >> 2] = 0;
    i3 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i3 = 0;
   i5 = 1;
  }
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   i1 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i5) {
    i6 = i4;
    break;
   } else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 23;
    break;
   }
  } else i24 = 23; while (0);
  if ((i24 | 0) == 23) {
   i24 = 0;
   if (i5) {
    i4 = 0;
    break;
   } else i6 = 0;
  }
  i4 = HEAP8[i9 >> 0] | 0;
  i4 = i4 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i4 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i2 + i4 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i4 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
   i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i2 + i4;
  }
  i4 = i3 + 12 | 0;
  i1 = HEAP32[i4 >> 2] | 0;
  i5 = i3 + 16 | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw(i1, i14, i2, i15, i12, i7, i19, i16, i13, i11) | 0) {
   i4 = i6;
   break;
  }
  i1 = HEAP32[i4 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   continue;
  } else {
   HEAP32[i4 >> 2] = i1 + 4;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i1 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i1 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i1 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i1 >> 2] = i11;
  i1 = i12;
 }
 i15 = __ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji(i2, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i1, i23);
 if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i21 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i4) {
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i24 = 53;
   break;
  } else {
   HEAP32[i22 >> 2] = 0;
   i24 = 51;
   break;
  }
 } else i24 = 51; while (0);
 if ((i24 | 0) == 51 ? i2 : 0) i24 = 53;
 if ((i24 | 0) == 53) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 304 | 0;
 i11 = i20 + 200 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i2;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP32[i3 >> 2] | 0;
 i3 = HEAP32[i21 >> 2] | 0;
 L13 : while (1) {
  if (i3) {
   i1 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i21 >> 2] = 0;
    i3 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i3 = 0;
   i5 = 1;
  }
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   i1 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i5) {
    i6 = i4;
    break;
   } else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 23;
    break;
   }
  } else i24 = 23; while (0);
  if ((i24 | 0) == 23) {
   i24 = 0;
   if (i5) {
    i4 = 0;
    break;
   } else i6 = 0;
  }
  i4 = HEAP8[i9 >> 0] | 0;
  i4 = i4 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i4 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i2 + i4 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i4 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
   i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i2 + i4;
  }
  i4 = i3 + 12 | 0;
  i1 = HEAP32[i4 >> 2] | 0;
  i5 = i3 + 16 | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw(i1, i14, i2, i15, i12, i7, i19, i16, i13, i11) | 0) {
   i4 = i6;
   break;
  }
  i1 = HEAP32[i4 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   continue;
  } else {
   HEAP32[i4 >> 2] = i1 + 4;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i1 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i1 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i1 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i1 >> 2] = i11;
  i1 = i12;
 }
 i15 = __ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji(i2, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i1, i23);
 if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i21 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i4) {
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i24 = 53;
   break;
  } else {
   HEAP32[i22 >> 2] = 0;
   i24 = 51;
   break;
  }
 } else i24 = 51; while (0);
 if ((i24 | 0) == 51 ? i2 : 0) i24 = 53;
 if ((i24 | 0) == 53) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i23, i24, i2, i25, i19) {
 i1 = i1 | 0;
 i23 = i23 | 0;
 i24 = i24 | 0;
 i2 = i2 | 0;
 i25 = i25 | 0;
 i19 = i19 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0, i21 = 0, i22 = 0, i26 = 0, d27 = 0.0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 352 | 0;
 i12 = i22 + 208 | 0;
 i3 = i22 + 200 | 0;
 i4 = i22 + 196 | 0;
 i21 = i22 + 184 | 0;
 i20 = i22 + 172 | 0;
 i17 = i22 + 168 | 0;
 i18 = i22 + 8 | 0;
 i15 = i22 + 4 | 0;
 i14 = i22;
 i16 = i22 + 337 | 0;
 i13 = i22 + 336 | 0;
 __ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_(i21, i2, i12, i3, i4);
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i20 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i10 = i20 + 11 | 0;
 i11 = i20 + 8 | 0;
 if ((HEAP8[i10 >> 0] | 0) < 0) i1 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i1, 0);
 i2 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
 HEAP32[i17 >> 2] = i2;
 HEAP32[i15 >> 2] = i18;
 HEAP32[i14 >> 2] = 0;
 HEAP8[i16 >> 0] = 1;
 HEAP8[i13 >> 0] = 69;
 i9 = i20 + 4 | 0;
 i8 = HEAP32[i3 >> 2] | 0;
 i7 = HEAP32[i4 >> 2] | 0;
 i3 = HEAP32[i23 >> 2] | 0;
 L8 : while (1) {
  if (i3) {
   i1 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i23 >> 2] = 0;
    i3 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i3 = 0;
   i5 = 1;
  }
  i4 = HEAP32[i24 >> 2] | 0;
  do if (i4) {
   i1 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i5) break; else break L8; else {
    HEAP32[i24 >> 2] = 0;
    i26 = 19;
    break;
   }
  } else i26 = 19; while (0);
  if ((i26 | 0) == 19) {
   i26 = 0;
   if (i5) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i10 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i9 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i17 >> 2] | 0) == (i2 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i5 << 1, 0);
   if ((HEAP8[i10 >> 0] | 0) < 0) i1 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i1, 0);
   i2 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
   HEAP32[i17 >> 2] = i2 + i5;
  }
  i5 = i3 + 12 | 0;
  i1 = HEAP32[i5 >> 2] | 0;
  i6 = i3 + 16 | 0;
  if ((i1 | 0) == (HEAP32[i6 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw(i1, i16, i13, i2, i17, i8, i7, i21, i18, i15, i14, i12) | 0) break;
  i1 = HEAP32[i5 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i1 + 4;
   continue;
  }
 }
 i13 = HEAP8[i21 + 11 >> 0] | 0;
 i1 = HEAP32[i15 >> 2] | 0;
 if (!((HEAP8[i16 >> 0] | 0) == 0 ? 1 : ((i13 << 24 >> 24 < 0 ? HEAP32[i21 + 4 >> 2] | 0 : i13 & 255) | 0) == 0) ? (i1 - i18 | 0) < 160 : 0) {
  i14 = HEAP32[i14 >> 2] | 0;
  i16 = i1 + 4 | 0;
  HEAP32[i15 >> 2] = i16;
  HEAP32[i1 >> 2] = i14;
  i1 = i16;
 }
 d27 = +__ZNSt3__215__num_get_floatIfEET_PKcS3_Rj(i2, HEAP32[i17 >> 2] | 0, i25);
 HEAPF32[i19 >> 2] = d27;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i21, i18, i1, i25);
 if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i23 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i4) {
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i26 = 49;
   break;
  } else {
   HEAP32[i24 >> 2] = 0;
   i26 = 47;
   break;
  }
 } else i26 = 47; while (0);
 if ((i26 | 0) == 47 ? i2 : 0) i26 = 49;
 if ((i26 | 0) == 49) HEAP32[i25 >> 2] = HEAP32[i25 >> 2] | 2;
 i26 = HEAP32[i23 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i20);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i21);
 STACKTOP = i22;
 return i26 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i23, i24, i2, i25, i19) {
 i1 = i1 | 0;
 i23 = i23 | 0;
 i24 = i24 | 0;
 i2 = i2 | 0;
 i25 = i25 | 0;
 i19 = i19 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0, i21 = 0, i22 = 0, i26 = 0, d27 = 0.0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 352 | 0;
 i12 = i22 + 208 | 0;
 i3 = i22 + 200 | 0;
 i4 = i22 + 196 | 0;
 i21 = i22 + 184 | 0;
 i20 = i22 + 172 | 0;
 i17 = i22 + 168 | 0;
 i18 = i22 + 8 | 0;
 i15 = i22 + 4 | 0;
 i14 = i22;
 i16 = i22 + 337 | 0;
 i13 = i22 + 336 | 0;
 __ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_(i21, i2, i12, i3, i4);
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i20 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i10 = i20 + 11 | 0;
 i11 = i20 + 8 | 0;
 if ((HEAP8[i10 >> 0] | 0) < 0) i1 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i1, 0);
 i2 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
 HEAP32[i17 >> 2] = i2;
 HEAP32[i15 >> 2] = i18;
 HEAP32[i14 >> 2] = 0;
 HEAP8[i16 >> 0] = 1;
 HEAP8[i13 >> 0] = 69;
 i9 = i20 + 4 | 0;
 i8 = HEAP32[i3 >> 2] | 0;
 i7 = HEAP32[i4 >> 2] | 0;
 i3 = HEAP32[i23 >> 2] | 0;
 L8 : while (1) {
  if (i3) {
   i1 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i23 >> 2] = 0;
    i3 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i3 = 0;
   i5 = 1;
  }
  i4 = HEAP32[i24 >> 2] | 0;
  do if (i4) {
   i1 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i5) break; else break L8; else {
    HEAP32[i24 >> 2] = 0;
    i26 = 19;
    break;
   }
  } else i26 = 19; while (0);
  if ((i26 | 0) == 19) {
   i26 = 0;
   if (i5) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i10 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i9 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i17 >> 2] | 0) == (i2 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i5 << 1, 0);
   if ((HEAP8[i10 >> 0] | 0) < 0) i1 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i1, 0);
   i2 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
   HEAP32[i17 >> 2] = i2 + i5;
  }
  i5 = i3 + 12 | 0;
  i1 = HEAP32[i5 >> 2] | 0;
  i6 = i3 + 16 | 0;
  if ((i1 | 0) == (HEAP32[i6 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw(i1, i16, i13, i2, i17, i8, i7, i21, i18, i15, i14, i12) | 0) break;
  i1 = HEAP32[i5 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i1 + 4;
   continue;
  }
 }
 i13 = HEAP8[i21 + 11 >> 0] | 0;
 i1 = HEAP32[i15 >> 2] | 0;
 if (!((HEAP8[i16 >> 0] | 0) == 0 ? 1 : ((i13 << 24 >> 24 < 0 ? HEAP32[i21 + 4 >> 2] | 0 : i13 & 255) | 0) == 0) ? (i1 - i18 | 0) < 160 : 0) {
  i14 = HEAP32[i14 >> 2] | 0;
  i16 = i1 + 4 | 0;
  HEAP32[i15 >> 2] = i16;
  HEAP32[i1 >> 2] = i14;
  i1 = i16;
 }
 d27 = +__ZNSt3__215__num_get_floatIeEET_PKcS3_Rj(i2, HEAP32[i17 >> 2] | 0, i25);
 HEAPF64[i19 >> 3] = d27;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i21, i18, i1, i25);
 if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i23 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i4) {
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i26 = 49;
   break;
  } else {
   HEAP32[i24 >> 2] = 0;
   i26 = 47;
   break;
  }
 } else i26 = 47; while (0);
 if ((i26 | 0) == 47 ? i2 : 0) i26 = 49;
 if ((i26 | 0) == 49) HEAP32[i25 >> 2] = HEAP32[i25 >> 2] | 2;
 i26 = HEAP32[i23 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i20);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i21);
 STACKTOP = i22;
 return i26 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i23, i24, i2, i25, i19) {
 i1 = i1 | 0;
 i23 = i23 | 0;
 i24 = i24 | 0;
 i2 = i2 | 0;
 i25 = i25 | 0;
 i19 = i19 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0, i21 = 0, i22 = 0, i26 = 0, d27 = 0.0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 352 | 0;
 i12 = i22 + 208 | 0;
 i3 = i22 + 200 | 0;
 i4 = i22 + 196 | 0;
 i21 = i22 + 184 | 0;
 i20 = i22 + 172 | 0;
 i17 = i22 + 168 | 0;
 i18 = i22 + 8 | 0;
 i15 = i22 + 4 | 0;
 i14 = i22;
 i16 = i22 + 337 | 0;
 i13 = i22 + 336 | 0;
 __ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_(i21, i2, i12, i3, i4);
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i20 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i10 = i20 + 11 | 0;
 i11 = i20 + 8 | 0;
 if ((HEAP8[i10 >> 0] | 0) < 0) i1 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i1, 0);
 i2 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
 HEAP32[i17 >> 2] = i2;
 HEAP32[i15 >> 2] = i18;
 HEAP32[i14 >> 2] = 0;
 HEAP8[i16 >> 0] = 1;
 HEAP8[i13 >> 0] = 69;
 i9 = i20 + 4 | 0;
 i8 = HEAP32[i3 >> 2] | 0;
 i7 = HEAP32[i4 >> 2] | 0;
 i3 = HEAP32[i23 >> 2] | 0;
 L8 : while (1) {
  if (i3) {
   i1 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i23 >> 2] = 0;
    i3 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i3 = 0;
   i5 = 1;
  }
  i4 = HEAP32[i24 >> 2] | 0;
  do if (i4) {
   i1 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i5) break; else break L8; else {
    HEAP32[i24 >> 2] = 0;
    i26 = 19;
    break;
   }
  } else i26 = 19; while (0);
  if ((i26 | 0) == 19) {
   i26 = 0;
   if (i5) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i10 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i9 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i17 >> 2] | 0) == (i2 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i5 << 1, 0);
   if ((HEAP8[i10 >> 0] | 0) < 0) i1 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i1, 0);
   i2 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
   HEAP32[i17 >> 2] = i2 + i5;
  }
  i5 = i3 + 12 | 0;
  i1 = HEAP32[i5 >> 2] | 0;
  i6 = i3 + 16 | 0;
  if ((i1 | 0) == (HEAP32[i6 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw(i1, i16, i13, i2, i17, i8, i7, i21, i18, i15, i14, i12) | 0) break;
  i1 = HEAP32[i5 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i1 + 4;
   continue;
  }
 }
 i13 = HEAP8[i21 + 11 >> 0] | 0;
 i1 = HEAP32[i15 >> 2] | 0;
 if (!((HEAP8[i16 >> 0] | 0) == 0 ? 1 : ((i13 << 24 >> 24 < 0 ? HEAP32[i21 + 4 >> 2] | 0 : i13 & 255) | 0) == 0) ? (i1 - i18 | 0) < 160 : 0) {
  i14 = HEAP32[i14 >> 2] | 0;
  i16 = i1 + 4 | 0;
  HEAP32[i15 >> 2] = i16;
  HEAP32[i1 >> 2] = i14;
  i1 = i16;
 }
 d27 = +__ZNSt3__215__num_get_floatIdEET_PKcS3_Rj(i2, HEAP32[i17 >> 2] | 0, i25);
 HEAPF64[i19 >> 3] = d27;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i21, i18, i1, i25);
 if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i23 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i4) {
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i26 = 49;
   break;
  } else {
   HEAP32[i24 >> 2] = 0;
   i26 = 47;
   break;
  }
 } else i26 = 47; while (0);
 if ((i26 | 0) == 47 ? i2 : 0) i26 = 49;
 if ((i26 | 0) == 49) HEAP32[i25 >> 2] = HEAP32[i25 >> 2] | 2;
 i26 = HEAP32[i23 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i20);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i21);
 STACKTOP = i22;
 return i26 | 0;
}

function __ZN4wasm15Asm2WasmBuilder24noteImportedFunctionCallEN6cashew3RefENS_8WasmTypeEP7AsmDataPNS_10CallImportE(i19, i7, i8, i13, i1) {
 i19 = i19 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 i13 = i13 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0, i21 = 0, i22 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i9 = i22 + 48 | 0;
 i21 = i22 + 40 | 0;
 i18 = i22 + 44 | 0;
 i3 = i22 + 32 | 0;
 i5 = i22 + 20 | 0;
 i6 = i22 + 8 | 0;
 i12 = i22 + 36 | 0;
 i10 = i22 + 4 | 0;
 i11 = i22;
 HEAP32[i21 >> 2] = i1;
 i20 = i1;
 if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 0) | 0, 59936) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i7, 1) | 0, 0) | 0, 59292) | 0 : 0) {
  i1 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i7, 1) | 0, 1) | 0;
  i1 = __ZN6cashew5Value10getIStringEv(HEAP32[i1 >> 2] | 0) | 0;
  i1 = HEAP32[i1 >> 2] | 0;
  HEAP32[i18 >> 2] = i1;
  i14 = __ZN4wasm11make_uniqueINS_12FunctionTypeEJEEENSt3__210unique_ptrIT_NS2_14default_deleteIS4_EEEEDpOT0_() | 0;
  i4 = i14;
  HEAP32[i6 >> 2] = 0;
  HEAP32[i6 + 4 >> 2] = 0;
  HEAP32[i6 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i6, 30505, 5);
  i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i6, i1) | 0;
  HEAP32[i5 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i5 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i5 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i5 + 11 >> 0] | 0) < 0 ? HEAP32[i5 >> 2] | 0 : i5, 0);
  HEAP32[i14 >> 2] = HEAP32[i3 >> 2];
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i6);
  i17 = i14 + 4 | 0;
  HEAP32[i17 >> 2] = i8;
  i1 = __ZN6cashew3RefixEj(i7, 2) | 0;
  i1 = HEAP32[i1 >> 2] | 0;
  HEAP32[i12 >> 2] = i1;
  i15 = i14 + 8 | 0;
  i16 = i14 + 12 | 0;
  i3 = i14 + 16 | 0;
  i5 = 0;
  while (1) {
   if (i5 >>> 0 >= (__ZN6cashew5Value4sizeEv(i1) | 0) >>> 0) break;
   i1 = __ZN6cashew3RefixEj(i12, i5) | 0;
   HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
   i1 = __ZN4wasm15Asm2WasmBuilder14detectWasmTypeEN6cashew3RefEP7AsmData(i19, i9, i13) | 0;
   HEAP32[i10 >> 2] = i1;
   i2 = HEAP32[i16 >> 2] | 0;
   if (i2 >>> 0 < (HEAP32[i3 >> 2] | 0) >>> 0) {
    HEAP32[i2 >> 2] = i1;
    HEAP32[i16 >> 2] = i2 + 4;
   } else __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i15, i10);
   i1 = HEAP32[i12 >> 2] | 0;
   i5 = i5 + 1 | 0;
  }
  i1 = i19 + 116 | 0;
  i13 = (__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE4findIS3_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_(i1, i18) | 0) == (i19 + 120 | 0);
  i1 = __ZNSt3__23mapIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS5_EEEENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S8_EEEEEixERSD_(i1, i18) | 0;
  if (!i13) {
   i9 = HEAP32[i1 >> 2] | 0;
   if (!(__ZN4wasm12FunctionTypeeqERS0_(i14, i9) | 0)) {
    i5 = i9 + 8 | 0;
    i6 = i9 + 12 | 0;
    i7 = i9 + 16 | 0;
    i8 = 0;
    while (1) {
     i14 = HEAP32[i15 >> 2] | 0;
     i2 = i14;
     if (i8 >>> 0 >= (HEAP32[i16 >> 2] | 0) - i14 >> 2 >>> 0) break;
     i14 = HEAP32[i6 >> 2] | 0;
     i1 = HEAP32[i5 >> 2] | 0;
     i3 = i14;
     do if (i14 - i1 >> 2 >>> 0 > i8 >>> 0) {
      i1 = i1 + (i8 << 2) | 0;
      if (!(HEAP32[i1 >> 2] | 0)) HEAP32[i1 >> 2] = HEAP32[i2 + (i8 << 2) >> 2];
     } else {
      i1 = i2 + (i8 << 2) | 0;
      if ((i3 | 0) == (HEAP32[i7 >> 2] | 0)) {
       __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i5, i1);
       break;
      } else {
       HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
       HEAP32[i6 >> 2] = i3 + 4;
       break;
      }
     } while (0);
     i8 = i8 + 1 | 0;
    }
    i1 = i9 + 4 | 0;
    if (!(HEAP32[i1 >> 2] | 0)) HEAP32[i1 >> 2] = HEAP32[i17 >> 2];
   }
  } else {
   i17 = HEAP32[i1 >> 2] | 0;
   HEAP32[i1 >> 2] = i4;
   i4 = i17;
  }
  i1 = __ZNSt3__23mapIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS6_EEEENS_4lessIS2_EENS7_INS_4pairIKS2_S9_EEEEEixERSD_(i19 + 128 | 0, i18) | 0;
  i2 = i1 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i1 + 8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10CallImportENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i1, i21); else {
   HEAP32[i3 >> 2] = i20;
   HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
  }
  if (i4 | 0) {
   __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i4 + 8 | 0);
   __ZdlPv(i4);
  }
  STACKTOP = i22;
  return;
 }
 ___assert_fail(30444, 16311, 224, 30480);
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv(i1, i20, i21, i3, i22, i16) {
 i1 = i1 | 0;
 i20 = i20 | 0;
 i21 = i21 | 0;
 i3 = i3 | 0;
 i22 = i22 | 0;
 i16 = i16 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i17 = 0, i18 = 0, i19 = 0, i23 = 0;
 i19 = STACKTOP;
 STACKTOP = STACKTOP + 320 | 0;
 i15 = i19;
 i10 = i19 + 208 | 0;
 i18 = i19 + 196 | 0;
 i1 = i19 + 180 | 0;
 i17 = i19 + 184 | 0;
 i14 = i19 + 176 | 0;
 i12 = i19 + 16 | 0;
 i13 = i19 + 8 | 0;
 i11 = i19 + 4 | 0;
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i18 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 i9 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
 HEAP32[i1 >> 2] = i9;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61712) | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 48 >> 2] & 7](i1, 53246, 53272, i10) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i9) | 0;
 HEAP32[i17 >> 2] = 0;
 HEAP32[i17 + 4 >> 2] = 0;
 HEAP32[i17 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i17 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i17 + 11 | 0;
 i8 = i17 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i8 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i17, i1, 0);
 i1 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i17 >> 2] | 0 : i17;
 HEAP32[i14 >> 2] = i1;
 HEAP32[i13 >> 2] = i12;
 HEAP32[i11 >> 2] = 0;
 i7 = i17 + 4 | 0;
 i2 = HEAP32[i20 >> 2] | 0;
 L12 : while (1) {
  if (i2) {
   i3 = HEAP32[i2 + 12 >> 2] | 0;
   if ((i3 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i3 = HEAP32[i3 >> 2] | 0;
   if ((i3 | 0) == -1) {
    HEAP32[i20 >> 2] = 0;
    i2 = 0;
    i5 = 1;
   } else i5 = 0;
  } else {
   i2 = 0;
   i5 = 1;
  }
  i3 = HEAP32[i21 >> 2] | 0;
  do if (i3) {
   i4 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i4 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i4 = HEAP32[i4 >> 2] | 0;
   if ((i4 | 0) != -1) if (i5) break; else break L12; else {
    HEAP32[i21 >> 2] = 0;
    i23 = 22;
    break;
   }
  } else i23 = 22; while (0);
  if ((i23 | 0) == 22) {
   i23 = 0;
   if (i5) {
    i3 = 0;
    break;
   } else i3 = 0;
  }
  i4 = HEAP8[i9 >> 0] | 0;
  i4 = i4 << 24 >> 24 < 0 ? HEAP32[i7 >> 2] | 0 : i4 & 255;
  if ((HEAP32[i14 >> 2] | 0) == (i1 + i4 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i17, i4 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i8 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i17, i1, 0);
   i1 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i17 >> 2] | 0 : i17;
   HEAP32[i14 >> 2] = i1 + i4;
  }
  i5 = i2 + 12 | 0;
  i4 = HEAP32[i5 >> 2] | 0;
  i6 = i2 + 16 | 0;
  if ((i4 | 0) == (HEAP32[i6 >> 2] | 0)) i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i4 = HEAP32[i4 >> 2] | 0;
  if (__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw(i4, 16, i1, i14, i11, 0, i18, i12, i13, i10) | 0) break;
  i3 = HEAP32[i5 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i3 + 4;
   continue;
  }
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i17, (HEAP32[i14 >> 2] | 0) - i1 | 0, 0);
 i13 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i17 >> 2] | 0 : i17;
 i14 = __ZNSt3__26__clocEv() | 0;
 HEAP32[i15 >> 2] = i16;
 if ((__ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z(i13, i14, 53281, i15) | 0) != 1) HEAP32[i22 >> 2] = 4;
 if (i2) {
  i1 = HEAP32[i2 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i20 >> 2] = 0;
   i2 = 1;
  } else i2 = 0;
 } else i2 = 1;
 do if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i23 = 51;
   break;
  } else {
   HEAP32[i21 >> 2] = 0;
   i23 = 49;
   break;
  }
 } else i23 = 49; while (0);
 if ((i23 | 0) == 49 ? i2 : 0) i23 = 51;
 if ((i23 | 0) == 51) HEAP32[i22 >> 2] = HEAP32[i22 >> 2] | 2;
 i23 = HEAP32[i20 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i17);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 STACKTOP = i19;
 return i23 | 0;
}

function _try_realloc_chunk(i14, i13) {
 i14 = i14 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0;
 i11 = i14 + 4 | 0;
 i12 = HEAP32[i11 >> 2] | 0;
 i1 = i12 & -8;
 i8 = i14 + i1 | 0;
 i6 = HEAP32[15038] | 0;
 i2 = i12 & 3;
 if (!((i2 | 0) != 1 & i14 >>> 0 >= i6 >>> 0 & i14 >>> 0 < i8 >>> 0)) _abort();
 i3 = HEAP32[i8 + 4 >> 2] | 0;
 if (!(i3 & 1)) _abort();
 if (!i2) {
  if (i13 >>> 0 < 256) {
   i14 = 0;
   return i14 | 0;
  }
  if (i1 >>> 0 >= (i13 + 4 | 0) >>> 0 ? (i1 - i13 | 0) >>> 0 <= HEAP32[15154] << 1 >>> 0 : 0) return i14 | 0;
  i14 = 0;
  return i14 | 0;
 }
 if (i1 >>> 0 >= i13 >>> 0) {
  i1 = i1 - i13 | 0;
  if (i1 >>> 0 <= 15) return i14 | 0;
  i10 = i14 + i13 | 0;
  HEAP32[i11 >> 2] = i12 & 1 | i13 | 2;
  HEAP32[i10 + 4 >> 2] = i1 | 3;
  i13 = i10 + i1 + 4 | 0;
  HEAP32[i13 >> 2] = HEAP32[i13 >> 2] | 1;
  _dispose_chunk(i10, i1);
  return i14 | 0;
 }
 if ((i8 | 0) == (HEAP32[15040] | 0)) {
  i1 = (HEAP32[15037] | 0) + i1 | 0;
  if (i1 >>> 0 <= i13 >>> 0) {
   i14 = 0;
   return i14 | 0;
  }
  i10 = i1 - i13 | 0;
  i9 = i14 + i13 | 0;
  HEAP32[i11 >> 2] = i12 & 1 | i13 | 2;
  HEAP32[i9 + 4 >> 2] = i10 | 1;
  HEAP32[15040] = i9;
  HEAP32[15037] = i10;
  return i14 | 0;
 }
 if ((i8 | 0) == (HEAP32[15039] | 0)) {
  i2 = (HEAP32[15036] | 0) + i1 | 0;
  if (i2 >>> 0 < i13 >>> 0) {
   i14 = 0;
   return i14 | 0;
  }
  i1 = i2 - i13 | 0;
  if (i1 >>> 0 > 15) {
   i2 = i14 + i13 | 0;
   i10 = i2 + i1 | 0;
   HEAP32[i11 >> 2] = i12 & 1 | i13 | 2;
   HEAP32[i2 + 4 >> 2] = i1 | 1;
   HEAP32[i10 >> 2] = i1;
   i13 = i10 + 4 | 0;
   HEAP32[i13 >> 2] = HEAP32[i13 >> 2] & -2;
  } else {
   HEAP32[i11 >> 2] = i12 & 1 | i2 | 2;
   i2 = i14 + i2 + 4 | 0;
   HEAP32[i2 >> 2] = HEAP32[i2 >> 2] | 1;
   i2 = 0;
   i1 = 0;
  }
  HEAP32[15036] = i1;
  HEAP32[15039] = i2;
  return i14 | 0;
 }
 if (i3 & 2 | 0) {
  i14 = 0;
  return i14 | 0;
 }
 i9 = (i3 & -8) + i1 | 0;
 if (i9 >>> 0 < i13 >>> 0) {
  i14 = 0;
  return i14 | 0;
 }
 i10 = i9 - i13 | 0;
 i4 = i3 >>> 3;
 do if (i3 >>> 0 >= 256) {
  i5 = HEAP32[i8 + 24 >> 2] | 0;
  i3 = HEAP32[i8 + 12 >> 2] | 0;
  do if ((i3 | 0) == (i8 | 0)) {
   i2 = i8 + 16 | 0;
   i3 = i2 + 4 | 0;
   i1 = HEAP32[i3 >> 2] | 0;
   if (!i1) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i7 = 0;
     break;
    }
   } else i2 = i3;
   while (1) {
    i3 = i1 + 20 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if (i4 | 0) {
     i1 = i4;
     i2 = i3;
     continue;
    }
    i3 = i1 + 16 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if (!i4) break; else {
     i1 = i4;
     i2 = i3;
    }
   }
   if (i2 >>> 0 < i6 >>> 0) _abort(); else {
    HEAP32[i2 >> 2] = 0;
    i7 = i1;
    break;
   }
  } else {
   i4 = HEAP32[i8 + 8 >> 2] | 0;
   if (i4 >>> 0 < i6 >>> 0) _abort();
   i1 = i4 + 12 | 0;
   if ((HEAP32[i1 >> 2] | 0) != (i8 | 0)) _abort();
   i2 = i3 + 8 | 0;
   if ((HEAP32[i2 >> 2] | 0) == (i8 | 0)) {
    HEAP32[i1 >> 2] = i3;
    HEAP32[i2 >> 2] = i4;
    i7 = i3;
    break;
   } else _abort();
  } while (0);
  if (i5 | 0) {
   i1 = HEAP32[i8 + 28 >> 2] | 0;
   i2 = 60440 + (i1 << 2) | 0;
   if ((i8 | 0) == (HEAP32[i2 >> 2] | 0)) {
    HEAP32[i2 >> 2] = i7;
    if (!i7) {
     HEAP32[15035] = HEAP32[15035] & ~(1 << i1);
     break;
    }
   } else {
    if (i5 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort();
    i1 = i5 + 16 | 0;
    if ((HEAP32[i1 >> 2] | 0) == (i8 | 0)) HEAP32[i1 >> 2] = i7; else HEAP32[i5 + 20 >> 2] = i7;
    if (!i7) break;
   }
   i3 = HEAP32[15038] | 0;
   if (i7 >>> 0 < i3 >>> 0) _abort();
   HEAP32[i7 + 24 >> 2] = i5;
   i1 = i8 + 16 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   do if (i2 | 0) if (i2 >>> 0 < i3 >>> 0) _abort(); else {
    HEAP32[i7 + 16 >> 2] = i2;
    HEAP32[i2 + 24 >> 2] = i7;
    break;
   } while (0);
   i1 = HEAP32[i1 + 4 >> 2] | 0;
   if (i1 | 0) if (i1 >>> 0 < (HEAP32[15038] | 0) >>> 0) _abort(); else {
    HEAP32[i7 + 20 >> 2] = i1;
    HEAP32[i1 + 24 >> 2] = i7;
    break;
   }
  }
 } else {
  i2 = HEAP32[i8 + 8 >> 2] | 0;
  i3 = HEAP32[i8 + 12 >> 2] | 0;
  i1 = 60176 + (i4 << 1 << 2) | 0;
  if ((i2 | 0) != (i1 | 0)) {
   if (i2 >>> 0 < i6 >>> 0) _abort();
   if ((HEAP32[i2 + 12 >> 2] | 0) != (i8 | 0)) _abort();
  }
  if ((i3 | 0) == (i2 | 0)) {
   HEAP32[15034] = HEAP32[15034] & ~(1 << i4);
   break;
  }
  if ((i3 | 0) != (i1 | 0)) {
   if (i3 >>> 0 < i6 >>> 0) _abort();
   i1 = i3 + 8 | 0;
   if ((HEAP32[i1 >> 2] | 0) == (i8 | 0)) i5 = i1; else _abort();
  } else i5 = i3 + 8 | 0;
  HEAP32[i2 + 12 >> 2] = i3;
  HEAP32[i5 >> 2] = i2;
 } while (0);
 if (i10 >>> 0 < 16) {
  HEAP32[i11 >> 2] = i9 | i12 & 1 | 2;
  i13 = i14 + i9 + 4 | 0;
  HEAP32[i13 >> 2] = HEAP32[i13 >> 2] | 1;
  return i14 | 0;
 } else {
  i9 = i14 + i13 | 0;
  HEAP32[i11 >> 2] = i12 & 1 | i13 | 2;
  HEAP32[i9 + 4 >> 2] = i10 | 3;
  i13 = i9 + i10 + 4 | 0;
  HEAP32[i13 >> 2] = HEAP32[i13 >> 2] | 1;
  _dispose_chunk(i9, i10);
  return i14 | 0;
 }
 return 0;
}

function __ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb(i16, i17, i1, i19, i15, i18, i14) {
 i16 = i16 | 0;
 i17 = i17 | 0;
 i1 = i1 | 0;
 i19 = i19 | 0;
 i15 = i15 | 0;
 i18 = i18 | 0;
 i14 = i14 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i20 = 0, i21 = 0, i22 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i2 = i22;
 i4 = (i19 - i1 | 0) / 12 | 0;
 if (i4 >>> 0 > 100) {
  i2 = _malloc(i4) | 0;
  if (!i2) {
   i20 = 0;
   i2 = 0;
  } else i20 = i2;
 } else i20 = 0;
 i7 = i1;
 i3 = 0;
 i6 = i2;
 while (1) {
  if ((i7 | 0) == (i19 | 0)) break;
  i5 = HEAP8[i7 + 11 >> 0] | 0;
  if (i5 << 24 >> 24 < 0) i5 = HEAP32[i7 + 4 >> 2] | 0; else i5 = i5 & 255;
  if (!i5) {
   HEAP8[i6 >> 0] = 2;
   i3 = i3 + 1 | 0;
   i4 = i4 + -1 | 0;
  } else HEAP8[i6 >> 0] = 1;
  i7 = i7 + 12 | 0;
  i6 = i6 + 1 | 0;
 }
 i13 = 0;
 i10 = i3;
 i8 = i4;
 L17 : while (1) {
  i3 = HEAP32[i16 >> 2] | 0;
  do if (i3) {
   if ((HEAP32[i3 + 12 >> 2] | 0) == (HEAP32[i3 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0) == -1) {
    HEAP32[i16 >> 2] = 0;
    i3 = 0;
    break;
   } else {
    i3 = HEAP32[i16 >> 2] | 0;
    break;
   }
  } else i3 = 0; while (0);
  i6 = (i3 | 0) == 0;
  i4 = HEAP32[i17 >> 2] | 0;
  if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
    HEAP32[i17 >> 2] = 0;
    i4 = 0;
   }
  } else i4 = 0;
  i5 = (i4 | 0) == 0;
  i3 = HEAP32[i16 >> 2] | 0;
  if (!((i8 | 0) != 0 & (i6 ^ i5))) break;
  i4 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i4 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i3 = HEAPU8[i4 >> 0] | 0;
  i3 = i3 & 255;
  if (!i14) i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i15 >> 2] | 0) + 12 >> 2] & 63](i15, i3) | 0;
  i12 = i13 + 1 | 0;
  i7 = 0;
  i9 = i1;
  i11 = i8;
  i8 = i2;
  while (1) {
   if ((i9 | 0) == (i19 | 0)) break;
   do if ((HEAP8[i8 >> 0] | 0) == 1) {
    i5 = i9 + 11 | 0;
    if ((HEAP8[i5 >> 0] | 0) < 0) i4 = HEAP32[i9 >> 2] | 0; else i4 = i9;
    i4 = HEAP8[i4 + i13 >> 0] | 0;
    if (!i14) i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i15 >> 2] | 0) + 12 >> 2] & 63](i15, i4) | 0;
    if (i3 << 24 >> 24 != i4 << 24 >> 24) {
     HEAP8[i8 >> 0] = 0;
     i4 = i7;
     i5 = i10;
     i6 = i11 + -1 | 0;
     break;
    }
    i4 = HEAP8[i5 >> 0] | 0;
    if (i4 << 24 >> 24 < 0) i4 = HEAP32[i9 + 4 >> 2] | 0; else i4 = i4 & 255;
    if ((i4 | 0) == (i12 | 0)) {
     HEAP8[i8 >> 0] = 2;
     i4 = 1;
     i5 = i10 + 1 | 0;
     i6 = i11 + -1 | 0;
    } else {
     i4 = 1;
     i5 = i10;
     i6 = i11;
    }
   } else {
    i4 = i7;
    i5 = i10;
    i6 = i11;
   } while (0);
   i7 = i4;
   i9 = i9 + 12 | 0;
   i10 = i5;
   i11 = i6;
   i8 = i8 + 1 | 0;
  }
  if (!i7) {
   i13 = i12;
   i8 = i11;
   continue;
  }
  i3 = HEAP32[i16 >> 2] | 0;
  i4 = i3 + 12 | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  if ((i5 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0; else HEAP32[i4 >> 2] = i5 + 1;
  if ((i10 + i11 | 0) >>> 0 > 1) {
   i6 = i1;
   i3 = i10;
   i5 = i2;
  } else {
   i13 = i12;
   i8 = i11;
   continue;
  }
  while (1) {
   if ((i6 | 0) == (i19 | 0)) {
    i13 = i12;
    i10 = i3;
    i8 = i11;
    continue L17;
   }
   if ((HEAP8[i5 >> 0] | 0) == 2) {
    i4 = HEAP8[i6 + 11 >> 0] | 0;
    if (i4 << 24 >> 24 < 0) i4 = HEAP32[i6 + 4 >> 2] | 0; else i4 = i4 & 255;
    if ((i4 | 0) != (i12 | 0)) {
     HEAP8[i5 >> 0] = 0;
     i3 = i3 + -1 | 0;
    }
   }
   i6 = i6 + 12 | 0;
   i5 = i5 + 1 | 0;
  }
 }
 do if (i3) {
  if ((HEAP32[i3 + 12 >> 2] | 0) == (HEAP32[i3 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0) == -1) {
   HEAP32[i16 >> 2] = 0;
   i3 = 0;
   break;
  } else {
   i3 = HEAP32[i16 >> 2] | 0;
   break;
  }
 } else i3 = 0; while (0);
 i3 = (i3 | 0) == 0;
 do if (!i5) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i17 >> 2] = 0;
   i21 = 34;
   break;
  }
  if (!i3) i21 = 69;
 } else i21 = 34; while (0);
 if ((i21 | 0) == 34) if (i3) i21 = 69;
 if ((i21 | 0) == 69) HEAP32[i18 >> 2] = HEAP32[i18 >> 2] | 2;
 while (1) {
  if ((i1 | 0) == (i19 | 0)) {
   i21 = 73;
   break;
  }
  if ((HEAP8[i2 >> 0] | 0) == 2) break;
  i1 = i1 + 12 | 0;
  i2 = i2 + 1 | 0;
 }
 if ((i21 | 0) == 73) {
  HEAP32[i18 >> 2] = HEAP32[i18 >> 2] | 4;
  i1 = i19;
 }
 _free(i20);
 STACKTOP = i22;
 return i1 | 0;
}

function _call_from_js(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, d5 = 0.0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0;
 i21 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i19 = i21 + 64 | 0;
 i1 = i21 + 96 | 0;
 i3 = i21 + 104 | 0;
 i4 = i21 + 100 | 0;
 i17 = i21 + 84 | 0;
 i13 = i21 + 48 | 0;
 i14 = i21 + 16 | 0;
 i15 = i21;
 i18 = i21 + 32 | 0;
 i16 = i21 + 80 | 0;
 if (HEAP8[63612] | 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60808, 18384) | 0, i2) | 0, 10) | 0;
 __ZN6cashew7IStringC2EPKcb(i1, i2, 1);
 i11 = HEAP32[HEAP32[14813] >> 2] | 0;
 i12 = HEAP32[i1 >> 2] | 0;
 HEAP32[i3 >> 2] = i12;
 HEAP32[i19 >> 2] = HEAP32[i3 >> 2];
 i11 = (__ZN4wasm6Module9getExportENS_4NameE(i11, i19) | 0) + 4 | 0;
 i1 = HEAP32[HEAP32[14813] >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i19 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN4wasm6Module11getFunctionENS_4NameE(i1, i19) | 0;
 if (!i1) ___assert_fail(47951, 18398, 436, 18414);
 i10 = _emscripten_asm_const_i(10) | 0;
 i11 = i1 + 8 | 0;
 i2 = (HEAP32[i1 + 12 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2;
 HEAP32[i17 >> 2] = 0;
 i3 = i17 + 4 | 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i17 + 8 >> 2] = 0;
 i4 = i13 + 8 | 0;
 i6 = i17 + 8 | 0;
 i7 = i14 + 8 | 0;
 i8 = i15 + 8 | 0;
 i9 = 0;
 L7 : while (1) {
  if (i9 >>> 0 >= i2 >>> 0) break;
  L10 : do switch (HEAP32[(HEAP32[i11 >> 2] | 0) + (i9 << 2) >> 2] | 0) {
  case 1:
   {
    if (i9 >>> 0 < i10 >>> 0) i1 = _emscripten_asm_const_ii(11, i9 | 0) | 0; else i1 = 0;
    HEAP32[i13 >> 2] = 1;
    HEAP32[i4 >> 2] = i1;
    i1 = HEAP32[i3 >> 2] | 0;
    if (i1 >>> 0 < (HEAP32[i6 >> 2] | 0) >>> 0) {
     HEAP32[i1 >> 2] = HEAP32[i13 >> 2];
     HEAP32[i1 + 4 >> 2] = HEAP32[i13 + 4 >> 2];
     HEAP32[i1 + 8 >> 2] = HEAP32[i13 + 8 >> 2];
     HEAP32[i1 + 12 >> 2] = HEAP32[i13 + 12 >> 2];
     HEAP32[i3 >> 2] = i1 + 16;
     break L10;
    } else {
     __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i17, i13);
     break L10;
    }
   }
  case 3:
   {
    if (i9 >>> 0 < i10 >>> 0) d5 = +_emscripten_asm_const_di(11, i9 | 0); else d5 = 0.0;
    HEAP32[i14 >> 2] = 3;
    HEAPF32[i7 >> 2] = d5;
    i1 = HEAP32[i3 >> 2] | 0;
    if (i1 >>> 0 < (HEAP32[i6 >> 2] | 0) >>> 0) {
     HEAP32[i1 >> 2] = HEAP32[i14 >> 2];
     HEAP32[i1 + 4 >> 2] = HEAP32[i14 + 4 >> 2];
     HEAP32[i1 + 8 >> 2] = HEAP32[i14 + 8 >> 2];
     HEAP32[i1 + 12 >> 2] = HEAP32[i14 + 12 >> 2];
     HEAP32[i3 >> 2] = i1 + 16;
     break L10;
    } else {
     __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i17, i14);
     break L10;
    }
   }
  case 4:
   {
    if (i9 >>> 0 < i10 >>> 0) d5 = +_emscripten_asm_const_di(11, i9 | 0); else d5 = 0.0;
    HEAP32[i15 >> 2] = 4;
    HEAPF64[i8 >> 3] = d5;
    i1 = HEAP32[i3 >> 2] | 0;
    if (i1 >>> 0 < (HEAP32[i6 >> 2] | 0) >>> 0) {
     HEAP32[i1 >> 2] = HEAP32[i15 >> 2];
     HEAP32[i1 + 4 >> 2] = HEAP32[i15 + 4 >> 2];
     HEAP32[i1 + 8 >> 2] = HEAP32[i15 + 8 >> 2];
     HEAP32[i1 + 12 >> 2] = HEAP32[i15 + 12 >> 2];
     HEAP32[i3 >> 2] = i1 + 16;
     break L10;
    } else {
     __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i17, i15);
     break L10;
    }
   }
  default:
   {
    i20 = 24;
    break L7;
   }
  } while (0);
  i9 = i9 + 1 | 0;
 }
 if ((i20 | 0) == 24) _abort();
 i20 = HEAP32[14813] | 0;
 HEAP32[i16 >> 2] = i12;
 HEAP32[i19 >> 2] = HEAP32[i16 >> 2];
 __ZN4wasm14ModuleInstance10callExportENS_4NameERNSt3__26vectorINS_7LiteralENS2_9allocatorIS4_EEEE(i18, i20, i19, i17);
 if (HEAP8[63612] | 0) {
  i20 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60808, 18508) | 0;
  HEAP32[i19 >> 2] = HEAP32[i18 >> 2];
  HEAP32[i19 + 4 >> 2] = HEAP32[i18 + 4 >> 2];
  HEAP32[i19 + 8 >> 2] = HEAP32[i18 + 8 >> 2];
  HEAP32[i19 + 12 >> 2] = HEAP32[i18 + 12 >> 2];
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_7LiteralE(i20, i19) | 0, 10) | 0;
 }
 switch (HEAP32[i18 >> 2] | 0) {
 case 0:
  {
   _emscripten_asm_const_v(12);
   break;
  }
 case 1:
  {
   _emscripten_asm_const_ii(13, __ZNK4wasm7Literal6geti32Ev(i18) | 0) | 0;
   break;
  }
 case 3:
  {
   _emscripten_asm_const_id(13, +(+__ZNK4wasm7Literal6getf32Ev(i18))) | 0;
   break;
  }
 case 4:
  {
   _emscripten_asm_const_id(13, +(+__ZNK4wasm7Literal6getf64Ev(i18))) | 0;
   break;
  }
 default:
  _abort();
 }
 __ZNSt3__213__vector_baseIN4wasm7LiteralENS_9allocatorIS2_EEED2Ev(i17);
 STACKTOP = i21;
 return;
}

function __ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE(i15, i17, i16, i18, i20, i19, i1) {
 i15 = i15 | 0;
 i17 = i17 | 0;
 i16 = i16 | 0;
 i18 = i18 | 0;
 i20 = i20 | 0;
 i19 = i19 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i21 = 0, i22 = 0, i23 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i14 = i22;
 i13 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61712) | 0;
 i11 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61720) | 0;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[i11 >> 2] | 0) + 20 >> 2] & 1023](i14, i11);
 HEAP32[i19 >> 2] = i18;
 i1 = HEAP8[i15 >> 0] | 0;
 switch (i1 << 24 >> 24) {
 case 43:
 case 45:
  {
   i12 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 44 >> 2] & 63](i13, i1) | 0;
   i2 = HEAP32[i19 >> 2] | 0;
   HEAP32[i19 >> 2] = i2 + 4;
   HEAP32[i2 >> 2] = i12;
   i2 = i15 + 1 | 0;
   break;
  }
 default:
  i2 = i15;
 }
 i12 = i16;
 L4 : do if ((i12 - i2 | 0) > 1 ? (HEAP8[i2 >> 0] | 0) == 48 : 0) {
  i1 = i2 + 1 | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 88:
  case 120:
   break;
  default:
   {
    i1 = i2;
    i21 = 10;
    break L4;
   }
  }
  i9 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 44 >> 2] & 63](i13, 48) | 0;
  i10 = HEAP32[i19 >> 2] | 0;
  HEAP32[i19 >> 2] = i10 + 4;
  HEAP32[i10 >> 2] = i9;
  i2 = i2 + 2 | 0;
  i10 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 44 >> 2] & 63](i13, HEAP8[i1 >> 0] | 0) | 0;
  i1 = HEAP32[i19 >> 2] | 0;
  HEAP32[i19 >> 2] = i1 + 4;
  HEAP32[i1 >> 2] = i10;
  i1 = i2;
  while (1) {
   if (i1 >>> 0 >= i16 >>> 0) break L4;
   i10 = HEAP8[i1 >> 0] | 0;
   if (!(_isxdigit_l(i10, __ZNSt3__26__clocEv() | 0) | 0)) break L4;
   i1 = i1 + 1 | 0;
  }
 } else {
  i1 = i2;
  i21 = 10;
 } while (0);
 L12 : do if ((i21 | 0) == 10) while (1) {
  i21 = 0;
  if (i1 >>> 0 >= i16 >>> 0) break L12;
  i10 = HEAP8[i1 >> 0] | 0;
  if (!(_isdigit_l(i10, __ZNSt3__26__clocEv() | 0) | 0)) break L12;
  i1 = i1 + 1 | 0;
  i21 = 10;
 } while (0);
 i9 = i14 + 11 | 0;
 i8 = HEAP8[i9 >> 0] | 0;
 i10 = i14 + 4 | 0;
 L18 : do if ((i8 << 24 >> 24 < 0 ? HEAP32[i10 >> 2] | 0 : i8 & 255) | 0) {
  L21 : do if ((i2 | 0) != (i1 | 0)) {
   i3 = i1;
   i4 = i2;
   while (1) {
    i3 = i3 + -1 | 0;
    if (i4 >>> 0 >= i3 >>> 0) break L21;
    i8 = HEAP8[i4 >> 0] | 0;
    HEAP8[i4 >> 0] = HEAP8[i3 >> 0] | 0;
    HEAP8[i3 >> 0] = i8;
    i4 = i4 + 1 | 0;
   }
  } while (0);
  i7 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i11 >> 2] | 0) + 16 >> 2] & 255](i11) | 0;
  i6 = 0;
  i3 = 0;
  i8 = i2;
  while (1) {
   if (i8 >>> 0 >= i1 >>> 0) break;
   i4 = HEAP8[i9 >> 0] | 0;
   i5 = i4 << 24 >> 24 < 0;
   i23 = HEAP8[(i5 ? HEAP32[i14 >> 2] | 0 : i14) + i3 >> 0] | 0;
   if (i23 << 24 >> 24 > 0 & (i6 | 0) == (i23 << 24 >> 24 | 0)) {
    i6 = HEAP32[i19 >> 2] | 0;
    HEAP32[i19 >> 2] = i6 + 4;
    HEAP32[i6 >> 2] = i7;
    i6 = 0;
    i3 = (i3 >>> 0 < ((i5 ? HEAP32[i10 >> 2] | 0 : i4 & 255) + -1 | 0) >>> 0 & 1) + i3 | 0;
   }
   i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 44 >> 2] & 63](i13, HEAP8[i8 >> 0] | 0) | 0;
   i23 = HEAP32[i19 >> 2] | 0;
   HEAP32[i19 >> 2] = i23 + 4;
   HEAP32[i23 >> 2] = i5;
   i6 = i6 + 1 | 0;
   i8 = i8 + 1 | 0;
  }
  i2 = i18 + (i2 - i15 << 2) | 0;
  i4 = HEAP32[i19 >> 2] | 0;
  if ((i2 | 0) == (i4 | 0)) i3 = i13; else {
   i3 = i4;
   while (1) {
    i3 = i3 + -4 | 0;
    if (i2 >>> 0 >= i3 >>> 0) {
     i3 = i13;
     i2 = i4;
     break L18;
    }
    i23 = HEAP32[i2 >> 2] | 0;
    HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
    HEAP32[i3 >> 2] = i23;
    i2 = i2 + 4 | 0;
   }
  }
 } else {
  FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i13 >> 2] | 0) + 48 >> 2] & 7](i13, i2, i1, HEAP32[i19 >> 2] | 0) | 0;
  i2 = (HEAP32[i19 >> 2] | 0) + (i1 - i2 << 2) | 0;
  HEAP32[i19 >> 2] = i2;
  i3 = i13;
 } while (0);
 while (1) {
  if (i1 >>> 0 >= i16 >>> 0) break;
  i2 = HEAP8[i1 >> 0] | 0;
  if (i2 << 24 >> 24 == 46) {
   i21 = 29;
   break;
  }
  i10 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 44 >> 2] & 63](i13, i2) | 0;
  i23 = HEAP32[i19 >> 2] | 0;
  i2 = i23 + 4 | 0;
  HEAP32[i19 >> 2] = i2;
  HEAP32[i23 >> 2] = i10;
  i1 = i1 + 1 | 0;
 }
 if ((i21 | 0) == 29) {
  i21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i11 >> 2] | 0) + 12 >> 2] & 255](i11) | 0;
  i23 = HEAP32[i19 >> 2] | 0;
  i2 = i23 + 4 | 0;
  HEAP32[i19 >> 2] = i2;
  HEAP32[i23 >> 2] = i21;
  i1 = i1 + 1 | 0;
 }
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i13 >> 2] | 0) + 48 >> 2] & 7](i13, i1, i16, i2) | 0;
 i23 = (HEAP32[i19 >> 2] | 0) + (i12 - i1 << 2) | 0;
 HEAP32[i19 >> 2] = i23;
 HEAP32[i20 >> 2] = (i17 | 0) == (i16 | 0) ? i23 : i18 + (i17 - i15 << 2) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i14);
 STACKTOP = i22;
 return;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 224 | 0;
 i11 = i20 + 198 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i6 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i6;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP8[i3 >> 0] | 0;
 i1 = HEAP32[i21 >> 2] | 0;
 i3 = i6;
 L13 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i21 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i2 = (i1 | 0) == 0;
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i2) break; else break L13;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i2) break; else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 20;
    break;
   }
  } else i24 = 20; while (0);
  if ((i24 | 0) == 20) {
   i24 = 0;
   if (i2) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i9 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i3 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i5 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i2 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i2, 0);
   i3 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i3 + i5;
  }
  i5 = i1 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAPU8[i2 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_(i2 & 255, i14, i3, i15, i12, i7, i19, i16, i13, i11) | 0) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i2 + 1;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i2 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i2 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i2 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i2 >> 2] = i11;
  i2 = i12;
 }
 i15 = __ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji(i3, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 HEAP32[i17 + 4 >> 2] = tempRet0;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i2, i23);
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i21 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i4) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i22 >> 2] = 0;
   i24 = 45;
   break;
  }
  if (!i1) i24 = 46;
 } else i24 = 45; while (0);
 if ((i24 | 0) == 45 ? i1 : 0) i24 = 46;
 if ((i24 | 0) == 46) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 224 | 0;
 i11 = i20 + 198 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i6 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i6;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP8[i3 >> 0] | 0;
 i1 = HEAP32[i21 >> 2] | 0;
 i3 = i6;
 L13 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i21 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i2 = (i1 | 0) == 0;
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i2) break; else break L13;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i2) break; else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 20;
    break;
   }
  } else i24 = 20; while (0);
  if ((i24 | 0) == 20) {
   i24 = 0;
   if (i2) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i9 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i3 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i5 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i2 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i2, 0);
   i3 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i3 + i5;
  }
  i5 = i1 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAPU8[i2 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_(i2 & 255, i14, i3, i15, i12, i7, i19, i16, i13, i11) | 0) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i2 + 1;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i2 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i2 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i2 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i2 >> 2] = i11;
  i2 = i12;
 }
 i15 = __ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji(i3, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 HEAP32[i17 + 4 >> 2] = tempRet0;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i2, i23);
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i21 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i4) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i22 >> 2] = 0;
   i24 = 45;
   break;
  }
  if (!i1) i24 = 46;
 } else i24 = 45; while (0);
 if ((i24 | 0) == 45 ? i1 : 0) i24 = 46;
 if ((i24 | 0) == 46) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i23, i24, i2, i25, i19) {
 i1 = i1 | 0;
 i23 = i23 | 0;
 i24 = i24 | 0;
 i2 = i2 | 0;
 i25 = i25 | 0;
 i19 = i19 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0, i21 = 0, i22 = 0, i26 = 0, d27 = 0.0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 240 | 0;
 i12 = i22 + 200 | 0;
 i3 = i22 + 199 | 0;
 i4 = i22 + 198 | 0;
 i21 = i22 + 184 | 0;
 i20 = i22 + 172 | 0;
 i17 = i22 + 168 | 0;
 i18 = i22 + 8 | 0;
 i15 = i22 + 4 | 0;
 i14 = i22;
 i16 = i22 + 197 | 0;
 i13 = i22 + 196 | 0;
 __ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_(i21, i2, i12, i3, i4);
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i20 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i10 = i20 + 11 | 0;
 i11 = i20 + 8 | 0;
 if ((HEAP8[i10 >> 0] | 0) < 0) i1 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i1, 0);
 i6 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
 HEAP32[i17 >> 2] = i6;
 HEAP32[i15 >> 2] = i18;
 HEAP32[i14 >> 2] = 0;
 HEAP8[i16 >> 0] = 1;
 HEAP8[i13 >> 0] = 69;
 i9 = i20 + 4 | 0;
 i8 = HEAP8[i3 >> 0] | 0;
 i7 = HEAP8[i4 >> 0] | 0;
 i1 = HEAP32[i23 >> 2] | 0;
 i3 = i6;
 L8 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i23 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i2 = (i1 | 0) == 0;
  i4 = HEAP32[i24 >> 2] | 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i2) break; else break L8;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i2) break; else break L8; else {
    HEAP32[i24 >> 2] = 0;
    i26 = 16;
    break;
   }
  } else i26 = 16; while (0);
  if ((i26 | 0) == 16) {
   i26 = 0;
   if (i2) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i10 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i9 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i17 >> 2] | 0) == (i3 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i5 << 1, 0);
   if ((HEAP8[i10 >> 0] | 0) < 0) i2 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i2, 0);
   i3 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
   HEAP32[i17 >> 2] = i3 + i5;
  }
  i5 = i1 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAPU8[i2 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_(i2 & 255, i16, i13, i3, i17, i8, i7, i21, i18, i15, i14, i12) | 0) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i2 + 1;
   continue;
  }
 }
 i13 = HEAP8[i21 + 11 >> 0] | 0;
 i2 = HEAP32[i15 >> 2] | 0;
 if (!((HEAP8[i16 >> 0] | 0) == 0 ? 1 : ((i13 << 24 >> 24 < 0 ? HEAP32[i21 + 4 >> 2] | 0 : i13 & 255) | 0) == 0) ? (i2 - i18 | 0) < 160 : 0) {
  i14 = HEAP32[i14 >> 2] | 0;
  i16 = i2 + 4 | 0;
  HEAP32[i15 >> 2] = i16;
  HEAP32[i2 >> 2] = i14;
  i2 = i16;
 }
 d27 = +__ZNSt3__215__num_get_floatIfEET_PKcS3_Rj(i3, HEAP32[i17 >> 2] | 0, i25);
 HEAPF32[i19 >> 2] = d27;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i21, i18, i2, i25);
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i23 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i4) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i24 >> 2] = 0;
   i26 = 41;
   break;
  }
  if (!i1) i26 = 42;
 } else i26 = 41; while (0);
 if ((i26 | 0) == 41 ? i1 : 0) i26 = 42;
 if ((i26 | 0) == 42) HEAP32[i25 >> 2] = HEAP32[i25 >> 2] | 2;
 i26 = HEAP32[i23 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i20);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i21);
 STACKTOP = i22;
 return i26 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i23, i24, i2, i25, i19) {
 i1 = i1 | 0;
 i23 = i23 | 0;
 i24 = i24 | 0;
 i2 = i2 | 0;
 i25 = i25 | 0;
 i19 = i19 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0, i21 = 0, i22 = 0, i26 = 0, d27 = 0.0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 240 | 0;
 i12 = i22 + 200 | 0;
 i3 = i22 + 199 | 0;
 i4 = i22 + 198 | 0;
 i21 = i22 + 184 | 0;
 i20 = i22 + 172 | 0;
 i17 = i22 + 168 | 0;
 i18 = i22 + 8 | 0;
 i15 = i22 + 4 | 0;
 i14 = i22;
 i16 = i22 + 197 | 0;
 i13 = i22 + 196 | 0;
 __ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_(i21, i2, i12, i3, i4);
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i20 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i10 = i20 + 11 | 0;
 i11 = i20 + 8 | 0;
 if ((HEAP8[i10 >> 0] | 0) < 0) i1 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i1, 0);
 i6 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
 HEAP32[i17 >> 2] = i6;
 HEAP32[i15 >> 2] = i18;
 HEAP32[i14 >> 2] = 0;
 HEAP8[i16 >> 0] = 1;
 HEAP8[i13 >> 0] = 69;
 i9 = i20 + 4 | 0;
 i8 = HEAP8[i3 >> 0] | 0;
 i7 = HEAP8[i4 >> 0] | 0;
 i1 = HEAP32[i23 >> 2] | 0;
 i3 = i6;
 L8 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i23 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i2 = (i1 | 0) == 0;
  i4 = HEAP32[i24 >> 2] | 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i2) break; else break L8;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i2) break; else break L8; else {
    HEAP32[i24 >> 2] = 0;
    i26 = 16;
    break;
   }
  } else i26 = 16; while (0);
  if ((i26 | 0) == 16) {
   i26 = 0;
   if (i2) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i10 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i9 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i17 >> 2] | 0) == (i3 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i5 << 1, 0);
   if ((HEAP8[i10 >> 0] | 0) < 0) i2 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i2, 0);
   i3 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
   HEAP32[i17 >> 2] = i3 + i5;
  }
  i5 = i1 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAPU8[i2 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_(i2 & 255, i16, i13, i3, i17, i8, i7, i21, i18, i15, i14, i12) | 0) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i2 + 1;
   continue;
  }
 }
 i13 = HEAP8[i21 + 11 >> 0] | 0;
 i2 = HEAP32[i15 >> 2] | 0;
 if (!((HEAP8[i16 >> 0] | 0) == 0 ? 1 : ((i13 << 24 >> 24 < 0 ? HEAP32[i21 + 4 >> 2] | 0 : i13 & 255) | 0) == 0) ? (i2 - i18 | 0) < 160 : 0) {
  i14 = HEAP32[i14 >> 2] | 0;
  i16 = i2 + 4 | 0;
  HEAP32[i15 >> 2] = i16;
  HEAP32[i2 >> 2] = i14;
  i2 = i16;
 }
 d27 = +__ZNSt3__215__num_get_floatIeEET_PKcS3_Rj(i3, HEAP32[i17 >> 2] | 0, i25);
 HEAPF64[i19 >> 3] = d27;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i21, i18, i2, i25);
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i23 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i4) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i24 >> 2] = 0;
   i26 = 41;
   break;
  }
  if (!i1) i26 = 42;
 } else i26 = 41; while (0);
 if ((i26 | 0) == 41 ? i1 : 0) i26 = 42;
 if ((i26 | 0) == 42) HEAP32[i25 >> 2] = HEAP32[i25 >> 2] | 2;
 i26 = HEAP32[i23 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i20);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i21);
 STACKTOP = i22;
 return i26 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i23, i24, i2, i25, i19) {
 i1 = i1 | 0;
 i23 = i23 | 0;
 i24 = i24 | 0;
 i2 = i2 | 0;
 i25 = i25 | 0;
 i19 = i19 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0, i21 = 0, i22 = 0, i26 = 0, d27 = 0.0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 240 | 0;
 i12 = i22 + 200 | 0;
 i3 = i22 + 199 | 0;
 i4 = i22 + 198 | 0;
 i21 = i22 + 184 | 0;
 i20 = i22 + 172 | 0;
 i17 = i22 + 168 | 0;
 i18 = i22 + 8 | 0;
 i15 = i22 + 4 | 0;
 i14 = i22;
 i16 = i22 + 197 | 0;
 i13 = i22 + 196 | 0;
 __ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_(i21, i2, i12, i3, i4);
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i20 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i10 = i20 + 11 | 0;
 i11 = i20 + 8 | 0;
 if ((HEAP8[i10 >> 0] | 0) < 0) i1 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i1, 0);
 i6 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
 HEAP32[i17 >> 2] = i6;
 HEAP32[i15 >> 2] = i18;
 HEAP32[i14 >> 2] = 0;
 HEAP8[i16 >> 0] = 1;
 HEAP8[i13 >> 0] = 69;
 i9 = i20 + 4 | 0;
 i8 = HEAP8[i3 >> 0] | 0;
 i7 = HEAP8[i4 >> 0] | 0;
 i1 = HEAP32[i23 >> 2] | 0;
 i3 = i6;
 L8 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i23 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i2 = (i1 | 0) == 0;
  i4 = HEAP32[i24 >> 2] | 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i2) break; else break L8;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i2) break; else break L8; else {
    HEAP32[i24 >> 2] = 0;
    i26 = 16;
    break;
   }
  } else i26 = 16; while (0);
  if ((i26 | 0) == 16) {
   i26 = 0;
   if (i2) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i10 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i9 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i17 >> 2] | 0) == (i3 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i5 << 1, 0);
   if ((HEAP8[i10 >> 0] | 0) < 0) i2 = (HEAP32[i11 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i20, i2, 0);
   i3 = (HEAP8[i10 >> 0] | 0) < 0 ? HEAP32[i20 >> 2] | 0 : i20;
   HEAP32[i17 >> 2] = i3 + i5;
  }
  i5 = i1 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAPU8[i2 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_(i2 & 255, i16, i13, i3, i17, i8, i7, i21, i18, i15, i14, i12) | 0) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i2 + 1;
   continue;
  }
 }
 i13 = HEAP8[i21 + 11 >> 0] | 0;
 i2 = HEAP32[i15 >> 2] | 0;
 if (!((HEAP8[i16 >> 0] | 0) == 0 ? 1 : ((i13 << 24 >> 24 < 0 ? HEAP32[i21 + 4 >> 2] | 0 : i13 & 255) | 0) == 0) ? (i2 - i18 | 0) < 160 : 0) {
  i14 = HEAP32[i14 >> 2] | 0;
  i16 = i2 + 4 | 0;
  HEAP32[i15 >> 2] = i16;
  HEAP32[i2 >> 2] = i14;
  i2 = i16;
 }
 d27 = +__ZNSt3__215__num_get_floatIdEET_PKcS3_Rj(i3, HEAP32[i17 >> 2] | 0, i25);
 HEAPF64[i19 >> 3] = d27;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i21, i18, i2, i25);
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i23 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i4) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i24 >> 2] = 0;
   i26 = 41;
   break;
  }
  if (!i1) i26 = 42;
 } else i26 = 41; while (0);
 if ((i26 | 0) == 41 ? i1 : 0) i26 = 42;
 if ((i26 | 0) == 42) HEAP32[i25 >> 2] = HEAP32[i25 >> 2] | 2;
 i26 = HEAP32[i23 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i20);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i21);
 STACKTOP = i22;
 return i26 | 0;
}

function __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i12, i13, i14, i10, i6) {
 i12 = i12 | 0;
 i13 = i13 | 0;
 i14 = i14 | 0;
 i10 = i10 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i11 = 0;
 i1 = HEAP32[i12 >> 2] | 0;
 do if (i1) {
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i12 >> 2] = 0;
   i3 = 1;
   break;
  } else {
   i3 = (HEAP32[i12 >> 2] | 0) == 0;
   break;
  }
 } else i3 = 1; while (0);
 i2 = HEAP32[i13 >> 2] | 0;
 do if (i2) {
  i1 = HEAP32[i2 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i3) {
   i11 = 17;
   break;
  } else {
   i11 = 16;
   break;
  } else {
   HEAP32[i13 >> 2] = 0;
   i11 = 14;
   break;
  }
 } else i11 = 14; while (0);
 if ((i11 | 0) == 14) if (i3) i11 = 16; else {
  i2 = 0;
  i11 = 17;
 }
 L22 : do if ((i11 | 0) == 16) {
  HEAP32[i14 >> 2] = HEAP32[i14 >> 2] | 6;
  i1 = 0;
 } else if ((i11 | 0) == 17) {
  i1 = HEAP32[i12 >> 2] | 0;
  i3 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i3 >> 2] | 0;
  if (!(FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i10 >> 2] | 0) + 12 >> 2] & 31](i10, 2048, i1) | 0)) {
   HEAP32[i14 >> 2] = HEAP32[i14 >> 2] | 4;
   i1 = 0;
   break;
  }
  i1 = (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i10 >> 2] | 0) + 52 >> 2] & 31](i10, i1, 0) | 0) << 24 >> 24;
  i3 = HEAP32[i12 >> 2] | 0;
  i4 = i3 + 12 | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  if ((i5 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 40 >> 2] & 255](i3) | 0;
   i8 = i6;
   i7 = i2;
   i4 = i2;
  } else {
   HEAP32[i4 >> 2] = i5 + 4;
   i8 = i6;
   i7 = i2;
   i4 = i2;
  }
  while (1) {
   i1 = i1 + -48 | 0;
   i9 = i8 + -1 | 0;
   i2 = HEAP32[i12 >> 2] | 0;
   do if (i2) {
    i3 = HEAP32[i2 + 12 >> 2] | 0;
    if ((i3 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i2 = HEAP32[i3 >> 2] | 0;
    if ((i2 | 0) == -1) {
     HEAP32[i12 >> 2] = 0;
     i5 = 1;
     break;
    } else {
     i5 = (HEAP32[i12 >> 2] | 0) == 0;
     break;
    }
   } else i5 = 1; while (0);
   do if (i4) {
    i2 = HEAP32[i4 + 12 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i2 = HEAP32[i2 >> 2] | 0;
    if ((i2 | 0) == -1) {
     HEAP32[i13 >> 2] = 0;
     i4 = 0;
     i6 = 0;
     i2 = 1;
     break;
    } else {
     i4 = i7;
     i6 = i7;
     i2 = (i7 | 0) == 0;
     break;
    }
   } else {
    i4 = i7;
    i6 = 0;
    i2 = 1;
   } while (0);
   i3 = HEAP32[i12 >> 2] | 0;
   if (!((i8 | 0) > 1 & (i5 ^ i2))) break;
   i2 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i2 = HEAP32[i2 >> 2] | 0;
   if (!(FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i10 >> 2] | 0) + 12 >> 2] & 31](i10, 2048, i2) | 0)) break L22;
   i1 = ((FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i10 >> 2] | 0) + 52 >> 2] & 31](i10, i2, 0) | 0) << 24 >> 24) + (i1 * 10 | 0) | 0;
   i2 = HEAP32[i12 >> 2] | 0;
   i3 = i2 + 12 | 0;
   i5 = HEAP32[i3 >> 2] | 0;
   if ((i5 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) {
    FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
    i8 = i9;
    i7 = i4;
    i4 = i6;
    continue;
   } else {
    HEAP32[i3 >> 2] = i5 + 4;
    i8 = i9;
    i7 = i4;
    i4 = i6;
    continue;
   }
  }
  do if (i3) {
   i2 = HEAP32[i3 + 12 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i2 = HEAP32[i2 >> 2] | 0;
   if ((i2 | 0) == -1) {
    HEAP32[i12 >> 2] = 0;
    i3 = 1;
    break;
   } else {
    i3 = (HEAP32[i12 >> 2] | 0) == 0;
    break;
   }
  } else i3 = 1; while (0);
  do if (i4) {
   i2 = HEAP32[i4 + 12 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i4 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0; else i2 = HEAP32[i2 >> 2] | 0;
   if ((i2 | 0) != -1) if (i3) break L22; else break; else {
    HEAP32[i13 >> 2] = 0;
    i11 = 60;
    break;
   }
  } else i11 = 60; while (0);
  if ((i11 | 0) == 60 ? !i3 : 0) break;
  HEAP32[i14 >> 2] = HEAP32[i14 >> 2] | 2;
 } while (0);
 return i1 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 224 | 0;
 i11 = i20 + 198 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i6 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i6;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP8[i3 >> 0] | 0;
 i1 = HEAP32[i21 >> 2] | 0;
 i3 = i6;
 L13 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i21 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i2 = (i1 | 0) == 0;
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i2) break; else break L13;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i2) break; else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 20;
    break;
   }
  } else i24 = 20; while (0);
  if ((i24 | 0) == 20) {
   i24 = 0;
   if (i2) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i9 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i3 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i5 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i2 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i2, 0);
   i3 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i3 + i5;
  }
  i5 = i1 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAPU8[i2 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_(i2 & 255, i14, i3, i15, i12, i7, i19, i16, i13, i11) | 0) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i2 + 1;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i2 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i2 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i2 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i2 >> 2] = i11;
  i2 = i12;
 }
 i15 = __ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji(i3, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP16[i17 >> 1] = i15;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i2, i23);
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i21 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i4) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i22 >> 2] = 0;
   i24 = 45;
   break;
  }
  if (!i1) i24 = 46;
 } else i24 = 45; while (0);
 if ((i24 | 0) == 45 ? i1 : 0) i24 = 46;
 if ((i24 | 0) == 46) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 224 | 0;
 i11 = i20 + 198 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i6 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i6;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP8[i3 >> 0] | 0;
 i1 = HEAP32[i21 >> 2] | 0;
 i3 = i6;
 L13 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i21 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i2 = (i1 | 0) == 0;
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i2) break; else break L13;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i2) break; else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 20;
    break;
   }
  } else i24 = 20; while (0);
  if ((i24 | 0) == 20) {
   i24 = 0;
   if (i2) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i9 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i3 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i5 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i2 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i2, 0);
   i3 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i3 + i5;
  }
  i5 = i1 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAPU8[i2 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_(i2 & 255, i14, i3, i15, i12, i7, i19, i16, i13, i11) | 0) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i2 + 1;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i2 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i2 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i2 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i2 >> 2] = i11;
  i2 = i12;
 }
 i15 = __ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji(i3, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i2, i23);
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i21 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i4) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i22 >> 2] = 0;
   i24 = 45;
   break;
  }
  if (!i1) i24 = 46;
 } else i24 = 45; while (0);
 if ((i24 | 0) == 45 ? i1 : 0) i24 = 46;
 if ((i24 | 0) == 46) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 224 | 0;
 i11 = i20 + 198 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i6 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i6;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP8[i3 >> 0] | 0;
 i1 = HEAP32[i21 >> 2] | 0;
 i3 = i6;
 L13 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i21 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i2 = (i1 | 0) == 0;
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i2) break; else break L13;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i2) break; else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 20;
    break;
   }
  } else i24 = 20; while (0);
  if ((i24 | 0) == 20) {
   i24 = 0;
   if (i2) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i9 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i3 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i5 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i2 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i2, 0);
   i3 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i3 + i5;
  }
  i5 = i1 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAPU8[i2 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_(i2 & 255, i14, i3, i15, i12, i7, i19, i16, i13, i11) | 0) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i2 + 1;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i2 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i2 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i2 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i2 >> 2] = i11;
  i2 = i12;
 }
 i15 = __ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji(i3, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i2, i23);
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i21 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i4) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i22 >> 2] = 0;
   i24 = 45;
   break;
  }
  if (!i1) i24 = 46;
 } else i24 = 45; while (0);
 if ((i24 | 0) == 45 ? i1 : 0) i24 = 46;
 if ((i24 | 0) == 46) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_(i1, i21, i22, i2, i23, i17) {
 i1 = i1 | 0;
 i21 = i21 | 0;
 i22 = i22 | 0;
 i2 = i2 | 0;
 i23 = i23 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0, i24 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 224 | 0;
 i11 = i20 + 198 | 0;
 i3 = i20 + 196 | 0;
 i19 = i20 + 184 | 0;
 i18 = i20 + 172 | 0;
 i15 = i20 + 168 | 0;
 i16 = i20 + 8 | 0;
 i13 = i20 + 4 | 0;
 i12 = i20;
 switch (HEAP32[i2 + 4 >> 2] & 74 | 0) {
 case 64:
  {
   i14 = 8;
   break;
  }
 case 8:
  {
   i14 = 16;
   break;
  }
 case 0:
  {
   i14 = 0;
   break;
  }
 default:
  i14 = 10;
 }
 __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc(i19, i2, i11, i3);
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i18 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i18 + 11 | 0;
 i10 = i18 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i1, 0);
 i6 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
 HEAP32[i15 >> 2] = i6;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i12 >> 2] = 0;
 i8 = i18 + 4 | 0;
 i7 = HEAP8[i3 >> 0] | 0;
 i1 = HEAP32[i21 >> 2] | 0;
 i3 = i6;
 L13 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i21 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i2 = (i1 | 0) == 0;
  i4 = HEAP32[i22 >> 2] | 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) != (HEAP32[i4 + 16 >> 2] | 0)) if (i2) break; else break L13;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) != -1) if (i2) break; else break L13; else {
    HEAP32[i22 >> 2] = 0;
    i24 = 20;
    break;
   }
  } else i24 = 20; while (0);
  if ((i24 | 0) == 20) {
   i24 = 0;
   if (i2) {
    i4 = 0;
    break;
   } else i4 = 0;
  }
  i5 = HEAP8[i9 >> 0] | 0;
  i5 = i5 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i5 & 255;
  if ((HEAP32[i15 >> 2] | 0) == (i3 + i5 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i5 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i2 = (HEAP32[i10 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i18, i2, 0);
   i3 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i18 >> 2] | 0 : i18;
   HEAP32[i15 >> 2] = i3 + i5;
  }
  i5 = i1 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i2 = HEAPU8[i2 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_(i2 & 255, i14, i3, i15, i12, i7, i19, i16, i13, i11) | 0) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i2 + 1;
   continue;
  }
 }
 i11 = HEAP8[i19 + 11 >> 0] | 0;
 i2 = HEAP32[i13 >> 2] | 0;
 if (((i11 << 24 >> 24 < 0 ? HEAP32[i19 + 4 >> 2] | 0 : i11 & 255) | 0) != 0 ? (i2 - i16 | 0) < 160 : 0) {
  i11 = HEAP32[i12 >> 2] | 0;
  i12 = i2 + 4 | 0;
  HEAP32[i13 >> 2] = i12;
  HEAP32[i2 >> 2] = i11;
  i2 = i12;
 }
 i15 = __ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji(i3, HEAP32[i15 >> 2] | 0, i23, i14) | 0;
 HEAP32[i17 >> 2] = i15;
 __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i19, i16, i2, i23);
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i21 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i4) {
  if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
   HEAP32[i22 >> 2] = 0;
   i24 = 45;
   break;
  }
  if (!i1) i24 = 46;
 } else i24 = 45; while (0);
 if ((i24 | 0) == 45 ? i1 : 0) i24 = 46;
 if ((i24 | 0) == 46) HEAP32[i23 >> 2] = HEAP32[i23 >> 2] | 2;
 i24 = HEAP32[i21 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i19);
 STACKTOP = i20;
 return i24 | 0;
}

function __ZN4wasm16PrintSExpression13visitFunctionEPNS_8FunctionE(i12, i10) {
 i12 = i12 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i11 = 0, i13 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i14 + 16 | 0;
 i7 = i14 + 12 | 0;
 i1 = i14 + 8 | 0;
 i5 = i14 + 4 | 0;
 i9 = i14;
 HEAP32[i12 + 24 >> 2] = i10;
 i2 = __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i12 >> 2] | 0, 34611, 1) | 0;
 HEAP32[i7 >> 2] = HEAP32[i10 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i7 >> 2];
 __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i2, i8) | 0;
 i2 = i10 + 32 | 0;
 if (HEAP32[i2 >> 2] | 0) {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i12 >> 2] | 0, HEAP32[i12 + 12 >> 2] | 0) | 0, 34617) | 0;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i7, i8) | 0, 41) | 0;
 }
 i6 = i10 + 8 | 0;
 i7 = i10 + 12 | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 L4 : do if ((i2 | 0) != (i1 | 0)) {
  i4 = i12 + 12 | 0;
  i3 = 0;
  while (1) {
   if (i3 >>> 0 >= i2 - i1 >> 2 >>> 0) break L4;
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i12 >> 2] | 0, HEAP32[i4 >> 2] | 0) | 0;
   i1 = __Z17printMinorOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i12 >> 2] | 0, 34624) | 0;
   i2 = __ZN4wasm16PrintSExpression14printableLocalEj(i12, i3) | 0;
   HEAP32[i5 >> 2] = i2;
   HEAP32[i8 >> 2] = HEAP32[i5 >> 2];
   i1 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i1, i8) | 0, 32) | 0;
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i1, __ZN4wasm13printWasmTypeENS_8WasmTypeE(__ZN4wasm8Function12getLocalTypeEj(i10, i3) | 0) | 0) | 0, 56966) | 0;
   i1 = HEAP32[i6 >> 2] | 0;
   i2 = HEAP32[i7 >> 2] | 0;
   i3 = i3 + 1 | 0;
  }
 } while (0);
 i1 = i10 + 4 | 0;
 if (HEAP32[i1 >> 2] | 0) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i12 >> 2] | 0, HEAP32[i12 + 12 >> 2] | 0) | 0;
  i5 = __Z17printMinorOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i12 >> 2] | 0, 34592) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i5, __ZN4wasm13printWasmTypeENS_8WasmTypeE(HEAP32[i1 >> 2] | 0) | 0) | 0, 56966) | 0;
 }
 __ZN4wasm16PrintSExpression9incIndentEv(i12);
 i2 = i12 + 4 | 0;
 i3 = i12 + 16 | 0;
 i1 = (HEAP32[i7 >> 2] | 0) - (HEAP32[i6 >> 2] | 0) >> 2;
 while (1) {
  if (i1 >>> 0 >= (__ZN4wasm8Function12getNumLocalsEv(i10) | 0) >>> 0) break;
  __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i12 >> 2] | 0, HEAP32[i2 >> 2] | 0) | 0;
  i7 = __Z17printMinorOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i12 >> 2] | 0, 34631) | 0;
  i6 = __ZN4wasm16PrintSExpression14printableLocalEj(i12, i1) | 0;
  HEAP32[i9 >> 2] = i6;
  HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i7, i8) | 0, 32) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i7, __ZN4wasm13printWasmTypeENS_8WasmTypeE(__ZN4wasm8Function12getLocalTypeEj(i10, i1) | 0) | 0) | 0, 56966) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i12 >> 2] | 0, HEAP32[i3 >> 2] | 0) | 0;
  i1 = i1 + 1 | 0;
 }
 i1 = i10 + 36 | 0;
 L17 : do if (((HEAP8[i12 + 20 >> 0] | 0) == 0 ? (i11 = HEAP32[i1 >> 2] | 0, (HEAP32[i11 >> 2] | 0) == 1) : 0) ? (i11 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(i11) | 0) + 8 | 0, (HEAP32[i11 >> 2] | 0) == 0) : 0) {
  i2 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
  i1 = i2 + 12 | 0;
  i2 = HEAP32[i2 + 20 >> 2] | 0;
  i3 = 0;
  while (1) {
   if ((i3 | 0) == (i2 | 0)) break L17;
   i11 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i3) | 0;
   __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i12, HEAP32[i11 >> 2] | 0);
   i3 = i3 + 1 | 0;
  }
 } else i13 = 18; while (0);
 if ((i13 | 0) == 18) __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i12, HEAP32[i1 >> 2] | 0);
 __ZN4wasm16PrintSExpression9decIndentEv(i12);
 STACKTOP = i14;
 return;
}

function __ZN4wasm17WasmBinaryBuilder10visitBlockEPNS_5BlockE(i16, i1) {
 i16 = i16 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0;
 i18 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i10 = i18 + 20 | 0;
 i11 = i18 + 16 | 0;
 i17 = i18 + 4 | 0;
 i14 = i18;
 HEAP32[i11 >> 2] = i1;
 i15 = i16 + 12 | 0;
 if (HEAP8[i15 >> 0] | 0) {
  i13 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23988) | 0;
  i12 = __ZNKSt3__28ios_base6getlocEv(i13 + (HEAP32[(HEAP32[i13 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i10 >> 2] = i12;
  i12 = __ZNKSt3__26locale9use_facetERNS0_2idE(i10, 61680) | 0;
  i12 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i12 >> 2] | 0) + 28 >> 2] & 63](i12, 10) | 0;
  __ZNSt3__26localeD2Ev(i10);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i13, i12) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i13) | 0;
 }
 HEAP32[i17 >> 2] = 0;
 i12 = i17 + 4 | 0;
 HEAP32[i12 >> 2] = 0;
 HEAP32[i17 + 8 >> 2] = 0;
 i13 = i16 + 88 | 0;
 i4 = i16 + 92 | 0;
 i5 = i16 + 84 | 0;
 i6 = i17 + 8 | 0;
 i7 = i16 + 4 | 0;
 while (1) {
  i2 = __ZN4wasm17WasmBinaryBuilder12getNextLabelEv(i16) | 0;
  HEAP32[i1 + 8 >> 2] = i2;
  i3 = HEAP32[i13 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i4 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i5, i1 + 8 | 0); else {
   HEAP32[i3 >> 2] = i2;
   HEAP32[i13 >> 2] = (HEAP32[i13 >> 2] | 0) + 4;
  }
  i2 = HEAP32[i12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm5BlockENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i17, i11); else {
   HEAP32[i2 >> 2] = i1;
   HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) + 4;
  }
  if ((__ZN4wasm17WasmBinaryBuilder7getInt8Ev(i16) | 0) << 24 >> 24 != 1) break;
  i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i7 >> 2] | 0) | 0;
  HEAP32[i11 >> 2] = i1;
 }
 __ZN4wasm17WasmBinaryBuilder9ungetInt8Ev(i16);
 i7 = i16 + 96 | 0;
 i8 = i16 + 100 | 0;
 i9 = i16 + 104 | 0;
 i4 = 0;
 L16 : while (1) {
  i6 = HEAP32[i12 >> 2] | 0;
  i1 = i6;
  if ((i6 | 0) == (HEAP32[i17 >> 2] | 0)) {
   i1 = 31;
   break;
  }
  i2 = i1 + -4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  HEAP32[i11 >> 2] = i3;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i6 = i1 + -4 | 0;
   HEAP32[i12 >> 2] = i6;
   i1 = i6;
  }
  i1 = HEAP32[i8 >> 2] | 0;
  i6 = i1 - (HEAP32[i7 >> 2] | 0) >> 2;
  do if (i4) {
   HEAP32[i14 >> 2] = i4;
   if (i1 >>> 0 < (HEAP32[i9 >> 2] | 0) >>> 0) {
    HEAP32[i1 >> 2] = i4;
    HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + 4;
    i5 = HEAP32[i11 >> 2] | 0;
    break;
   } else {
    __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i7, i14);
    i5 = i3;
    break;
   }
  } else i5 = i3; while (0);
  __ZN4wasm17WasmBinaryBuilder18processExpressionsEv(i16);
  i1 = (HEAP32[i8 >> 2] | 0) - (HEAP32[i7 >> 2] | 0) >> 2;
  if (i1 >>> 0 < i6 >>> 0) {
   i1 = 23;
   break;
  }
  i2 = i5 + 12 | 0;
  i3 = i5 + 20 | 0;
  i4 = i6;
  while (1) {
   if (i4 >>> 0 >= i1 >>> 0) break;
   if (HEAP8[i15 >> 0] | 0) {
    i19 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 34501) | 0;
    i19 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i19, HEAP32[(HEAP32[i7 >> 2] | 0) + (i4 << 2) >> 2] | 0) | 0, 24027) | 0;
    i19 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i19, HEAP32[i3 >> 2] | 0) | 0;
    i20 = __ZNKSt3__28ios_base6getlocEv(i19 + (HEAP32[(HEAP32[i19 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
    HEAP32[i10 >> 2] = i20;
    i20 = __ZNKSt3__26locale9use_facetERNS0_2idE(i10, 61680) | 0;
    i20 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i20 >> 2] | 0) + 28 >> 2] & 63](i20, 10) | 0;
    __ZNSt3__26localeD2Ev(i10);
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i19, i20) | 0;
    __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i19) | 0;
   }
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, HEAP32[(HEAP32[i7 >> 2] | 0) + (i4 << 2) >> 2] | 0);
   i4 = i4 + 1 | 0;
  }
  __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE6resizeEj(i7, i6);
  __ZN4wasm5Block8finalizeEv(HEAP32[i11 >> 2] | 0);
  i1 = HEAP32[i13 >> 2] | 0;
  i2 = i1 + -4 | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) {
    i4 = i5;
    continue L16;
   }
   i20 = i1 + -4 | 0;
   HEAP32[i13 >> 2] = i20;
   i1 = i20;
  }
 }
 if ((i1 | 0) == 23) ___assert_fail(24003, 22948, 1719, 24016); else if ((i1 | 0) == 31) {
  __ZNSt3__213__vector_baseIPN4wasm5BlockENS_9allocatorIS3_EEED2Ev(i17);
  STACKTOP = i18;
  return;
 }
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv(i1, i20, i21, i3, i22, i16) {
 i1 = i1 | 0;
 i20 = i20 | 0;
 i21 = i21 | 0;
 i3 = i3 | 0;
 i22 = i22 | 0;
 i16 = i16 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i17 = 0, i18 = 0, i19 = 0, i23 = 0;
 i19 = STACKTOP;
 STACKTOP = STACKTOP + 240 | 0;
 i15 = i19;
 i10 = i19 + 208 | 0;
 i18 = i19 + 196 | 0;
 i1 = i19 + 180 | 0;
 i17 = i19 + 184 | 0;
 i14 = i19 + 176 | 0;
 i12 = i19 + 16 | 0;
 i13 = i19 + 8 | 0;
 i11 = i19 + 4 | 0;
 HEAP32[i18 >> 2] = 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i18 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 i9 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
 HEAP32[i1 >> 2] = i9;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 32 >> 2] & 7](i1, 53246, 53272, i10) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i9) | 0;
 HEAP32[i17 >> 2] = 0;
 HEAP32[i17 + 4 >> 2] = 0;
 HEAP32[i17 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i17 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = i17 + 11 | 0;
 i8 = i17 + 8 | 0;
 if ((HEAP8[i9 >> 0] | 0) < 0) i1 = (HEAP32[i8 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i17, i1, 0);
 i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i17 >> 2] | 0 : i17;
 HEAP32[i14 >> 2] = i2;
 HEAP32[i13 >> 2] = i12;
 HEAP32[i11 >> 2] = 0;
 i7 = i17 + 4 | 0;
 i1 = HEAP32[i20 >> 2] | 0;
 L12 : while (1) {
  if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
    HEAP32[i20 >> 2] = 0;
    i1 = 0;
   }
  } else i1 = 0;
  i4 = (i1 | 0) == 0;
  i3 = HEAP32[i21 >> 2] | 0;
  do if (i3) {
   if ((HEAP32[i3 + 12 >> 2] | 0) != (HEAP32[i3 + 16 >> 2] | 0)) if (i4) break; else break L12;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0) != -1) if (i4) break; else break L12; else {
    HEAP32[i21 >> 2] = 0;
    i23 = 19;
    break;
   }
  } else i23 = 19; while (0);
  if ((i23 | 0) == 19) {
   i23 = 0;
   if (i4) {
    i3 = 0;
    break;
   } else i3 = 0;
  }
  i4 = HEAP8[i9 >> 0] | 0;
  i4 = i4 << 24 >> 24 < 0 ? HEAP32[i7 >> 2] | 0 : i4 & 255;
  if ((HEAP32[i14 >> 2] | 0) == (i2 + i4 | 0)) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i17, i4 << 1, 0);
   if ((HEAP8[i9 >> 0] | 0) < 0) i2 = (HEAP32[i8 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i17, i2, 0);
   i2 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i17 >> 2] | 0 : i17;
   HEAP32[i14 >> 2] = i2 + i4;
  }
  i5 = i1 + 12 | 0;
  i4 = HEAP32[i5 >> 2] | 0;
  i6 = i1 + 16 | 0;
  if ((i4 | 0) == (HEAP32[i6 >> 2] | 0)) i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i4 = HEAPU8[i4 >> 0] | 0;
  if (__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_(i4 & 255, 16, i2, i14, i11, 0, i18, i12, i13, i10) | 0) break;
  i3 = HEAP32[i5 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i6 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i5 >> 2] = i3 + 1;
   continue;
  }
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i17, (HEAP32[i14 >> 2] | 0) - i2 | 0, 0);
 i13 = (HEAP8[i9 >> 0] | 0) < 0 ? HEAP32[i17 >> 2] | 0 : i17;
 i14 = __ZNSt3__26__clocEv() | 0;
 HEAP32[i15 >> 2] = i16;
 if ((__ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z(i13, i14, 53281, i15) | 0) != 1) HEAP32[i22 >> 2] = 4;
 if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i20 >> 2] = 0;
   i1 = 0;
  }
 } else i1 = 0;
 i1 = (i1 | 0) == 0;
 do if (i3) {
  if ((HEAP32[i3 + 12 >> 2] | 0) == (HEAP32[i3 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0) == -1 : 0) {
   HEAP32[i21 >> 2] = 0;
   i23 = 43;
   break;
  }
  if (!i1) i23 = 44;
 } else i23 = 43; while (0);
 if ((i23 | 0) == 43 ? i1 : 0) i23 = 44;
 if ((i23 | 0) == 44) HEAP32[i22 >> 2] = HEAP32[i22 >> 2] | 2;
 i23 = HEAP32[i20 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i17);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i18);
 STACKTOP = i19;
 return i23 | 0;
}

function __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 if (!i2) ___assert_fail(41743, 49642, 68, 41748);
 do switch (HEAP32[i2 >> 2] | 0) {
 case 1:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner10visitBlockEPNS_5BlockE(i1, i3, i2);
   break;
  }
 case 2:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner7visitIfEPNS_2IfE(i1, i3, i2);
   break;
  }
 case 3:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner9visitLoopEPNS_4LoopE(i1, i3, i2);
   break;
  }
 case 4:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner10visitBreakEPNS_5BreakE(i1, i3, i2);
   break;
  }
 case 5:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11visitSwitchEPNS_6SwitchE(i1, i3, i2);
   break;
  }
 case 6:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner9visitCallEPNS_4CallE(i1, i3, i2);
   break;
  }
 case 7:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner15visitCallImportEPNS_10CallImportE(i1, i3, i2);
   break;
  }
 case 8:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner17visitCallIndirectEPNS_12CallIndirectE(i1, i3, i2);
   break;
  }
 case 9:
  {
   i3 = (HEAP32[HEAP32[i3 + 4 >> 2] >> 2] | 0) + (HEAP32[i2 + 8 >> 2] << 4) | 0;
   HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
   HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
   HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
   HEAP32[i1 + 16 >> 2] = 0;
   break;
  }
 case 10:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner13visitSetLocalEPNS_8SetLocalE(i1, i3, i2);
   break;
  }
 case 11:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner9visitLoadEPNS_4LoadE(i1, i3, i2);
   break;
  }
 case 12:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner10visitStoreEPNS_5StoreE(i1, i3, i2);
   break;
  }
 case 13:
  {
   i3 = i2 + 8 | 0;
   HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
   HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
   HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
   HEAP32[i1 + 16 >> 2] = 0;
   break;
  }
 case 14:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner10visitUnaryEPNS_5UnaryE(i1, i3, i2);
   break;
  }
 case 15:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11visitBinaryEPNS_6BinaryE(i1, i3, i2);
   break;
  }
 case 16:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11visitSelectEPNS_6SelectE(i1, i3, i2);
   break;
  }
 case 17:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11visitReturnEPNS_6ReturnE(i1, i3, i2);
   break;
  }
 case 18:
  {
   __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner9visitHostEPNS_4HostE(i1, i3, i2);
   break;
  }
 case 19:
  {
   HEAP32[i1 >> 2] = 0;
   i3 = i1 + 8 | 0;
   HEAP32[i3 >> 2] = 0;
   HEAP32[i3 + 4 >> 2] = 0;
   HEAP32[i1 + 16 >> 2] = 0;
   break;
  }
 case 20:
  {
   i3 = HEAP32[(HEAP32[i3 >> 2] | 0) + 24 >> 2] | 0;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i3 >> 2] | 0) + 20 >> 2] & 1023](i3, 36141);
   HEAP32[i1 >> 2] = 0;
   i3 = i1 + 8 | 0;
   HEAP32[i3 >> 2] = 0;
   HEAP32[i3 + 4 >> 2] = 0;
   HEAP32[i1 + 16 >> 2] = 0;
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZNSt3__26locale5__impC2Ej(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 HEAP32[i4 + 4 >> 2] = i1 + -1;
 HEAP32[i4 >> 2] = 14916;
 i1 = i4 + 8 | 0;
 __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEEC2Ej(i1, 28);
 i2 = i4 + 144 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i2, 53279, 1);
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = i4 + 12 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 HEAP32[14681] = 0;
 HEAP32[14680] = 12580;
 __ZNSt3__26locale5__imp7installINS_7collateIcEEEEvPT_(i4, 58720);
 HEAP32[14683] = 0;
 HEAP32[14682] = 12612;
 __ZNSt3__26locale5__imp7installINS_7collateIwEEEEvPT_(i4, 58728);
 __ZNSt3__25ctypeIcEC2EPKtbj(58736, 0, 0, 1);
 __ZNSt3__26locale5__imp7installINS_5ctypeIcEEEEvPT_(i4, 58736);
 HEAP32[14689] = 0;
 HEAP32[14688] = 15132;
 __ZNSt3__26locale5__imp7installINS_5ctypeIwEEEEvPT_(i4, 58752);
 HEAP32[14691] = 0;
 HEAP32[14690] = 15200;
 __ZNSt3__26locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_(i4, 58760);
 HEAP32[14693] = 0;
 HEAP32[14692] = 14868;
 i5 = __ZNSt3__26__clocEv() | 0;
 HEAP32[14694] = i5;
 __ZNSt3__26locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_(i4, 58768);
 HEAP32[14697] = 0;
 HEAP32[14696] = 15248;
 __ZNSt3__26locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_(i4, 58784);
 HEAP32[14699] = 0;
 HEAP32[14698] = 15296;
 __ZNSt3__26locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_(i4, 58792);
 __ZNSt3__28numpunctIcEC2Ej(58800, 1);
 __ZNSt3__26locale5__imp7installINS_8numpunctIcEEEEvPT_(i4, 58800);
 __ZNSt3__28numpunctIwEC2Ej(58824, 1);
 __ZNSt3__26locale5__imp7installINS_8numpunctIwEEEEvPT_(i4, 58824);
 HEAP32[14715] = 0;
 HEAP32[14714] = 12644;
 __ZNSt3__26locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i4, 58856);
 HEAP32[14717] = 0;
 HEAP32[14716] = 12708;
 __ZNSt3__26locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i4, 58864);
 HEAP32[14719] = 0;
 HEAP32[14718] = 12772;
 __ZNSt3__26locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i4, 58872);
 HEAP32[14721] = 0;
 HEAP32[14720] = 12824;
 __ZNSt3__26locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i4, 58880);
 HEAP32[14723] = 0;
 HEAP32[14722] = 14372;
 __ZNSt3__26locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_(i4, 58888);
 HEAP32[14725] = 0;
 HEAP32[14724] = 14428;
 __ZNSt3__26locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_(i4, 58896);
 HEAP32[14727] = 0;
 HEAP32[14726] = 14484;
 __ZNSt3__26locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_(i4, 58904);
 HEAP32[14729] = 0;
 HEAP32[14728] = 14540;
 __ZNSt3__26locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_(i4, 58912);
 HEAP32[14731] = 0;
 HEAP32[14730] = 14596;
 __ZNSt3__26locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i4, 58920);
 HEAP32[14733] = 0;
 HEAP32[14732] = 14624;
 __ZNSt3__26locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i4, 58928);
 HEAP32[14735] = 0;
 HEAP32[14734] = 14652;
 __ZNSt3__26locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i4, 58936);
 HEAP32[14737] = 0;
 HEAP32[14736] = 14680;
 __ZNSt3__26locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i4, 58944);
 HEAP32[14739] = 0;
 HEAP32[14738] = 12876;
 HEAP32[14740] = 12924;
 __ZNSt3__26locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i4, 58952);
 HEAP32[14743] = 0;
 HEAP32[14742] = 12960;
 HEAP32[14744] = 13008;
 __ZNSt3__26locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i4, 58968);
 HEAP32[14747] = 0;
 HEAP32[14746] = 15112;
 i5 = __ZNSt3__26__clocEv() | 0;
 HEAP32[14748] = i5;
 HEAP32[14746] = 14324;
 __ZNSt3__26locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i4, 58984);
 HEAP32[14751] = 0;
 HEAP32[14750] = 15112;
 i5 = __ZNSt3__26__clocEv() | 0;
 HEAP32[14752] = i5;
 HEAP32[14750] = 14348;
 __ZNSt3__26locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i4, 59e3);
 HEAP32[14755] = 0;
 HEAP32[14754] = 14708;
 __ZNSt3__26locale5__imp7installINS_8messagesIcEEEEvPT_(i4, 59016);
 HEAP32[14757] = 0;
 HEAP32[14756] = 14740;
 __ZNSt3__26locale5__imp7installINS_8messagesIwEEEEvPT_(i4, 59024);
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4scanEPS1_PPNS_10ExpressionE(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 L1 : do switch (HEAP32[i2 >> 2] | 0) {
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 470, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 471, i3);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i2) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i1 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 472, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 473, i3);
   i4 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 16 | 0;
   if (HEAP32[i4 >> 2] | 0) {
    __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 469, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 16 | 0);
    __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 474, i3);
   }
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 469, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 475, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 469, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 476, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 477, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i2) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 478, i3);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 479, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 480, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i2) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i2) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 481, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 482, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i2) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i2) | 0) + 28 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 483, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 484, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 469, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i2) | 0) + 8 | 0);
   break;
  }
 case 20:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 483, i3);
   __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 485, i3);
   break;
  }
 default:
  __ZN4wasm10PostWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i3);
 } while (0);
 return;
}

function __ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE(i13, i15, i14, i16, i18, i17, i1) {
 i13 = i13 | 0;
 i15 = i15 | 0;
 i14 = i14 | 0;
 i16 = i16 | 0;
 i18 = i18 | 0;
 i17 = i17 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i12 = i20;
 i11 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
 i9 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61692) | 0;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[i9 >> 2] | 0) + 20 >> 2] & 1023](i12, i9);
 HEAP32[i17 >> 2] = i16;
 i1 = HEAP8[i13 >> 0] | 0;
 switch (i1 << 24 >> 24) {
 case 43:
 case 45:
  {
   i10 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 28 >> 2] & 63](i11, i1) | 0;
   i2 = HEAP32[i17 >> 2] | 0;
   HEAP32[i17 >> 2] = i2 + 1;
   HEAP8[i2 >> 0] = i10;
   i2 = i13 + 1 | 0;
   break;
  }
 default:
  i2 = i13;
 }
 i10 = i14;
 L4 : do if ((i10 - i2 | 0) > 1 ? (HEAP8[i2 >> 0] | 0) == 48 : 0) {
  i1 = i2 + 1 | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 88:
  case 120:
   break;
  default:
   {
    i1 = i2;
    i19 = 10;
    break L4;
   }
  }
  i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 28 >> 2] & 63](i11, 48) | 0;
  i8 = HEAP32[i17 >> 2] | 0;
  HEAP32[i17 >> 2] = i8 + 1;
  HEAP8[i8 >> 0] = i7;
  i2 = i2 + 2 | 0;
  i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 28 >> 2] & 63](i11, HEAP8[i1 >> 0] | 0) | 0;
  i1 = HEAP32[i17 >> 2] | 0;
  HEAP32[i17 >> 2] = i1 + 1;
  HEAP8[i1 >> 0] = i8;
  i1 = i2;
  while (1) {
   if (i1 >>> 0 >= i14 >>> 0) break L4;
   i8 = HEAP8[i1 >> 0] | 0;
   if (!(_isxdigit_l(i8, __ZNSt3__26__clocEv() | 0) | 0)) break L4;
   i1 = i1 + 1 | 0;
  }
 } else {
  i1 = i2;
  i19 = 10;
 } while (0);
 L12 : do if ((i19 | 0) == 10) while (1) {
  i19 = 0;
  if (i1 >>> 0 >= i14 >>> 0) break L12;
  i8 = HEAP8[i1 >> 0] | 0;
  if (!(_isdigit_l(i8, __ZNSt3__26__clocEv() | 0) | 0)) break L12;
  i1 = i1 + 1 | 0;
  i19 = 10;
 } while (0);
 i7 = i12 + 11 | 0;
 i6 = HEAP8[i7 >> 0] | 0;
 i8 = i12 + 4 | 0;
 L18 : do if ((i6 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i6 & 255) | 0) {
  L21 : do if ((i2 | 0) != (i1 | 0)) {
   i3 = i1;
   i4 = i2;
   while (1) {
    i3 = i3 + -1 | 0;
    if (i4 >>> 0 >= i3 >>> 0) break L21;
    i6 = HEAP8[i4 >> 0] | 0;
    HEAP8[i4 >> 0] = HEAP8[i3 >> 0] | 0;
    HEAP8[i3 >> 0] = i6;
    i4 = i4 + 1 | 0;
   }
  } while (0);
  i5 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i9 >> 2] | 0) + 16 >> 2] & 255](i9) | 0;
  i3 = 0;
  i4 = 0;
  i6 = i2;
  while (1) {
   if (i6 >>> 0 >= i1 >>> 0) break;
   i21 = HEAP8[((HEAP8[i7 >> 0] | 0) < 0 ? HEAP32[i12 >> 2] | 0 : i12) + i4 >> 0] | 0;
   if (i21 << 24 >> 24 > 0 & (i3 | 0) == (i21 << 24 >> 24 | 0)) {
    i21 = HEAP32[i17 >> 2] | 0;
    HEAP32[i17 >> 2] = i21 + 1;
    HEAP8[i21 >> 0] = i5;
    i21 = HEAP8[i7 >> 0] | 0;
    i3 = 0;
    i4 = (i4 >>> 0 < ((i21 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i21 & 255) + -1 | 0) >>> 0 & 1) + i4 | 0;
   }
   i22 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 28 >> 2] & 63](i11, HEAP8[i6 >> 0] | 0) | 0;
   i21 = HEAP32[i17 >> 2] | 0;
   HEAP32[i17 >> 2] = i21 + 1;
   HEAP8[i21 >> 0] = i22;
   i3 = i3 + 1 | 0;
   i6 = i6 + 1 | 0;
  }
  i3 = i16 + (i2 - i13) | 0;
  i2 = HEAP32[i17 >> 2] | 0;
  if ((i3 | 0) == (i2 | 0)) i3 = i11; else while (1) {
   i2 = i2 + -1 | 0;
   if (i3 >>> 0 >= i2 >>> 0) {
    i3 = i11;
    break L18;
   }
   i22 = HEAP8[i3 >> 0] | 0;
   HEAP8[i3 >> 0] = HEAP8[i2 >> 0] | 0;
   HEAP8[i2 >> 0] = i22;
   i3 = i3 + 1 | 0;
  }
 } else {
  FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i11 >> 2] | 0) + 32 >> 2] & 7](i11, i2, i1, HEAP32[i17 >> 2] | 0) | 0;
  HEAP32[i17 >> 2] = (HEAP32[i17 >> 2] | 0) + (i1 - i2);
  i3 = i11;
 } while (0);
 while (1) {
  if (i1 >>> 0 >= i14 >>> 0) break;
  i2 = HEAP8[i1 >> 0] | 0;
  if (i2 << 24 >> 24 == 46) {
   i19 = 29;
   break;
  }
  i21 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i11, i2) | 0;
  i22 = HEAP32[i17 >> 2] | 0;
  HEAP32[i17 >> 2] = i22 + 1;
  HEAP8[i22 >> 0] = i21;
  i1 = i1 + 1 | 0;
 }
 if ((i19 | 0) == 29) {
  i21 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i9 >> 2] | 0) + 12 >> 2] & 255](i9) | 0;
  i22 = HEAP32[i17 >> 2] | 0;
  HEAP32[i17 >> 2] = i22 + 1;
  HEAP8[i22 >> 0] = i21;
  i1 = i1 + 1 | 0;
 }
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i11 >> 2] | 0) + 32 >> 2] & 7](i11, i1, i14, HEAP32[i17 >> 2] | 0) | 0;
 i22 = (HEAP32[i17 >> 2] | 0) + (i10 - i1) | 0;
 HEAP32[i17 >> 2] = i22;
 HEAP32[i18 >> 2] = (i15 | 0) == (i14 | 0) ? i22 : i16 + (i15 - i13) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i12);
 STACKTOP = i20;
 return;
}

function __ZN4wasm14SimplifyLocals19optimizeBlockReturnEPNS_5BlockE(i18, i13) {
 i18 = i18 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i19 = 0;
 i19 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i15 = i19 + 12 | 0;
 i17 = i19 + 16 | 0;
 i14 = i19 + 8 | 0;
 i7 = i19 + 4 | 0;
 i12 = i19;
 HEAP32[i15 >> 2] = i13;
 i16 = i13;
 if (HEAP32[i13 + 8 >> 2] | 0 ? (i1 = i13 + 8 | 0, (__ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(i18 + 68 | 0, i1) | 0) == 0) : 0) {
  i4 = i18 + 56 | 0;
  i11 = __ZNSt3__23mapIN4wasm4NameENS_6vectorINS1_14SimplifyLocals10BlockBreakENS_9allocatorIS5_EEEENS_4lessIS2_EENS6_INS_4pairIKS2_S8_EEEEEixERSC_(i4, i1) | 0;
  i9 = i17 + 4 | 0;
  i2 = HEAP32[i11 >> 2] | 0;
  HEAP32[i17 >> 2] = i2;
  i6 = i11 + 4 | 0;
  i3 = HEAP32[i6 >> 2] | 0;
  HEAP32[i9 >> 2] = i3;
  i5 = i11 + 8 | 0;
  HEAP32[i17 + 8 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i5 >> 2] = 0;
  HEAP32[i6 >> 2] = 0;
  HEAP32[i11 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE14__erase_uniqueIS3_EEjRKT_(i4, i1) | 0;
  i4 = i2;
  if ((i3 | 0) != (i2 | 0)) {
   if (HEAP32[(HEAP32[i4 >> 2] | 0) + 12 >> 2] | 0) ___assert_fail(42180, 41949, 261, 42201);
   HEAP32[i14 >> 2] = -1;
   i11 = i18 + 44 | 0;
   i5 = i18 + 48 | 0;
   i1 = i3 - i2 >> 4;
   i2 = HEAP32[i11 >> 2] | 0;
   L9 : while (1) {
    if ((i2 | 0) == (i5 | 0)) break;
    i6 = HEAP32[i2 + 16 >> 2] | 0;
    HEAP32[i7 >> 2] = i6;
    i3 = 0;
    while (1) {
     if (i3 >>> 0 >= i1 >>> 0) {
      i8 = 11;
      break L9;
     }
     if (!(__ZNKSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE14__count_uniqueIjEEjRKT_(i4 + (i3 << 4) + 4 | 0, i7) | 0)) break; else i3 = i3 + 1 | 0;
    }
    i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i2) | 0;
   }
   do if ((i8 | 0) == 11) {
    HEAP32[i14 >> 2] = i6;
    i1 = i13 + 20 | 0;
    if (HEAP32[i1 >> 2] | 0 ? (i10 = i13 + 12 | 0, i8 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i10) | 0, (HEAP32[HEAP32[i8 >> 2] >> 2] | 0) == 19) : 0) {
     i2 = __ZNSt3__23mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS3_EEEEE2atERS8_(i11, i14) | 0;
     i2 = HEAP32[i2 >> 2] | 0;
     i5 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i2 >> 2] | 0) | 0) + 12 | 0;
     i5 = HEAP32[i5 >> 2] | 0;
     i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i10, (HEAP32[i1 >> 2] | 0) + -1 | 0) | 0;
     HEAP32[i1 >> 2] = i5;
     HEAP32[i13 + 4 >> 2] = HEAP32[i5 + 4 >> 2];
     i1 = HEAP32[i2 >> 2] | 0;
     HEAP32[i1 >> 2] = 19;
     HEAP32[i1 + 4 >> 2] = 0;
     i1 = HEAP32[i17 >> 2] | 0;
     i2 = (HEAP32[i9 >> 2] | 0) - i1 >> 4;
     i5 = 0;
     while (1) {
      if (i5 >>> 0 >= i2 >>> 0) {
       i8 = 19;
       break;
      }
      i3 = __ZNSt3__23mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS3_EEEEE2atERS8_(i1 + (i5 << 4) + 4 | 0, i14) | 0;
      i3 = HEAP32[i3 >> 2] | 0;
      i4 = i1 + (i5 << 4) | 0;
      if (HEAP32[(HEAP32[i4 >> 2] | 0) + 12 >> 2] | 0) {
       i8 = 21;
       break;
      }
      i10 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i3 >> 2] | 0) | 0) + 12 | 0;
      HEAP32[(HEAP32[i4 >> 2] | 0) + 12 >> 2] = HEAP32[i10 >> 2];
      i10 = HEAP32[i3 >> 2] | 0;
      HEAP32[i10 >> 2] = 19;
      HEAP32[i10 + 4 >> 2] = 0;
      i5 = i5 + 1 | 0;
     }
     if ((i8 | 0) == 19) {
      HEAP32[i12 >> 2] = (HEAP32[i18 + 40 >> 2] | 0) + 88;
      i16 = __ZN4wasm7Builder12makeSetLocalEjPNS_10ExpressionE(i12, i6, i13) | 0;
      HEAP32[i18 + 20 >> 2] = i16;
      __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5clearEv(i11);
      HEAP8[i18 + 92 >> 0] = 1;
      break;
     } else if ((i8 | 0) == 21) ___assert_fail(42221, 41949, 299, 42201);
    }
    i1 = i18 + 112 | 0;
    i2 = HEAP32[i1 >> 2] | 0;
    if ((i2 | 0) == (HEAP32[i18 + 116 >> 2] | 0)) {
     __ZNSt3__26vectorIPN4wasm5BlockENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i18 + 108 | 0, i15);
     break;
    } else {
     HEAP32[i2 >> 2] = i16;
     HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
     break;
    }
   } while (0);
  }
  __ZNSt3__213__vector_baseIN4wasm14SimplifyLocals10BlockBreakENS_9allocatorIS3_EEED2Ev(i17);
 }
 STACKTOP = i19;
 return;
}

function __ZN4wasm13WasmValidator10visitUnaryEPNS_5UnaryE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = i3 + 12 | 0;
 __ZN4wasm13WasmValidator15shouldBeUnequalIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, HEAP32[(HEAP32[i1 >> 2] | 0) + 4 >> 2] | 0, 0, i3, 19934) | 0;
 i2 = i3 + 8 | 0;
 if ((HEAP32[i2 >> 2] & -2 | 0) == 20) __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, HEAP32[i3 + 4 >> 2] | 0, 1, i3, 19981) | 0;
 i1 = HEAP32[(HEAP32[i1 >> 2] | 0) + 4 >> 2] | 0;
 L4 : do if ((i1 | 0) != 5) do switch (HEAP32[i2 >> 2] | 0) {
 case 19:
 case 17:
 case 15:
 case 13:
 case 11:
 case 9:
 case 7:
 case 5:
 case 3:
 case 1:
 case 18:
 case 16:
 case 14:
 case 12:
 case 10:
 case 8:
 case 6:
 case 4:
 case 2:
 case 0:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, HEAP32[i3 + 4 >> 2] | 0, i3, 20001) | 0;
   break L4;
  }
 case 21:
 case 20:
  {
   __ZN4wasm13WasmValidator12shouldBeTrueIPNS_5UnaryEEEbbT_PKc(i4, (i1 + -1 | 0) >>> 0 < 2, i3, 20050) | 0;
   break L4;
  }
 case 22:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 1, i3, 20079) | 0;
   break L4;
  }
 case 23:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 1, i3, 20079) | 0;
   break L4;
  }
 case 24:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 2, i3, 20107) | 0;
   break L4;
  }
 case 25:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 3, i3, 20133) | 0;
   break L4;
  }
 case 26:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 3, i3, 20133) | 0;
   break L4;
  }
 case 27:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 3, i3, 20133) | 0;
   break L4;
  }
 case 28:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 3, i3, 20133) | 0;
   break L4;
  }
 case 29:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 4, i3, 20133) | 0;
   break L4;
  }
 case 30:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 4, i3, 20133) | 0;
   break L4;
  }
 case 31:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 4, i3, 20133) | 0;
   break L4;
  }
 case 32:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 4, i3, 20133) | 0;
   break L4;
  }
 case 33:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 3, i3, 20160) | 0;
   break L4;
  }
 case 34:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 4, i3, 20197) | 0;
   break L4;
  }
 case 37:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 1, i3, 20234) | 0;
   break L4;
  }
 case 38:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 1, i3, 20234) | 0;
   break L4;
  }
 case 35:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 1, i3, 20234) | 0;
   break L4;
  }
 case 36:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 1, i3, 20234) | 0;
   break L4;
  }
 case 41:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 2, i3, 20234) | 0;
   break L4;
  }
 case 42:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 2, i3, 20234) | 0;
   break L4;
  }
 case 39:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 2, i3, 20234) | 0;
   break L4;
  }
 case 40:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 2, i3, 20234) | 0;
   break L4;
  }
 case 43:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 3, i3, 20263) | 0;
   break L4;
  }
 case 44:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 4, i3, 20292) | 0;
   break L4;
  }
 case 45:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 1, i3, 20320) | 0;
   break L4;
  }
 case 46:
  {
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, 2, i3, 20357) | 0;
   break L4;
  }
 default:
  _abort();
 } while (0); while (0);
 return;
}

function __ZN6cashew9JSPrinter11numToStringEdb(d2, i1) {
 d2 = +d2;
 i1 = i1 | 0;
 var d3 = 0.0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0, i24 = 0, i25 = 0;
 i25 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i19 = i25 + 80 | 0;
 i18 = i25 + 72 | 0;
 i17 = i25 + 64 | 0;
 i21 = i25 + 56 | 0;
 i20 = i25 + 48 | 0;
 i16 = i25 + 40 | 0;
 i15 = i25 + 32 | 0;
 i23 = i25 + 24 | 0;
 i12 = i25 + 16 | 0;
 i13 = i25 + 8 | 0;
 i14 = i25;
 i24 = d2 < 0.0;
 d2 = i24 ? -d2 : d2;
 i10 = +_fmod(d2, 1.0) == 0.0;
 HEAPF64[i23 >> 3] = nan;
 HEAPF64[i12 >> 3] = nan;
 i11 = !(d2 >= 0.0);
 i8 = i1 ^ 1;
 i9 = 0;
 L1 : while (1) {
  if ((i9 | 0) >= 2) {
   i22 = 3;
   break;
  }
  i5 = (i9 | 0) != 0;
  i7 = i5 ? HEAP32[1232] | 0 : HEAP32[1231] | 0;
  L4 : do if (i10) {
   if (i11) {
    i22 = 12;
    break L1;
   }
   if (!(__ZN4wasm12isUInteger64Ed(d2) | 0)) {
    HEAPF64[i18 >> 3] = d2;
    _snprintf(i7, 999, i5 ? 29483 : 29486, i18) | 0;
    HEAP32[i19 >> 2] = i13;
    _sscanf(i7, 29443, i19) | 0;
    break;
   }
   i1 = __ZN4wasm12toUInteger64Ed(d2) | 0;
   i6 = i5 & i8;
   i4 = i20;
   HEAP32[i4 >> 2] = i1;
   HEAP32[i4 + 4 >> 2] = tempRet0;
   _snprintf(i7, 999, i6 ? 29466 : 29473, i20) | 0;
   if (i6) {
    HEAP32[i21 >> 2] = i14;
    _sscanf(i7, 29478, i21) | 0;
    i6 = i14;
    HEAPF64[i13 >> 3] = +((HEAP32[i6 >> 2] | 0) >>> 0) + 4294967296.0 * +((HEAP32[i6 + 4 >> 2] | 0) >>> 0);
    break;
   } else {
    HEAP32[i17 >> 2] = i13;
    _sscanf(i7, 29443, i17) | 0;
    break;
   }
  } else {
   i1 = i5 ? 101 : 102;
   i4 = 0;
   while (1) {
    if ((i4 | 0) >= 19) break L4;
    HEAP8[65614] = 37;
    HEAP8[65615] = 46;
    if ((i4 | 0) < 10) {
     HEAP8[65616] = i4 + 48;
     HEAP8[65617] = i1;
     HEAP8[65618] = 0;
    } else {
     HEAP8[65616] = 49;
     HEAP8[65617] = i4 + 38;
     HEAP8[65618] = i1;
     HEAP8[65619] = 0;
    }
    HEAPF64[i15 >> 3] = d2;
    _snprintf(i7, 999, 65614, i15) | 0;
    HEAP32[i16 >> 2] = i13;
    _sscanf(i7, 29443, i16) | 0;
    if (+HEAPF64[i13 >> 3] == d2) break; else i4 = i4 + 1 | 0;
   }
  } while (0);
  d3 = +Math_abs(+(+HEAPF64[i13 >> 3] - d2));
  HEAPF64[(i5 ? i12 : i23) >> 3] = d3;
  i1 = _strchr(i7, 46) | 0;
  L22 : do if (!i1) {
   if (!(i10 & i5)) {
    i6 = i7 + (_strlen(i7) | 0) + -1 | 0;
    i4 = i7;
    i1 = i6;
    while (1) {
     if ((HEAP8[i1 >> 0] | 0) == 48) {
      if (i1 >>> 0 <= i7 >>> 0) {
       i22 = 30;
       break;
      }
     } else {
      i5 = i1;
      if (!(i1 >>> 0 > i7 >>> 0 & (i5 - i4 | 0) > 24)) {
       i4 = i1;
       break;
      }
     }
     i1 = i1 + -1 | 0;
    }
    if ((i22 | 0) == 30) {
     i22 = 0;
     i5 = i1;
     i4 = i1;
    }
    i1 = i6 - i5 | 0;
    if ((i1 | 0) > 2) {
     HEAP8[i4 + 1 >> 0] = 101;
     if ((i1 | 0) < 10) {
      HEAP8[i4 + 2 >> 0] = i1 + 48;
      HEAP8[i4 + 3 >> 0] = 0;
      break;
     }
     if ((i1 | 0) < 100) {
      HEAP8[i4 + 2 >> 0] = ((i1 | 0) / 10 | 0) + 48;
      HEAP8[i4 + 3 >> 0] = ((i1 | 0) % 10 | 0) + 48;
      HEAP8[i4 + 4 >> 0] = 0;
      break;
     }
     if ((i1 | 0) >= 1e3) {
      i22 = 38;
      break L1;
     }
     HEAP8[i4 + 2 >> 0] = ((i1 | 0) / 100 | 0) + 48;
     HEAP8[i4 + 3 >> 0] = (((i1 | 0) % 100 | 0 | 0) / 10 | 0) + 48;
     HEAP8[i4 + 4 >> 0] = ((i1 | 0) % 10 | 0) + 48;
     HEAP8[i4 + 5 >> 0] = 0;
    }
   }
  } else {
   while (1) {
    i4 = i1 + 1 | 0;
    if (((HEAP8[i4 >> 0] | 0) + -48 & 255) < 10) i1 = i4; else break;
   }
   while (1) {
    if ((HEAP8[i1 >> 0] | 0) == 48) i4 = i1; else break;
    do {
     i5 = i4;
     i4 = i4 + 1 | 0;
     i6 = HEAP8[i4 >> 0] | 0;
     HEAP8[i5 >> 0] = i6;
    } while (i6 << 24 >> 24 != 0);
    i1 = i1 + -1 | 0;
   }
   L49 : while (1) {
    if ((HEAP8[i7 >> 0] | 0) == 48) i4 = i7; else break L22;
    while (1) {
     i1 = i4 + 1 | 0;
     i6 = HEAP8[i1 >> 0] | 0;
     HEAP8[i4 >> 0] = i6;
     if (!(i6 << 24 >> 24)) continue L49; else i4 = i1;
    }
   }
  } while (0);
  i9 = i9 + 1 | 0;
 }
 if ((i22 | 0) == 3) {
  d3 = +HEAPF64[i12 >> 3];
  d2 = +HEAPF64[i23 >> 3];
  if (d3 == d2) {
   i23 = HEAP32[1232] | 0;
   i22 = _strlen(i23) | 0;
   i1 = HEAP32[1231] | 0;
   i22 = i22 >>> 0 < (_strlen(i1) | 0) >>> 0;
   i1 = i22 ? i23 : i1;
  } else i1 = d3 < d2 ? HEAP32[1232] | 0 : HEAP32[1231] | 0;
  if (i24) {
   i1 = i1 + -1 | 0;
   HEAP8[i1 >> 0] = 45;
  }
  STACKTOP = i25;
  return i1 | 0;
 } else if ((i22 | 0) == 12) ___assert_fail(29447, 48272, 872, 29454); else if ((i22 | 0) == 38) ___assert_fail(29491, 48272, 935, 29454);
 return 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN13FunctionScopeC2EPNS_8FunctionES9_(i7, i13, i12) {
 i7 = i7 | 0;
 i13 = i13 | 0;
 i12 = i12 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i14 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i9 = i8 + 8 | 0;
 i1 = i8 + 4 | 0;
 i10 = i8;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i7 + 4 >> 2] = 0;
 HEAP32[i7 + 8 >> 2] = 0;
 HEAP32[i7 + 12 >> 2] = i13;
 i11 = i13 + 8 | 0;
 i6 = i13 + 12 | 0;
 i5 = i12 + 4 | 0;
 if (((HEAP32[i6 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2 | 0) != ((HEAP32[i5 >> 2] | 0) - (HEAP32[i12 >> 2] | 0) >> 4 | 0)) {
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 28164) | 0;
  HEAP32[i1 >> 2] = HEAP32[i13 >> 2];
  HEAP32[i9 >> 2] = HEAP32[i1 >> 2];
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i4, i9) | 0, 28175) | 0;
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i4, (HEAP32[i6 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2) | 0, 28186) | 0;
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i4, (HEAP32[i5 >> 2] | 0) - (HEAP32[i12 >> 2] | 0) >> 4) | 0, 28204) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i9 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i9, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i9);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  _abort();
 }
 __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE6resizeEj(i7, __ZN4wasm8Function12getNumLocalsEv(i13) | 0);
 i1 = 0;
 while (1) {
  if (i1 >>> 0 >= (__ZN4wasm8Function12getNumLocalsEv(i13) | 0) >>> 0) {
   i2 = 5;
   break;
  }
  i14 = HEAP32[i12 >> 2] | 0;
  i4 = HEAP32[i11 >> 2] | 0;
  i2 = (HEAP32[i6 >> 2] | 0) - i4 >> 2 >>> 0 > i1 >>> 0;
  i3 = i14;
  if (i1 >>> 0 < (HEAP32[i5 >> 2] | 0) - i14 >> 4 >>> 0) {
   if (!i2) {
    i2 = 8;
    break;
   }
   i2 = i3 + (i1 << 4) | 0;
   if ((HEAP32[i4 + (i1 << 2) >> 2] | 0) != (HEAP32[i2 >> 2] | 0)) {
    i2 = 10;
    break;
   }
   i14 = (HEAP32[i7 >> 2] | 0) + (i1 << 4) | 0;
   HEAP32[i14 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i14 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   HEAP32[i14 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
   HEAP32[i14 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
  } else {
   if (i2) {
    i2 = 13;
    break;
   }
   i14 = __ZN4wasm8Function12getLocalTypeEj(i13, i1) | 0;
   HEAP32[(HEAP32[i7 >> 2] | 0) + (i1 << 4) >> 2] = i14;
  }
  i1 = i1 + 1 | 0;
 }
 if ((i2 | 0) == 5) {
  STACKTOP = i8;
  return;
 } else if ((i2 | 0) == 8) ___assert_fail(28216, 28043, 167, 28237); else if ((i2 | 0) == 10) {
  i14 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 28164) | 0;
  HEAP32[i10 >> 2] = HEAP32[i13 >> 2];
  HEAP32[i9 >> 2] = HEAP32[i10 >> 2];
  i14 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i14, i9) | 0, 28251) | 0;
  i14 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i14, __ZN4wasm13printWasmTypeENS_8WasmTypeE(HEAP32[(HEAP32[i11 >> 2] | 0) + (i1 << 2) >> 2] | 0) | 0) | 0, 28267) | 0, i1) | 0, 28283) | 0;
  i14 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i14, __ZN4wasm13printWasmTypeENS_8WasmTypeE(HEAP32[(HEAP32[i12 >> 2] | 0) + (i1 << 4) >> 2] | 0) | 0) | 0, 58005) | 0;
  i13 = __ZNKSt3__28ios_base6getlocEv(i14 + (HEAP32[(HEAP32[i14 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i9 >> 2] = i13;
  i13 = __ZNKSt3__26locale9use_facetERNS0_2idE(i9, 61680) | 0;
  i13 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 28 >> 2] & 63](i13, 10) | 0;
  __ZNSt3__26localeD2Ev(i9);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i14, i13) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i14) | 0;
  _abort();
 } else if ((i2 | 0) == 13) ___assert_fail(28290, 28043, 177, 28237);
}

function ___cxa_demangle(i10, i1, i16, i18) {
 i10 = i10 | 0;
 i1 = i1 | 0;
 i16 = i16 | 0;
 i18 = i18 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i17 = 0, i19 = 0;
 i19 = STACKTOP;
 STACKTOP = STACKTOP + 4208 | 0;
 i15 = i19 + 4176 | 0;
 i3 = i19;
 i17 = i19 + 4112 | 0;
 if ((i10 | 0) != 0 ? (i2 = (i1 | 0) != 0, i14 = (i16 | 0) == 0, !(i2 & i14)) : 0) {
  if (i2) i12 = HEAP32[i16 >> 2] | 0; else i12 = 0;
  HEAP32[i3 + 4096 >> 2] = i3;
  i2 = i3;
  HEAP32[i17 >> 2] = 0;
  i13 = i17 + 4 | 0;
  HEAP32[i13 >> 2] = 0;
  HEAP32[i17 + 8 >> 2] = 0;
  HEAP32[i17 + 12 >> 2] = i2;
  i6 = i17 + 16 | 0;
  HEAP32[i6 >> 2] = 0;
  i7 = i17 + 20 | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i17 + 24 >> 2] = 0;
  HEAP32[i17 + 28 >> 2] = i2;
  HEAP32[i17 + 32 >> 2] = 0;
  i3 = i17 + 36 | 0;
  HEAP32[i3 >> 2] = 0;
  HEAP32[i17 + 40 >> 2] = 0;
  i8 = i17 + 44 | 0;
  HEAP32[i8 >> 2] = i2;
  i5 = i17 + 48 | 0;
  i4 = i17 + 61 | 0;
  HEAP32[i5 >> 2] = 0;
  HEAP32[i5 + 4 >> 2] = 0;
  HEAP32[i5 + 8 >> 2] = 0;
  HEAP8[i5 + 12 >> 0] = 0;
  HEAP8[i4 >> 0] = 1;
  i5 = i17 + 32 | 0;
  __ZNSt3__214__split_bufferINS_6vectorINS1_IN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEEERNS5_IS9_Lj4096EEEEC2EjjSB_(i15, 1, 0, i8);
  i8 = i15 + 8 | 0;
  i9 = HEAP32[i8 >> 2] | 0;
  HEAP32[i9 >> 2] = 0;
  HEAP32[i9 + 4 >> 2] = 0;
  HEAP32[i9 + 8 >> 2] = 0;
  HEAP32[i9 + 12 >> 2] = i2;
  HEAP32[i8 >> 2] = i9 + 16;
  __ZNSt3__26vectorINS0_INS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEEENS4_IS8_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS8_RS9_EE(i5, i15);
  __ZNSt3__214__split_bufferINS_6vectorINS1_IN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEEERNS5_IS9_Lj4096EEEED2Ev(i15);
  i8 = i17 + 62 | 0;
  HEAP8[i8 >> 0] = 0;
  HEAP8[i17 + 63 >> 0] = 1;
  HEAP32[i15 >> 2] = 0;
  i9 = i10 + (_strlen(i10) | 0) | 0;
  __ZN10__cxxabiv112_GLOBAL__N_18demangleINS0_2DbEEEvPKcS4_RT_Ri(i10, i9, i17, i15);
  i2 = HEAP32[i15 >> 2] | 0;
  do if (!((i2 | 0) != 0 | (HEAP8[i8 >> 0] | 0) == 0)) {
   i5 = HEAP32[i5 >> 2] | 0;
   if ((i5 | 0) != (HEAP32[i3 >> 2] | 0) ? (HEAP32[i5 >> 2] | 0) != (HEAP32[i5 + 4 >> 2] | 0) : 0) {
    HEAP8[i8 >> 0] = 0;
    HEAP8[i4 >> 0] = 0;
    i2 = HEAP32[i17 >> 2] | 0;
    while (1) {
     i3 = HEAP32[i13 >> 2] | 0;
     if ((i3 | 0) == (i2 | 0)) break;
     i5 = i3 + -24 | 0;
     HEAP32[i13 >> 2] = i5;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i5);
    }
    i2 = HEAP32[i6 >> 2] | 0;
    while (1) {
     i3 = HEAP32[i7 >> 2] | 0;
     if ((i3 | 0) == (i2 | 0)) break;
     i6 = i3 + -16 | 0;
     HEAP32[i7 >> 2] = i6;
     __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i6);
    }
    __ZN10__cxxabiv112_GLOBAL__N_18demangleINS0_2DbEEEvPKcS4_RT_Ri(i10, i9, i17, i15);
    if (!(HEAP8[i8 >> 0] | 0)) {
     i2 = HEAP32[i15 >> 2] | 0;
     i11 = 19;
     break;
    } else {
     HEAP32[i15 >> 2] = -2;
     i1 = 0;
     i2 = -2;
     break;
    }
   } else i11 = 20;
  } else i11 = 19; while (0);
  if ((i11 | 0) == 19) if (!i2) i11 = 20; else i1 = 0;
  do if ((i11 | 0) == 20) {
   i3 = HEAP32[i13 >> 2] | 0;
   i2 = HEAP8[i3 + -24 + 11 >> 0] | 0;
   if (i2 << 24 >> 24 < 0) i4 = HEAP32[i3 + -20 >> 2] | 0; else i4 = i2 & 255;
   i2 = HEAP8[i3 + -12 + 11 >> 0] | 0;
   if (i2 << 24 >> 24 < 0) i2 = HEAP32[i3 + -8 >> 2] | 0; else i2 = i2 & 255;
   i3 = i2 + i4 | 0;
   i2 = i3 + 1 | 0;
   if (i2 >>> 0 > i12 >>> 0) {
    i1 = _realloc(i1, i2) | 0;
    if (!i1) {
     HEAP32[i15 >> 2] = -1;
     i1 = 0;
     i2 = -1;
     break;
    }
    if (!i14) HEAP32[i16 >> 2] = i2;
   } else if (!i1) {
    i1 = 0;
    i2 = 0;
    break;
   }
   i16 = HEAP32[i13 >> 2] | 0;
   i14 = i16 + -12 | 0;
   i2 = HEAP8[i14 + 11 >> 0] | 0;
   i15 = i2 << 24 >> 24 < 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i16 + -24 | 0, i15 ? HEAP32[i14 >> 2] | 0 : i14, i15 ? HEAP32[i16 + -8 >> 2] | 0 : i2 & 255) | 0;
   i2 = (HEAP32[i13 >> 2] | 0) + -24 | 0;
   if ((HEAP8[i2 + 11 >> 0] | 0) < 0) i2 = HEAP32[i2 >> 2] | 0;
   _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
   HEAP8[i1 + i3 >> 0] = 0;
   i2 = 0;
  } while (0);
  if (i18 | 0) HEAP32[i18 >> 2] = i2;
  __ZN10__cxxabiv112_GLOBAL__N_12DbD2Ev(i17);
 } else if (!i18) i1 = 0; else {
  HEAP32[i18 >> 2] = -3;
  i1 = 0;
 }
 STACKTOP = i19;
 return i1 | 0;
}

function __GLOBAL__sub_I_parser_cpp() {
 __ZN6cashew7IString3setEPKcb(59272, 47582, 1);
 __ZN6cashew7IString3setEPKcb(59276, 47591, 1);
 __ZN6cashew7IString3setEPKcb(59280, 49182, 1);
 __ZN6cashew7IString3setEPKcb(59284, 47597, 1);
 __ZN6cashew7IString3setEPKcb(59288, 47602, 1);
 __ZN6cashew7IString3setEPKcb(59292, 47609, 1);
 __ZN6cashew7IString3setEPKcb(59296, 47614, 1);
 __ZN6cashew7IString3setEPKcb(59300, 47618, 1);
 __ZN6cashew7IString3setEPKcb(59304, 47624, 1);
 __ZN6cashew7IString3setEPKcb(59308, 47636, 1);
 __ZN6cashew7IString3setEPKcb(59312, 47643, 1);
 __ZN6cashew7IString3setEPKcb(59316, 47650, 1);
 __ZN6cashew7IString3setEPKcb(59320, 49199, 1);
 __ZN6cashew7IString3setEPKcb(59324, 47653, 1);
 __ZN6cashew7IString3setEPKcb(59328, 47659, 1);
 __ZN6cashew7IString3setEPKcb(59332, 47662, 1);
 __ZN6cashew7IString3setEPKcb(59336, 47666, 1);
 __ZN6cashew7IString3setEPKcb(59340, 47670, 1);
 __ZN6cashew7IString3setEPKcb(59344, 49151, 1);
 __ZN6cashew7IString3setEPKcb(59348, 47674, 1);
 __ZN6cashew7IString3setEPKcb(59352, 47678, 1);
 __ZN6cashew7IString3setEPKcb(59356, 47684, 1);
 __ZN6cashew7IString3setEPKcb(59360, 47690, 1);
 __ZN6cashew7IString3setEPKcb(59364, 47699, 1);
 __ZN6cashew7IString3setEPKcb(59368, 47706, 1);
 __ZN6cashew7IString3setEPKcb(59372, 52363, 1);
 __ZN6cashew7IString3setEPKcb(59376, 52371, 1);
 __ZN6cashew7IString3setEPKcb(59380, 47713, 1);
 __ZN6cashew7IString3setEPKcb(59384, 47722, 1);
 __ZN6cashew7IString3setEPKcb(59388, 47734, 1);
 __ZN6cashew7IString3setEPKcb(59392, 47749, 1);
 __ZN6cashew7IString3setEPKcb(59396, 47763, 1);
 __ZN6cashew7IString3setEPKcb(59400, 47776, 1);
 __ZN6cashew7IString3setEPKcb(59404, 47790, 1);
 __ZN6cashew7IString3setEPKcb(59408, 47802, 1);
 __ZN6cashew7IString3setEPKcb(59412, 47817, 1);
 __ZN6cashew7IString3setEPKcb(59416, 47832, 1);
 __ZN6cashew7IString3setEPKcb(59420, 47845, 1);
 __ZN6cashew7IString3setEPKcb(59424, 47858, 1);
 __ZN6cashew7IString3setEPKcb(59428, 58085, 1);
 __ZN6cashew7IString3setEPKcb(59432, 58036, 1);
 __ZN6cashew7IString3setEPKcb(59436, 58076, 1);
 __ZN6cashew7IString3setEPKcb(59440, 57019, 1);
 __ZN6cashew7IString3setEPKcb(59444, 58012, 1);
 __ZN6cashew7IString3setEPKcb(59448, 58060, 1);
 __ZN6cashew7IString3setEPKcb(59452, 57053, 1);
 __ZN6cashew7IString3setEPKcb(59456, 57596, 1);
 __ZN6cashew7IString3setEPKcb(59460, 58020, 1);
 __ZN6cashew7IString3setEPKcb(59464, 58026, 1);
 __ZN6cashew7IString3setEPKcb(59468, 57011, 1);
 __ZN6cashew7IString3setEPKcb(59472, 58017, 1);
 __ZN6cashew7IString3setEPKcb(59476, 58057, 1);
 __ZN6cashew7IString3setEPKcb(59480, 58007, 1);
 __ZN6cashew7IString3setEPKcb(59484, 58130, 1);
 __ZN6cashew7IString3setEPKcb(59488, 57085, 1);
 __ZN6cashew7IString3setEPKcb(59492, 58135, 1);
 __ZN6cashew7IString3setEPKcb(59496, 58029, 1);
 __ZN6cashew7IString3setEPKcb(59500, 47871, 1);
 __ZN6cashew7IString3setEPKcb(59504, 47875, 1);
 __ZN6cashew7IString3setEPKcb(59508, 47889, 1);
 __ZN6cashew7IString3setEPKcb(59512, 47895, 1);
 __ZN6cashew7IString3setEPKcb(59516, 47902, 1);
 __ZN6cashew7IString3setEPKcb(59520, 47909, 1);
 __ZN6cashew7IString3setEPKcb(59524, 47917, 1);
 __ZN6cashew7IString3setEPKcb(59528, 47924, 1);
 __ZN6cashew7IString3setEPKcb(59532, 47932, 1);
 __ZN6cashew7IString3setEPKcb(59536, 47940, 1);
 __ZN6cashew7IString3setEPKcb(59540, 47948, 1);
 __ZN6cashew7IString3setEPKcb(59544, 67717, 1);
 __ZN6cashew7IString3setEPKcb(59548, 47951, 1);
 __ZN6cashew7IString3setEPKcb(59552, 56964, 1);
 __ZN6cashew7IString3setEPKcb(59556, 47960, 1);
 __ZN6cashew7IString3setEPKcb(59560, 47962, 1);
 __ZN6cashew7IString3setEPKcb(59564, 47964, 1);
 __ZN6cashew7IString3setEPKcb(59568, 57051, 1);
 __ZN6cashew7IString3setEPKcb(59572, 47966, 1);
 __ZN6cashew7IString3setEPKcb(59576, 47968, 1);
 __ZN6cashew7IString3setEPKcb(59580, 49219, 1);
 __ZN6cashew7IString3setEPKcb(59584, 47970, 1);
 __ZN6cashew7IString3setEPKcb(59588, 47978, 1);
 __ZN6cashew7IString3setEPKcb(59592, 58005, 1);
 __ZN6cashew7IString3setEPKcb(59596, 47982, 1);
 __ZN6cashew7IString3setEPKcb(59600, 47986, 1);
 __ZN6cashew7IString3setEPKcb(59604, 47992, 1);
 __ZN6cashew7IString3setEPKcb(59608, 58183, 1);
 __ZN6cashew7IString3setEPKcb(59612, 57024, 1);
 __ZN6cashew10IStringSetC2EPKc(59616, 47999);
 ___cxa_atexit(281, 59616, ___dso_handle | 0) | 0;
 HEAP32[14912] = 0;
 HEAP32[14913] = 0;
 HEAP32[14914] = 0;
 ___cxa_atexit(282, 59648, ___dso_handle | 0) | 0;
 HEAP32[14915] = 0;
 HEAP32[14916] = 0;
 HEAP32[14917] = 0;
 ___cxa_atexit(283, 59660, ___dso_handle | 0) | 0;
 __ZN6cashew4InitC2Ev(65643);
 return;
}

function __ZN4wasm15RemoveUnusedBrs8visitAnyEPS0_PPNS_10ExpressionE(i13, i1) {
 i13 = i13 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i15;
 i8 = i15 + 4 | 0;
 HEAP32[i6 >> 2] = i1;
 i4 = HEAP32[i1 >> 2] | 0;
 i14 = i13 + 48 | 0;
 i5 = i1;
 L1 : do switch (HEAP32[i4 >> 2] | 0) {
 case 4:
  {
   i1 = HEAP32[i14 >> 2] | 0;
   i3 = i13 + 52 | 0;
   i2 = HEAP32[i3 >> 2] | 0;
   while (1) {
    if ((i2 | 0) == (i1 | 0)) break;
    i12 = i2 + -4 | 0;
    HEAP32[i3 >> 2] = i12;
    i2 = i12;
   }
   i12 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i4) | 0) + 16 | 0;
   if (HEAP32[i12 >> 2] | 0) {
    HEAP8[i13 + 45 >> 0] = 0;
    break L1;
   }
   i1 = HEAP32[i3 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i13 + 56 >> 2] | 0)) __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE21__push_back_slow_pathIRKS4_EEvOT_(i14, i6); else {
    HEAP32[i1 >> 2] = i5;
    HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 4;
   }
   HEAP8[i13 + 45 >> 0] = 1;
   break;
  }
 case 17:
  {
   i1 = HEAP32[i14 >> 2] | 0;
   i2 = i13 + 52 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   while (1) {
    if ((i3 | 0) == (i1 | 0)) break;
    i12 = i3 + -4 | 0;
    HEAP32[i2 >> 2] = i12;
    i3 = i12;
   }
   if ((i1 | 0) == (HEAP32[i13 + 56 >> 2] | 0)) __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE21__push_back_slow_pathIRKS4_EEvOT_(i14, i6); else {
    HEAP32[i1 >> 2] = i5;
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
   }
   HEAP8[i13 + 45 >> 0] = 1;
   break;
  }
 case 2:
  {
   i12 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i4) | 0) + 16 | 0;
   if (HEAP32[i12 >> 2] | 0) {
    i7 = i13 + 64 | 0;
    i12 = HEAP32[i7 >> 2] | 0;
    i1 = i12;
    if ((i12 | 0) == (HEAP32[i13 + 60 >> 2] | 0)) ___assert_fail(38241, 38266, 66, 38297);
    i5 = HEAP32[i1 + -8 >> 2] | 0;
    i6 = i13 + 52 | 0;
    i4 = i13 + 56 | 0;
    i3 = HEAP32[i1 + -12 >> 2] | 0;
    while (1) {
     if ((i3 | 0) == (i5 | 0)) break;
     i1 = HEAP32[i3 >> 2] | 0;
     HEAP32[i8 >> 2] = i1;
     i2 = HEAP32[i6 >> 2] | 0;
     if ((i2 | 0) == (HEAP32[i4 >> 2] | 0)) __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE21__push_back_slow_pathIRKS4_EEvOT_(i14, i8); else {
      HEAP32[i2 >> 2] = i1;
      HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + 4;
     }
     i3 = i3 + 4 | 0;
    }
    i2 = HEAP32[i7 >> 2] | 0;
    i1 = i2 + -12 | 0;
    while (1) {
     if ((i2 | 0) == (i1 | 0)) break L1;
     i14 = i2 + -12 | 0;
     HEAP32[i7 >> 2] = i14;
     __ZNSt3__213__vector_baseIPPN4wasm10ExpressionENS_9allocatorIS4_EEED2Ev(i14);
     i2 = HEAP32[i7 >> 2] | 0;
    }
   }
   break;
  }
 case 1:
  {
   i10 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i4) | 0;
   i8 = HEAP32[i10 + 8 >> 2] | 0;
   if (i8 | 0) {
    i9 = (HEAP32[i13 + 52 >> 2] | 0) - (HEAP32[i14 >> 2] | 0) >> 2;
    i11 = i13 + 44 | 0;
    i6 = i13 + 45 | 0;
    i7 = 0;
    i1 = 0;
    while (1) {
     if ((i7 | 0) == (i9 | 0)) break;
     i2 = HEAP32[i14 >> 2] | 0;
     i4 = HEAP32[i2 + (i7 << 2) >> 2] | 0;
     i5 = HEAP32[i4 >> 2] | 0;
     i3 = i4;
     do if (!((i5 | 0) == 0 | (HEAP32[i5 >> 2] | 0) != 4) ? (HEAP32[i5 + 8 >> 2] | 0) == (i8 | 0) : 0) {
      i2 = HEAP32[i5 + 12 >> 2] | 0;
      if (!i2) {
       HEAP32[i5 >> 2] = 19;
       HEAP32[i5 + 4 >> 2] = 0;
      } else {
       if (!(HEAP8[i6 >> 0] | 0)) break;
       HEAP32[i4 >> 2] = i2;
      }
      HEAP8[i11 >> 0] = 1;
      i1 = i1 + 1 | 0;
     } else i12 = 41; while (0);
     if ((i12 | 0) == 41) {
      i12 = 0;
      if (!i1) i1 = 0; else HEAP32[i2 + (i7 - i1 << 2) >> 2] = i3;
     }
     i7 = i7 + 1 | 0;
    }
    if (i1 | 0) __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE6resizeEj(i14, i9 - i1 | 0);
    i2 = i10 + 12 | 0;
    i1 = i10 + 20 | 0;
    while (1) {
     if (!(HEAP32[i1 >> 2] | 0)) break L1;
     i14 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i2) | 0;
     if ((HEAP32[HEAP32[i14 >> 2] >> 2] | 0) != 19) break L1;
     __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i2, (HEAP32[i1 >> 2] | 0) + -1 | 0);
     HEAP8[i11 >> 0] = 1;
    }
   }
   break;
  }
 case 19:
  {
   HEAP8[i13 + 45 >> 0] = 0;
   break;
  }
 default:
  {
   i1 = HEAP32[i14 >> 2] | 0;
   i2 = i13 + 52 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   while (1) {
    if ((i3 | 0) == (i1 | 0)) break;
    i14 = i3 + -4 | 0;
    HEAP32[i2 >> 2] = i14;
    i3 = i14;
   }
   HEAP8[i13 + 45 >> 0] = 0;
  }
 } while (0);
 STACKTOP = i15;
 return;
}

function __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i12, i14, i15, i11, i6) {
 i12 = i12 | 0;
 i14 = i14 | 0;
 i15 = i15 | 0;
 i11 = i11 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i13 = 0;
 i1 = HEAP32[i12 >> 2] | 0;
 do if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
   HEAP32[i12 >> 2] = 0;
   i1 = 0;
   break;
  } else {
   i1 = HEAP32[i12 >> 2] | 0;
   break;
  }
 } else i1 = 0; while (0);
 i2 = (i1 | 0) == 0;
 i1 = HEAP32[i14 >> 2] | 0;
 do if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i14 >> 2] = 0;
   i13 = 11;
   break;
  }
  if (i2) i13 = 13; else i13 = 12;
 } else i13 = 11; while (0);
 if ((i13 | 0) == 11) if (i2) i13 = 12; else {
  i1 = 0;
  i13 = 13;
 }
 L16 : do if ((i13 | 0) == 12) {
  HEAP32[i15 >> 2] = HEAP32[i15 >> 2] | 6;
  i1 = 0;
 } else if ((i13 | 0) == 13) {
  i2 = HEAP32[i12 >> 2] | 0;
  i3 = HEAP32[i2 + 12 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i2 = HEAPU8[i3 >> 0] | 0;
  i3 = i2 & 255;
  if (i3 << 24 >> 24 > -1 ? (i10 = i11 + 8 | 0, HEAP16[(HEAP32[i10 >> 2] | 0) + (i2 << 24 >> 24 << 1) >> 1] & 2048) : 0) {
   i5 = (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i11 >> 2] | 0) + 36 >> 2] & 31](i11, i3, 0) | 0) << 24 >> 24;
   i2 = HEAP32[i12 >> 2] | 0;
   i3 = i2 + 12 | 0;
   i4 = HEAP32[i3 >> 2] | 0;
   if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) {
    FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
    i8 = i6;
    i7 = i1;
    i6 = i1;
    i1 = i5;
   } else {
    HEAP32[i3 >> 2] = i4 + 1;
    i8 = i6;
    i7 = i1;
    i6 = i1;
    i1 = i5;
   }
   while (1) {
    i1 = i1 + -48 | 0;
    i9 = i8 + -1 | 0;
    i2 = HEAP32[i12 >> 2] | 0;
    do if (i2) {
     if ((HEAP32[i2 + 12 >> 2] | 0) == (HEAP32[i2 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) == -1) {
      HEAP32[i12 >> 2] = 0;
      i2 = 0;
      break;
     } else {
      i2 = HEAP32[i12 >> 2] | 0;
      break;
     }
    } else i2 = 0; while (0);
    i4 = (i2 | 0) == 0;
    if (i6) if ((HEAP32[i6 + 12 >> 2] | 0) == (HEAP32[i6 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i6 >> 2] | 0) + 36 >> 2] & 255](i6) | 0) == -1) {
     HEAP32[i14 >> 2] = 0;
     i3 = 0;
     i6 = 0;
    } else {
     i3 = i7;
     i6 = i7;
    } else i3 = i7; else {
     i3 = i7;
     i6 = 0;
    }
    i2 = HEAP32[i12 >> 2] | 0;
    if (!((i8 | 0) > 1 & (i4 ^ (i6 | 0) == 0))) break;
    i4 = HEAP32[i2 + 12 >> 2] | 0;
    if ((i4 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i2 = HEAPU8[i4 >> 0] | 0;
    i4 = i2 & 255;
    if (i4 << 24 >> 24 <= -1) break L16;
    if (!(HEAP16[(HEAP32[i10 >> 2] | 0) + (i2 << 24 >> 24 << 1) >> 1] & 2048)) break L16;
    i1 = ((FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i11 >> 2] | 0) + 36 >> 2] & 31](i11, i4, 0) | 0) << 24 >> 24) + (i1 * 10 | 0) | 0;
    i2 = HEAP32[i12 >> 2] | 0;
    i4 = i2 + 12 | 0;
    i5 = HEAP32[i4 >> 2] | 0;
    if ((i5 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) {
     FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
     i8 = i9;
     i7 = i3;
     continue;
    } else {
     HEAP32[i4 >> 2] = i5 + 1;
     i8 = i9;
     i7 = i3;
     continue;
    }
   }
   do if (i2) {
    if ((HEAP32[i2 + 12 >> 2] | 0) == (HEAP32[i2 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) == -1) {
     HEAP32[i12 >> 2] = 0;
     i2 = 0;
     break;
    } else {
     i2 = HEAP32[i12 >> 2] | 0;
     break;
    }
   } else i2 = 0; while (0);
   i2 = (i2 | 0) == 0;
   do if (i3) {
    if ((HEAP32[i3 + 12 >> 2] | 0) == (HEAP32[i3 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0) == -1 : 0) {
     HEAP32[i14 >> 2] = 0;
     i13 = 50;
     break;
    }
    if (i2) break L16;
   } else i13 = 50; while (0);
   if ((i13 | 0) == 50 ? !i2 : 0) break;
   HEAP32[i15 >> 2] = HEAP32[i15 >> 2] | 2;
   break;
  }
  HEAP32[i15 >> 2] = HEAP32[i15 >> 2] | 4;
  i1 = 0;
 } while (0);
 return i1 | 0;
}

function _mbsrtowcs(i5, i10, i1, i3) {
 i5 = i5 | 0;
 i10 = i10 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = HEAP32[i10 >> 2] | 0;
 if ((i3 | 0) != 0 ? (i4 = HEAP32[i3 >> 2] | 0, (i4 | 0) != 0) : 0) if (!i5) {
  i3 = i1;
  i6 = i2;
  i9 = 16;
 } else {
  HEAP32[i3 >> 2] = 0;
  i8 = i5;
  i3 = i1;
  i7 = i4;
  i9 = 37;
 } else if (!i5) {
  i3 = i1;
  i9 = 7;
 } else {
  i4 = i5;
  i3 = i1;
  i9 = 6;
 }
 L7 : while (1) if ((i9 | 0) == 6) {
  if (!i3) {
   i9 = 26;
   break;
  } else i5 = i4;
  while (1) {
   i4 = HEAP8[i2 >> 0] | 0;
   do if (((i4 & 255) + -1 | 0) >>> 0 < 127 ? i3 >>> 0 > 4 & (i2 & 3 | 0) == 0 : 0) {
    i6 = i2;
    while (1) {
     i2 = HEAP32[i6 >> 2] | 0;
     if ((i2 + -16843009 | i2) & -2139062144 | 0) {
      i4 = i2;
      i2 = i6;
      i9 = 32;
      break;
     }
     HEAP32[i5 >> 2] = i2 & 255;
     HEAP32[i5 + 4 >> 2] = HEAPU8[i6 + 1 >> 0];
     HEAP32[i5 + 8 >> 2] = HEAPU8[i6 + 2 >> 0];
     i2 = i6 + 4 | 0;
     i4 = i5 + 16 | 0;
     HEAP32[i5 + 12 >> 2] = HEAPU8[i6 + 3 >> 0];
     i3 = i3 + -4 | 0;
     if (i3 >>> 0 > 4) {
      i5 = i4;
      i6 = i2;
     } else {
      i9 = 31;
      break;
     }
    }
    if ((i9 | 0) == 31) {
     i5 = i4;
     i4 = HEAP8[i2 >> 0] | 0;
     break;
    } else if ((i9 | 0) == 32) {
     i4 = i4 & 255;
     break;
    }
   } while (0);
   i4 = i4 & 255;
   if ((i4 + -1 | 0) >>> 0 >= 127) break;
   i2 = i2 + 1 | 0;
   HEAP32[i5 >> 2] = i4;
   i3 = i3 + -1 | 0;
   if (!i3) {
    i9 = 26;
    break L7;
   } else i5 = i5 + 4 | 0;
  }
  i4 = i4 + -194 | 0;
  if (i4 >>> 0 > 50) {
   i9 = 48;
   break;
  }
  i8 = i5;
  i7 = HEAP32[8196 + (i4 << 2) >> 2] | 0;
  i2 = i2 + 1 | 0;
  i9 = 37;
  continue;
 } else if ((i9 | 0) == 7) {
  i4 = HEAP8[i2 >> 0] | 0;
  if (((i4 & 255) + -1 | 0) >>> 0 < 127 ? (i2 & 3 | 0) == 0 : 0) {
   i9 = HEAP32[i2 >> 2] | 0;
   i4 = i9 & 255;
   if (!((i9 + -16843009 | i9) & -2139062144)) {
    do {
     i2 = i2 + 4 | 0;
     i3 = i3 + -4 | 0;
     i4 = HEAP32[i2 >> 2] | 0;
    } while (((i4 + -16843009 | i4) & -2139062144 | 0) == 0);
    i4 = i4 & 255;
   }
  }
  i4 = i4 & 255;
  if ((i4 + -1 | 0) >>> 0 < 127) {
   i3 = i3 + -1 | 0;
   i2 = i2 + 1 | 0;
   i9 = 7;
   continue;
  }
  i4 = i4 + -194 | 0;
  if (i4 >>> 0 > 50) {
   i9 = 48;
   break;
  }
  i4 = HEAP32[8196 + (i4 << 2) >> 2] | 0;
  i6 = i2 + 1 | 0;
  i9 = 16;
  continue;
 } else if ((i9 | 0) == 16) {
  i9 = (HEAPU8[i6 >> 0] | 0) >>> 3;
  if ((i9 + -16 | i9 + (i4 >> 26)) >>> 0 > 7) {
   i9 = 17;
   break;
  }
  i2 = i6 + 1 | 0;
  if (i4 & 33554432) {
   if ((HEAP8[i2 >> 0] & -64) << 24 >> 24 != -128) {
    i9 = 20;
    break;
   }
   i2 = i6 + 2 | 0;
   if (i4 & 524288) {
    if ((HEAP8[i2 >> 0] & -64) << 24 >> 24 != -128) {
     i9 = 23;
     break;
    }
    i2 = i6 + 3 | 0;
   }
  }
  i3 = i3 + -1 | 0;
  i9 = 7;
  continue;
 } else if ((i9 | 0) == 37) {
  i4 = HEAPU8[i2 >> 0] | 0;
  i9 = i4 >>> 3;
  if ((i9 + -16 | i9 + (i7 >> 26)) >>> 0 > 7) {
   i9 = 38;
   break;
  }
  i6 = i2 + 1 | 0;
  i5 = i4 + -128 | i7 << 6;
  if ((i5 | 0) < 0) {
   i4 = HEAPU8[i6 >> 0] | 0;
   if ((i4 & 192 | 0) != 128) {
    i9 = 41;
    break;
   }
   i6 = i2 + 2 | 0;
   i5 = i4 + -128 | i5 << 6;
   if ((i5 | 0) < 0) {
    i4 = HEAPU8[i6 >> 0] | 0;
    if ((i4 & 192 | 0) != 128) {
     i9 = 44;
     break;
    }
    i5 = i4 + -128 | i5 << 6;
    i2 = i2 + 3 | 0;
   } else i2 = i6;
  } else i2 = i6;
  HEAP32[i8 >> 2] = i5;
  i4 = i8 + 4 | 0;
  i3 = i3 + -1 | 0;
  i9 = 6;
  continue;
 }
 if ((i9 | 0) == 17) {
  i2 = i6 + -1 | 0;
  i9 = 47;
 } else if ((i9 | 0) == 20) {
  i2 = i6 + -1 | 0;
  i9 = 47;
 } else if ((i9 | 0) == 23) {
  i2 = i6 + -1 | 0;
  i9 = 47;
 } else if ((i9 | 0) == 26) HEAP32[i10 >> 2] = i2; else if ((i9 | 0) == 38) {
  i5 = i8;
  i4 = i7;
  i2 = i2 + -1 | 0;
  i9 = 47;
 } else if ((i9 | 0) == 41) {
  i3 = i8;
  i1 = i2 + -1 | 0;
  i9 = 52;
 } else if ((i9 | 0) == 44) {
  i3 = i8;
  i1 = i2 + -1 | 0;
  i9 = 52;
 }
 if ((i9 | 0) == 47) if (!i4) i9 = 48; else {
  i3 = i5;
  i1 = i2;
  i9 = 52;
 }
 if ((i9 | 0) == 48) if (!(HEAP8[i2 >> 0] | 0)) {
  if (i5 | 0) {
   HEAP32[i5 >> 2] = 0;
   HEAP32[i10 >> 2] = 0;
  }
  i1 = i1 - i3 | 0;
 } else {
  i3 = i5;
  i1 = i2;
  i9 = 52;
 }
 if ((i9 | 0) == 52) {
  i9 = ___errno_location() | 0;
  HEAP32[i9 >> 2] = 84;
  if (!i3) i1 = -1; else {
   HEAP32[i10 >> 2] = i1;
   i1 = -1;
  }
 }
 return i1 | 0;
}

function __ZN4wasm17WasmBinaryBuilder11readImportsEv(i14) {
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i3 = i15 + 40 | 0;
 i4 = i15 + 36 | 0;
 i6 = i15 + 24 | 0;
 i7 = i15 + 12 | 0;
 i10 = i15;
 i11 = i14 + 12 | 0;
 if (HEAP8[i11 >> 0] | 0) {
  i13 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23591) | 0;
  i12 = __ZNKSt3__28ios_base6getlocEv(i13 + (HEAP32[(HEAP32[i13 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i3 >> 2] = i12;
  i12 = __ZNKSt3__26locale9use_facetERNS0_2idE(i3, 61680) | 0;
  i12 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i12 >> 2] | 0) + 28 >> 2] & 63](i12, 10) | 0;
  __ZNSt3__26localeD2Ev(i3);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i13, i12) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i13) | 0;
 }
 i5 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i14) | 0;
 if (HEAP8[i11 >> 0] | 0) {
  i13 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23493) | 0, i5) | 0;
  i12 = __ZNKSt3__28ios_base6getlocEv(i13 + (HEAP32[(HEAP32[i13 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i3 >> 2] = i12;
  i12 = __ZNKSt3__26locale9use_facetERNS0_2idE(i3, 61680) | 0;
  i12 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i12 >> 2] | 0) + 28 >> 2] & 63](i12, 10) | 0;
  __ZNSt3__26localeD2Ev(i3);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i13, i12) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i13) | 0;
 }
 i8 = i10 + 11 | 0;
 i9 = i10 + 4 | 0;
 i13 = 0;
 while (1) {
  if (i13 >>> 0 >= i5 >>> 0) {
   i1 = 7;
   break;
  }
  if (HEAP8[i11 >> 0] | 0) {
   i12 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23499) | 0;
   i2 = __ZNKSt3__28ios_base6getlocEv(i12 + (HEAP32[(HEAP32[i12 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i3 >> 2] = i2;
   i2 = __ZNKSt3__26locale9use_facetERNS0_2idE(i3, 61680) | 0;
   i2 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i2 >> 2] | 0) + 28 >> 2] & 63](i2, 10) | 0;
   __ZNSt3__26localeD2Ev(i3);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i12, i2) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i12) | 0;
  }
  i12 = __Znwj(16) | 0;
  HEAP32[i12 >> 2] = 0;
  HEAP32[i12 + 4 >> 2] = 0;
  HEAP32[i12 + 8 >> 2] = 0;
  HEAP32[i12 + 12 >> 2] = 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i7 + 4 >> 2] = 0;
  HEAP32[i7 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i7, 23606, 7);
  __ZNSt3__29to_stringEj(i10, i13);
  i1 = HEAP8[i8 >> 0] | 0;
  i2 = i1 << 24 >> 24 < 0;
  i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj(i7, i2 ? HEAP32[i10 >> 2] | 0 : i10, i2 ? HEAP32[i9 >> 2] | 0 : i1 & 255) | 0;
  HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i6 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i6 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  __ZN4wasm4NameC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i4, i6);
  HEAP32[i12 >> 2] = HEAP32[i4 >> 2];
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i6);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i10);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i7);
  i1 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i14) | 0;
  i2 = HEAP32[i14 >> 2] | 0;
  if (i1 >>> 0 >= (HEAP32[i2 + 4 >> 2] | 0) - (HEAP32[i2 >> 2] | 0) >> 2 >>> 0) {
   i1 = 14;
   break;
  }
  i2 = __ZN4wasm6Module15getFunctionTypeEj(i2, i1) | 0;
  HEAP32[i12 + 12 >> 2] = i2;
  if (!(HEAP32[i2 >> 2] | 0)) {
   i1 = 16;
   break;
  }
  i2 = __ZN4wasm17WasmBinaryBuilder15getInlineStringEv(i14) | 0;
  HEAP32[i12 + 4 >> 2] = i2;
  i2 = __ZN4wasm17WasmBinaryBuilder15getInlineStringEv(i14) | 0;
  HEAP32[i12 + 8 >> 2] = i2;
  __ZN4wasm6Module9addImportEPNS_6ImportE(HEAP32[i14 >> 2] | 0, i12);
  i13 = i13 + 1 | 0;
 }
 if ((i1 | 0) == 7) {
  STACKTOP = i15;
  return;
 } else if ((i1 | 0) == 14) ___assert_fail(23614, 22948, 1444, 23648); else if ((i1 | 0) == 16) ___assert_fail(23660, 22948, 1446, 23648);
}

function __ZN4wasm17WasmBinaryBuilder14readSignaturesEv(i14) {
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i15 + 4 | 0;
 i2 = i15;
 i4 = i14 + 12 | 0;
 if (HEAP8[i4 >> 0] | 0) {
  i13 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23475) | 0;
  i12 = __ZNKSt3__28ios_base6getlocEv(i13 + (HEAP32[(HEAP32[i13 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i12;
  i12 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i12 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i12 >> 2] | 0) + 28 >> 2] & 63](i12, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i13, i12) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i13) | 0;
 }
 i3 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i14) | 0;
 if (HEAP8[i4 >> 0] | 0) {
  i13 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23493) | 0, i3) | 0;
  i12 = __ZNKSt3__28ios_base6getlocEv(i13 + (HEAP32[(HEAP32[i13 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i12;
  i12 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i12 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i12 >> 2] | 0) + 28 >> 2] & 63](i12, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i13, i12) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i13) | 0;
 }
 i12 = 0;
 L7 : while (1) {
  if (i12 >>> 0 >= i3 >>> 0) {
   i1 = 7;
   break;
  }
  if (HEAP8[i4 >> 0] | 0) {
   i13 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23499) | 0;
   i11 = __ZNKSt3__28ios_base6getlocEv(i13 + (HEAP32[(HEAP32[i13 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i1 >> 2] = i11;
   i11 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
   i11 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 28 >> 2] & 63](i11, 10) | 0;
   __ZNSt3__26localeD2Ev(i1);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i13, i11) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i13) | 0;
  }
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 0;
  HEAP32[i5 + 4 >> 2] = 0;
  HEAP32[i5 + 8 >> 2] = 0;
  HEAP32[i5 + 12 >> 2] = 0;
  HEAP32[i5 + 16 >> 2] = 0;
  if ((__ZN4wasm17WasmBinaryBuilder7getInt8Ev(i14) | 0) << 24 >> 24 != 64) {
   i1 = 11;
   break;
  }
  i6 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i14) | 0;
  if (HEAP8[i4 >> 0] | 0) {
   i13 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23562) | 0, i6) | 0;
   i11 = __ZNKSt3__28ios_base6getlocEv(i13 + (HEAP32[(HEAP32[i13 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i1 >> 2] = i11;
   i11 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
   i11 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 28 >> 2] & 63](i11, 10) | 0;
   __ZNSt3__26localeD2Ev(i1);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i13, i11) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i13) | 0;
  }
  i7 = i5 + 12 | 0;
  i8 = i5 + 16 | 0;
  i9 = i5 + 8 | 0;
  i13 = 0;
  while (1) {
   if ((i13 | 0) == (i6 | 0)) break;
   i10 = __ZN4wasm17WasmBinaryBuilder11getWasmTypeEv(i14) | 0;
   HEAP32[i2 >> 2] = i10;
   i11 = HEAP32[i7 >> 2] | 0;
   if (i11 >>> 0 < (HEAP32[i8 >> 2] | 0) >>> 0) {
    HEAP32[i11 >> 2] = i10;
    HEAP32[i7 >> 2] = i11 + 4;
   } else __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i9, i2);
   i13 = i13 + 1 | 0;
  }
  switch (__ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i14) | 0) {
  case 0:
   {
    HEAP32[i5 + 4 >> 2] = 0;
    break;
   }
  case 1:
   {
    i13 = __ZN4wasm17WasmBinaryBuilder11getWasmTypeEv(i14) | 0;
    HEAP32[i5 + 4 >> 2] = i13;
    break;
   }
  default:
   {
    i1 = 22;
    break L7;
   }
  }
  __ZN4wasm6Module15addFunctionTypeEPNS_12FunctionTypeE(HEAP32[i14 >> 2] | 0, i5);
  i12 = i12 + 1 | 0;
 }
 if ((i1 | 0) == 7) {
  STACKTOP = i15;
  return;
 } else if ((i1 | 0) == 11) ___assert_fail(23508, 22948, 1418, 23547); else if ((i1 | 0) == 22) ___assert_fail(23575, 22948, 1428, 23547);
}

function __ZN4wasm21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 L1 : do switch (HEAP32[i2 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 320, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 321, i3);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i2) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break L1;
    __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
  }
 case 2:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 322, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 321, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 321, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 321, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 8 | 0);
   break;
  }
 case 3:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 323, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_4LoopEEEPT_v(i2) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 321, i3);
   break;
  }
 case 4:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 324, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 321, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i2) | 0) + 16 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(i2) | 0) + 12 | 0);
   break;
  }
 case 5:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 325, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 321, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i2) | 0) + 32 | 0);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i2) | 0) + 28 | 0);
   break;
  }
 case 17:
  {
   i4 = i1 + 16 | 0;
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 326, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 321, i3);
   __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 314, (__ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i2) | 0) + 8 | 0);
   break;
  }
 default:
  __ZN4wasm10PostWalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i3);
 } while (0);
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_19base_nameINSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEEEET_RS9_(i7, i2) {
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i5 = HEAP8[i2 + 11 >> 0] | 0;
 i4 = i5 << 24 >> 24 < 0;
 i5 = i4 ? HEAP32[i2 + 4 >> 2] | 0 : i5 & 255;
 L1 : do switch (i5 | 0) {
 case 0:
  {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i7, i2);
   break;
  }
 case 11:
  {
   if (!(__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i4 ? HEAP32[i2 >> 2] | 0 : i2, 57647, 11) | 0)) {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6assignEPKcj(i2, 57699, 70);
    HEAP32[i7 >> 2] = 0;
    HEAP32[i7 + 4 >> 2] = 0;
    HEAP32[i7 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i7, 57770, 12);
   } else i6 = 9;
   break;
  }
 case 12:
  {
   if (!(__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i4 ? HEAP32[i2 >> 2] | 0 : i2, 57659, 12) | 0)) {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6assignEPKcj(i2, 57783, 49);
    HEAP32[i7 >> 2] = 0;
    HEAP32[i7 + 4 >> 2] = 0;
    HEAP32[i7 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i7, 57833, 13);
    break L1;
   }
   if (!(__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i4 ? HEAP32[i2 >> 2] | 0 : i2, 57672, 12) | 0)) {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6assignEPKcj(i2, 57847, 49);
    HEAP32[i7 >> 2] = 0;
    HEAP32[i7 + 4 >> 2] = 0;
    HEAP32[i7 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i7, 57897, 13);
   } else i6 = 9;
   break;
  }
 case 13:
  {
   i1 = HEAP32[i2 >> 2] | 0;
   if (!(__ZNSt3__211char_traitsIcE7compareEPKcS3_j(i4 ? i1 : i2, 57685, 13) | 0)) {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6assignEPKcj(i2, 57911, 50);
    HEAP32[i7 >> 2] = 0;
    HEAP32[i7 + 4 >> 2] = 0;
    HEAP32[i7 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i7, 57962, 14);
   } else {
    i3 = i2;
    i6 = 12;
   }
   break;
  }
 default:
  i6 = 9;
 } while (0);
 if ((i6 | 0) == 9) {
  i3 = i2;
  i1 = HEAP32[i2 >> 2] | 0;
  i6 = 12;
 }
 L14 : do if ((i6 | 0) == 12) {
  i2 = i4 ? i1 : i3;
  i1 = i2 + i5 | 0;
  L16 : do if ((HEAP8[i1 + -1 >> 0] | 0) == 62) {
   i4 = 1;
   L17 : while (1) {
    i3 = i1;
    L19 : while (1) {
     i1 = i3 + -1 | 0;
     if ((i1 | 0) == (i2 | 0)) break L17;
     i3 = i3 + -2 | 0;
     switch (HEAP8[i3 >> 0] | 0) {
     case 60:
      {
       i6 = 19;
       break L19;
      }
     case 62:
      {
       i6 = 20;
       break L19;
      }
     default:
      i3 = i1;
     }
    }
    if ((i6 | 0) == 19) {
     i4 = i4 + -1 | 0;
     if (!i4) {
      i1 = i3;
      break L16;
     } else continue;
    } else if ((i6 | 0) == 20) {
     i4 = i4 + 1 | 0;
     continue;
    }
   }
   HEAP32[i7 >> 2] = 0;
   HEAP32[i7 + 4 >> 2] = 0;
   HEAP32[i7 + 8 >> 2] = 0;
   i1 = 0;
   while (1) {
    if ((i1 | 0) == 3) break L14;
    HEAP32[i7 + (i1 << 2) >> 2] = 0;
    i1 = i1 + 1 | 0;
   }
  } while (0);
  i4 = i1;
  while (1) {
   i3 = i4 + -1 | 0;
   if ((i3 | 0) == (i2 | 0)) break;
   if ((HEAP8[i3 >> 0] | 0) == 58) {
    i2 = i4;
    break;
   } else i4 = i3;
  }
  HEAP32[i7 >> 2] = 0;
  HEAP32[i7 + 4 >> 2] = 0;
  HEAP32[i7 + 8 >> 2] = 0;
  i5 = i1 - i2 | 0;
  if (i5 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i7);
  if (i5 >>> 0 < 11) {
   HEAP8[i7 + 11 >> 0] = i5;
   i4 = i7;
  } else {
   i6 = i5 + 16 & -16;
   i4 = _malloc(i6) | 0;
   HEAP32[i7 >> 2] = i4;
   HEAP32[i7 + 8 >> 2] = i6 | -2147483648;
   HEAP32[i7 + 4 >> 2] = i5;
  }
  i3 = i4;
  while (1) {
   if ((i2 | 0) == (i1 | 0)) break;
   HEAP8[i3 >> 0] = HEAP8[i2 >> 0] | 0;
   i2 = i2 + 1 | 0;
   i3 = i3 + 1 | 0;
  }
  HEAP8[i4 + i5 >> 0] = 0;
 } while (0);
 return;
}

function __ZN4wasm10PassRunner3runEv(i14) {
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0, d16 = 0.0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i12 = i15;
 i13 = i14 + 24 | 0;
 L1 : do if (!(HEAP8[i13 >> 0] | 0)) {
  i3 = HEAP32[i14 + 8 >> 2] | 0;
  i5 = HEAP32[i14 + 12 >> 2] | 0;
  i6 = 0;
  i7 = 0;
  i11 = 0;
 } else {
  i6 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 32383) | 0;
  i7 = __ZNKSt3__28ios_base6getlocEv(i6 + (HEAP32[(HEAP32[i6 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i12 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i12, 61680) | 0;
  i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
  __ZNSt3__26localeD2Ev(i12);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i6, i7) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i6) | 0;
  i6 = __ZNSt3__26chrono12steady_clock3nowEv() | 0;
  i7 = tempRet0;
  i3 = HEAP32[i14 + 8 >> 2] | 0;
  i5 = HEAP32[i14 + 12 >> 2] | 0;
  i4 = i3;
  i8 = 0;
  while (1) {
   if ((i4 | 0) == (i5 | 0)) {
    i11 = i8;
    break L1;
   }
   i1 = HEAP32[i4 >> 2] | 0;
   i2 = HEAP8[i1 + 4 + 11 >> 0] | 0;
   if (i2 << 24 >> 24 < 0) i1 = HEAP32[i1 + 8 >> 2] | 0; else i1 = i2 & 255;
   i4 = i4 + 4 | 0;
   i8 = i8 >>> 0 < i1 >>> 0 ? i1 : i8;
  }
 } while (0);
 i10 = i14 + 20 | 0;
 while (1) {
  if ((i3 | 0) == (i5 | 0)) break;
  i9 = HEAP32[i3 >> 2] | 0;
  HEAP32[i10 >> 2] = i9;
  if (!(HEAP8[i13 >> 0] | 0)) {
   i1 = 0;
   i2 = 0;
  } else {
   i2 = i9 + 4 | 0;
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_13basic_ostreamIT_T0_EES9_RKNS_12basic_stringIS6_S7_T1_EE(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 32414) | 0, i2) | 0, 32444) | 0;
   i2 = i2 + 11 | 0;
   i4 = i9 + 8 | 0;
   i8 = 0;
   while (1) {
    i1 = HEAP8[i2 >> 0] | 0;
    if (i1 << 24 >> 24 < 0) i1 = HEAP32[i4 >> 2] | 0; else i1 = i1 & 255;
    if (i8 >>> 0 >= (i11 - i1 | 0) >>> 0) break;
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(60976, 32) | 0;
    i8 = i8 + 1 | 0;
   }
   i1 = __ZNSt3__26chrono12steady_clock3nowEv() | 0;
   i2 = tempRet0;
  }
  FUNCTION_TABLE_viii[HEAP32[(HEAP32[i9 >> 2] | 0) + 12 >> 2] & 31](i9, i14, HEAP32[i14 >> 2] | 0);
  if (HEAP8[i13 >> 0] | 0) {
   i9 = __ZNSt3__26chrono12steady_clock3nowEv() | 0;
   i9 = _i64Subtract(i9 | 0, tempRet0 | 0, i1 | 0, i2 | 0) | 0;
   i9 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd(60976, (+(i9 >>> 0) + 4294967296.0 * +(tempRet0 | 0)) / 1.0e9) | 0, 32449) | 0;
   i8 = __ZNKSt3__28ios_base6getlocEv(i9 + (HEAP32[(HEAP32[i9 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i12 >> 2] = i8;
   i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i12, 61680) | 0;
   i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i8 >> 2] | 0) + 28 >> 2] & 63](i8, 10) | 0;
   __ZNSt3__26localeD2Ev(i12);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i9, i8) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i9) | 0;
  }
  i3 = i3 + 4 | 0;
 }
 if (HEAP8[i13 >> 0] | 0) {
  i14 = __ZNSt3__26chrono12steady_clock3nowEv() | 0;
  i14 = _i64Subtract(i14 | 0, tempRet0 | 0, i6 | 0, i7 | 0) | 0;
  d16 = (+(i14 >>> 0) + 4294967296.0 * +(tempRet0 | 0)) / 1.0e9;
  i14 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 32459) | 0, d16) | 0, 32449) | 0;
  i13 = __ZNKSt3__28ios_base6getlocEv(i14 + (HEAP32[(HEAP32[i14 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i12 >> 2] = i13;
  i13 = __ZNKSt3__26locale9use_facetERNS0_2idE(i12, 61680) | 0;
  i13 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 28 >> 2] & 63](i13, 10) | 0;
  __ZNSt3__26localeD2Ev(i12);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i14, i13) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i14) | 0;
 }
 STACKTOP = i15;
 return;
}
function ___udivmoddi4(i5, i6, i8, i11, i13) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i8 = i8 | 0;
 i11 = i11 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0, i10 = 0, i12 = 0, i14 = 0, i15 = 0;
 i9 = i5;
 i4 = i6;
 i7 = i4;
 i2 = i8;
 i12 = i11;
 i3 = i12;
 if (!i7) {
  i1 = (i13 | 0) != 0;
  if (!i3) {
   if (i1) {
    HEAP32[i13 >> 2] = (i9 >>> 0) % (i2 >>> 0);
    HEAP32[i13 + 4 >> 2] = 0;
   }
   i12 = 0;
   i13 = (i9 >>> 0) / (i2 >>> 0) >>> 0;
   return (tempRet0 = i12, i13) | 0;
  } else {
   if (!i1) {
    i12 = 0;
    i13 = 0;
    return (tempRet0 = i12, i13) | 0;
   }
   HEAP32[i13 >> 2] = i5 | 0;
   HEAP32[i13 + 4 >> 2] = i6 & 0;
   i12 = 0;
   i13 = 0;
   return (tempRet0 = i12, i13) | 0;
  }
 }
 i1 = (i3 | 0) == 0;
 do if (i2) {
  if (!i1) {
   i1 = (Math_clz32(i3 | 0) | 0) - (Math_clz32(i7 | 0) | 0) | 0;
   if (i1 >>> 0 <= 31) {
    i10 = i1 + 1 | 0;
    i3 = 31 - i1 | 0;
    i6 = i1 - 31 >> 31;
    i2 = i10;
    i5 = i9 >>> (i10 >>> 0) & i6 | i7 << i3;
    i6 = i7 >>> (i10 >>> 0) & i6;
    i1 = 0;
    i3 = i9 << i3;
    break;
   }
   if (!i13) {
    i12 = 0;
    i13 = 0;
    return (tempRet0 = i12, i13) | 0;
   }
   HEAP32[i13 >> 2] = i5 | 0;
   HEAP32[i13 + 4 >> 2] = i4 | i6 & 0;
   i12 = 0;
   i13 = 0;
   return (tempRet0 = i12, i13) | 0;
  }
  i1 = i2 - 1 | 0;
  if (i1 & i2 | 0) {
   i3 = (Math_clz32(i2 | 0) | 0) + 33 - (Math_clz32(i7 | 0) | 0) | 0;
   i15 = 64 - i3 | 0;
   i10 = 32 - i3 | 0;
   i4 = i10 >> 31;
   i14 = i3 - 32 | 0;
   i6 = i14 >> 31;
   i2 = i3;
   i5 = i10 - 1 >> 31 & i7 >>> (i14 >>> 0) | (i7 << i10 | i9 >>> (i3 >>> 0)) & i6;
   i6 = i6 & i7 >>> (i3 >>> 0);
   i1 = i9 << i15 & i4;
   i3 = (i7 << i15 | i9 >>> (i14 >>> 0)) & i4 | i9 << i10 & i3 - 33 >> 31;
   break;
  }
  if (i13 | 0) {
   HEAP32[i13 >> 2] = i1 & i9;
   HEAP32[i13 + 4 >> 2] = 0;
  }
  if ((i2 | 0) == 1) {
   i14 = i4 | i6 & 0;
   i15 = i5 | 0 | 0;
   return (tempRet0 = i14, i15) | 0;
  } else {
   i15 = _llvm_cttz_i32(i2 | 0) | 0;
   i14 = i7 >>> (i15 >>> 0) | 0;
   i15 = i7 << 32 - i15 | i9 >>> (i15 >>> 0) | 0;
   return (tempRet0 = i14, i15) | 0;
  }
 } else {
  if (i1) {
   if (i13 | 0) {
    HEAP32[i13 >> 2] = (i7 >>> 0) % (i2 >>> 0);
    HEAP32[i13 + 4 >> 2] = 0;
   }
   i14 = 0;
   i15 = (i7 >>> 0) / (i2 >>> 0) >>> 0;
   return (tempRet0 = i14, i15) | 0;
  }
  if (!i9) {
   if (i13 | 0) {
    HEAP32[i13 >> 2] = 0;
    HEAP32[i13 + 4 >> 2] = (i7 >>> 0) % (i3 >>> 0);
   }
   i14 = 0;
   i15 = (i7 >>> 0) / (i3 >>> 0) >>> 0;
   return (tempRet0 = i14, i15) | 0;
  }
  i1 = i3 - 1 | 0;
  if (!(i1 & i3)) {
   if (i13 | 0) {
    HEAP32[i13 >> 2] = i5 | 0;
    HEAP32[i13 + 4 >> 2] = i1 & i7 | i6 & 0;
   }
   i14 = 0;
   i15 = i7 >>> ((_llvm_cttz_i32(i3 | 0) | 0) >>> 0);
   return (tempRet0 = i14, i15) | 0;
  }
  i1 = (Math_clz32(i3 | 0) | 0) - (Math_clz32(i7 | 0) | 0) | 0;
  if (i1 >>> 0 <= 30) {
   i6 = i1 + 1 | 0;
   i3 = 31 - i1 | 0;
   i2 = i6;
   i5 = i7 << i3 | i9 >>> (i6 >>> 0);
   i6 = i7 >>> (i6 >>> 0);
   i1 = 0;
   i3 = i9 << i3;
   break;
  }
  if (!i13) {
   i14 = 0;
   i15 = 0;
   return (tempRet0 = i14, i15) | 0;
  }
  HEAP32[i13 >> 2] = i5 | 0;
  HEAP32[i13 + 4 >> 2] = i4 | i6 & 0;
  i14 = 0;
  i15 = 0;
  return (tempRet0 = i14, i15) | 0;
 } while (0);
 if (!i2) {
  i7 = i3;
  i4 = 0;
  i3 = 0;
 } else {
  i10 = i8 | 0 | 0;
  i9 = i12 | i11 & 0;
  i7 = _i64Add(i10 | 0, i9 | 0, -1, -1) | 0;
  i8 = tempRet0;
  i4 = i3;
  i3 = 0;
  do {
   i11 = i4;
   i4 = i1 >>> 31 | i4 << 1;
   i1 = i3 | i1 << 1;
   i11 = i5 << 1 | i11 >>> 31 | 0;
   i12 = i5 >>> 31 | i6 << 1 | 0;
   _i64Subtract(i7 | 0, i8 | 0, i11 | 0, i12 | 0) | 0;
   i15 = tempRet0;
   i14 = i15 >> 31 | ((i15 | 0) < 0 ? -1 : 0) << 1;
   i3 = i14 & 1;
   i5 = _i64Subtract(i11 | 0, i12 | 0, i14 & i10 | 0, (((i15 | 0) < 0 ? -1 : 0) >> 31 | ((i15 | 0) < 0 ? -1 : 0) << 1) & i9 | 0) | 0;
   i6 = tempRet0;
   i2 = i2 - 1 | 0;
  } while ((i2 | 0) != 0);
  i7 = i4;
  i4 = 0;
 }
 i2 = 0;
 if (i13 | 0) {
  HEAP32[i13 >> 2] = i5;
  HEAP32[i13 + 4 >> 2] = i6;
 }
 i14 = (i1 | 0) >>> 31 | (i7 | i2) << 1 | (i2 << 1 | i1 >>> 31) & 0 | i4;
 i15 = (i1 << 1 | 0 >>> 31) & -2 | i3;
 return (tempRet0 = i14, i15) | 0;
}

function __ZN4wasm14SimplifyLocals16optimizeIfReturnEPNS_2IfEPPNS_10ExpressionERNSt3__23mapIjNS0_12SinkableInfoENS6_4lessIjEENS6_9allocatorINS6_4pairIKjS8_EEEEEE(i19, i15, i14, i10) {
 i19 = i19 | 0;
 i15 = i15 | 0;
 i14 = i14 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i11 = 0, i12 = 0, i13 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i17 = i20 + 20 | 0;
 i1 = i20 + 4 | 0;
 i16 = i20 + 24 | 0;
 i4 = i20 + 16 | 0;
 i11 = i20;
 HEAP32[i17 >> 2] = i15;
 i6 = i15 + 16 | 0;
 i18 = i15;
 if (!(HEAP32[i6 >> 2] | 0)) ___assert_fail(41989, 41949, 312, 42020);
 if ((HEAP32[(HEAP32[i19 + 100 >> 2] | 0) + -4 >> 2] | 0) != (i15 | 0)) ___assert_fail(42037, 41949, 314, 42020);
 __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEEC2ERKS6_(i1, i19 + 96 | 0);
 i7 = __ZN4wasm18ExpressionAnalyzer12isResultUsedENSt3__26vectorIPNS_10ExpressionENS1_9allocatorIS4_EEEEPNS_8FunctionE(i1, HEAP32[i19 + 36 >> 2] | 0) | 0;
 __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i1);
 if (!i7) {
  i7 = i19 + 44 | 0;
  HEAP32[i16 >> 2] = -1;
  i1 = i10 + 4 | 0;
  i2 = HEAP32[i10 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i1 | 0)) break;
   i3 = HEAP32[i2 + 16 >> 2] | 0;
   HEAP32[i4 >> 2] = i3;
   if (__ZNKSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE14__count_uniqueIjEEjRKT_(i7, i4) | 0) {
    i5 = 9;
    break;
   }
   i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i2) | 0;
  }
  do if ((i5 | 0) == 9) {
   HEAP32[i16 >> 2] = i3;
   i1 = HEAP32[i15 + 12 >> 2] | 0;
   i2 = HEAP32[i6 >> 2] | 0;
   i2 = (HEAP32[i2 >> 2] | 0) == 1 ? i2 : 0;
   if ((((!((i1 | 0) == 0 | (HEAP32[i1 >> 2] | 0) != 1) ? (i8 = i1 + 12 | 0, i9 = i8 + 8 | 0, HEAP32[i9 >> 2] | 0) : 0) ? (i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i8) | 0, i2 | 0 ? (HEAP32[HEAP32[i6 >> 2] >> 2] | 0) == 19 : 0) : 0) ? (i12 = i2 + 12 | 0, i13 = i2 + 20 | 0, HEAP32[i13 >> 2] | 0) : 0) ? (i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i12) | 0, (HEAP32[HEAP32[i6 >> 2] >> 2] | 0) == 19) : 0) {
    i10 = __ZNSt3__23mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS3_EEEEE2atERS8_(i10, i16) | 0;
    i10 = HEAP32[i10 >> 2] | 0;
    i6 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i10 >> 2] | 0) | 0) + 12 | 0;
    i6 = HEAP32[i6 >> 2] | 0;
    i9 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i8, (HEAP32[i9 >> 2] | 0) + -1 | 0) | 0;
    HEAP32[i9 >> 2] = i6;
    i10 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = 19;
    HEAP32[i10 + 4 >> 2] = 0;
    __ZN4wasm5Block8finalizeEv(i1);
    i1 = i1 + 4 | 0;
    if (!(HEAP32[i1 >> 2] | 0)) ___assert_fail(42067, 41949, 344, 42020);
    i16 = __ZNSt3__23mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS3_EEEEE2atERS8_(i7, i16) | 0;
    i16 = HEAP32[i16 >> 2] | 0;
    i10 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i16 >> 2] | 0) | 0) + 12 | 0;
    i10 = HEAP32[i10 >> 2] | 0;
    i13 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i12, (HEAP32[i13 >> 2] | 0) + -1 | 0) | 0;
    HEAP32[i13 >> 2] = i10;
    i16 = HEAP32[i16 >> 2] | 0;
    HEAP32[i16 >> 2] = 19;
    HEAP32[i16 + 4 >> 2] = 0;
    __ZN4wasm5Block8finalizeEv(i2);
    if (!(HEAP32[i1 >> 2] | 0)) ___assert_fail(42067, 41949, 349, 42020);
    __ZN4wasm2If8finalizeEv(i15);
    if (!(HEAP32[i15 + 4 >> 2] | 0)) ___assert_fail(42093, 41949, 351, 42020); else {
     HEAP32[i11 >> 2] = (HEAP32[i19 + 40 >> 2] | 0) + 88;
     i18 = __ZN4wasm7Builder12makeSetLocalEjPNS_10ExpressionE(i11, i3, i15) | 0;
     HEAP32[i14 >> 2] = i18;
     HEAP8[i19 + 92 >> 0] = 1;
     break;
    }
   }
   i1 = i19 + 124 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i19 + 128 >> 2] | 0)) {
    __ZNSt3__26vectorIPN4wasm2IfENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i19 + 120 | 0, i17);
    break;
   } else {
    HEAP32[i2 >> 2] = i18;
    HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
    break;
   }
  } while (0);
 }
 STACKTOP = i20;
 return;
}

function __ZN4wasm14SimplifyLocals14doWalkFunctionEPNS_8FunctionE(i1, i19) {
 i1 = i1 | 0;
 i19 = i19 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i20 = 0, i21 = 0, i22 = 0, i23 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 128 | 0;
 i6 = i22 + 104 | 0;
 i7 = i22 + 48 | 0;
 i20 = i22 + 108 | 0;
 i18 = i22 + 56 | 0;
 i21 = i22;
 i10 = i1 + 92 | 0;
 i11 = i1 + 16 | 0;
 i12 = i19 + 36 | 0;
 i13 = i1 + 108 | 0;
 i14 = i1 + 112 | 0;
 i15 = i1 + 120 | 0;
 i16 = i1 + 124 | 0;
 i17 = i1 + 44 | 0;
 i8 = i1 + 56 | 0;
 i9 = i1 + 68 | 0;
 i5 = i1 + 40 | 0;
 do {
  HEAP8[i10 >> 0] = 0;
  __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i11, i12);
  i4 = HEAP32[i14 >> 2] | 0;
  i1 = HEAP32[i13 >> 2] | 0;
  i2 = i4;
  if ((i4 | 0) != (i1 | 0)) {
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break;
    i4 = (HEAP32[i1 >> 2] | 0) + 12 | 0;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i4, __ZN10MixedArena5allocIN4wasm3NopEEEPT_v((HEAP32[i5 >> 2] | 0) + 88 | 0) | 0);
    i1 = i1 + 4 | 0;
   }
   i1 = HEAP32[i13 >> 2] | 0;
   i2 = HEAP32[i14 >> 2] | 0;
   while (1) {
    if ((i2 | 0) == (i1 | 0)) break;
    i4 = i2 + -4 | 0;
    HEAP32[i14 >> 2] = i4;
    i2 = i4;
   }
   HEAP8[i10 >> 0] = 1;
  }
  i3 = HEAP32[i16 >> 2] | 0;
  i1 = HEAP32[i15 >> 2] | 0;
  i4 = i3;
  if ((i3 | 0) != (i1 | 0)) {
   while (1) {
    if ((i1 | 0) == (i4 | 0)) break;
    i2 = HEAP32[i1 >> 2] | 0;
    HEAP32[i6 >> 2] = (HEAP32[i5 >> 2] | 0) + 88;
    i3 = i2 + 12 | 0;
    i23 = __ZN4wasm7Builder8blockifyEPNS_10ExpressionES2_(i6, HEAP32[i3 >> 2] | 0, 0) | 0;
    HEAP32[i3 >> 2] = i23;
    i3 = i23 + 12 | 0;
    if (!((HEAP32[i23 + 20 >> 2] | 0) != 0 ? (i23 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i3) | 0, (HEAP32[HEAP32[i23 >> 2] >> 2] | 0) == 19) : 0)) __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i3, __ZN10MixedArena5allocIN4wasm3NopEEEPT_v((HEAP32[i5 >> 2] | 0) + 88 | 0) | 0);
    HEAP32[i7 >> 2] = (HEAP32[i5 >> 2] | 0) + 88;
    i2 = i2 + 16 | 0;
    i23 = __ZN4wasm7Builder8blockifyEPNS_10ExpressionES2_(i7, HEAP32[i2 >> 2] | 0, 0) | 0;
    HEAP32[i2 >> 2] = i23;
    i2 = i23 + 12 | 0;
    if (!((HEAP32[i23 + 20 >> 2] | 0) != 0 ? (i23 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i2) | 0, (HEAP32[HEAP32[i23 >> 2] >> 2] | 0) == 19) : 0)) __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, __ZN10MixedArena5allocIN4wasm3NopEEEPT_v((HEAP32[i5 >> 2] | 0) + 88 | 0) | 0);
    i1 = i1 + 4 | 0;
   }
   i1 = HEAP32[i15 >> 2] | 0;
   i2 = HEAP32[i16 >> 2] | 0;
   while (1) {
    if ((i2 | 0) == (i1 | 0)) break;
    i23 = i2 + -4 | 0;
    HEAP32[i16 >> 2] = i23;
    i2 = i23;
   }
   HEAP8[i10 >> 0] = 1;
  }
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5clearEv(i17);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE5clearEv(i8);
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE5clearEv(i9);
 } while ((HEAP8[i10 >> 0] | 0) != 0);
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 __ZNSt3__26vectorIiNS_9allocatorIiEEE6resizeEj(i20, __ZN4wasm8Function12getNumLocalsEv(i19) | 0);
 __ZN4wasm15GetLocalCounterC2Ev(i18);
 HEAP32[i18 + 44 >> 2] = i20;
 HEAP32[i18 + 36 >> 2] = i19;
 __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i18 + 16 + -16 + 16 | 0, i12);
 __ZN4wasm15SetLocalRemoverC2Ev(i21);
 HEAP32[i21 + 44 >> 2] = i20;
 HEAP32[i21 + 36 >> 2] = i19;
 __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i21 + 16 + -16 + 16 | 0, i12);
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEED2Ev(i21);
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEED2Ev(i18);
 __ZNSt3__213__vector_baseIiNS_9allocatorIiEEED2Ev(i20);
 STACKTOP = i22;
 return;
}

function __ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe(i1, i24, i12, i22, i21, d4) {
 i1 = i1 | 0;
 i24 = i24 | 0;
 i12 = i12 | 0;
 i22 = i22 | 0;
 i21 = i21 | 0;
 d4 = +d4;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i23 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0;
 i28 = STACKTOP;
 STACKTOP = STACKTOP + 1008 | 0;
 i14 = i28 + 8 | 0;
 i1 = i28;
 i5 = i28 + 896 | 0;
 i7 = i28 + 888 | 0;
 i2 = i28 + 488 | 0;
 i23 = i28 + 480 | 0;
 i19 = i28 + 892 | 0;
 i16 = i28 + 476 | 0;
 i20 = i28 + 472 | 0;
 i25 = i28 + 460 | 0;
 i27 = i28 + 448 | 0;
 i26 = i28 + 436 | 0;
 i11 = i28 + 432 | 0;
 i6 = i28 + 32 | 0;
 i18 = i28 + 24 | 0;
 i17 = i28 + 16 | 0;
 i15 = i28 + 20 | 0;
 HEAP32[i7 >> 2] = i5;
 HEAPF64[i14 >> 3] = d4;
 i5 = _snprintf(i5, 100, 54741, i14) | 0;
 if (i5 >>> 0 > 99) {
  i5 = __ZNSt3__26__clocEv() | 0;
  HEAPF64[i1 >> 3] = d4;
  i5 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i7, i5, 54741, i1) | 0;
  i1 = HEAP32[i7 >> 2] | 0;
  if (!i1) i1 = HEAP32[i7 >> 2] | 0;
  i2 = _malloc(i5 << 2) | 0;
  i3 = i2;
  if (!i2) {
   i2 = 0;
   i13 = i1;
   i10 = i5;
  } else {
   i13 = i1;
   i10 = i5;
  }
 } else {
  i3 = 0;
  i13 = 0;
  i10 = i5;
 }
 i1 = __ZNKSt3__28ios_base6getlocEv(i22) | 0;
 HEAP32[i23 >> 2] = i1;
 i9 = __ZNKSt3__26locale9use_facetERNS0_2idE(i23, 61712) | 0;
 i8 = HEAP32[i7 >> 2] | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i9 >> 2] | 0) + 48 >> 2] & 7](i9, i8, i8 + i10 | 0, i2) | 0;
 if (!i10) i8 = 0; else i8 = (HEAP8[HEAP32[i7 >> 2] >> 0] | 0) == 45;
 HEAP32[i25 >> 2] = 0;
 HEAP32[i25 + 4 >> 2] = 0;
 HEAP32[i25 + 8 >> 2] = 0;
 i5 = 0;
 while (1) {
  if ((i5 | 0) == 3) break;
  HEAP32[i25 + (i5 << 2) >> 2] = 0;
  i5 = i5 + 1 | 0;
 }
 HEAP32[i27 >> 2] = 0;
 HEAP32[i27 + 4 >> 2] = 0;
 HEAP32[i27 + 8 >> 2] = 0;
 i5 = 0;
 while (1) {
  if ((i5 | 0) == 3) break;
  HEAP32[i27 + (i5 << 2) >> 2] = 0;
  i5 = i5 + 1 | 0;
 }
 HEAP32[i26 >> 2] = 0;
 HEAP32[i26 + 4 >> 2] = 0;
 HEAP32[i26 + 8 >> 2] = 0;
 i5 = 0;
 while (1) {
  if ((i5 | 0) == 3) break;
  HEAP32[i26 + (i5 << 2) >> 2] = 0;
  i5 = i5 + 1 | 0;
 }
 __ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri(i12, i8, i23, i19, i16, i20, i25, i27, i26, i11);
 i7 = HEAP32[i11 >> 2] | 0;
 if ((i10 | 0) > (i7 | 0)) {
  i12 = HEAP8[i26 + 8 + 3 >> 0] | 0;
  i5 = HEAP8[i27 + 8 + 3 >> 0] | 0;
  i5 = (i12 << 24 >> 24 < 0 ? HEAP32[i26 + 4 >> 2] | 0 : i12 & 255) + (i10 - i7 << 1 | 1) + (i5 << 24 >> 24 < 0 ? HEAP32[i27 + 4 >> 2] | 0 : i5 & 255) | 0;
 } else {
  i12 = HEAP8[i26 + 8 + 3 >> 0] | 0;
  i5 = HEAP8[i27 + 8 + 3 >> 0] | 0;
  i5 = (i12 << 24 >> 24 < 0 ? HEAP32[i26 + 4 >> 2] | 0 : i12 & 255) + 2 + (i5 << 24 >> 24 < 0 ? HEAP32[i27 + 4 >> 2] | 0 : i5 & 255) | 0;
 }
 i5 = i5 + i7 | 0;
 if (i5 >>> 0 > 100) {
  i6 = _malloc(i5 << 2) | 0;
  i5 = i6;
  if (!i6) i6 = 0;
 } else i5 = 0;
 __ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i(i6, i18, i17, HEAP32[i22 + 4 >> 2] | 0, i2, i2 + (i10 << 2) | 0, i9, i8, i19, HEAP32[i16 >> 2] | 0, HEAP32[i20 >> 2] | 0, i25, i27, i26, i7);
 HEAP32[i15 >> 2] = HEAP32[i24 >> 2];
 i24 = HEAP32[i18 >> 2] | 0;
 i2 = HEAP32[i17 >> 2] | 0;
 HEAP32[i14 >> 2] = HEAP32[i15 >> 2];
 i2 = __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i14, i6, i24, i2, i22, i21) | 0;
 if (i5) {
  _free(i5);
  i1 = HEAP32[i23 >> 2] | 0;
 }
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i26);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i27);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i25);
 __ZNSt3__214__shared_count16__release_sharedEv(i1) | 0;
 if (i3 | 0) _free(i3);
 if (i13 | 0) _free(i13);
 STACKTOP = i28;
 return i2 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder9makeBlockERNS_7ElementE(i14, i1) {
 i14 = i14 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i10 = i16 + 28 | 0;
 i11 = i16 + 24 | 0;
 i15 = i16 + 12 | 0;
 i5 = i16;
 i6 = i14 + 4 | 0;
 i2 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i6 >> 2] | 0) | 0;
 HEAP32[i10 >> 2] = i2;
 HEAP32[i11 >> 2] = i1;
 HEAP32[i15 >> 2] = 0;
 i12 = i15 + 4 | 0;
 HEAP32[i12 >> 2] = 0;
 HEAP32[i15 + 8 >> 2] = 0;
 i7 = i15 + 8 | 0;
 i13 = i14 + 68 | 0;
 i8 = i14 + 72 | 0;
 i9 = i14 + 64 | 0;
 i3 = 0;
 i4 = 0;
 while (1) {
  if (i3 >>> 0 < i4 >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i2;
   HEAP32[i12 >> 2] = i3 + 8;
  } else __ZNSt3__26vectorINS_4pairIPN4wasm7ElementEPNS2_5BlockEEENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRS4_RS6_EEEvDpOT_(i15, i11, i10);
  i4 = (__ZN4wasm7Element4listEv(i1) | 0) + 8 | 0;
  if ((HEAP32[i4 >> 2] | 0) >>> 0 > 1 ? (i4 = __ZN4wasm7ElementixEj(i1, 1) | 0, (HEAP8[i4 >> 0] | 0) == 0) : 0) {
   i2 = i2 + 8 | 0;
   i4 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 1) | 0) | 0;
   HEAP32[i2 >> 2] = i4;
   i4 = 2;
  } else {
   HEAP32[i5 >> 2] = 0;
   HEAP32[i5 + 4 >> 2] = 0;
   HEAP32[i5 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i5, 49182, 5);
   i4 = __ZN4wasm22SExpressionWasmBuilder15getPrefixedNameENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i14, i5) | 0;
   HEAP32[i2 + 8 >> 2] = i4;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
   i2 = i2 + 8 | 0;
   i4 = 1;
  }
  i3 = HEAP32[i13 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i8 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i9, i2); else {
   HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i13 >> 2] = (HEAP32[i13 >> 2] | 0) + 4;
  }
  i3 = (__ZN4wasm7Element4listEv(i1) | 0) + 8 | 0;
  if (i4 >>> 0 >= (HEAP32[i3 >> 2] | 0) >>> 0) break;
  i1 = __ZN4wasm7ElementixEj(i1, i4) | 0;
  i4 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 0) | 0) | 0;
  if ((i4 | 0) != (HEAP32[14987] | 0)) break;
  i2 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i6 >> 2] | 0) | 0;
  HEAP32[i10 >> 2] = i2;
  HEAP32[i11 >> 2] = i1;
  i3 = HEAP32[i12 >> 2] | 0;
  i4 = HEAP32[i7 >> 2] | 0;
 }
 i3 = HEAP32[i15 >> 2] | 0;
 i1 = i3;
 i3 = (HEAP32[i12 >> 2] | 0) - i3 >> 3;
 while (1) {
  i6 = i3 + -1 | 0;
  if ((i3 | 0) <= 0) {
   i2 = 17;
   break;
  }
  i4 = HEAP32[i1 + (i6 << 3) >> 2] | 0;
  i5 = HEAP32[i1 + (i6 << 3) + 4 >> 2] | 0;
  i11 = (__ZN4wasm7Element4listEv(i4) | 0) + 8 | 0;
  L23 : do if ((HEAP32[i11 >> 2] | 0) >>> 0 > 1) {
   i1 = __ZN4wasm7ElementixEj(i4, 1) | 0;
   i1 = (HEAP8[i1 >> 0] | 0) == 0 ? 2 : 1;
   i2 = HEAP32[i15 >> 2] | 0;
   if ((i3 | 0) < ((HEAP32[i12 >> 2] | 0) - i2 >> 3 | 0)) {
    i11 = i5 + 12 | 0;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i11, HEAP32[i2 + (i3 << 3) + 4 >> 2] | 0);
    i2 = i11;
    i1 = i1 + 1 | 0;
   } else i2 = i5 + 12 | 0;
   while (1) {
    i11 = (__ZN4wasm7Element4listEv(i4) | 0) + 8 | 0;
    if (i1 >>> 0 >= (HEAP32[i11 >> 2] | 0) >>> 0) break L23;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i14, __ZN4wasm7ElementixEj(i4, i1) | 0) | 0);
    i1 = i1 + 1 | 0;
   }
  } while (0);
  i1 = HEAP32[i13 >> 2] | 0;
  i2 = i1 + -4 | 0;
  if ((HEAP32[i2 >> 2] | 0) != (HEAP32[i5 + 8 >> 2] | 0)) {
   i2 = 26;
   break;
  }
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i11 = i1 + -4 | 0;
   HEAP32[i13 >> 2] = i11;
   i1 = i11;
  }
  __ZN4wasm5Block8finalizeEv(i5);
  i1 = HEAP32[i15 >> 2] | 0;
  i3 = i6;
 }
 if ((i2 | 0) == 17) {
  i14 = HEAP32[i1 + 4 >> 2] | 0;
  __ZNSt3__213__vector_baseINS_4pairIPN4wasm7ElementEPNS2_5BlockEEENS_9allocatorIS7_EEED2Ev(i15);
  STACKTOP = i16;
  return i14 | 0;
 } else if ((i2 | 0) == 26) ___assert_fail(22474, 21446, 890, 22506);
 return 0;
}

function __ZN4wasm17WasmBinaryBuilder4readEv(i13) {
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i15 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i8 = i14 + 76 | 0;
 i11 = i14 + 72 | 0;
 i7 = i14 + 68 | 0;
 i5 = i14 + 64 | 0;
 i6 = i14 + 48 | 0;
 i12 = i14;
 __ZN4wasm17WasmBinaryBuilder10readHeaderEv(i13);
 i9 = i13 + 16 | 0;
 i10 = i13 + 8 | 0;
 i2 = i6 + 4 | 0;
 i3 = i6 + 8 | 0;
 i4 = i6 + 12 | 0;
 i1 = HEAP32[i9 >> 2] | 0;
 L1 : while (1) {
  i15 = HEAP32[i10 >> 2] | 0;
  if (i1 >>> 0 >= ((HEAP32[i15 + 4 >> 2] | 0) - (HEAP32[i15 >> 2] | 0) | 0) >>> 0) {
   i1 = 30;
   break;
  }
  i15 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i13) | 0;
  HEAP32[i11 >> 2] = i15;
  HEAP32[i6 >> 2] = i11;
  HEAP32[i2 >> 2] = i13;
  HEAP32[i3 >> 2] = i7;
  HEAP32[i4 >> 2] = i5;
  do if (__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1065] | 0) | 0) __ZN4wasm17WasmBinaryBuilder9readStartEv(i13); else {
   if (__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1056] | 0) | 0) {
    __ZN4wasm17WasmBinaryBuilder10readMemoryEv(i13);
    break;
   }
   if (__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1057] | 0) | 0) {
    __ZN4wasm17WasmBinaryBuilder14readSignaturesEv(i13);
    break;
   }
   if (__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1058] | 0) | 0) {
    __ZN4wasm17WasmBinaryBuilder11readImportsEv(i13);
    break;
   }
   if (__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1059] | 0) | 0) {
    __ZN4wasm17WasmBinaryBuilder22readFunctionSignaturesEv(i13);
    break;
   }
   if (__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1060] | 0) | 0) {
    __ZN4wasm17WasmBinaryBuilder13readFunctionsEv(i13);
    break;
   }
   if (__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1061] | 0) | 0) {
    __ZN4wasm17WasmBinaryBuilder11readExportsEv(i13);
    break;
   }
   if (__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1062] | 0) | 0) {
    __ZN4wasm17WasmBinaryBuilder16readDataSegmentsEv(i13);
    break;
   }
   if (__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1063] | 0) | 0) {
    __ZN4wasm17WasmBinaryBuilder17readFunctionTableEv(i13);
    break;
   }
   if (!(__ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i6, HEAP32[1064] | 0) | 0)) {
    i1 = 23;
    break L1;
   }
   __ZN4wasm17WasmBinaryBuilder9readNamesEv(i13);
  } while (0);
  i1 = HEAP32[i9 >> 2] | 0;
  if ((i1 | 0) != ((HEAP32[i7 >> 2] | 0) + (HEAP32[i5 >> 2] | 0) | 0)) {
   i1 = 28;
   break;
  }
 }
 if ((i1 | 0) == 23) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 22899) | 0;
  i1 = 0;
  while (1) {
   if (i1 >>> 0 >= (HEAP32[i11 >> 2] | 0) >>> 0) break;
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(60976, HEAP8[(HEAP32[HEAP32[i10 >> 2] >> 2] | 0) + ((HEAP32[i9 >> 2] | 0) + i1) >> 0] | 0) | 0;
   i1 = i1 + 1 | 0;
  }
  i15 = __ZNKSt3__28ios_base6getlocEv(60976 + (HEAP32[(HEAP32[15244] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i8 >> 2] = i15;
  i15 = __ZNKSt3__26locale9use_facetERNS0_2idE(i8, 61680) | 0;
  i15 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i15 >> 2] | 0) + 28 >> 2] & 63](i15, 10) | 0;
  __ZNSt3__26localeD2Ev(i8);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(60976, i15) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(60976) | 0;
  _abort();
 } else if ((i1 | 0) == 28) ___assert_fail(22920, 22948, 1241, 22966); else if ((i1 | 0) == 30) {
  __ZN4wasm17WasmBinaryBuilder16processFunctionsEv(i13);
  i1 = i12;
  i2 = i1 + 44 | 0;
  do {
   HEAP32[i1 >> 2] = 0;
   i1 = i1 + 4 | 0;
  } while ((i1 | 0) < (i2 | 0));
  HEAP32[i12 >> 2] = 4272;
  HEAP32[i12 + 36 >> 2] = 0;
  HEAP32[i12 + 40 >> 2] = 0;
  HEAP32[i12 + 32 >> 2] = i12 + 36;
  HEAP32[i12 + 44 >> 2] = 5;
  i15 = __ZN4wasm13WasmValidator8validateERNS_6ModuleE(i12, HEAP32[i13 >> 2] | 0) | 0;
  __ZN4wasm13WasmValidatorD2Ev(i12);
  if (i15) {
   STACKTOP = i14;
   return;
  } else _abort();
 }
}

function __ZN4wasm17WasmBinaryBuilder14maybeVisitLoadERPNS_10ExpressionEh(i5, i4, i1) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i6 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i7;
 do switch (i1 & 255 | 0) {
 case 32:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 1;
   HEAP32[i3 + 4 >> 2] = 1;
   HEAP8[i3 + 9 >> 0] = 1;
   i1 = 1;
   i6 = 16;
   break;
  }
 case 33:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 1;
   HEAP32[i3 + 4 >> 2] = 1;
   HEAP8[i3 + 9 >> 0] = 0;
   i1 = 1;
   i6 = 16;
   break;
  }
 case 34:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 2;
   HEAP32[i3 + 4 >> 2] = 1;
   HEAP8[i3 + 9 >> 0] = 1;
   i1 = 2;
   i6 = 16;
   break;
  }
 case 35:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 2;
   HEAP32[i3 + 4 >> 2] = 1;
   HEAP8[i3 + 9 >> 0] = 0;
   i1 = 2;
   i6 = 16;
   break;
  }
 case 42:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 4;
   HEAP32[i3 + 4 >> 2] = 1;
   i1 = 4;
   i6 = 16;
   break;
  }
 case 36:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 1;
   HEAP32[i3 + 4 >> 2] = 2;
   HEAP8[i3 + 9 >> 0] = 1;
   i1 = 1;
   i6 = 16;
   break;
  }
 case 37:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 1;
   HEAP32[i3 + 4 >> 2] = 2;
   HEAP8[i3 + 9 >> 0] = 0;
   i1 = 1;
   i6 = 16;
   break;
  }
 case 38:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 2;
   HEAP32[i3 + 4 >> 2] = 2;
   HEAP8[i3 + 9 >> 0] = 1;
   i1 = 2;
   i6 = 16;
   break;
  }
 case 39:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 2;
   HEAP32[i3 + 4 >> 2] = 2;
   HEAP8[i3 + 9 >> 0] = 0;
   i1 = 2;
   i6 = 16;
   break;
  }
 case 40:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 4;
   HEAP32[i3 + 4 >> 2] = 2;
   HEAP8[i3 + 9 >> 0] = 1;
   i1 = 4;
   i6 = 16;
   break;
  }
 case 41:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 4;
   HEAP32[i3 + 4 >> 2] = 2;
   HEAP8[i3 + 9 >> 0] = 0;
   i1 = 4;
   i6 = 16;
   break;
  }
 case 43:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 8;
   HEAP32[i3 + 4 >> 2] = 2;
   i1 = 8;
   i6 = 16;
   break;
  }
 case 44:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 4;
   HEAP32[i3 + 4 >> 2] = 3;
   i1 = 4;
   i6 = 16;
   break;
  }
 case 45:
  {
   i3 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 8;
   HEAP32[i3 + 4 >> 2] = 4;
   i1 = 8;
   i6 = 16;
   break;
  }
 default:
  i1 = 0;
 } while (0);
 if ((i6 | 0) == 16) {
  if (HEAP8[i5 + 12 >> 0] | 0) {
   i1 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25149) | 0;
   i6 = __ZNKSt3__28ios_base6getlocEv(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i2 >> 2] = i6;
   i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
   i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
   __ZNSt3__26localeD2Ev(i2);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i1, i6) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i1) | 0;
   i1 = HEAP8[i3 + 8 >> 0] | 0;
  }
  __ZN4wasm17WasmBinaryBuilder16readMemoryAccessERNS_7AddressEjS2_(i5, i3 + 16 | 0, i1 & 255, i3 + 12 | 0);
  i1 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i5) | 0;
  HEAP32[i3 + 20 >> 2] = i1;
  HEAP32[i4 >> 2] = i3;
  i1 = 1;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder11parseMemoryERNS_7ElementE(i21, i20) {
 i21 = i21 | 0;
 i20 = i20 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i22 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i11 = i22 + 56 | 0;
 i10 = i22 + 52 | 0;
 i12 = i22 + 36 | 0;
 i13 = i22 + 32 | 0;
 i1 = i22 + 40 | 0;
 i19 = i22 + 8 | 0;
 i14 = i22 + 28 | 0;
 i15 = i22 + 24 | 0;
 i16 = i22 + 20 | 0;
 i17 = i22 + 4 | 0;
 i18 = i22;
 HEAP8[i21 + 76 >> 0] = 1;
 i8 = (HEAP32[i21 >> 2] | 0) + 60 | 0;
 i9 = _atoi(__ZN4wasm7Element5c_strEv(__ZN4wasm7ElementixEj(i20, 1) | 0) | 0) | 0;
 __ZN4wasm7AddressaSEy(i8, i9, ((i9 | 0) < 0) << 31 >> 31) | 0;
 i9 = (__ZN4wasm7Element4listEv(i20) | 0) + 8 | 0;
 L1 : do if ((HEAP32[i9 >> 2] | 0) != 2) {
  i9 = __ZN4wasm7ElementixEj(i20, 2) | 0;
  do if (!(HEAP8[i9 >> 0] | 0)) {
   i2 = _atoll(__ZN4wasm7Element5c_strEv(__ZN4wasm7ElementixEj(i20, 2) | 0) | 0) | 0;
   i3 = tempRet0;
   if (i3 >>> 0 > 0 | (i3 | 0) == 0 & i2 >>> 0 > 65535) {
    i22 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 20619, 27);
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i22, i1);
    ___cxa_throw(i22 | 0, 64, 279);
   } else {
    __ZN4wasm7AddressaSEy((HEAP32[i21 >> 2] | 0) + 64 | 0, i2, i3) | 0;
    i1 = 3;
    break;
   }
  } else i1 = 2; while (0);
  i8 = i19 + 4 | 0;
  i9 = i19 + 8 | 0;
  while (1) {
   i7 = (__ZN4wasm7Element4listEv(i20) | 0) + 8 | 0;
   if (i1 >>> 0 >= (HEAP32[i7 >> 2] | 0) >>> 0) break L1;
   i4 = __ZN4wasm7ElementixEj(i20, i1) | 0;
   i7 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i4, 0) | 0) | 0;
   if ((i7 | 0) != (HEAP32[14978] | 0)) break;
   i2 = __ZN4wasm7Element5c_strEv(__ZN4wasm7ElementixEj(i4, 2) | 0) | 0;
   i3 = _strlen(i2) | 0;
   do if (!i3) {
    i5 = HEAP32[i21 >> 2] | 0;
    i2 = _atoi(__ZN4wasm7Element5c_strEv(__ZN4wasm7ElementixEj(i4, 1) | 0) | 0) | 0;
    HEAP32[i17 >> 2] = i2;
    HEAP32[i18 >> 2] = 0;
    i3 = i5 + 72 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if (i4 >>> 0 < (HEAP32[i5 + 76 >> 2] | 0) >>> 0) {
     __ZN4wasm7AddressC2Ey(i12, i2, ((i2 | 0) < 0) << 31 >> 31);
     __ZN4wasm7AddressC2Ey(i13, 0, 0);
     HEAP32[i10 >> 2] = HEAP32[i12 >> 2];
     HEAP32[i11 >> 2] = HEAP32[i13 >> 2];
     __ZN4wasm6Memory7SegmentC2ENS_7AddressEPKcS2_(i4, i10, 67717, i11);
     HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 16;
     break;
    } else {
     __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE24__emplace_back_slow_pathIJiRA1_KciEEEvDpOT_(i5 + 68 | 0, i17, 67717, i18);
     break;
    }
   } else {
    HEAP32[i19 >> 2] = 0;
    HEAP32[i8 >> 2] = 0;
    HEAP32[i9 >> 2] = 0;
    __ZN4wasm22SExpressionWasmBuilder14stringToBinaryEPKcjRNSt3__26vectorIcNS3_9allocatorIcEEEE(i21, i2, i3, i19);
    i7 = HEAP32[i21 >> 2] | 0;
    i2 = _atoi(__ZN4wasm7Element5c_strEv(__ZN4wasm7ElementixEj(i4, 1) | 0) | 0) | 0;
    HEAP32[i14 >> 2] = i2;
    i3 = HEAP32[i19 >> 2] | 0;
    HEAP32[i15 >> 2] = i3;
    i4 = (HEAP32[i8 >> 2] | 0) - i3 | 0;
    HEAP32[i16 >> 2] = i4;
    i5 = i7 + 72 | 0;
    i6 = HEAP32[i5 >> 2] | 0;
    if (i6 >>> 0 < (HEAP32[i7 + 76 >> 2] | 0) >>> 0) {
     __ZN4wasm7AddressC2Ey(i12, i2, ((i2 | 0) < 0) << 31 >> 31);
     __ZN4wasm7AddressC2Ey(i13, i4, 0);
     HEAP32[i10 >> 2] = HEAP32[i12 >> 2];
     HEAP32[i11 >> 2] = HEAP32[i13 >> 2];
     __ZN4wasm6Memory7SegmentC2ENS_7AddressEPKcS2_(i6, i10, i3, i11);
     HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 16;
    } else __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE24__emplace_back_slow_pathIJiPcjEEEvDpOT_(i7 + 68 | 0, i14, i15, i16);
    __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i19);
   } while (0);
   i1 = i1 + 1 | 0;
  }
  ___assert_fail(22797, 21446, 1220, 22823);
 } while (0);
 STACKTOP = i22;
 return;
}

function __ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce(i1, i24, i12, i22, i21, d4) {
 i1 = i1 | 0;
 i24 = i24 | 0;
 i12 = i12 | 0;
 i22 = i22 | 0;
 i21 = i21 | 0;
 d4 = +d4;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i23 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0;
 i28 = STACKTOP;
 STACKTOP = STACKTOP + 384 | 0;
 i14 = i28 + 8 | 0;
 i1 = i28;
 i5 = i28 + 284 | 0;
 i7 = i28 + 72 | 0;
 i2 = i28 + 184 | 0;
 i23 = i28 + 68 | 0;
 i19 = i28 + 180 | 0;
 i16 = i28 + 177 | 0;
 i20 = i28 + 176 | 0;
 i25 = i28 + 56 | 0;
 i27 = i28 + 44 | 0;
 i26 = i28 + 32 | 0;
 i11 = i28 + 28 | 0;
 i6 = i28 + 76 | 0;
 i18 = i28 + 24 | 0;
 i17 = i28 + 16 | 0;
 i15 = i28 + 20 | 0;
 HEAP32[i7 >> 2] = i5;
 HEAPF64[i14 >> 3] = d4;
 i5 = _snprintf(i5, 100, 54741, i14) | 0;
 if (i5 >>> 0 > 99) {
  i5 = __ZNSt3__26__clocEv() | 0;
  HEAPF64[i1 >> 3] = d4;
  i5 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i7, i5, 54741, i1) | 0;
  i1 = HEAP32[i7 >> 2] | 0;
  if (!i1) i1 = HEAP32[i7 >> 2] | 0;
  i2 = _malloc(i5) | 0;
  i3 = i2;
  if (!i2) {
   i2 = 0;
   i13 = i1;
   i10 = i5;
  } else {
   i13 = i1;
   i10 = i5;
  }
 } else {
  i3 = 0;
  i13 = 0;
  i10 = i5;
 }
 i1 = __ZNKSt3__28ios_base6getlocEv(i22) | 0;
 HEAP32[i23 >> 2] = i1;
 i9 = __ZNKSt3__26locale9use_facetERNS0_2idE(i23, 61680) | 0;
 i8 = HEAP32[i7 >> 2] | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i9 >> 2] | 0) + 32 >> 2] & 7](i9, i8, i8 + i10 | 0, i2) | 0;
 if (!i10) i8 = 0; else i8 = (HEAP8[HEAP32[i7 >> 2] >> 0] | 0) == 45;
 HEAP32[i25 >> 2] = 0;
 HEAP32[i25 + 4 >> 2] = 0;
 HEAP32[i25 + 8 >> 2] = 0;
 i5 = 0;
 while (1) {
  if ((i5 | 0) == 3) break;
  HEAP32[i25 + (i5 << 2) >> 2] = 0;
  i5 = i5 + 1 | 0;
 }
 HEAP32[i27 >> 2] = 0;
 HEAP32[i27 + 4 >> 2] = 0;
 HEAP32[i27 + 8 >> 2] = 0;
 i5 = 0;
 while (1) {
  if ((i5 | 0) == 3) break;
  HEAP32[i27 + (i5 << 2) >> 2] = 0;
  i5 = i5 + 1 | 0;
 }
 HEAP32[i26 >> 2] = 0;
 HEAP32[i26 + 4 >> 2] = 0;
 HEAP32[i26 + 8 >> 2] = 0;
 i5 = 0;
 while (1) {
  if ((i5 | 0) == 3) break;
  HEAP32[i26 + (i5 << 2) >> 2] = 0;
  i5 = i5 + 1 | 0;
 }
 __ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri(i12, i8, i23, i19, i16, i20, i25, i27, i26, i11);
 i7 = HEAP32[i11 >> 2] | 0;
 if ((i10 | 0) > (i7 | 0)) {
  i12 = HEAP8[i26 + 11 >> 0] | 0;
  i5 = HEAP8[i27 + 11 >> 0] | 0;
  i5 = (i12 << 24 >> 24 < 0 ? HEAP32[i26 + 4 >> 2] | 0 : i12 & 255) + (i10 - i7 << 1 | 1) + (i5 << 24 >> 24 < 0 ? HEAP32[i27 + 4 >> 2] | 0 : i5 & 255) | 0;
 } else {
  i12 = HEAP8[i26 + 11 >> 0] | 0;
  i5 = HEAP8[i27 + 11 >> 0] | 0;
  i5 = (i12 << 24 >> 24 < 0 ? HEAP32[i26 + 4 >> 2] | 0 : i12 & 255) + 2 + (i5 << 24 >> 24 < 0 ? HEAP32[i27 + 4 >> 2] | 0 : i5 & 255) | 0;
 }
 i5 = i5 + i7 | 0;
 if (i5 >>> 0 > 100) {
  i6 = _malloc(i5) | 0;
  i5 = i6;
  if (!i6) i6 = 0;
 } else i5 = 0;
 __ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i(i6, i18, i17, HEAP32[i22 + 4 >> 2] | 0, i2, i2 + i10 | 0, i9, i8, i19, HEAP8[i16 >> 0] | 0, HEAP8[i20 >> 0] | 0, i25, i27, i26, i7);
 HEAP32[i15 >> 2] = HEAP32[i24 >> 2];
 i24 = HEAP32[i18 >> 2] | 0;
 i2 = HEAP32[i17 >> 2] | 0;
 HEAP32[i14 >> 2] = HEAP32[i15 >> 2];
 i2 = __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i14, i6, i24, i2, i22, i21) | 0;
 if (i5) {
  _free(i5);
  i1 = HEAP32[i23 >> 2] | 0;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i26);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i27);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i25);
 __ZNSt3__214__shared_count16__release_sharedEv(i1) | 0;
 if (i3 | 0) _free(i3);
 if (i13 | 0) _free(i13);
 STACKTOP = i28;
 return i2 | 0;
}

function __ZN4wasm14SimplifyLocals9visitPostEPS0_PPNS_10ExpressionE(i8, i12) {
 i8 = i8 | 0;
 i12 = i12 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 272 | 0;
 i9 = i15 + 256 | 0;
 i14 = i15 + 176 | 0;
 i5 = i15 + 248 | 0;
 i6 = i15 + 164 | 0;
 i13 = i15 + 160 | 0;
 i10 = i15 + 80 | 0;
 i11 = i15;
 i1 = HEAP32[i12 >> 2] | 0;
 i7 = (HEAP32[i1 >> 2] | 0) == 10 ? i1 : 0;
 i4 = (i7 | 0) != 0;
 if (i4 ? (i2 = i8 + 44 | 0, i3 = __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE4findIjEENS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEERKT_(i2, i7 + 8 | 0) | 0, (i3 | 0) != (i8 + 48 | 0)) : 0) {
  i1 = i3 + 20 | 0;
  i16 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[HEAP32[i1 >> 2] >> 2] | 0) | 0) + 12 | 0;
  HEAP32[HEAP32[i1 >> 2] >> 2] = HEAP32[i16 >> 2];
  HEAP32[i14 >> 2] = i3;
  HEAP32[i9 >> 2] = HEAP32[i14 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5eraseENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEE(i2, i9) | 0;
  HEAP8[i8 + 92 >> 0] = 1;
  i1 = HEAP32[i12 >> 2] | 0;
 }
 i16 = i14 + 4 | 0;
 HEAP32[i16 >> 2] = 0;
 HEAP32[i16 + 4 >> 2] = 0;
 HEAP32[i16 + 8 >> 2] = 0;
 HEAP32[i16 + 12 >> 2] = 0;
 HEAP32[i16 + 16 >> 2] = 0;
 HEAP32[i16 + 20 >> 2] = 0;
 HEAP32[i14 >> 2] = 5392;
 HEAP8[i14 + 28 >> 0] = 0;
 HEAP8[i14 + 29 >> 0] = 0;
 HEAP32[i14 + 36 >> 2] = 0;
 HEAP32[i14 + 40 >> 2] = 0;
 HEAP32[i14 + 32 >> 2] = i14 + 36;
 HEAP32[i14 + 48 >> 2] = 0;
 HEAP32[i14 + 52 >> 2] = 0;
 HEAP32[i14 + 44 >> 2] = i14 + 48;
 HEAP8[i14 + 56 >> 0] = 0;
 HEAP8[i14 + 57 >> 0] = 0;
 HEAP32[i14 + 64 >> 2] = 0;
 HEAP32[i14 + 68 >> 2] = 0;
 HEAP32[i14 + 60 >> 2] = i14 + 64;
 if (__ZN4wasm14EffectAnalyzer9checkPostEPNS_10ExpressionE(i14, i1) | 0) __ZN4wasm14SimplifyLocals18checkInvalidationsERNS_14EffectAnalyzerE(i8, i14);
 i3 = i8 + 100 | 0;
 do if (i4) {
  i1 = HEAP32[i3 >> 2] | 0;
  i2 = i1 + -4 | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i16 = i1 + -4 | 0;
   HEAP32[i3 >> 2] = i16;
   i1 = i16;
  }
  i1 = i8 + 96 | 0;
  HEAP32[i5 >> 2] = i7;
  if (i2 >>> 0 < (HEAP32[i8 + 104 >> 2] | 0) >>> 0) {
   HEAP32[i2 >> 2] = i7;
   HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 4;
  } else __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i1, i5);
  __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEEC2ERKS6_(i6, i1);
  i16 = __ZN4wasm18ExpressionAnalyzer12isResultUsedENSt3__26vectorIPNS_10ExpressionENS1_9allocatorIS4_EEEEPNS_8FunctionE(i6, HEAP32[i8 + 36 >> 2] | 0) | 0;
  __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i6);
  if (!i16) {
   i2 = HEAP32[i7 + 8 >> 2] | 0;
   HEAP32[i13 >> 2] = i2;
   i1 = i8 + 44 | 0;
   if (!(__ZNKSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE14__count_uniqueIjEEjRKT_(i1, i13) | 0)) {
    __ZN4wasm14SimplifyLocals12SinkableInfoC2EPPNS_10ExpressionE(i11, i12);
    HEAP32[i10 >> 2] = i2;
    __ZN4wasm14SimplifyLocals12SinkableInfoC2EOS1_(i10 + 4 | 0, i11);
    __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIjJNS_4pairIjS4_EEEEENSE_INS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i9, i1, i10, i10);
    __ZN4wasm14EffectAnalyzerD2Ev(i10 + 8 | 0);
    __ZN4wasm14EffectAnalyzerD2Ev(i11 + 4 | 0);
    break;
   } else ___assert_fail(41915, 41949, 243, 41979);
  }
 } while (0);
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = i2 + -4 | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  i16 = i2 + -4 | 0;
  HEAP32[i3 >> 2] = i16;
  i2 = i16;
 }
 __ZN4wasm14EffectAnalyzerD2Ev(i14);
 STACKTOP = i15;
 return;
}

function __ZN4wasm6Vacuum8optimizeEPNS_10ExpressionEb(i2, i1, i17) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i17 = i17 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i19 = 0, i20 = 0;
 i18 = STACKTOP;
 STACKTOP = STACKTOP + 720 | 0;
 i6 = i18 + 648 | 0;
 i7 = i18 + 576 | 0;
 i8 = i18 + 504 | 0;
 i9 = i18 + 432 | 0;
 i10 = i18 + 360 | 0;
 i11 = i18 + 288 | 0;
 i12 = i18 + 216 | 0;
 i13 = i18 + 144 | 0;
 i14 = i18 + 72 | 0;
 i15 = i18;
 L1 : while (1) {
  i2 = HEAP32[i1 >> 2] | 0;
  switch (i2 | 0) {
  case 19:
   {
    i1 = 0;
    i19 = 19;
    break L1;
   }
  case 20:
  case 18:
  case 17:
  case 12:
  case 11:
  case 10:
  case 8:
  case 7:
  case 6:
  case 5:
  case 4:
  case 3:
  case 2:
  case 1:
   {
    i16 = i1;
    break L1;
   }
  case 16:
  case 15:
  case 14:
  case 9:
  case 13:
   break;
  default:
   {
    i19 = 18;
    break L1;
   }
  }
  if (i17) {
   i19 = 19;
   break;
  }
  switch (i2 | 0) {
  case 9:
  case 13:
   {
    i1 = 0;
    i19 = 19;
    break L1;
   }
  default:
   {}
  }
  i3 = (i1 | 0) == 0;
  do if (i3 | (i2 | 0) != 14) {
   if (!(i3 | (i2 | 0) != 15)) {
    i2 = i1 + 12 | 0;
    __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i7, HEAP32[i2 >> 2] | 0);
    i5 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i7) | 0;
    __ZN4wasm14EffectAnalyzerD2Ev(i7);
    i3 = i1 + 16 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if (i5) {
     __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i8, i4);
     i5 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i8) | 0;
     __ZN4wasm14EffectAnalyzerD2Ev(i8);
     if (i5) {
      i19 = 19;
      break L1;
     } else {
      i1 = i2;
      break;
     }
    } else {
     __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i9, i4);
     i5 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i9) | 0;
     __ZN4wasm14EffectAnalyzerD2Ev(i9);
     if (i5) {
      i1 = i3;
      break;
     } else {
      i1 = 0;
      i19 = 19;
      break L1;
     }
    }
   }
   i2 = __ZN4wasm10Expression4castINS_6SelectEEEPT_v(i1) | 0;
   i3 = i2 + 8 | 0;
   __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i10, HEAP32[i3 >> 2] | 0);
   i20 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i10) | 0;
   __ZN4wasm14EffectAnalyzerD2Ev(i10);
   i5 = i2 + 12 | 0;
   i4 = HEAP32[i5 >> 2] | 0;
   if (i20) {
    __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i11, i4);
    i20 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i11) | 0;
    __ZN4wasm14EffectAnalyzerD2Ev(i11);
    if (i20) {
     i19 = 19;
     break L1;
    }
    __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i12, HEAP32[i2 + 16 >> 2] | 0);
    i20 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i12) | 0;
    __ZN4wasm14EffectAnalyzerD2Ev(i12);
    if (i20) {
     i19 = 19;
     break L1;
    } else {
     i1 = i3;
     break;
    }
   }
   __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i13, i4);
   i20 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i13) | 0;
   __ZN4wasm14EffectAnalyzerD2Ev(i13);
   i2 = i2 + 16 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   if (i20) {
    __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i14, i3);
    i20 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i14) | 0;
    __ZN4wasm14EffectAnalyzerD2Ev(i14);
    if (i20) {
     i19 = 19;
     break L1;
    } else {
     i1 = i5;
     break;
    }
   } else {
    __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i15, i3);
    i20 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i15) | 0;
    __ZN4wasm14EffectAnalyzerD2Ev(i15);
    if (i20) {
     i1 = i2;
     break;
    } else {
     i1 = 0;
     i19 = 19;
     break L1;
    }
   }
  } else {
   i1 = i1 + 12 | 0;
   __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i6, HEAP32[i1 >> 2] | 0);
   i20 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i6) | 0;
   __ZN4wasm14EffectAnalyzerD2Ev(i6);
   if (!i20) {
    i1 = 0;
    i19 = 19;
    break L1;
   }
  } while (0);
  i1 = HEAP32[i1 >> 2] | 0;
 }
 if ((i19 | 0) != 18) if ((i19 | 0) == 19) i16 = i1;
 STACKTOP = i18;
 return i16 | 0;
}

function __ZN4wasm19DeadCodeElimination4scanEPS0_PPNS_10ExpressionE(i2, i5) {
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 L1 : do if (!(HEAP8[i2 + 44 >> 0] | 0)) do switch (i1 | 0) {
 case 1:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 2:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 3:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 4:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 5:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 6:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 7:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 8:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 9:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 10:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 11:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 12:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 13:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 14:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 15:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 16:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 17:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 18:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 19:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 case 20:
  {
   HEAP32[i3 >> 2] = 20;
   HEAP32[i3 + 4 >> 2] = 0;
   break L1;
  }
 default:
  {}
 } while (0); else switch (i1 | 0) {
 case 2:
  {
   i1 = i2 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 119, i5);
   i4 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i3) | 0) + 16 | 0;
   if (HEAP32[i4 >> 2] | 0) {
    __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 118, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i3) | 0) + 16 | 0);
    __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 120, i5);
   }
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 118, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i3) | 0) + 12 | 0);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 121, i5);
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 118, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i3) | 0) + 8 | 0);
   break L1;
  }
 case 1:
  {
   i4 = i2 + 16 | 0;
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 122, i5);
   i3 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i3) | 0;
   i1 = i3 + 12 | 0;
   i3 = HEAP32[i3 + 20 >> 2] | 0;
   while (1) {
    i2 = i3 + -1 | 0;
    if ((i3 | 0) <= 0) break;
    __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 124, i5);
    __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 118, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2) | 0);
    i3 = i2;
   }
   __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i4, 123, i5);
   break L1;
  }
 default:
  {
   __ZN4wasm10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i2, i5);
   break L1;
  }
 } while (0);
 return;
}

function __ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE(i1, i23, i3, i21, i20, i19) {
 i1 = i1 | 0;
 i23 = i23 | 0;
 i3 = i3 | 0;
 i21 = i21 | 0;
 i20 = i20 | 0;
 i19 = i19 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i22 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0;
 i27 = STACKTOP;
 STACKTOP = STACKTOP + 480 | 0;
 i11 = i27 + 468 | 0;
 i22 = i27 + 464 | 0;
 i17 = i27 + 472 | 0;
 i14 = i27 + 460 | 0;
 i18 = i27 + 456 | 0;
 i24 = i27 + 444 | 0;
 i26 = i27 + 432 | 0;
 i25 = i27 + 420 | 0;
 i4 = i27 + 416 | 0;
 i9 = i27 + 16 | 0;
 i16 = i27 + 8 | 0;
 i15 = i27 + 4 | 0;
 i12 = i27;
 i1 = __ZNKSt3__28ios_base6getlocEv(i21) | 0;
 HEAP32[i22 >> 2] = i1;
 i13 = __ZNKSt3__26locale9use_facetERNS0_2idE(i22, 61712) | 0;
 i7 = i19 + 8 + 3 | 0;
 i10 = HEAP8[i7 >> 0] | 0;
 i2 = i10 << 24 >> 24 < 0;
 i8 = i19 + 4 | 0;
 if (!((i2 ? HEAP32[i8 >> 2] | 0 : i10 & 255) | 0)) i10 = 0; else {
  i10 = HEAP32[(i2 ? HEAP32[i19 >> 2] | 0 : i19) >> 2] | 0;
  i10 = (i10 | 0) == (FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 44 >> 2] & 63](i13, 45) | 0);
 };
 HEAP32[i24 >> 2] = 0;
 HEAP32[i24 + 4 >> 2] = 0;
 HEAP32[i24 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i24 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 HEAP32[i26 >> 2] = 0;
 HEAP32[i26 + 4 >> 2] = 0;
 HEAP32[i26 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i26 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 HEAP32[i25 >> 2] = 0;
 HEAP32[i25 + 4 >> 2] = 0;
 HEAP32[i25 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i25 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 __ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri(i3, i10, i22, i17, i14, i18, i24, i26, i25, i4);
 i5 = HEAP8[i7 >> 0] | 0;
 i3 = HEAP32[i8 >> 2] | 0;
 i2 = i5 << 24 >> 24 < 0 ? i3 : i5 & 255;
 i6 = HEAP32[i4 >> 2] | 0;
 if ((i2 | 0) > (i6 | 0)) {
  i28 = HEAP8[i25 + 8 + 3 >> 0] | 0;
  i4 = HEAP8[i26 + 8 + 3 >> 0] | 0;
  i2 = (i28 << 24 >> 24 < 0 ? HEAP32[i25 + 4 >> 2] | 0 : i28 & 255) + (i2 - i6 << 1 | 1) + (i4 << 24 >> 24 < 0 ? HEAP32[i26 + 4 >> 2] | 0 : i4 & 255) | 0;
 } else {
  i28 = HEAP8[i25 + 8 + 3 >> 0] | 0;
  i2 = HEAP8[i26 + 8 + 3 >> 0] | 0;
  i2 = (i28 << 24 >> 24 < 0 ? HEAP32[i25 + 4 >> 2] | 0 : i28 & 255) + 2 + (i2 << 24 >> 24 < 0 ? HEAP32[i26 + 4 >> 2] | 0 : i2 & 255) | 0;
 }
 i2 = i2 + i6 | 0;
 if (i2 >>> 0 > 100) {
  i2 = _malloc(i2 << 2) | 0;
  i4 = i2;
  if (!i2) {
   i5 = HEAP8[i7 >> 0] | 0;
   i3 = HEAP32[i8 >> 2] | 0;
   i2 = 0;
  }
 } else {
  i4 = 0;
  i2 = i9;
 }
 i28 = i5 << 24 >> 24 < 0;
 i19 = i28 ? HEAP32[i19 >> 2] | 0 : i19;
 __ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i(i2, i16, i15, HEAP32[i21 + 4 >> 2] | 0, i19, i19 + ((i28 ? i3 : i5 & 255) << 2) | 0, i13, i10, i17, HEAP32[i14 >> 2] | 0, HEAP32[i18 >> 2] | 0, i24, i26, i25, i6);
 HEAP32[i12 >> 2] = HEAP32[i23 >> 2];
 i23 = HEAP32[i16 >> 2] | 0;
 i28 = HEAP32[i15 >> 2] | 0;
 HEAP32[i11 >> 2] = HEAP32[i12 >> 2];
 i2 = __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i11, i2, i23, i28, i21, i20) | 0;
 if (i4) {
  _free(i4);
  i1 = HEAP32[i22 >> 2] | 0;
 }
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i25);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i26);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i24);
 __ZNSt3__214__shared_count16__release_sharedEv(i1) | 0;
 STACKTOP = i27;
 return i2 | 0;
}

function __ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE(i1, i23, i3, i21, i20, i19) {
 i1 = i1 | 0;
 i23 = i23 | 0;
 i3 = i3 | 0;
 i21 = i21 | 0;
 i20 = i20 | 0;
 i19 = i19 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i22 = 0, i24 = 0, i25 = 0, i26 = 0, i27 = 0, i28 = 0;
 i27 = STACKTOP;
 STACKTOP = STACKTOP + 176 | 0;
 i11 = i27 + 56 | 0;
 i22 = i27 + 52 | 0;
 i17 = i27 + 164 | 0;
 i14 = i27 + 161 | 0;
 i18 = i27 + 160 | 0;
 i24 = i27 + 40 | 0;
 i26 = i27 + 28 | 0;
 i25 = i27 + 16 | 0;
 i4 = i27 + 12 | 0;
 i9 = i27 + 60 | 0;
 i16 = i27 + 8 | 0;
 i15 = i27 + 4 | 0;
 i12 = i27;
 i1 = __ZNKSt3__28ios_base6getlocEv(i21) | 0;
 HEAP32[i22 >> 2] = i1;
 i13 = __ZNKSt3__26locale9use_facetERNS0_2idE(i22, 61680) | 0;
 i7 = i19 + 11 | 0;
 i10 = HEAP8[i7 >> 0] | 0;
 i2 = i10 << 24 >> 24 < 0;
 i8 = i19 + 4 | 0;
 if (!((i2 ? HEAP32[i8 >> 2] | 0 : i10 & 255) | 0)) i10 = 0; else {
  i10 = HEAP8[(i2 ? HEAP32[i19 >> 2] | 0 : i19) >> 0] | 0;
  i10 = i10 << 24 >> 24 == (FUNCTION_TABLE_iii[HEAP32[(HEAP32[i13 >> 2] | 0) + 28 >> 2] & 63](i13, 45) | 0) << 24 >> 24;
 };
 HEAP32[i24 >> 2] = 0;
 HEAP32[i24 + 4 >> 2] = 0;
 HEAP32[i24 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i24 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 HEAP32[i26 >> 2] = 0;
 HEAP32[i26 + 4 >> 2] = 0;
 HEAP32[i26 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i26 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 HEAP32[i25 >> 2] = 0;
 HEAP32[i25 + 4 >> 2] = 0;
 HEAP32[i25 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i25 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 __ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri(i3, i10, i22, i17, i14, i18, i24, i26, i25, i4);
 i5 = HEAP8[i7 >> 0] | 0;
 i3 = HEAP32[i8 >> 2] | 0;
 i2 = i5 << 24 >> 24 < 0 ? i3 : i5 & 255;
 i6 = HEAP32[i4 >> 2] | 0;
 if ((i2 | 0) > (i6 | 0)) {
  i28 = HEAP8[i25 + 11 >> 0] | 0;
  i4 = HEAP8[i26 + 11 >> 0] | 0;
  i2 = (i28 << 24 >> 24 < 0 ? HEAP32[i25 + 4 >> 2] | 0 : i28 & 255) + (i2 - i6 << 1 | 1) + (i4 << 24 >> 24 < 0 ? HEAP32[i26 + 4 >> 2] | 0 : i4 & 255) | 0;
 } else {
  i28 = HEAP8[i25 + 11 >> 0] | 0;
  i2 = HEAP8[i26 + 11 >> 0] | 0;
  i2 = (i28 << 24 >> 24 < 0 ? HEAP32[i25 + 4 >> 2] | 0 : i28 & 255) + 2 + (i2 << 24 >> 24 < 0 ? HEAP32[i26 + 4 >> 2] | 0 : i2 & 255) | 0;
 }
 i2 = i2 + i6 | 0;
 if (i2 >>> 0 > 100) {
  i2 = _malloc(i2) | 0;
  i4 = i2;
  if (!i2) {
   i5 = HEAP8[i7 >> 0] | 0;
   i3 = HEAP32[i8 >> 2] | 0;
   i2 = 0;
  }
 } else {
  i4 = 0;
  i2 = i9;
 }
 i28 = i5 << 24 >> 24 < 0;
 i19 = i28 ? HEAP32[i19 >> 2] | 0 : i19;
 __ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i(i2, i16, i15, HEAP32[i21 + 4 >> 2] | 0, i19, i19 + (i28 ? i3 : i5 & 255) | 0, i13, i10, i17, HEAP8[i14 >> 0] | 0, HEAP8[i18 >> 0] | 0, i24, i26, i25, i6);
 HEAP32[i12 >> 2] = HEAP32[i23 >> 2];
 i23 = HEAP32[i16 >> 2] | 0;
 i28 = HEAP32[i15 >> 2] | 0;
 HEAP32[i11 >> 2] = HEAP32[i12 >> 2];
 i2 = __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i11, i2, i23, i28, i21, i20) | 0;
 if (i4) {
  _free(i4);
  i1 = HEAP32[i22 >> 2] | 0;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i25);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i26);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i24);
 __ZNSt3__214__shared_count16__release_sharedEv(i1) | 0;
 STACKTOP = i27;
 return i2 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_126parse_base_unresolved_nameINS0_2DbEEEPKcS4_S4_RT_(i5, i4, i6) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i8;
 L1 : do if ((i4 - i5 | 0) > 1) {
  i1 = HEAP8[i5 >> 0] | 0;
  switch (i1 << 24 >> 24) {
  case 100:
  case 111:
   {
    if ((HEAP8[i5 + 1 >> 0] | 0) == 110) {
     i3 = i5 + 2 | 0;
     if (i1 << 24 >> 24 == 111) {
      i1 = __ZN10__cxxabiv112_GLOBAL__N_119parse_operator_nameINS0_2DbEEEPKcS4_S4_RT_(i3, i4, i6) | 0;
      if ((i1 | 0) == (i3 | 0)) {
       i1 = i5;
       break L1;
      }
      i5 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i1, i4, i6) | 0;
      if ((i5 | 0) == (i1 | 0)) break L1;
      i4 = i6 + 4 | 0;
      i1 = HEAP32[i4 >> 2] | 0;
      if (((i1 - (HEAP32[i6 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) {
       i1 = i5;
       break L1;
      }
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i7, i1 + -24 | 0);
      i1 = HEAP32[i4 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i6 = i3 + -24 | 0;
       HEAP32[i4 >> 2] = i6;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
       i3 = HEAP32[i4 >> 2] | 0;
      }
      i6 = HEAP8[i7 + 11 >> 0] | 0;
      i4 = i6 << 24 >> 24 < 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i4 ? HEAP32[i7 >> 2] | 0 : i7, i4 ? HEAP32[i7 + 4 >> 2] | 0 : i6 & 255) | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i7);
      i1 = i5;
      break L1;
     } else {
      if ((i3 | 0) != (i4 | 0)) {
       i1 = __ZN10__cxxabiv112_GLOBAL__N_121parse_unresolved_typeINS0_2DbEEEPKcS4_S4_RT_(i3, i4, i6) | 0;
       if ((i1 | 0) == (i3 | 0)) i1 = __ZN10__cxxabiv112_GLOBAL__N_115parse_simple_idINS0_2DbEEEPKcS4_S4_RT_(i3, i4, i6) | 0;
       if ((i1 | 0) != (i3 | 0) ? (i2 = HEAP32[i6 + 4 >> 2] | 0, (HEAP32[i6 >> 2] | 0) != (i2 | 0)) : 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i2 + -24 | 0, 0, 57053) | 0; else i1 = i3;
      } else i1 = i4;
      i1 = (i1 | 0) == (i3 | 0) ? i5 : i1;
      break L1;
     }
    }
    break;
   }
  default:
   {}
  }
  i1 = __ZN10__cxxabiv112_GLOBAL__N_115parse_simple_idINS0_2DbEEEPKcS4_S4_RT_(i5, i4, i6) | 0;
  if ((i1 | 0) == (i5 | 0)) {
   i1 = __ZN10__cxxabiv112_GLOBAL__N_119parse_operator_nameINS0_2DbEEEPKcS4_S4_RT_(i5, i4, i6) | 0;
   if ((i1 | 0) != (i5 | 0)) {
    i5 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i1, i4, i6) | 0;
    if ((i5 | 0) != (i1 | 0)) {
     i4 = i6 + 4 | 0;
     i1 = HEAP32[i4 >> 2] | 0;
     if (((i1 - (HEAP32[i6 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) i1 = i5; else {
      __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i7, i1 + -24 | 0);
      i1 = HEAP32[i4 >> 2] | 0;
      i2 = i1 + -24 | 0;
      i3 = i1;
      while (1) {
       if ((i3 | 0) == (i2 | 0)) break;
       i6 = i3 + -24 | 0;
       HEAP32[i4 >> 2] = i6;
       __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i6);
       i3 = HEAP32[i4 >> 2] | 0;
      }
      i6 = HEAP8[i7 + 11 >> 0] | 0;
      i4 = i6 << 24 >> 24 < 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i4 ? HEAP32[i7 >> 2] | 0 : i7, i4 ? HEAP32[i7 + 4 >> 2] | 0 : i6 & 255) | 0;
      __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i7);
      i1 = i5;
     }
    }
   } else i1 = i5;
  }
 } else i1 = i5; while (0);
 STACKTOP = i8;
 return i1 | 0;
}

function __GLOBAL__sub_I_shared_constants_cpp() {
 __ZN6cashew7IString3setEPKcb(59764, 48798, 1);
 __ZN6cashew7IString3setEPKcb(59768, 48805, 1);
 __ZN6cashew7IString3setEPKcb(59772, 48809, 1);
 __ZN6cashew7IString3setEPKcb(59776, 52371, 1);
 __ZN6cashew7IString3setEPKcb(59780, 49946, 1);
 __ZN6cashew7IString3setEPKcb(59784, 48818, 1);
 __ZN6cashew7IString3setEPKcb(59788, 48826, 1);
 __ZN6cashew7IString3setEPKcb(59792, 48836, 1);
 __ZN6cashew7IString3setEPKcb(59796, 48847, 1);
 __ZN6cashew7IString3setEPKcb(59800, 48858, 1);
 __ZN6cashew7IString3setEPKcb(59804, 48869, 1);
 __ZN6cashew7IString3setEPKcb(59808, 48881, 1);
 __ZN6cashew7IString3setEPKcb(59812, 48893, 1);
 __ZN6cashew7IString3setEPKcb(59816, 48906, 1);
 __ZN6cashew7IString3setEPKcb(59820, 48919, 1);
 __ZN6cashew7IString3setEPKcb(59824, 48939, 1);
 __ZN6cashew7IString3setEPKcb(59828, 48944, 1);
 __ZN6cashew7IString3setEPKcb(59832, 48949, 1);
 __ZN6cashew7IString3setEPKcb(59836, 48955, 1);
 __ZN6cashew7IString3setEPKcb(59840, 48962, 1);
 __ZN6cashew7IString3setEPKcb(59844, 48971, 1);
 __ZN6cashew7IString3setEPKcb(59848, 48979, 1);
 __ZN6cashew7IString3setEPKcb(59852, 48990, 1);
 __ZN6cashew7IString3setEPKcb(59856, 49002, 1);
 __ZN6cashew7IString3setEPKcb(59860, 49006, 1);
 __ZN6cashew7IString3setEPKcb(59864, 49012, 1);
 __ZN6cashew7IString3setEPKcb(59868, 49017, 1);
 __ZN6cashew7IString3setEPKcb(59872, 49022, 1);
 __ZN6cashew7IString3setEPKcb(59876, 49040, 1);
 __ZN6cashew7IString3setEPKcb(59880, 49049, 1);
 __ZN6cashew7IString3setEPKcb(59884, 49066, 1);
 __ZN6cashew7IString3setEPKcb(59888, 49074, 1);
 __ZN6cashew7IString3setEPKcb(59892, 49081, 1);
 __ZN6cashew7IString3setEPKcb(59896, 49087, 1);
 __ZN6cashew7IString3setEPKcb(59900, 49092, 1);
 __ZN6cashew7IString3setEPKcb(59904, 49098, 1);
 __ZN6cashew7IString3setEPKcb(59908, 49105, 1);
 __ZN6cashew7IString3setEPKcb(59912, 49112, 1);
 __ZN6cashew7IString3setEPKcb(59916, 49120, 1);
 __ZN6cashew7IString3setEPKcb(59920, 49127, 1);
 __ZN6cashew7IString3setEPKcb(59924, 49134, 1);
 __ZN6cashew7IString3setEPKcb(59928, 49140, 1);
 __ZN6cashew7IString3setEPKcb(59932, 49146, 1);
 __ZN6cashew7IString3setEPKcb(59936, 49151, 1);
 __ZN6cashew7IString3setEPKcb(59940, 49156, 1);
 __ZN6cashew7IString3setEPKcb(59944, 49168, 1);
 __ZN6cashew7IString3setEPKcb(59948, 49182, 1);
 __ZN6cashew7IString3setEPKcb(59952, 49188, 1);
 __ZN6cashew7IString3setEPKcb(59956, 49194, 1);
 __ZN6cashew7IString3setEPKcb(59960, 49199, 1);
 __ZN6cashew7IString3setEPKcb(59964, 49204, 1);
 __ZN6cashew7IString3setEPKcb(59968, 49214, 1);
 __ZN6cashew7IString3setEPKcb(59972, 49219, 1);
 __ZN6cashew7IString3setEPKcb(59976, 49224, 1);
 __ZN6cashew7IString3setEPKcb(59980, 49227, 1);
 __ZN6cashew7IString3setEPKcb(59984, 49235, 1);
 __ZN6cashew7IString3setEPKcb(59988, 49242, 1);
 __ZN6cashew7IString3setEPKcb(59992, 49246, 1);
 __ZN6cashew7IString3setEPKcb(59996, 49266, 1);
 __ZN6cashew7IString3setEPKcb(6e4, 49276, 1);
 __ZN6cashew7IString3setEPKcb(60004, 49287, 1);
 __ZN6cashew7IString3setEPKcb(60008, 49298, 1);
 __ZN6cashew7IString3setEPKcb(60012, 49312, 1);
 __ZN6cashew7IString3setEPKcb(60016, 49321, 1);
 __ZN6cashew7IString3setEPKcb(60020, 49331, 1);
 __ZN6cashew7IString3setEPKcb(60024, 49342, 1);
 __ZN6cashew7IString3setEPKcb(60028, 49353, 1);
 __ZN6cashew7IString3setEPKcb(60032, 49366, 1);
 __ZN6cashew7IString3setEPKcb(60036, 49376, 1);
 __ZN6cashew7IString3setEPKcb(60040, 49385, 1);
 __ZN6cashew7IString3setEPKcb(60044, 49394, 1);
 __ZN6cashew7IString3setEPKcb(60048, 49408, 1);
 __ZN6cashew7IString3setEPKcb(60052, 49420, 1);
 __ZN6cashew7IString3setEPKcb(60056, 49435, 1);
 __ZN6cashew7IString3setEPKcb(60060, 49444, 1);
 __ZN6cashew7IString3setEPKcb(60064, 49450, 1);
 __ZN6cashew7IString3setEPKcb(60068, 49457, 1);
 return;
}

function __ZN4wasm14CoalesceLocals20pickIndicesFromOrderERNSt3__26vectorIjNS1_9allocatorIjEEEES6_(i14, i13, i11) {
 i14 = i14 | 0;
 i13 = i13 | 0;
 i11 = i11 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0, i15 = 0, i16 = 0, i17 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i15 = i16 + 12 | 0;
 i12 = i16;
 HEAP32[i15 >> 2] = 0;
 HEAP32[i15 + 4 >> 2] = 0;
 HEAP32[i15 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = i12 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i12 + 8 >> 2] = 0;
 i10 = i14 + 112 | 0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i11, HEAP32[i10 >> 2] | 0);
 __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE6resizeEj(i15, HEAP32[i10 >> 2] | 0);
 i3 = HEAP32[i10 >> 2] | 0;
 __ZNSt3__26vectorIbNS_9allocatorIbEEE6resizeEjb(i12, Math_imul(i3, i3) | 0, 0);
 i3 = HEAP32[i12 >> 2] | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 i4 = i3;
 i1 = (i4 + (i1 >>> 5 << 2) - i3 << 3) + (i1 & 31) | 0;
 i2 = 0;
 while (1) {
  if ((i1 | 0) <= 0) break;
  i7 = i3;
  HEAP32[i7 >> 2] = HEAP32[i7 >> 2] & ~(1 << i2);
  i7 = (i2 | 0) == 31;
  i9 = i4 + 4 | 0;
  i1 = i1 + -1 | 0;
  i2 = i7 ? 0 : i2 + 1 | 0;
  i3 = i7 ? i9 : i3;
  i4 = i7 ? i9 : i4;
 }
 i9 = HEAP32[i14 + 36 >> 2] | 0;
 i3 = (HEAP32[i9 + 12 >> 2] | 0) - (HEAP32[i9 + 8 >> 2] | 0) >> 2;
 i4 = 0;
 while (1) {
  if (i4 >>> 0 >= i3 >>> 0) {
   i6 = i4;
   break;
  }
  if ((HEAP32[(HEAP32[i13 >> 2] | 0) + (i4 << 2) >> 2] | 0) != (i4 | 0)) {
   i8 = 8;
   break;
  }
  HEAP32[(HEAP32[i11 >> 2] | 0) + (i4 << 2) >> 2] = i4;
  i5 = __ZN4wasm8Function12getLocalTypeEj(i9, i4) | 0;
  HEAP32[(HEAP32[i15 >> 2] | 0) + (i4 << 2) >> 2] = i5;
  i5 = 0;
  while (1) {
   i1 = HEAP32[i10 >> 2] | 0;
   if (i5 >>> 0 >= i1 >>> 0) break;
   i1 = (Math_imul(i1, i4) | 0) + i5 | 0;
   i2 = (HEAP32[i12 >> 2] | 0) + (i1 >>> 5 << 2) | 0;
   i1 = 1 << (i1 & 31);
   if (__ZN4wasm14CoalesceLocals10interferesEjj(i14, i4, i5) | 0) i1 = HEAP32[i2 >> 2] | i1; else i1 = HEAP32[i2 >> 2] & ~i1;
   HEAP32[i2 >> 2] = i1;
   i5 = i5 + 1 | 0;
  }
  i4 = i4 + 1 | 0;
 }
 if ((i8 | 0) == 8) ___assert_fail(46912, 46670, 378, 46926);
 i1 = HEAP32[i10 >> 2] | 0;
 i7 = i6;
 i5 = i6;
 while (1) {
  if (i7 >>> 0 >= i1 >>> 0) break;
  i6 = HEAP32[(HEAP32[i13 >> 2] | 0) + (i7 << 2) >> 2] | 0;
  i3 = HEAP32[i12 >> 2] | 0;
  i2 = HEAP32[i15 >> 2] | 0;
  i4 = 0;
  while (1) {
   if (i4 >>> 0 >= i5 >>> 0) {
    i8 = 24;
    break;
   }
   i8 = (Math_imul(i1, i4) | 0) + i6 | 0;
   if ((1 << (i8 & 31) & HEAP32[i3 + (i8 >>> 5 << 2) >> 2] | 0) == 0 ? (i8 = __ZN4wasm8Function12getLocalTypeEj(i9, i6) | 0, (i8 | 0) == (HEAP32[i2 + (i4 << 2) >> 2] | 0)) : 0) {
    i2 = i4;
    i8 = 22;
    break;
   }
   i4 = i4 + 1 | 0;
  }
  if ((i8 | 0) == 22) {
   i8 = 0;
   i1 = HEAP32[i11 >> 2] | 0;
   HEAP32[i1 + (i6 << 2) >> 2] = i2;
   if ((i2 | 0) == -1) {
    i2 = HEAP32[i15 >> 2] | 0;
    i8 = 25;
   } else i4 = i5;
  } else if ((i8 | 0) == 24) {
   i1 = HEAP32[i11 >> 2] | 0;
   i8 = 25;
  }
  if ((i8 | 0) == 25) {
   HEAP32[i1 + (i6 << 2) >> 2] = i5;
   i4 = __ZN4wasm8Function12getLocalTypeEj(i9, i6) | 0;
   HEAP32[i2 + (i5 << 2) >> 2] = i4;
   i2 = i5;
   i4 = i5 + 1 | 0;
  }
  i3 = 0;
  while (1) {
   i1 = HEAP32[i10 >> 2] | 0;
   if (i3 >>> 0 >= i1 >>> 0) break;
   i5 = (Math_imul(i1, i2) | 0) + i3 | 0;
   i8 = (HEAP32[i12 >> 2] | 0) + (i5 >>> 5 << 2) | 0;
   i5 = 1 << (i5 & 31);
   i1 = HEAP32[i8 >> 2] | 0;
   i17 = __ZN4wasm14CoalesceLocals10interferesEjj(i14, i6, i3) | 0 | (i1 & i5 | 0) != 0;
   HEAP32[i8 >> 2] = i17 ? i1 | i5 : i1 & ~i5;
   i3 = i3 + 1 | 0;
  }
  i7 = i7 + 1 | 0;
  i5 = i4;
 }
 __ZNSt3__26vectorIbNS_9allocatorIbEEED2Ev(i12);
 __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i15);
 STACKTOP = i16;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseAfterIdentERNS3_4FragERPcPKc(i16, i12, i15, i14) {
 i16 = i16 | 0;
 i12 = i12 | 0;
 i15 = i15 | 0;
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i17 = 0, i18 = 0, i19 = 0;
 i19 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i17 = i19 + 64 | 0;
 i6 = i19 + 36 | 0;
 i1 = i19 + 56 | 0;
 i2 = i19 + 48 | 0;
 i3 = i19 + 40 | 0;
 i4 = i19 + 32 | 0;
 i8 = i19 + 28 | 0;
 i9 = i19 + 24 | 0;
 i10 = i19 + 16 | 0;
 i11 = i19 + 8 | 0;
 i13 = i19;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i15);
 i5 = HEAP32[i15 >> 2] | 0;
 i7 = HEAP8[i5 >> 0] | 0;
 L1 : do switch (i7 << 24 >> 24) {
 case 40:
  {
   i13 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseFragERNS3_4FragE(i16, i12) | 0;
   HEAP32[i2 >> 2] = i13;
   HEAP32[i17 >> 2] = HEAP32[i2 >> 2];
   i13 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseCallES1_RPc(i16, i17, i15) | 0;
   HEAP8[i1 >> 0] = 1;
   HEAP32[i1 + 4 >> 2] = i13;
   HEAP32[i17 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i17 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i16, i17, i15, i14) | 0;
   break;
  }
 case 91:
  {
   i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseFragERNS3_4FragE(i16, i12) | 0;
   HEAP32[i4 >> 2] = i1;
   HEAP32[i17 >> 2] = HEAP32[i4 >> 2];
   i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseIndexingES1_RPc(i16, i17, i15) | 0;
   HEAP8[i3 >> 0] = 1;
   HEAP32[i3 + 4 >> 2] = i1;
   HEAP32[i17 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i17 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
   i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i16, i17, i15, i14) | 0;
   break;
  }
 case 58:
  {
   i11 = HEAP32[i16 + 4 >> 2] | 0;
   if ((HEAP32[i11 + -8 >> 2] | 0) != (HEAP32[i11 + -12 >> 2] | 0)) {
    i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseFragERNS3_4FragE(i16, i12) | 0;
    i18 = 12;
    break L1;
   }
   HEAP32[i15 >> 2] = i5 + 1;
   __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i15);
   if ((HEAP8[HEAP32[i15 >> 2] >> 0] | 0) == 123) i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseBracketedBlockERPc(i16, i15) | 0; else i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i16, i15, i14) | 0;
   HEAP32[i8 >> 2] = HEAP32[i12 >> 2];
   HEAP32[i9 >> 2] = i1;
   HEAP32[i6 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i17 >> 2] = HEAP32[i9 >> 2];
   i1 = __ZN6cashew12ValueBuilder9makeLabelENS_7IStringENS_3RefE(i6, i17) | 0;
   break;
  }
 default:
  {
   i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseFragERNS3_4FragE(i16, i12) | 0;
   if (i7 << 24 >> 24 == 46) {
    HEAP32[i11 >> 2] = i1;
    HEAP32[i17 >> 2] = HEAP32[i11 >> 2];
    i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseDottingES1_RPc(i16, i17, i15) | 0;
    HEAP8[i10 >> 0] = 1;
    HEAP32[i10 + 4 >> 2] = i1;
    HEAP32[i17 >> 2] = HEAP32[i10 >> 2];
    HEAP32[i17 + 4 >> 2] = HEAP32[i10 + 4 >> 2];
    i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i16, i17, i15, i14) | 0;
   } else i18 = 12;
  }
 } while (0);
 if ((i18 | 0) == 12) {
  HEAP8[i13 >> 0] = 1;
  HEAP32[i13 + 4 >> 2] = i1;
  HEAP32[i17 >> 2] = HEAP32[i13 >> 2];
  HEAP32[i17 + 4 >> 2] = HEAP32[i13 + 4 >> 2];
  i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i16, i17, i15, i14) | 0;
 }
 STACKTOP = i19;
 return i1 | 0;
}

function __ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib(i3, i14, i13, i6, i12) {
 i3 = i3 | 0;
 i14 = i14 | 0;
 i13 = i13 | 0;
 i6 = i6 | 0;
 i12 = i12 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 L1 : do if ((i3 | 0) == (HEAP32[i14 + 8 >> 2] | 0)) {
  if ((HEAP32[i14 + 4 >> 2] | 0) == (i13 | 0) ? (i1 = i14 + 28 | 0, (HEAP32[i1 >> 2] | 0) != 1) : 0) HEAP32[i1 >> 2] = i6;
 } else {
  if ((i3 | 0) != (HEAP32[i14 >> 2] | 0)) {
   i11 = HEAP32[i3 + 12 >> 2] | 0;
   i4 = i3 + 16 + (i11 << 3) | 0;
   __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib(i3 + 16 | 0, i14, i13, i6, i12);
   i1 = i3 + 24 | 0;
   if ((i11 | 0) <= 1) break;
   i2 = HEAP32[i3 + 8 >> 2] | 0;
   if ((i2 & 2 | 0) == 0 ? (i5 = i14 + 36 | 0, (HEAP32[i5 >> 2] | 0) != 1) : 0) {
    if (!(i2 & 1)) {
     i2 = i14 + 54 | 0;
     while (1) {
      if (HEAP8[i2 >> 0] | 0) break L1;
      if ((HEAP32[i5 >> 2] | 0) == 1) break L1;
      __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib(i1, i14, i13, i6, i12);
      i1 = i1 + 8 | 0;
      if (i1 >>> 0 >= i4 >>> 0) break L1;
     }
    }
    i2 = i14 + 24 | 0;
    i3 = i14 + 54 | 0;
    while (1) {
     if (HEAP8[i3 >> 0] | 0) break L1;
     if ((HEAP32[i5 >> 2] | 0) == 1 ? (HEAP32[i2 >> 2] | 0) == 1 : 0) break L1;
     __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib(i1, i14, i13, i6, i12);
     i1 = i1 + 8 | 0;
     if (i1 >>> 0 >= i4 >>> 0) break L1;
    }
   }
   i2 = i14 + 54 | 0;
   while (1) {
    if (HEAP8[i2 >> 0] | 0) break L1;
    __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib(i1, i14, i13, i6, i12);
    i1 = i1 + 8 | 0;
    if (i1 >>> 0 >= i4 >>> 0) break L1;
   }
  }
  if ((HEAP32[i14 + 16 >> 2] | 0) != (i13 | 0) ? (i11 = i14 + 20 | 0, (HEAP32[i11 >> 2] | 0) != (i13 | 0)) : 0) {
   HEAP32[i14 + 32 >> 2] = i6;
   i10 = i14 + 44 | 0;
   if ((HEAP32[i10 >> 2] | 0) == 4) break;
   i4 = i3 + 16 + (HEAP32[i3 + 12 >> 2] << 3) | 0;
   i5 = i14 + 52 | 0;
   i6 = i14 + 53 | 0;
   i8 = i14 + 54 | 0;
   i7 = i3 + 8 | 0;
   i9 = i14 + 24 | 0;
   i2 = 0;
   i1 = 0;
   i3 = i3 + 16 | 0;
   L34 : while (1) {
    if (i3 >>> 0 >= i4 >>> 0) {
     i3 = 20;
     break;
    }
    HEAP8[i5 >> 0] = 0;
    HEAP8[i6 >> 0] = 0;
    __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib(i3, i14, i13, i13, 1, i12);
    if (HEAP8[i8 >> 0] | 0) {
     i3 = 20;
     break;
    }
    do if (HEAP8[i6 >> 0] | 0) {
     if (!(HEAP8[i5 >> 0] | 0)) if (!(HEAP32[i7 >> 2] & 1)) {
      i1 = 1;
      i3 = 20;
      break L34;
     } else {
      i1 = 1;
      break;
     }
     if ((HEAP32[i9 >> 2] | 0) == 1) {
      i3 = 25;
      break L34;
     }
     if (!(HEAP32[i7 >> 2] & 2)) {
      i3 = 25;
      break L34;
     } else {
      i2 = 1;
      i1 = 1;
     }
    } while (0);
    i3 = i3 + 8 | 0;
   }
   do if ((i3 | 0) == 20) {
    if ((!i2 ? (HEAP32[i11 >> 2] = i13, i13 = i14 + 40 | 0, HEAP32[i13 >> 2] = (HEAP32[i13 >> 2] | 0) + 1, (HEAP32[i14 + 36 >> 2] | 0) == 1) : 0) ? (HEAP32[i9 >> 2] | 0) == 2 : 0) {
     HEAP8[i8 >> 0] = 1;
     if (i1) {
      i3 = 25;
      break;
     } else {
      i1 = 4;
      break;
     }
    }
    if (i1) i3 = 25; else i1 = 4;
   } while (0);
   if ((i3 | 0) == 25) i1 = 3;
   HEAP32[i10 >> 2] = i1;
   break;
  }
  if ((i6 | 0) == 1) HEAP32[i14 + 32 >> 2] = 1;
 } while (0);
 return;
}

function __ZNSt3__2L13utf8_to_utf16EPKhS1_RS1_PtS3_RS3_mNS_12codecvt_modeE(i1, i11, i12, i3, i13, i14, i10, i2) {
 i1 = i1 | 0;
 i11 = i11 | 0;
 i12 = i12 | 0;
 i3 = i3 | 0;
 i13 = i13 | 0;
 i14 = i14 | 0;
 i10 = i10 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i15 = 0;
 HEAP32[i12 >> 2] = i1;
 HEAP32[i14 >> 2] = i3;
 if (i2 & 4) {
  i1 = HEAP32[i12 >> 2] | 0;
  i2 = i11;
  if ((((i2 - i1 | 0) > 2 ? (HEAP8[i1 >> 0] | 0) == -17 : 0) ? (HEAP8[i1 + 1 >> 0] | 0) == -69 : 0) ? (HEAP8[i1 + 2 >> 0] | 0) == -65 : 0) HEAP32[i12 >> 2] = i1 + 3;
 } else i2 = i11;
 i8 = i13;
 L9 : while (1) {
  i5 = HEAP32[i12 >> 2] | 0;
  i1 = i5 >>> 0 < i11 >>> 0;
  if (!i1) {
   i15 = 41;
   break;
  }
  i9 = HEAP32[i14 >> 2] | 0;
  if (i9 >>> 0 >= i13 >>> 0) {
   i15 = 41;
   break;
  }
  i1 = HEAP8[i5 >> 0] | 0;
  i7 = i1 & 255;
  if (i7 >>> 0 > i10 >>> 0) {
   i1 = 2;
   break;
  }
  do if (i1 << 24 >> 24 > -1) {
   HEAP16[i9 >> 1] = i1 & 255;
   HEAP32[i12 >> 2] = i5 + 1;
  } else {
   if ((i1 & 255) < 194) {
    i1 = 2;
    break L9;
   }
   if ((i1 & 255) < 224) {
    if ((i2 - i5 | 0) < 2) {
     i1 = 1;
     break L9;
    }
    i1 = HEAPU8[i5 + 1 >> 0] | 0;
    if ((i1 & 192 | 0) != 128) {
     i1 = 2;
     break L9;
    }
    i1 = i1 & 63 | i7 << 6 & 1984;
    if (i1 >>> 0 > i10 >>> 0) {
     i1 = 2;
     break L9;
    }
    HEAP16[i9 >> 1] = i1;
    HEAP32[i12 >> 2] = i5 + 2;
    break;
   }
   if ((i1 & 255) < 240) {
    if ((i2 - i5 | 0) < 3) {
     i1 = 1;
     break L9;
    }
    i3 = HEAP8[i5 + 1 >> 0] | 0;
    i1 = HEAP8[i5 + 2 >> 0] | 0;
    switch (i7 | 0) {
    case 224:
     {
      if ((i3 & -32) << 24 >> 24 != -96) {
       i1 = 2;
       break L9;
      }
      break;
     }
    case 237:
     {
      if ((i3 & -32) << 24 >> 24 != -128) {
       i1 = 2;
       break L9;
      }
      break;
     }
    default:
     if ((i3 & -64) << 24 >> 24 != -128) {
      i1 = 2;
      break L9;
     }
    }
    i1 = i1 & 255;
    if ((i1 & 192 | 0) != 128) {
     i1 = 2;
     break L9;
    }
    i1 = (i3 & 255) << 6 & 4032 | i7 << 12 | i1 & 63;
    if ((i1 & 65535) >>> 0 > i10 >>> 0) {
     i1 = 2;
     break L9;
    }
    HEAP16[i9 >> 1] = i1;
    HEAP32[i12 >> 2] = i5 + 3;
    break;
   }
   if ((i1 & 255) >= 245) {
    i1 = 2;
    break L9;
   }
   if ((i2 - i5 | 0) < 4) {
    i1 = 1;
    break L9;
   }
   i4 = HEAP8[i5 + 1 >> 0] | 0;
   i1 = HEAP8[i5 + 2 >> 0] | 0;
   i3 = HEAP8[i5 + 3 >> 0] | 0;
   switch (i7 | 0) {
   case 240:
    {
     if ((i4 + 112 & 255) >= 48) {
      i1 = 2;
      break L9;
     }
     break;
    }
   case 244:
    {
     if ((i4 & -16) << 24 >> 24 != -128) {
      i1 = 2;
      break L9;
     }
     break;
    }
   default:
    if ((i4 & -64) << 24 >> 24 != -128) {
     i1 = 2;
     break L9;
    }
   }
   i6 = i1 & 255;
   if ((i6 & 192 | 0) != 128) {
    i1 = 2;
    break L9;
   }
   i1 = i3 & 255;
   if ((i1 & 192 | 0) != 128) {
    i1 = 2;
    break L9;
   }
   if ((i8 - i9 | 0) < 4) {
    i1 = 1;
    break L9;
   }
   i5 = i7 & 7;
   i4 = i4 & 255;
   i3 = i6 << 6;
   i1 = i1 & 63;
   if ((i4 << 12 & 258048 | i5 << 18 | i3 & 4032 | i1) >>> 0 > i10 >>> 0) {
    i1 = 2;
    break L9;
   }
   HEAP16[i9 >> 1] = i4 << 2 & 60 | i6 >>> 4 & 3 | ((i4 >>> 4 & 3 | i5 << 2) << 6) + 16320 | 55296;
   i9 = i9 + 2 | 0;
   HEAP32[i14 >> 2] = i9;
   HEAP16[i9 >> 1] = i1 | i3 & 960 | 56320;
   HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) + 4;
  } while (0);
  HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) + 2;
 }
 if ((i15 | 0) == 41) i1 = i1 & 1;
 return i1 | 0;
}

function __ZNK4wasm7Literal3minERKS0_(i14, i1, i4) {
 i14 = i14 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var d2 = 0.0, d3 = 0.0, d5 = 0.0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0, d16 = 0.0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 128 | 0;
 i6 = i15 + 112 | 0;
 i7 = i15 + 96 | 0;
 i10 = i15 + 80 | 0;
 i12 = i15 + 64 | 0;
 i8 = i15 + 48 | 0;
 i9 = i15 + 32 | 0;
 i11 = i15 + 16 | 0;
 i13 = i15;
 do if ((HEAP32[i1 >> 2] | 0) == 3) {
  d5 = +__ZNK4wasm7Literal6getf32Ev(i1);
  d2 = +__ZNK4wasm7Literal6getf32Ev(i4);
  if (d5 == 0.0 & d5 == d2) {
   d5 = ((HEAPF32[tempDoublePtr >> 2] = d5, HEAP32[tempDoublePtr >> 2] | 0) | 0) < 0 ? d5 : d2;
   HEAP32[i14 >> 2] = 3;
   HEAPF32[i14 + 8 >> 2] = d5;
   break;
  }
  d3 = d2 < d5 ? d2 : d5;
  d16 = +Math_abs(+d5);
  i1 = (HEAPF32[tempDoublePtr >> 2] = d16, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 2139095040;
  d16 = +Math_abs(+d2);
  i4 = (HEAPF32[tempDoublePtr >> 2] = d16, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 2139095040;
  d16 = +Math_abs(+d3);
  if (!(i4 | (i1 | (HEAPF32[tempDoublePtr >> 2] = d16, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 2139095040))) {
   HEAP32[i14 >> 2] = 3;
   HEAPF32[i14 + 8 >> 2] = d3;
   break;
  }
  if (!(i1 | i4)) {
   HEAP32[i6 >> 2] = 1;
   HEAP32[i6 + 8 >> 2] = 2143289344;
   __ZN4wasm7Literal9castToF32Ev(i14, i6);
   break;
  }
  HEAP32[i7 >> 2] = 3;
  HEAPF32[i7 + 8 >> 2] = i1 ? d5 : d2;
  __ZN4wasm7Literal9castToI32Ev(i10, i7);
  i1 = i10 + 8 | 0;
  if ((HEAP32[i10 >> 2] | 0) == 1) {
   HEAP32[i12 + 8 >> 2] = HEAP32[i1 >> 2] | 12582912;
   i1 = 1;
  } else {
   i11 = i1;
   i13 = HEAP32[i11 + 4 >> 2] | 0;
   i1 = i12 + 8 | 0;
   HEAP32[i1 >> 2] = HEAP32[i11 >> 2] | 12582912;
   HEAP32[i1 + 4 >> 2] = i13;
   i1 = 2;
  }
  HEAP32[i12 >> 2] = i1;
  __ZN4wasm7Literal9castToF32Ev(i14, i12);
 } else {
  d5 = +__ZNK4wasm7Literal6getf64Ev(i1);
  d2 = +__ZNK4wasm7Literal6getf64Ev(i4);
  if (d5 == 0.0 & d5 == d2) {
   HEAPF64[tempDoublePtr >> 3] = d5;
   d16 = (HEAP32[tempDoublePtr + 4 >> 2] | 0) < 0 ? d5 : d2;
   HEAP32[i14 >> 2] = 4;
   HEAPF64[i14 + 8 >> 3] = d16;
   break;
  }
  d3 = d2 < d5 ? d2 : d5;
  d16 = +Math_abs(+d5);
  HEAPF64[tempDoublePtr >> 3] = d16;
  i1 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
  i1 = i1 >>> 0 > 2146435072 | (i1 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0;
  d16 = +Math_abs(+d2);
  HEAPF64[tempDoublePtr >> 3] = d16;
  i4 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
  i4 = i4 >>> 0 > 2146435072 | (i4 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0;
  d16 = +Math_abs(+d3);
  HEAPF64[tempDoublePtr >> 3] = d16;
  i12 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
  if (!(i4 | (i1 | (i12 >>> 0 > 2146435072 | (i12 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0)))) {
   HEAP32[i14 >> 2] = 4;
   HEAPF64[i14 + 8 >> 3] = d3;
   break;
  }
  if (!(i1 | i4)) {
   HEAP32[i8 >> 2] = 2;
   i13 = i8 + 8 | 0;
   HEAP32[i13 >> 2] = 0;
   HEAP32[i13 + 4 >> 2] = 2146959360;
   __ZN4wasm7Literal9castToF64Ev(i14, i8);
   break;
  }
  HEAP32[i9 >> 2] = 4;
  HEAPF64[i9 + 8 >> 3] = i1 ? d5 : d2;
  __ZN4wasm7Literal9castToI64Ev(i11, i9);
  i1 = i11 + 8 | 0;
  if ((HEAP32[i11 >> 2] | 0) == 1) {
   HEAP32[i13 + 8 >> 2] = HEAP32[i1 >> 2];
   i1 = 1;
  } else {
   i11 = i1;
   i12 = HEAP32[i11 + 4 >> 2] | 524288;
   i1 = i13 + 8 | 0;
   HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
   HEAP32[i1 + 4 >> 2] = i12;
   i1 = 2;
  }
  HEAP32[i13 >> 2] = i1;
  __ZN4wasm7Literal9castToF64Ev(i14, i13);
 } while (0);
 STACKTOP = i15;
 return;
}

function __ZNK4wasm7Literal3maxERKS0_(i14, i1, i4) {
 i14 = i14 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var d2 = 0.0, d3 = 0.0, d5 = 0.0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0, d16 = 0.0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 128 | 0;
 i6 = i15 + 112 | 0;
 i7 = i15 + 96 | 0;
 i10 = i15 + 80 | 0;
 i12 = i15 + 64 | 0;
 i8 = i15 + 48 | 0;
 i9 = i15 + 32 | 0;
 i11 = i15 + 16 | 0;
 i13 = i15;
 do if ((HEAP32[i1 >> 2] | 0) == 3) {
  d5 = +__ZNK4wasm7Literal6getf32Ev(i1);
  d2 = +__ZNK4wasm7Literal6getf32Ev(i4);
  if (d5 == 0.0 & d5 == d2) {
   d5 = ((HEAPF32[tempDoublePtr >> 2] = d5, HEAP32[tempDoublePtr >> 2] | 0) | 0) < 0 ? d2 : d5;
   HEAP32[i14 >> 2] = 3;
   HEAPF32[i14 + 8 >> 2] = d5;
   break;
  }
  d3 = d5 < d2 ? d2 : d5;
  d16 = +Math_abs(+d5);
  i1 = (HEAPF32[tempDoublePtr >> 2] = d16, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 2139095040;
  d16 = +Math_abs(+d2);
  i4 = (HEAPF32[tempDoublePtr >> 2] = d16, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 2139095040;
  d16 = +Math_abs(+d3);
  if (!(i4 | (i1 | (HEAPF32[tempDoublePtr >> 2] = d16, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 2139095040))) {
   HEAP32[i14 >> 2] = 3;
   HEAPF32[i14 + 8 >> 2] = d3;
   break;
  }
  if (!(i1 | i4)) {
   HEAP32[i6 >> 2] = 1;
   HEAP32[i6 + 8 >> 2] = 2143289344;
   __ZN4wasm7Literal9castToF32Ev(i14, i6);
   break;
  }
  HEAP32[i7 >> 2] = 3;
  HEAPF32[i7 + 8 >> 2] = i1 ? d5 : d2;
  __ZN4wasm7Literal9castToI32Ev(i10, i7);
  i1 = i10 + 8 | 0;
  if ((HEAP32[i10 >> 2] | 0) == 1) {
   HEAP32[i12 + 8 >> 2] = HEAP32[i1 >> 2] | 12582912;
   i1 = 1;
  } else {
   i11 = i1;
   i13 = HEAP32[i11 + 4 >> 2] | 0;
   i1 = i12 + 8 | 0;
   HEAP32[i1 >> 2] = HEAP32[i11 >> 2] | 12582912;
   HEAP32[i1 + 4 >> 2] = i13;
   i1 = 2;
  }
  HEAP32[i12 >> 2] = i1;
  __ZN4wasm7Literal9castToF32Ev(i14, i12);
 } else {
  d5 = +__ZNK4wasm7Literal6getf64Ev(i1);
  d2 = +__ZNK4wasm7Literal6getf64Ev(i4);
  if (d5 == 0.0 & d5 == d2) {
   HEAPF64[tempDoublePtr >> 3] = d5;
   d16 = (HEAP32[tempDoublePtr + 4 >> 2] | 0) < 0 ? d2 : d5;
   HEAP32[i14 >> 2] = 4;
   HEAPF64[i14 + 8 >> 3] = d16;
   break;
  }
  d3 = d5 < d2 ? d2 : d5;
  d16 = +Math_abs(+d5);
  HEAPF64[tempDoublePtr >> 3] = d16;
  i1 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
  i1 = i1 >>> 0 > 2146435072 | (i1 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0;
  d16 = +Math_abs(+d2);
  HEAPF64[tempDoublePtr >> 3] = d16;
  i4 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
  i4 = i4 >>> 0 > 2146435072 | (i4 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0;
  d16 = +Math_abs(+d3);
  HEAPF64[tempDoublePtr >> 3] = d16;
  i12 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
  if (!(i4 | (i1 | (i12 >>> 0 > 2146435072 | (i12 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0)))) {
   HEAP32[i14 >> 2] = 4;
   HEAPF64[i14 + 8 >> 3] = d3;
   break;
  }
  if (!(i1 | i4)) {
   HEAP32[i8 >> 2] = 2;
   i13 = i8 + 8 | 0;
   HEAP32[i13 >> 2] = 0;
   HEAP32[i13 + 4 >> 2] = 2146959360;
   __ZN4wasm7Literal9castToF64Ev(i14, i8);
   break;
  }
  HEAP32[i9 >> 2] = 4;
  HEAPF64[i9 + 8 >> 3] = i1 ? d5 : d2;
  __ZN4wasm7Literal9castToI64Ev(i11, i9);
  i1 = i11 + 8 | 0;
  if ((HEAP32[i11 >> 2] | 0) == 1) {
   HEAP32[i13 + 8 >> 2] = HEAP32[i1 >> 2];
   i1 = 1;
  } else {
   i11 = i1;
   i12 = HEAP32[i11 + 4 >> 2] | 524288;
   i1 = i13 + 8 | 0;
   HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
   HEAP32[i1 + 4 >> 2] = i12;
   i1 = 2;
  }
  HEAP32[i13 >> 2] = i1;
  __ZN4wasm7Literal9castToF64Ev(i14, i13);
 } while (0);
 STACKTOP = i15;
 return;
}

function __Z10detectSignN6cashew3RefENS_7IStringE(i14, i11) {
 i14 = i14 | 0;
 i11 = i11 | 0;
 var d1 = 0.0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i12 = i15 + 32 | 0;
 i3 = i15 + 24 | 0;
 i13 = i15 + 28 | 0;
 i4 = i15 + 20 | 0;
 i6 = i15 + 16 | 0;
 i7 = i15 + 12 | 0;
 i8 = i15 + 8 | 0;
 i9 = i15 + 4 | 0;
 i10 = i15;
 i5 = __ZN6cashew3RefixEj(i14, 0) | 0;
 i5 = __ZN6cashew5Value10getIStringEv(HEAP32[i5 >> 2] | 0) | 0;
 i5 = HEAP32[i5 >> 2] | 0;
 L1 : do if ((i5 | 0) != (HEAP32[14827] | 0)) {
  if ((i5 | 0) == (HEAP32[14849] | 0)) {
   i13 = __ZN6cashew3RefixEj(i14, 1) | 0;
   i13 = __ZN6cashew5Value10getIStringEv(HEAP32[i13 >> 2] | 0) | 0;
   switch (HEAP8[HEAP32[i13 >> 2] >> 0] | 0) {
   case 45:
    {
     i2 = 0;
     break L1;
    }
   case 43:
    {
     i2 = 3;
     break L1;
    }
   case 126:
    {
     i2 = 1;
     break L1;
    }
   default:
    {
     HEAP32[i4 >> 2] = HEAP32[i14 >> 2];
     HEAP32[i12 >> 2] = HEAP32[i4 >> 2];
     __ZL8abort_onN6cashew3RefE(i12);
    }
   }
  }
  if ((i5 | 0) == (HEAP32[14837] | 0)) {
   i14 = __ZN6cashew3RefixEj(i14, 1) | 0;
   i14 = __ZN6cashew5Value9getNumberEv(HEAP32[i14 >> 2] | 0) | 0;
   d1 = +HEAPF64[i14 >> 3];
   if (d1 < 0.0) {
    i2 = 1;
    break;
   }
   if (d1 > 4294967295.0) {
    i2 = 3;
    break;
   }
   if (+_fmod(d1, 1.0) != 0.0) {
    i2 = 3;
    break;
   }
   i2 = __ZN4wasm12isSInteger32Ed(d1) | 0;
   i2 = i2 ? 0 : 2;
   break;
  }
  if ((i5 | 0) == (HEAP32[14823] | 0)) i2 = 0; else {
   if ((i5 | 0) == (HEAP32[14826] | 0)) {
    i2 = __ZN6cashew3RefixEj(i14, 2) | 0;
    HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i7 >> 2] = HEAP32[i11 >> 2];
    HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
    HEAP32[i12 >> 2] = HEAP32[i7 >> 2];
    i2 = __Z10detectSignN6cashew3RefENS_7IStringE(i3, i12) | 0;
    break;
   }
   if ((i5 | 0) == (HEAP32[14836] | 0)) {
    if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i14, 1) | 0, 0) | 0, 59292) | 0) {
     if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i14, 1) | 0, 1) | 0, 59404) | 0) {
      i2 = 3;
      break;
     }
     if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i14, 1) | 0, 1) | 0, i11) | 0) {
      i2 = 3;
      break;
     }
    }
   } else if ((i5 | 0) == (HEAP32[14834] | 0)) {
    i2 = __ZN6cashew3RefixEj(i14, 2) | 0;
    HEAP32[i8 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
    HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
    HEAP32[i12 >> 2] = HEAP32[i9 >> 2];
    i2 = __Z10detectSignN6cashew3RefENS_7IStringE(i3, i12) | 0;
    break;
   }
   HEAP32[i10 >> 2] = HEAP32[i14 >> 2];
   HEAP32[i12 >> 2] = HEAP32[i10 >> 2];
   __ZL8abort_onN6cashew3RefE(i12);
  }
 } else {
  i2 = __ZN6cashew3RefixEj(i14, 1) | 0;
  i2 = __ZN6cashew5Value10getIStringEv(HEAP32[i2 >> 2] | 0) | 0;
  i2 = HEAP32[i2 >> 2] | 0;
  switch (HEAP8[i2 >> 0] | 0) {
  case 45:
  case 43:
   {
    i2 = 0;
    break L1;
   }
  case 62:
   {
    if ((i2 | 0) == (HEAP32[14875] | 0)) {
     i2 = 2;
     break L1;
    }
    break;
   }
  case 33:
  case 61:
  case 60:
  case 94:
  case 38:
  case 124:
   break;
  case 47:
  case 42:
   {
    i2 = 3;
    break L1;
   }
  default:
   {
    HEAP32[i13 >> 2] = HEAP32[i14 >> 2];
    HEAP32[i12 >> 2] = HEAP32[i13 >> 2];
    __ZL8abort_onN6cashew3RefE(i12);
   }
  }
  i2 = 1;
 } while (0);
 STACKTOP = i15;
 return i2 | 0;
}

function __ZZ11instantiateEN19JSExternalInterface4loadEPN4wasm4LoadENS0_7AddressE(i14, i1, i8, i3) {
 i14 = i14 | 0;
 i1 = i1 | 0;
 i8 = i8 | 0;
 i3 = i3 | 0;
 var d2 = 0.0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i12 = i13;
 i4 = HEAP32[i3 >> 2] | 0;
 i7 = i8 + 8 | 0;
 i3 = HEAP16[i7 >> 1] | 0;
 i5 = i3 & 255;
 i1 = i3 & 255;
 i3 = (i3 & 65535) >>> 8;
 i6 = i3 & 255;
 L1 : do if ((HEAP32[i8 + 16 >> 2] | 0) >>> 0 >= i1 >>> 0 ? (i1 + -1 & i4 | 0) == 0 : 0) {
  i1 = i8 + 4 | 0;
  if (((HEAP32[i1 >> 2] | 0) + -3 | 0) >>> 0 < 2) switch (i5 << 24 >> 24) {
  case 4:
   {
    d2 = +_emscripten_asm_const_di(26, i4 | 0);
    HEAP32[i14 >> 2] = 3;
    HEAPF32[i14 + 8 >> 2] = d2;
    break L1;
   }
  case 8:
   {
    d2 = +_emscripten_asm_const_di(27, i4 | 0);
    HEAP32[i14 >> 2] = 4;
    HEAPF64[i14 + 8 >> 3] = d2;
    break L1;
   }
  default:
   _abort();
  }
  L11 : do switch (i5 << 24 >> 24) {
  case 1:
   if (!(i6 << 24 >> 24)) {
    i10 = _emscripten_asm_const_ii(21, i4 | 0) | 0;
    i9 = i10;
    i10 = ((i10 | 0) < 0) << 31 >> 31;
    break L11;
   } else {
    i10 = _emscripten_asm_const_ii(20, i4 | 0) | 0;
    i9 = i10;
    i10 = ((i10 | 0) < 0) << 31 >> 31;
    break L11;
   }
  case 2:
   if (!(i6 << 24 >> 24)) {
    i10 = _emscripten_asm_const_ii(23, i4 | 0) | 0;
    i9 = i10;
    i10 = ((i10 | 0) < 0) << 31 >> 31;
    break L11;
   } else {
    i10 = _emscripten_asm_const_ii(22, i4 | 0) | 0;
    i9 = i10;
    i10 = ((i10 | 0) < 0) << 31 >> 31;
    break L11;
   }
  case 4:
   if (!(i6 << 24 >> 24)) {
    i9 = _emscripten_asm_const_ii(25, i4 | 0) | 0;
    i10 = 0;
    break L11;
   } else {
    i10 = _emscripten_asm_const_ii(24, i4 | 0) | 0;
    i9 = i10;
    i10 = ((i10 | 0) < 0) << 31 >> 31;
    break L11;
   }
  case 8:
   {
    i9 = _emscripten_asm_const_ii(24, i4 | 0) | 0;
    i10 = _emscripten_asm_const_ii(24, i4 + 4 | 0) | 0;
    break;
   }
  default:
   _abort();
  } while (0);
  if ((HEAP32[i1 >> 2] | 0) == 1) {
   HEAP32[i14 >> 2] = 1;
   HEAP32[i14 + 8 >> 2] = i9;
   break;
  } else {
   HEAP32[i14 >> 2] = 2;
   i14 = i14 + 8 | 0;
   HEAP32[i14 >> 2] = i9;
   HEAP32[i14 + 4 >> 2] = i10;
   break;
  }
 } else i11 = 3; while (0);
 if ((i11 | 0) == 3) {
  i11 = i8 + 4 | 0;
  d2 = +_emscripten_asm_const_diiiii(19, i4 | 0, i1 | 0, ((HEAP32[i11 >> 2] | 0) + -3 | 0) >>> 0 < 2 | 0, i3 & 65535 | 0, i12 | 0);
  i1 = HEAP32[i11 >> 2] | 0;
  L32 : do if ((i1 + -3 | 0) >>> 0 >= 2) {
   if ((i1 | 0) != 2) {
    HEAP32[i14 >> 2] = 1;
    HEAP32[i14 + 8 >> 2] = ~~d2;
    break;
   }
   i1 = HEAP16[i7 >> 1] | 0;
   if ((i1 & 255) << 24 >> 24 == 8) {
    i11 = HEAP32[i12 >> 2] | 0;
    i12 = HEAP32[i12 + 4 >> 2] | 0;
    HEAP32[i14 >> 2] = 2;
    i14 = i14 + 8 | 0;
    HEAP32[i14 >> 2] = i11;
    HEAP32[i14 + 4 >> 2] = i12;
    break;
   }
   if ((i1 & 65535) < 256) {
    HEAP32[i14 >> 2] = 2;
    i14 = i14 + 8 | 0;
    HEAP32[i14 >> 2] = ~~d2 >>> 0;
    HEAP32[i14 + 4 >> 2] = 0;
    break;
   } else {
    i12 = ~~d2;
    HEAP32[i14 >> 2] = 2;
    i14 = i14 + 8 | 0;
    HEAP32[i14 >> 2] = i12;
    HEAP32[i14 + 4 >> 2] = ((i12 | 0) < 0) << 31 >> 31;
    break;
   }
  } else switch (HEAP8[i7 >> 0] | 0) {
  case 4:
   {
    HEAP32[i14 >> 2] = 3;
    HEAPF32[i14 + 8 >> 2] = d2;
    break L32;
   }
  case 8:
   {
    HEAP32[i14 >> 2] = 4;
    HEAPF64[i14 + 8 >> 3] = d2;
    break L32;
   }
  default:
   _abort();
  } while (0);
 }
 STACKTOP = i13;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE16unlinkDeadBlocksENSt3__213unordered_setIPNS5_10BasicBlockENS6_4hashIS9_EENS6_8equal_toIS9_EENS6_9allocatorIS9_EEEE(i1, i20) {
 i1 = i1 | 0;
 i20 = i20 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i21 = 0, i22 = 0;
 i21 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i7 = i21 + 52 | 0;
 i6 = i21 + 48 | 0;
 i5 = i21 + 36 | 0;
 i8 = i21 + 44 | 0;
 i9 = i21 + 40 | 0;
 i12 = i21 + 32 | 0;
 i13 = i21 + 28 | 0;
 i14 = i21 + 24 | 0;
 i15 = i21 + 20 | 0;
 i16 = i21 + 16 | 0;
 i17 = i21 + 12 | 0;
 i18 = i21 + 8 | 0;
 i19 = i21 + 4 | 0;
 i10 = i21;
 i11 = HEAP32[i1 + 36 >> 2] | 0;
 i4 = HEAP32[i1 + 32 >> 2] | 0;
 while (1) {
  if ((i4 | 0) == (i11 | 0)) break;
  HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
  i22 = (__ZNKSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE4findIS9_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEERKT_(i20, i8) | 0) == 0;
  i1 = HEAP32[i4 >> 2] | 0;
  i2 = i1 + 48 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  L4 : do if (i22) {
   i1 = i1 + 52 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   while (1) {
    if ((i2 | 0) == (i3 | 0)) break;
    i22 = i2 + -4 | 0;
    HEAP32[i1 >> 2] = i22;
    i2 = i22;
   }
   i2 = HEAP32[i4 >> 2] | 0;
   i1 = HEAP32[i2 + 36 >> 2] | 0;
   i2 = i2 + 40 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   while (1) {
    if ((i3 | 0) == (i1 | 0)) break L4;
    i22 = i3 + -4 | 0;
    HEAP32[i2 >> 2] = i22;
    i3 = i22;
   }
  } else {
   HEAP32[i12 >> 2] = i3;
   HEAP32[i13 >> 2] = HEAP32[(HEAP32[i4 >> 2] | 0) + 52 >> 2];
   HEAP32[i14 >> 2] = i20;
   HEAP32[i5 >> 2] = HEAP32[i12 >> 2];
   HEAP32[i6 >> 2] = HEAP32[i13 >> 2];
   HEAP32[i7 >> 2] = HEAP32[i14 >> 2];
   i22 = __ZNSt3__29remove_ifINS_11__wrap_iterIPPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEEEZNS8_16unlinkDeadBlocksENS_13unordered_setISA_NS_4hashISA_EENS_8equal_toISA_EENS_9allocatorISA_EEEEEUlSA_E_EET_SM_SM_T0_(i5, i6, i7) | 0;
   HEAP32[i9 >> 2] = i22;
   HEAP32[i15 >> 2] = HEAP32[(HEAP32[i4 >> 2] | 0) + 52 >> 2];
   HEAP32[i6 >> 2] = HEAP32[i9 >> 2];
   HEAP32[i7 >> 2] = HEAP32[i15 >> 2];
   __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE5eraseENS_11__wrap_iterIPKS9_EESG_(i2, i6, i7) | 0;
   i22 = (HEAP32[i4 >> 2] | 0) + 36 | 0;
   HEAP32[i17 >> 2] = HEAP32[i22 >> 2];
   HEAP32[i18 >> 2] = HEAP32[(HEAP32[i4 >> 2] | 0) + 40 >> 2];
   HEAP32[i19 >> 2] = i20;
   HEAP32[i5 >> 2] = HEAP32[i17 >> 2];
   HEAP32[i6 >> 2] = HEAP32[i18 >> 2];
   HEAP32[i7 >> 2] = HEAP32[i19 >> 2];
   i3 = __ZNSt3__29remove_ifINS_11__wrap_iterIPPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEEEZNS8_16unlinkDeadBlocksENS_13unordered_setISA_NS_4hashISA_EENS_8equal_toISA_EENS_9allocatorISA_EEEEEUlSA_E0_EET_SM_SM_T0_(i5, i6, i7) | 0;
   HEAP32[i16 >> 2] = i3;
   HEAP32[i10 >> 2] = HEAP32[(HEAP32[i4 >> 2] | 0) + 40 >> 2];
   HEAP32[i6 >> 2] = HEAP32[i16 >> 2];
   HEAP32[i7 >> 2] = HEAP32[i10 >> 2];
   __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE5eraseENS_11__wrap_iterIPKS9_EESG_(i22, i6, i7) | 0;
  } while (0);
  i4 = i4 + 4 | 0;
 }
 STACKTOP = i21;
 return;
}

function _fmod(d12, d1) {
 d12 = +d12;
 d1 = +d1;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0, d15 = 0.0;
 HEAPF64[tempDoublePtr >> 3] = d12;
 i2 = HEAP32[tempDoublePtr >> 2] | 0;
 i9 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 HEAPF64[tempDoublePtr >> 3] = d1;
 i10 = HEAP32[tempDoublePtr >> 2] | 0;
 i11 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 i3 = _bitshift64Lshr(i2 | 0, i9 | 0, 52) | 0;
 i3 = i3 & 2047;
 i7 = _bitshift64Lshr(i10 | 0, i11 | 0, 52) | 0;
 i7 = i7 & 2047;
 i13 = i9 & -2147483648;
 i6 = _bitshift64Shl(i10 | 0, i11 | 0, 1) | 0;
 i8 = tempRet0;
 L1 : do if (!((i6 | 0) == 0 & (i8 | 0) == 0) ? (d15 = +Math_abs(+d1), HEAPF64[tempDoublePtr >> 3] = d15, i5 = HEAP32[tempDoublePtr + 4 >> 2] | 0, !(i5 >>> 0 > 2146435072 | (i5 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0 | (i3 | 0) == 2047)) : 0) {
  i4 = _bitshift64Shl(i2 | 0, i9 | 0, 1) | 0;
  i5 = tempRet0;
  if (!(i5 >>> 0 > i8 >>> 0 | (i5 | 0) == (i8 | 0) & i4 >>> 0 > i6 >>> 0)) return +((i4 | 0) == (i6 | 0) & (i5 | 0) == (i8 | 0) ? d12 * 0.0 : d12);
  if (!i3) {
   i3 = _bitshift64Shl(i2 | 0, i9 | 0, 12) | 0;
   i4 = tempRet0;
   if ((i4 | 0) > -1 | (i4 | 0) == -1 & i3 >>> 0 > 4294967295) {
    i5 = i3;
    i3 = 0;
    do {
     i3 = i3 + -1 | 0;
     i5 = _bitshift64Shl(i5 | 0, i4 | 0, 1) | 0;
     i4 = tempRet0;
    } while ((i4 | 0) > -1 | (i4 | 0) == -1 & i5 >>> 0 > 4294967295);
   } else i3 = 0;
   i2 = _bitshift64Shl(i2 | 0, i9 | 0, 1 - i3 | 0) | 0;
   i4 = tempRet0;
  } else i4 = i9 & 1048575 | 1048576;
  if (!i7) {
   i5 = _bitshift64Shl(i10 | 0, i11 | 0, 12) | 0;
   i6 = tempRet0;
   if ((i6 | 0) > -1 | (i6 | 0) == -1 & i5 >>> 0 > 4294967295) {
    i7 = 0;
    do {
     i7 = i7 + -1 | 0;
     i5 = _bitshift64Shl(i5 | 0, i6 | 0, 1) | 0;
     i6 = tempRet0;
    } while ((i6 | 0) > -1 | (i6 | 0) == -1 & i5 >>> 0 > 4294967295);
   } else i7 = 0;
   i10 = _bitshift64Shl(i10 | 0, i11 | 0, 1 - i7 | 0) | 0;
   i9 = tempRet0;
  } else i9 = i11 & 1048575 | 1048576;
  i8 = _i64Subtract(i2 | 0, i4 | 0, i10 | 0, i9 | 0) | 0;
  i6 = tempRet0;
  i5 = (i6 | 0) > -1 | (i6 | 0) == -1 & i8 >>> 0 > 4294967295;
  L23 : do if ((i3 | 0) > (i7 | 0)) {
   while (1) {
    if (i5) if ((i2 | 0) == (i10 | 0) & (i4 | 0) == (i9 | 0)) break; else {
     i2 = i8;
     i4 = i6;
    }
    i2 = _bitshift64Shl(i2 | 0, i4 | 0, 1) | 0;
    i4 = tempRet0;
    i3 = i3 + -1 | 0;
    i8 = _i64Subtract(i2 | 0, i4 | 0, i10 | 0, i9 | 0) | 0;
    i6 = tempRet0;
    i5 = (i6 | 0) > -1 | (i6 | 0) == -1 & i8 >>> 0 > 4294967295;
    if ((i3 | 0) <= (i7 | 0)) break L23;
   }
   d1 = d12 * 0.0;
   break L1;
  } while (0);
  if (i5) if ((i2 | 0) == (i10 | 0) & (i4 | 0) == (i9 | 0)) {
   d1 = d12 * 0.0;
   break;
  } else {
   i4 = i6;
   i2 = i8;
  }
  if (i4 >>> 0 < 1048576 | (i4 | 0) == 1048576 & i2 >>> 0 < 0) do {
   i2 = _bitshift64Shl(i2 | 0, i4 | 0, 1) | 0;
   i4 = tempRet0;
   i3 = i3 + -1 | 0;
  } while (i4 >>> 0 < 1048576 | (i4 | 0) == 1048576 & i2 >>> 0 < 0);
  if ((i3 | 0) > 0) {
   i11 = _i64Add(i2 | 0, i4 | 0, 0, -1048576) | 0;
   i2 = tempRet0;
   i3 = _bitshift64Shl(i3 | 0, 0, 52) | 0;
   i2 = i2 | tempRet0;
   i3 = i11 | i3;
  } else {
   i3 = _bitshift64Lshr(i2 | 0, i4 | 0, 1 - i3 | 0) | 0;
   i2 = tempRet0;
  }
  HEAP32[tempDoublePtr >> 2] = i3;
  HEAP32[tempDoublePtr + 4 >> 2] = i2 | i13;
  d1 = +HEAPF64[tempDoublePtr >> 3];
 } else i14 = 3; while (0);
 if ((i14 | 0) == 3) {
  d1 = d12 * d1;
  d1 = d1 / d1;
 }
 return +d1;
}

function __ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE(i2, i15, i14, i16, i17, i12, i1) {
 i2 = i2 | 0;
 i15 = i15 | 0;
 i14 = i14 | 0;
 i16 = i16 | 0;
 i17 = i17 | 0;
 i12 = i12 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i18 = 0, i19 = 0;
 i18 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i13 = i18;
 i11 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61712) | 0;
 i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61720) | 0;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[i5 >> 2] | 0) + 20 >> 2] & 1023](i13, i5);
 i9 = i13 + 11 | 0;
 i8 = HEAP8[i9 >> 0] | 0;
 i10 = i13 + 4 | 0;
 L1 : do if ((i8 << 24 >> 24 < 0 ? HEAP32[i10 >> 2] | 0 : i8 & 255) | 0) {
  HEAP32[i12 >> 2] = i16;
  i1 = HEAP8[i2 >> 0] | 0;
  switch (i1 << 24 >> 24) {
  case 43:
  case 45:
   {
    i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 44 >> 2] & 63](i11, i1) | 0;
    i3 = HEAP32[i12 >> 2] | 0;
    HEAP32[i12 >> 2] = i3 + 4;
    HEAP32[i3 >> 2] = i8;
    i3 = i2 + 1 | 0;
    break;
   }
  default:
   i3 = i2;
  }
  L7 : do if ((i14 - i3 | 0) > 1 ? (HEAP8[i3 >> 0] | 0) == 48 : 0) {
   i1 = i3 + 1 | 0;
   switch (HEAP8[i1 >> 0] | 0) {
   case 88:
   case 120:
    break;
   default:
    break L7;
   }
   i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 44 >> 2] & 63](i11, 48) | 0;
   i7 = HEAP32[i12 >> 2] | 0;
   HEAP32[i12 >> 2] = i7 + 4;
   HEAP32[i7 >> 2] = i8;
   i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 44 >> 2] & 63](i11, HEAP8[i1 >> 0] | 0) | 0;
   i8 = HEAP32[i12 >> 2] | 0;
   HEAP32[i12 >> 2] = i8 + 4;
   HEAP32[i8 >> 2] = i7;
   i3 = i3 + 2 | 0;
  } while (0);
  L12 : do if ((i3 | 0) != (i14 | 0)) {
   i1 = i14;
   i4 = i3;
   while (1) {
    i1 = i1 + -1 | 0;
    if (i4 >>> 0 >= i1 >>> 0) break L12;
    i8 = HEAP8[i4 >> 0] | 0;
    HEAP8[i4 >> 0] = HEAP8[i1 >> 0] | 0;
    HEAP8[i1 >> 0] = i8;
    i4 = i4 + 1 | 0;
   }
  } while (0);
  i7 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 16 >> 2] & 255](i5) | 0;
  i6 = 0;
  i1 = 0;
  i8 = i3;
  while (1) {
   if (i8 >>> 0 >= i14 >>> 0) break;
   i4 = HEAP8[i9 >> 0] | 0;
   i5 = i4 << 24 >> 24 < 0;
   i19 = HEAP8[(i5 ? HEAP32[i13 >> 2] | 0 : i13) + i1 >> 0] | 0;
   if (i19 << 24 >> 24 != 0 & (i6 | 0) == (i19 << 24 >> 24 | 0)) {
    i6 = HEAP32[i12 >> 2] | 0;
    HEAP32[i12 >> 2] = i6 + 4;
    HEAP32[i6 >> 2] = i7;
    i6 = 0;
    i1 = (i1 >>> 0 < ((i5 ? HEAP32[i10 >> 2] | 0 : i4 & 255) + -1 | 0) >>> 0 & 1) + i1 | 0;
   }
   i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 44 >> 2] & 63](i11, HEAP8[i8 >> 0] | 0) | 0;
   i19 = HEAP32[i12 >> 2] | 0;
   HEAP32[i12 >> 2] = i19 + 4;
   HEAP32[i19 >> 2] = i5;
   i6 = i6 + 1 | 0;
   i8 = i8 + 1 | 0;
  }
  i1 = i16 + (i3 - i2 << 2) | 0;
  i4 = HEAP32[i12 >> 2] | 0;
  if ((i1 | 0) != (i4 | 0)) {
   i3 = i4;
   while (1) {
    i3 = i3 + -4 | 0;
    if (i1 >>> 0 >= i3 >>> 0) {
     i1 = i4;
     break L1;
    }
    i19 = HEAP32[i1 >> 2] | 0;
    HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
    HEAP32[i3 >> 2] = i19;
    i1 = i1 + 4 | 0;
   }
  }
 } else {
  FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i11 >> 2] | 0) + 48 >> 2] & 7](i11, i2, i14, i16) | 0;
  i1 = i16 + (i14 - i2 << 2) | 0;
  HEAP32[i12 >> 2] = i1;
 } while (0);
 HEAP32[i17 >> 2] = (i15 | 0) == (i14 | 0) ? i1 : i16 + (i15 - i2 << 2) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i13);
 STACKTOP = i18;
 return;
}

function __ZNSt3__2L20utf8_to_utf16_lengthEPKhS1_jmNS_12codecvt_modeE(i12, i10, i11, i9, i1) {
 i12 = i12 | 0;
 i10 = i10 | 0;
 i11 = i11 | 0;
 i9 = i9 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i8 = i10;
 if ((((i1 & 4 | 0) != 0 ? (i8 - i12 | 0) > 2 : 0) ? (HEAP8[i12 >> 0] | 0) == -17 : 0) ? (HEAP8[i12 + 1 >> 0] | 0) == -69 : 0) {
  i7 = (HEAP8[i12 + 2 >> 0] | 0) == -65 ? i12 + 3 | 0 : i12;
  i2 = 0;
 } else {
  i7 = i12;
  i2 = 0;
 }
 L6 : while (1) {
  if (!(i2 >>> 0 < i11 >>> 0 & i7 >>> 0 < i10 >>> 0)) {
   i1 = i7;
   i2 = 40;
   break;
  }
  i1 = HEAP8[i7 >> 0] | 0;
  i6 = i1 & 255;
  if (i6 >>> 0 > i9 >>> 0) {
   i1 = i7;
   i2 = 40;
   break;
  }
  do if (i1 << 24 >> 24 > -1) i1 = i7 + 1 | 0; else {
   if ((i1 & 255) < 194) {
    i1 = i7;
    i2 = 40;
    break L6;
   }
   if ((i1 & 255) < 224) {
    if ((i8 - i7 | 0) < 2) {
     i1 = i7;
     i2 = 40;
     break L6;
    }
    i1 = HEAPU8[i7 + 1 >> 0] | 0;
    if ((i1 & 192 | 0) != 128) {
     i1 = i7;
     i2 = 40;
     break L6;
    }
    if ((i1 & 63 | i6 << 6 & 1984) >>> 0 > i9 >>> 0) {
     i1 = i7;
     i2 = 40;
     break L6;
    } else {
     i1 = i7 + 2 | 0;
     break;
    }
   }
   if ((i1 & 255) < 240) {
    i1 = i7;
    if ((i8 - i1 | 0) < 3) {
     i1 = i7;
     i2 = 40;
     break L6;
    }
    i4 = HEAP8[i7 + 1 >> 0] | 0;
    i3 = HEAP8[i7 + 2 >> 0] | 0;
    switch (i6 | 0) {
    case 224:
     {
      if ((i4 & -32) << 24 >> 24 != -96) {
       i2 = 19;
       break L6;
      }
      break;
     }
    case 237:
     {
      if ((i4 & -32) << 24 >> 24 != -128) {
       i2 = 21;
       break L6;
      }
      break;
     }
    default:
     if ((i4 & -64) << 24 >> 24 != -128) {
      i2 = 23;
      break L6;
     }
    }
    i1 = i3 & 255;
    if ((i1 & 192 | 0) != 128) {
     i1 = i7;
     i2 = 40;
     break L6;
    }
    if (((i4 & 255) << 6 & 4032 | i6 << 12 & 61440 | i1 & 63) >>> 0 > i9 >>> 0) {
     i1 = i7;
     i2 = 40;
     break L6;
    } else {
     i1 = i7 + 3 | 0;
     break;
    }
   }
   if ((i1 & 255) >= 245) {
    i1 = i7;
    i2 = 40;
    break L6;
   }
   i1 = i7;
   if ((i11 - i2 | 0) >>> 0 < 2 | (i8 - i1 | 0) < 4) {
    i1 = i7;
    i2 = 40;
    break L6;
   }
   i5 = HEAP8[i7 + 1 >> 0] | 0;
   i3 = HEAP8[i7 + 2 >> 0] | 0;
   i4 = HEAP8[i7 + 3 >> 0] | 0;
   switch (i6 | 0) {
   case 240:
    {
     if ((i5 + 112 & 255) >= 48) {
      i2 = 30;
      break L6;
     }
     break;
    }
   case 244:
    {
     if ((i5 & -16) << 24 >> 24 != -128) {
      i2 = 32;
      break L6;
     }
     break;
    }
   default:
    if ((i5 & -64) << 24 >> 24 != -128) {
     i2 = 34;
     break L6;
    }
   }
   i3 = i3 & 255;
   if ((i3 & 192 | 0) != 128) {
    i1 = i7;
    i2 = 40;
    break L6;
   }
   i1 = i4 & 255;
   if ((i1 & 192 | 0) != 128) {
    i1 = i7;
    i2 = 40;
    break L6;
   }
   if (((i5 & 255) << 12 & 258048 | i6 << 18 & 1835008 | i3 << 6 & 4032 | i1 & 63) >>> 0 > i9 >>> 0) {
    i1 = i7;
    i2 = 40;
    break L6;
   }
   i1 = i7 + 4 | 0;
   i2 = i2 + 1 | 0;
  } while (0);
  i7 = i1;
  i2 = i2 + 1 | 0;
 }
 if ((i2 | 0) == 19) i1 = i1 - i12 | 0; else if ((i2 | 0) == 21) i1 = i1 - i12 | 0; else if ((i2 | 0) == 23) i1 = i1 - i12 | 0; else if ((i2 | 0) == 30) i1 = i1 - i12 | 0; else if ((i2 | 0) == 32) i1 = i1 - i12 | 0; else if ((i2 | 0) == 34) i1 = i1 - i12 | 0; else if ((i2 | 0) == 40) i1 = i1 - i12 | 0;
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilderC2ERNS_6ModuleERNS_7ElementE(i10, i7, i9) {
 i10 = i10 | 0;
 i7 = i7 | 0;
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 144 | 0;
 i6 = i11 + 128 | 0;
 i5 = i11;
 HEAP32[i10 >> 2] = i7;
 i3 = i7 + 88 | 0;
 HEAP32[i10 + 4 >> 2] = i3;
 HEAP32[i10 + 8 >> 2] = 0;
 HEAP32[i10 + 12 >> 2] = 0;
 HEAP32[i10 + 16 >> 2] = 0;
 HEAP32[i10 + 24 >> 2] = 0;
 HEAP32[i10 + 32 >> 2] = 0;
 HEAP32[i10 + 36 >> 2] = 0;
 HEAP32[i10 + 28 >> 2] = i10 + 32;
 HEAP32[i10 + 40 >> 2] = 0;
 HEAP32[i10 + 48 >> 2] = 0;
 HEAP32[i10 + 52 >> 2] = 0;
 HEAP32[i10 + 44 >> 2] = i10 + 48;
 i4 = i10 + 64 | 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 HEAP8[i4 + 12 >> 0] = 0;
 i4 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i9, 0) | 0) | 0;
 if ((i4 | 0) != (HEAP32[14972] | 0)) ___assert_fail(21532, 21446, 269, 21559);
 i4 = (__ZN4wasm7Element4listEv(i9) | 0) + 8 | 0;
 if ((HEAP32[i4 >> 2] | 0) >>> 0 > 1 ? (i4 = __ZN4wasm7ElementixEj(i9, 1) | 0, (HEAP8[i4 >> 0] | 0) == 0) : 0) {
  HEAP32[i6 >> 2] = 0;
  HEAP32[i6 + 4 >> 2] = 0;
  HEAP32[i6 + 8 >> 2] = 0;
  i1 = 1;
  while (1) {
   i4 = (__ZN4wasm7Element4listEv(i9) | 0) + 8 | 0;
   if (i1 >>> 0 >= (HEAP32[i4 >> 2] | 0) >>> 0) break;
   i4 = i1 + 1 | 0;
   i1 = __ZN4wasm7Element5c_strEv(__ZN4wasm7ElementixEj(i9, i1) | 0) | 0;
   i2 = _strlen(i1) | 0;
   if (!i2) {
    i1 = i4;
    continue;
   }
   __ZN4wasm22SExpressionWasmBuilder14stringToBinaryEPKcjRNSt3__26vectorIcNS3_9allocatorIcEEEE(i10, i1, i2, i6);
   i1 = i4;
  }
  HEAP32[i5 >> 2] = i7;
  HEAP32[i5 + 4 >> 2] = i3;
  HEAP32[i5 + 8 >> 2] = i6;
  HEAP8[i5 + 12 >> 0] = 0;
  HEAP32[i5 + 16 >> 2] = 0;
  HEAP32[i5 + 20 >> 2] = -1;
  HEAP32[i5 + 24 >> 2] = 0;
  HEAP32[i5 + 28 >> 2] = 0;
  HEAP32[i5 + 32 >> 2] = 0;
  HEAP32[i5 + 40 >> 2] = 0;
  HEAP32[i5 + 44 >> 2] = 0;
  HEAP32[i5 + 48 >> 2] = 0;
  HEAP32[i5 + 56 >> 2] = 0;
  HEAP32[i5 + 60 >> 2] = 0;
  HEAP32[i5 + 52 >> 2] = i5 + 56;
  HEAP32[i5 + 64 >> 2] = 0;
  HEAP32[i5 + 76 >> 2] = 0;
  HEAP32[i5 + 80 >> 2] = 0;
  HEAP32[i5 + 72 >> 2] = i5 + 76;
  i10 = i5 + 84 | 0;
  HEAP32[i10 >> 2] = 0;
  HEAP32[i10 + 4 >> 2] = 0;
  HEAP32[i10 + 8 >> 2] = 0;
  HEAP32[i10 + 12 >> 2] = 0;
  HEAP32[i10 + 16 >> 2] = 0;
  HEAP32[i10 + 20 >> 2] = 0;
  HEAP32[i5 + 108 >> 2] = 15;
  HEAP32[i5 + 112 >> 2] = 0;
  HEAP32[i5 + 116 >> 2] = 0;
  HEAP32[i5 + 120 >> 2] = 0;
  __ZN4wasm17WasmBinaryBuilder4readEv(i5);
  __ZN4wasm17WasmBinaryBuilderD2Ev(i5);
  __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i6);
 } else i8 = 10;
 L12 : do if ((i8 | 0) == 10) {
  i1 = i10 + 20 | 0;
  HEAP32[i1 >> 2] = 0;
  i2 = 1;
  while (1) {
   i8 = (__ZN4wasm7Element4listEv(i9) | 0) + 8 | 0;
   if (i2 >>> 0 >= (HEAP32[i8 >> 2] | 0) >>> 0) break;
   __ZN4wasm22SExpressionWasmBuilder20preParseFunctionTypeERNS_7ElementE(i10, __ZN4wasm7ElementixEj(i9, i2) | 0);
   __ZN4wasm22SExpressionWasmBuilder15preParseImportsERNS_7ElementE(i10, __ZN4wasm7ElementixEj(i9, i2) | 0);
   i2 = i2 + 1 | 0;
  }
  HEAP32[i1 >> 2] = 0;
  i1 = 1;
  while (1) {
   i8 = (__ZN4wasm7Element4listEv(i9) | 0) + 8 | 0;
   if (i1 >>> 0 >= (HEAP32[i8 >> 2] | 0) >>> 0) break L12;
   __ZN4wasm22SExpressionWasmBuilder18parseModuleElementERNS_7ElementE(i10, __ZN4wasm7ElementixEj(i9, i1) | 0);
   i1 = i1 + 1 | 0;
  }
 } while (0);
 STACKTOP = i11;
 return;
}

function __ZNSt3__2L19utf8_to_ucs4_lengthEPKhS1_jmNS_12codecvt_modeE(i12, i10, i11, i9, i1) {
 i12 = i12 | 0;
 i10 = i10 | 0;
 i11 = i11 | 0;
 i9 = i9 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i8 = i10;
 if ((((i1 & 4 | 0) != 0 ? (i8 - i12 | 0) > 2 : 0) ? (HEAP8[i12 >> 0] | 0) == -17 : 0) ? (HEAP8[i12 + 1 >> 0] | 0) == -69 : 0) {
  i6 = (HEAP8[i12 + 2 >> 0] | 0) == -65 ? i12 + 3 | 0 : i12;
  i7 = 0;
 } else {
  i6 = i12;
  i7 = 0;
 }
 L6 : while (1) {
  if (!(i7 >>> 0 < i11 >>> 0 & i6 >>> 0 < i10 >>> 0)) {
   i1 = i6;
   i2 = 40;
   break;
  }
  i1 = HEAP8[i6 >> 0] | 0;
  i5 = i1 & 255;
  do if (i1 << 24 >> 24 <= -1) {
   if ((i1 & 255) < 194) {
    i1 = i6;
    i2 = 40;
    break L6;
   }
   if ((i1 & 255) < 224) {
    if ((i8 - i6 | 0) < 2) {
     i1 = i6;
     i2 = 40;
     break L6;
    }
    i1 = HEAPU8[i6 + 1 >> 0] | 0;
    if ((i1 & 192 | 0) != 128) {
     i1 = i6;
     i2 = 40;
     break L6;
    }
    if ((i1 & 63 | i5 << 6 & 1984) >>> 0 > i9 >>> 0) {
     i1 = i6;
     i2 = 40;
     break L6;
    }
    i1 = i6 + 2 | 0;
    break;
   }
   if ((i1 & 255) < 240) {
    i1 = i6;
    if ((i8 - i1 | 0) < 3) {
     i1 = i6;
     i2 = 40;
     break L6;
    }
    i3 = HEAP8[i6 + 1 >> 0] | 0;
    i2 = HEAP8[i6 + 2 >> 0] | 0;
    switch (i5 | 0) {
    case 224:
     {
      if ((i3 & -32) << 24 >> 24 != -96) {
       i2 = 20;
       break L6;
      }
      break;
     }
    case 237:
     {
      if ((i3 & -32) << 24 >> 24 != -128) {
       i2 = 22;
       break L6;
      }
      break;
     }
    default:
     if ((i3 & -64) << 24 >> 24 != -128) {
      i2 = 24;
      break L6;
     }
    }
    i1 = i2 & 255;
    if ((i1 & 192 | 0) != 128) {
     i1 = i6;
     i2 = 40;
     break L6;
    }
    if (((i3 & 255) << 6 & 4032 | i5 << 12 & 61440 | i1 & 63) >>> 0 > i9 >>> 0) {
     i1 = i6;
     i2 = 40;
     break L6;
    } else {
     i1 = i6 + 3 | 0;
     break;
    }
   }
   if ((i1 & 255) >= 245) {
    i1 = i6;
    i2 = 40;
    break L6;
   }
   i1 = i6;
   if ((i8 - i1 | 0) < 4) {
    i1 = i6;
    i2 = 40;
    break L6;
   }
   i4 = HEAP8[i6 + 1 >> 0] | 0;
   i2 = HEAP8[i6 + 2 >> 0] | 0;
   i3 = HEAP8[i6 + 3 >> 0] | 0;
   switch (i5 | 0) {
   case 240:
    {
     if ((i4 + 112 & 255) >= 48) {
      i2 = 31;
      break L6;
     }
     break;
    }
   case 244:
    {
     if ((i4 & -16) << 24 >> 24 != -128) {
      i2 = 33;
      break L6;
     }
     break;
    }
   default:
    if ((i4 & -64) << 24 >> 24 != -128) {
     i2 = 35;
     break L6;
    }
   }
   i2 = i2 & 255;
   if ((i2 & 192 | 0) != 128) {
    i1 = i6;
    i2 = 40;
    break L6;
   }
   i1 = i3 & 255;
   if ((i1 & 192 | 0) != 128) {
    i1 = i6;
    i2 = 40;
    break L6;
   }
   if (((i4 & 255) << 12 & 258048 | i5 << 18 & 1835008 | i2 << 6 & 4032 | i1 & 63) >>> 0 > i9 >>> 0) {
    i1 = i6;
    i2 = 40;
    break L6;
   } else i1 = i6 + 4 | 0;
  } else {
   if (i5 >>> 0 > i9 >>> 0) {
    i1 = i6;
    i2 = 40;
    break L6;
   }
   i1 = i6 + 1 | 0;
  } while (0);
  i6 = i1;
  i7 = i7 + 1 | 0;
 }
 if ((i2 | 0) == 20) i1 = i1 - i12 | 0; else if ((i2 | 0) == 22) i1 = i1 - i12 | 0; else if ((i2 | 0) == 24) i1 = i1 - i12 | 0; else if ((i2 | 0) == 31) i1 = i1 - i12 | 0; else if ((i2 | 0) == 33) i1 = i1 - i12 | 0; else if ((i2 | 0) == 35) i1 = i1 - i12 | 0; else if ((i2 | 0) == 40) i1 = i1 - i12 | 0;
 return i1 | 0;
}

function __ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE(i2, i13, i12, i14, i15, i10, i1) {
 i2 = i2 | 0;
 i13 = i13 | 0;
 i12 = i12 | 0;
 i14 = i14 | 0;
 i15 = i15 | 0;
 i10 = i10 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i11 = 0, i16 = 0, i17 = 0, i18 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i11 = i16;
 i9 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
 i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61692) | 0;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[i5 >> 2] | 0) + 20 >> 2] & 1023](i11, i5);
 i7 = i11 + 11 | 0;
 i6 = HEAP8[i7 >> 0] | 0;
 i8 = i11 + 4 | 0;
 if ((i6 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i6 & 255) | 0) {
  HEAP32[i10 >> 2] = i14;
  i1 = HEAP8[i2 >> 0] | 0;
  switch (i1 << 24 >> 24) {
  case 43:
  case 45:
   {
    i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i9 >> 2] | 0) + 28 >> 2] & 63](i9, i1) | 0;
    i3 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = i3 + 1;
    HEAP8[i3 >> 0] = i6;
    i3 = i2 + 1 | 0;
    break;
   }
  default:
   i3 = i2;
  }
  L7 : do if ((i12 - i3 | 0) > 1 ? (HEAP8[i3 >> 0] | 0) == 48 : 0) {
   i1 = i3 + 1 | 0;
   switch (HEAP8[i1 >> 0] | 0) {
   case 88:
   case 120:
    break;
   default:
    break L7;
   }
   i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i9 >> 2] | 0) + 28 >> 2] & 63](i9, 48) | 0;
   i4 = HEAP32[i10 >> 2] | 0;
   HEAP32[i10 >> 2] = i4 + 1;
   HEAP8[i4 >> 0] = i6;
   i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i9 >> 2] | 0) + 28 >> 2] & 63](i9, HEAP8[i1 >> 0] | 0) | 0;
   i6 = HEAP32[i10 >> 2] | 0;
   HEAP32[i10 >> 2] = i6 + 1;
   HEAP8[i6 >> 0] = i4;
   i3 = i3 + 2 | 0;
  } while (0);
  L12 : do if ((i3 | 0) != (i12 | 0)) {
   i1 = i12;
   i4 = i3;
   while (1) {
    i1 = i1 + -1 | 0;
    if (i4 >>> 0 >= i1 >>> 0) break L12;
    i6 = HEAP8[i4 >> 0] | 0;
    HEAP8[i4 >> 0] = HEAP8[i1 >> 0] | 0;
    HEAP8[i1 >> 0] = i6;
    i4 = i4 + 1 | 0;
   }
  } while (0);
  i5 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 16 >> 2] & 255](i5) | 0;
  i1 = 0;
  i4 = 0;
  i6 = i3;
  while (1) {
   if (i6 >>> 0 >= i12 >>> 0) break;
   i17 = HEAP8[((HEAP8[i7 >> 0] | 0) < 0 ? HEAP32[i11 >> 2] | 0 : i11) + i4 >> 0] | 0;
   if (i17 << 24 >> 24 != 0 & (i1 | 0) == (i17 << 24 >> 24 | 0)) {
    i17 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = i17 + 1;
    HEAP8[i17 >> 0] = i5;
    i17 = HEAP8[i7 >> 0] | 0;
    i1 = 0;
    i4 = (i4 >>> 0 < ((i17 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i17 & 255) + -1 | 0) >>> 0 & 1) + i4 | 0;
   }
   i18 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i9 >> 2] | 0) + 28 >> 2] & 63](i9, HEAP8[i6 >> 0] | 0) | 0;
   i17 = HEAP32[i10 >> 2] | 0;
   HEAP32[i10 >> 2] = i17 + 1;
   HEAP8[i17 >> 0] = i18;
   i1 = i1 + 1 | 0;
   i6 = i6 + 1 | 0;
  }
  i1 = i14 + (i3 - i2) | 0;
  i3 = HEAP32[i10 >> 2] | 0;
  if ((i1 | 0) != (i3 | 0)) {
   while (1) {
    i3 = i3 + -1 | 0;
    if (i1 >>> 0 >= i3 >>> 0) break;
    i18 = HEAP8[i1 >> 0] | 0;
    HEAP8[i1 >> 0] = HEAP8[i3 >> 0] | 0;
    HEAP8[i3 >> 0] = i18;
    i1 = i1 + 1 | 0;
   }
   i1 = HEAP32[i10 >> 2] | 0;
  }
 } else {
  FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i9 >> 2] | 0) + 32 >> 2] & 7](i9, i2, i12, i14) | 0;
  i1 = i14 + (i12 - i2) | 0;
  HEAP32[i10 >> 2] = i1;
 }
 HEAP32[i15 >> 2] = (i13 | 0) == (i12 | 0) ? i1 : i14 + (i13 - i2) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i11);
 STACKTOP = i16;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder20preParseFunctionTypeERNS_7ElementE(i11, i5) {
 i11 = i11 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i12 + 28 | 0;
 i10 = i12 + 24 | 0;
 i2 = i12 + 16 | 0;
 i7 = i12 + 20 | 0;
 i8 = i12 + 4 | 0;
 i9 = i12;
 i1 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i5, 0) | 0) | 0;
 if ((i1 | 0) != (HEAP32[14983] | 0)) {
  if ((i1 | 0) == (HEAP32[14974] | 0)) {
   HEAP32[i10 >> 2] = 0;
   HEAP32[i2 >> 2] = 0;
   i3 = __ZN4wasm22SExpressionWasmBuilder18parseFunctionNamesERNS_7ElementERNS_4NameES4_(i11, i5, i10, i2) | 0;
   i1 = HEAP32[i10 >> 2] | 0;
   if (!i1) {
    i1 = __ZN4wasm4Name7fromIntEj(HEAP32[i11 + 20 >> 2] | 0) | 0;
    HEAP32[i10 >> 2] = i1;
   }
   i2 = i11 + 12 | 0;
   i4 = HEAP32[i2 >> 2] | 0;
   if ((i4 | 0) == (HEAP32[i11 + 16 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i11 + 8 | 0, i10); else {
    HEAP32[i4 >> 2] = i1;
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
   }
   i4 = i11 + 20 | 0;
   HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
   while (1) {
    i4 = (__ZN4wasm7Element4listEv(i5) | 0) + 8 | 0;
    if (i3 >>> 0 >= (HEAP32[i4 >> 2] | 0) >>> 0) {
     i2 = 17;
     break;
    }
    i1 = __ZN4wasm7ElementixEj(i5, i3) | 0;
    i2 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 0) | 0) | 0;
    if ((i2 | 0) == (HEAP32[14976] | 0)) {
     i2 = 12;
     break;
    }
    if ((i2 | 0) == (HEAP32[14983] | 0)) {
     i2 = 14;
     break;
    } else i3 = i3 + 1 | 0;
   }
   do if ((i2 | 0) == 12) {
    i9 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i11, __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 1) | 0) | 0, 0, 0) | 0;
    i11 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i11 + 28 | 0, i10) | 0;
    HEAP32[i11 >> 2] = i9;
   } else if ((i2 | 0) == 14) {
    i1 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 1) | 0) | 0;
    i5 = HEAP32[i11 >> 2] | 0;
    HEAP32[i7 >> 2] = i1;
    HEAP32[i6 >> 2] = HEAP32[i7 >> 2];
    if (!(__ZN4wasm6Module17checkFunctionTypeENS_4NameE(i5, i6) | 0)) {
     i12 = ___cxa_allocate_exception(20) | 0;
     HEAP32[i8 >> 2] = 0;
     HEAP32[i8 + 4 >> 2] = 0;
     HEAP32[i8 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i8, 21659, 16);
     __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i12, i8);
     ___cxa_throw(i12 | 0, 64, 279);
    } else {
     i8 = HEAP32[i11 >> 2] | 0;
     HEAP32[i9 >> 2] = i1;
     HEAP32[i6 >> 2] = HEAP32[i9 >> 2];
     i9 = (__ZN4wasm6Module15getFunctionTypeENS_4NameE(i8, i6) | 0) + 4 | 0;
     i9 = HEAP32[i9 >> 2] | 0;
     i11 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i11 + 28 | 0, i10) | 0;
     HEAP32[i11 >> 2] = i9;
     break;
    }
   } else if ((i2 | 0) == 17) {
    i11 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i11 + 28 | 0, i10) | 0;
    HEAP32[i11 >> 2] = 0;
   } while (0);
  }
 } else __ZN4wasm22SExpressionWasmBuilder9parseTypeERNS_7ElementE(i11, i5);
 STACKTOP = i12;
 return;
}

function __ZN6cashew7IString3setEPKcb(i16, i1, i3) {
 i16 = i16 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, d5 = 0.0, d6 = 0.0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i17 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i17;
 HEAP32[i2 >> 2] = i1;
 if ((HEAP8[58544] | 0) == 0 ? ___cxa_guard_acquire(58544) | 0 : 0) {
  i15 = __Znwj(20) | 0;
  HEAP32[i15 >> 2] = 0;
  HEAP32[i15 + 4 >> 2] = 0;
  HEAP32[i15 + 8 >> 2] = 0;
  HEAP32[i15 + 12 >> 2] = 0;
  HEAPF32[i15 + 16 >> 2] = 1.0;
  HEAP32[14815] = i15;
 }
 i1 = __ZNSt3__212__hash_tableIPKcN6cashew7IString11CStringHashENS4_12CStringEqualENS_9allocatorIS2_EEE4findIS2_EENS_15__hash_iteratorIPNS_11__hash_nodeIS2_PvEEEERKT_(HEAP32[14815] | 0, i2) | 0;
 L5 : do if (!i1) {
  if (__ZN4wasm10ThreadPool9isRunningEv() | 0) ___assert_fail(18666, 18623, 76, 18697);
  i1 = HEAP32[i2 >> 2] | 0;
  if (i3) i11 = i1; else {
   i15 = (_strlen(i1) | 0) + 1 | 0;
   i11 = _malloc(i15) | 0;
   _strncpy(i11, i1, i15) | 0;
   HEAP32[i2 >> 2] = i11;
  }
  i1 = i11;
  i15 = HEAP32[14815] | 0;
  i2 = i11;
  i4 = 5381;
  while (1) {
   i3 = HEAP8[i2 >> 0] | 0;
   if (!(i3 << 24 >> 24)) break;
   i2 = i2 + 1 | 0;
   i4 = i3 << 24 >> 24 ^ i4 * 33;
  }
  i10 = i11;
  i13 = i15 + 4 | 0;
  i14 = HEAP32[i13 >> 2] | 0;
  i12 = (i14 | 0) == 0;
  L17 : do if (!i12) {
   i8 = i14 + -1 | 0;
   i9 = (i8 & i14 | 0) == 0;
   if (i9) i2 = i8 & i4; else i2 = (i4 >>> 0) % (i14 >>> 0) | 0;
   i3 = HEAP32[(HEAP32[i15 >> 2] | 0) + (i2 << 2) >> 2] | 0;
   if (i3) while (1) {
    i3 = HEAP32[i3 >> 2] | 0;
    if (!i3) break L17;
    i7 = HEAP32[i3 + 4 >> 2] | 0;
    if (i9) i7 = i7 & i8; else i7 = (i7 >>> 0) % (i14 >>> 0) | 0;
    if ((i7 | 0) != (i2 | 0)) break L17;
    if (!(_strcmp(HEAP32[i3 + 8 >> 2] | 0, i11) | 0)) break L5;
   }
  } else i2 = 0; while (0);
  i9 = __Znwj(12) | 0;
  HEAP32[i9 + 8 >> 2] = i10;
  HEAP32[i9 + 4 >> 2] = i4;
  HEAP32[i9 >> 2] = 0;
  i8 = i15 + 12 | 0;
  d5 = +(((HEAP32[i8 >> 2] | 0) + 1 | 0) >>> 0);
  d6 = +HEAPF32[i15 + 16 >> 2];
  do if (i12 | d5 > +(i14 >>> 0) * d6) {
   if (i14 >>> 0 > 2) i2 = (i14 + -1 & i14 | 0) == 0; else i2 = 0;
   i2 = (i2 & 1 | i14 << 1) ^ 1;
   i3 = ~~+Math_ceil(+(d5 / d6)) >>> 0;
   __ZNSt3__212__hash_tableIPKcN6cashew7IString11CStringHashENS4_12CStringEqualENS_9allocatorIS2_EEE6rehashEj(i15, i2 >>> 0 < i3 >>> 0 ? i3 : i2);
   i2 = HEAP32[i13 >> 2] | 0;
   i3 = i2 + -1 | 0;
   if (!(i3 & i2)) {
    i7 = i2;
    i2 = i3 & i4;
    break;
   } else {
    i7 = i2;
    i2 = (i4 >>> 0) % (i2 >>> 0) | 0;
    break;
   }
  } else i7 = i14; while (0);
  i2 = (HEAP32[i15 >> 2] | 0) + (i2 << 2) | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (!i3) {
   i14 = i15 + 8 | 0;
   HEAP32[i9 >> 2] = HEAP32[i14 >> 2];
   HEAP32[i14 >> 2] = i9;
   HEAP32[i2 >> 2] = i14;
   i2 = HEAP32[i9 >> 2] | 0;
   if (i2 | 0) {
    i2 = HEAP32[i2 + 4 >> 2] | 0;
    i3 = i7 + -1 | 0;
    if (!(i3 & i7)) i2 = i2 & i3; else i2 = (i2 >>> 0) % (i7 >>> 0) | 0;
    HEAP32[(HEAP32[i15 >> 2] | 0) + (i2 << 2) >> 2] = i9;
   }
  } else {
   HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i3 >> 2] = i9;
  }
  HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + 1;
 } else {
  i1 = HEAP32[i1 + 8 >> 2] | 0;
  HEAP32[i2 >> 2] = i1;
 } while (0);
 HEAP32[i16 >> 2] = i1;
 STACKTOP = i17;
 return;
}

function __ZNSt3__2L13utf16_to_utf8EPKtS1_RS1_PhS3_RS3_mNS_12codecvt_modeE(i1, i8, i9, i4, i2, i10, i7, i3) {
 i1 = i1 | 0;
 i8 = i8 | 0;
 i9 = i9 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i10 = i10 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 var i5 = 0, i6 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP32[i10 >> 2] = i4;
 if (i3 & 2) if ((i2 - i4 | 0) < 3) i1 = 1; else {
  HEAP32[i10 >> 2] = i4 + 1;
  HEAP8[i4 >> 0] = -17;
  i5 = HEAP32[i10 >> 2] | 0;
  HEAP32[i10 >> 2] = i5 + 1;
  HEAP8[i5 >> 0] = -69;
  i5 = HEAP32[i10 >> 2] | 0;
  HEAP32[i10 >> 2] = i5 + 1;
  HEAP8[i5 >> 0] = -65;
  i5 = 4;
 } else i5 = 4;
 L4 : do if ((i5 | 0) == 4) {
  i6 = i8;
  i1 = HEAP32[i9 >> 2] | 0;
  while (1) {
   if (i1 >>> 0 >= i8 >>> 0) {
    i1 = 0;
    break L4;
   }
   i3 = HEAP16[i1 >> 1] | 0;
   i5 = i3 & 65535;
   if (i5 >>> 0 > i7 >>> 0) {
    i1 = 2;
    break L4;
   }
   do if ((i3 & 65535) < 128) {
    i1 = HEAP32[i10 >> 2] | 0;
    if ((i2 - i1 | 0) < 1) {
     i1 = 1;
     break L4;
    }
    HEAP32[i10 >> 2] = i1 + 1;
    HEAP8[i1 >> 0] = i3;
   } else {
    if ((i3 & 65535) < 2048) {
     i1 = HEAP32[i10 >> 2] | 0;
     if ((i2 - i1 | 0) < 2) {
      i1 = 1;
      break L4;
     }
     HEAP32[i10 >> 2] = i1 + 1;
     HEAP8[i1 >> 0] = i5 >>> 6 | 192;
     i4 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i4 + 1;
     HEAP8[i4 >> 0] = i5 & 63 | 128;
     break;
    }
    if ((i3 & 65535) < 55296) {
     i1 = HEAP32[i10 >> 2] | 0;
     if ((i2 - i1 | 0) < 3) {
      i1 = 1;
      break L4;
     }
     HEAP32[i10 >> 2] = i1 + 1;
     HEAP8[i1 >> 0] = i5 >>> 12 | 224;
     i4 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i4 + 1;
     HEAP8[i4 >> 0] = i5 >>> 6 & 63 | 128;
     i4 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i4 + 1;
     HEAP8[i4 >> 0] = i5 & 63 | 128;
     break;
    }
    if ((i3 & 65535) >= 56320) {
     if ((i3 & 65535) < 57344) {
      i1 = 2;
      break L4;
     }
     i1 = HEAP32[i10 >> 2] | 0;
     if ((i2 - i1 | 0) < 3) {
      i1 = 1;
      break L4;
     }
     HEAP32[i10 >> 2] = i1 + 1;
     HEAP8[i1 >> 0] = i5 >>> 12 | 224;
     i4 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i4 + 1;
     HEAP8[i4 >> 0] = i5 >>> 6 & 63 | 128;
     i4 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i4 + 1;
     HEAP8[i4 >> 0] = i5 & 63 | 128;
     break;
    }
    if ((i6 - i1 | 0) < 4) {
     i1 = 1;
     break L4;
    }
    i1 = i1 + 2 | 0;
    i3 = HEAPU16[i1 >> 1] | 0;
    if ((i3 & 64512 | 0) != 56320) {
     i1 = 2;
     break L4;
    }
    if ((i2 - (HEAP32[i10 >> 2] | 0) | 0) < 4) {
     i1 = 1;
     break L4;
    }
    i4 = i5 & 960;
    if (((i4 << 10) + 65536 | i5 << 10 & 64512 | i3 & 1023) >>> 0 > i7 >>> 0) {
     i1 = 2;
     break L4;
    }
    HEAP32[i9 >> 2] = i1;
    i1 = (i4 >>> 6) + 1 | 0;
    i4 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = i4 + 1;
    HEAP8[i4 >> 0] = i1 >>> 2 | 240;
    i4 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = i4 + 1;
    HEAP8[i4 >> 0] = i5 >>> 2 & 15 | i1 << 4 & 48 | 128;
    i4 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = i4 + 1;
    HEAP8[i4 >> 0] = i5 << 4 & 48 | i3 >>> 6 & 15 | 128;
    i5 = HEAP32[i10 >> 2] | 0;
    HEAP32[i10 >> 2] = i5 + 1;
    HEAP8[i5 >> 0] = i3 & 63 | 128;
   } while (0);
   i1 = (HEAP32[i9 >> 2] | 0) + 2 | 0;
   HEAP32[i9 >> 2] = i1;
  }
 } while (0);
 return i1 | 0;
}

function __ZNSt3__213unordered_setIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEEC2ERKSG_(i20, i1) {
 i20 = i20 | 0;
 i1 = i1 | 0;
 var i2 = 0, d3 = 0.0, d4 = 0.0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i21 = 0, i22 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i19 = i22;
 i18 = i22 + 4 | 0;
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 HEAP32[i20 + 12 >> 2] = 0;
 HEAP32[i20 + 16 >> 2] = HEAP32[i1 + 16 >> 2];
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6rehashEj(i20, HEAP32[i1 + 4 >> 2] | 0);
 i17 = HEAP32[i1 + 8 >> 2] | 0;
 i15 = i20 + 4 | 0;
 i16 = i20 + 12 | 0;
 i13 = i20 + 16 | 0;
 i14 = i20 + 8 | 0;
 i1 = i17;
 while (1) {
  if (!i1) break;
  i9 = HEAP32[i1 + 8 >> 2] | 0;
  HEAP32[i19 >> 2] = i9;
  i12 = __ZNSt3__221__murmur2_or_cityhashIjLj32EEclEPKvj(i18, i19, 4) | 0;
  i11 = HEAP32[i15 >> 2] | 0;
  i10 = (i11 | 0) == 0;
  i6 = i9;
  L4 : do if (!i10) {
   i7 = i11 + -1 | 0;
   i8 = (i7 & i11 | 0) == 0;
   if (i8) i1 = i7 & i12; else i1 = (i12 >>> 0) % (i11 >>> 0) | 0;
   i2 = HEAP32[(HEAP32[i20 >> 2] | 0) + (i1 << 2) >> 2] | 0;
   if (!i2) i21 = 14; else do {
    i2 = HEAP32[i2 >> 2] | 0;
    if (!i2) {
     i21 = 14;
     break L4;
    }
    i5 = HEAP32[i2 + 4 >> 2] | 0;
    if (i8) i5 = i5 & i7; else i5 = (i5 >>> 0) % (i11 >>> 0) | 0;
    if ((i5 | 0) != (i1 | 0)) {
     i21 = 14;
     break L4;
    }
   } while ((HEAP32[i2 + 8 >> 2] | 0) != (i6 | 0));
  } else {
   i1 = 0;
   i21 = 14;
  } while (0);
  if ((i21 | 0) == 14) {
   i21 = 0;
   i6 = __Znwj(12) | 0;
   HEAP32[i6 + 8 >> 2] = i9;
   HEAP32[i6 + 4 >> 2] = i12;
   HEAP32[i6 >> 2] = 0;
   d3 = +(((HEAP32[i16 >> 2] | 0) + 1 | 0) >>> 0);
   d4 = +HEAPF32[i13 >> 2];
   do if (i10 | d3 > +(i11 >>> 0) * d4) {
    if (i11 >>> 0 > 2) i1 = (i11 + -1 & i11 | 0) == 0; else i1 = 0;
    i1 = (i1 & 1 | i11 << 1) ^ 1;
    i2 = ~~+Math_ceil(+(d3 / d4)) >>> 0;
    __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6rehashEj(i20, i1 >>> 0 < i2 >>> 0 ? i2 : i1);
    i1 = HEAP32[i15 >> 2] | 0;
    i2 = i1 + -1 | 0;
    if (!(i2 & i1)) {
     i5 = i1;
     i1 = i2 & i12;
     break;
    } else {
     i5 = i1;
     i1 = (i12 >>> 0) % (i1 >>> 0) | 0;
     break;
    }
   } else i5 = i11; while (0);
   i1 = (HEAP32[i20 >> 2] | 0) + (i1 << 2) | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if (!i2) {
    HEAP32[i6 >> 2] = HEAP32[i14 >> 2];
    HEAP32[i14 >> 2] = i6;
    HEAP32[i1 >> 2] = i14;
    i1 = HEAP32[i6 >> 2] | 0;
    if (i1 | 0) {
     i1 = HEAP32[i1 + 4 >> 2] | 0;
     i2 = i5 + -1 | 0;
     if (!(i2 & i5)) i1 = i1 & i2; else i1 = (i1 >>> 0) % (i5 >>> 0) | 0;
     HEAP32[(HEAP32[i20 >> 2] | 0) + (i1 << 2) >> 2] = i6;
    }
   } else {
    HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i2 >> 2] = i6;
   }
   HEAP32[i16 >> 2] = (HEAP32[i16 >> 2] | 0) + 1;
  }
  i12 = HEAP32[i17 >> 2] | 0;
  i1 = i12;
  i17 = i12;
 }
 STACKTOP = i22;
 return;
}

function __ZNSt3__2L12utf8_to_ucs4EPKhS1_RS1_PjS3_RS3_mNS_12codecvt_modeE(i1, i10, i11, i3, i12, i13, i9, i2) {
 i1 = i1 | 0;
 i10 = i10 | 0;
 i11 = i11 | 0;
 i3 = i3 | 0;
 i12 = i12 | 0;
 i13 = i13 | 0;
 i9 = i9 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i14 = 0;
 HEAP32[i11 >> 2] = i1;
 HEAP32[i13 >> 2] = i3;
 if (i2 & 4) {
  i1 = HEAP32[i11 >> 2] | 0;
  i2 = i10;
  if ((((i2 - i1 | 0) > 2 ? (HEAP8[i1 >> 0] | 0) == -17 : 0) ? (HEAP8[i1 + 1 >> 0] | 0) == -69 : 0) ? (HEAP8[i1 + 2 >> 0] | 0) == -65 : 0) HEAP32[i11 >> 2] = i1 + 3;
 } else i2 = i10;
 L9 : while (1) {
  i7 = HEAP32[i11 >> 2] | 0;
  i1 = i7 >>> 0 < i10 >>> 0;
  if (!i1) {
   i14 = 40;
   break;
  }
  i8 = HEAP32[i13 >> 2] | 0;
  if (i8 >>> 0 >= i12 >>> 0) {
   i14 = 40;
   break;
  }
  i1 = HEAP8[i7 >> 0] | 0;
  i6 = i1 & 255;
  do if (i1 << 24 >> 24 > -1) {
   if (i6 >>> 0 > i9 >>> 0) {
    i1 = 2;
    break L9;
   }
   HEAP32[i8 >> 2] = i6;
   HEAP32[i11 >> 2] = i7 + 1;
  } else {
   if ((i1 & 255) < 194) {
    i1 = 2;
    break L9;
   }
   if ((i1 & 255) < 224) {
    if ((i2 - i7 | 0) < 2) {
     i1 = 1;
     break L9;
    }
    i1 = HEAPU8[i7 + 1 >> 0] | 0;
    if ((i1 & 192 | 0) != 128) {
     i1 = 2;
     break L9;
    }
    i1 = i1 & 63 | i6 << 6 & 1984;
    if (i1 >>> 0 > i9 >>> 0) {
     i1 = 2;
     break L9;
    }
    HEAP32[i8 >> 2] = i1;
    HEAP32[i11 >> 2] = i7 + 2;
    break;
   }
   if ((i1 & 255) < 240) {
    if ((i2 - i7 | 0) < 3) {
     i1 = 1;
     break L9;
    }
    i3 = HEAP8[i7 + 1 >> 0] | 0;
    i1 = HEAP8[i7 + 2 >> 0] | 0;
    switch (i6 | 0) {
    case 224:
     {
      if ((i3 & -32) << 24 >> 24 != -96) {
       i1 = 2;
       break L9;
      }
      break;
     }
    case 237:
     {
      if ((i3 & -32) << 24 >> 24 != -128) {
       i1 = 2;
       break L9;
      }
      break;
     }
    default:
     if ((i3 & -64) << 24 >> 24 != -128) {
      i1 = 2;
      break L9;
     }
    }
    i1 = i1 & 255;
    if ((i1 & 192 | 0) != 128) {
     i1 = 2;
     break L9;
    }
    i1 = (i3 & 255) << 6 & 4032 | i6 << 12 & 61440 | i1 & 63;
    if (i1 >>> 0 > i9 >>> 0) {
     i1 = 2;
     break L9;
    }
    HEAP32[i8 >> 2] = i1;
    HEAP32[i11 >> 2] = i7 + 3;
    break;
   }
   if ((i1 & 255) >= 245) {
    i1 = 2;
    break L9;
   }
   if ((i2 - i7 | 0) < 4) {
    i1 = 1;
    break L9;
   }
   i5 = HEAP8[i7 + 1 >> 0] | 0;
   i1 = HEAP8[i7 + 2 >> 0] | 0;
   i3 = HEAP8[i7 + 3 >> 0] | 0;
   switch (i6 | 0) {
   case 240:
    {
     if ((i5 + 112 & 255) >= 48) {
      i1 = 2;
      break L9;
     }
     break;
    }
   case 244:
    {
     if ((i5 & -16) << 24 >> 24 != -128) {
      i1 = 2;
      break L9;
     }
     break;
    }
   default:
    if ((i5 & -64) << 24 >> 24 != -128) {
     i1 = 2;
     break L9;
    }
   }
   i4 = i1 & 255;
   if ((i4 & 192 | 0) != 128) {
    i1 = 2;
    break L9;
   }
   i1 = i3 & 255;
   if ((i1 & 192 | 0) != 128) {
    i1 = 2;
    break L9;
   }
   i1 = (i5 & 255) << 12 & 258048 | i6 << 18 & 1835008 | i4 << 6 & 4032 | i1 & 63;
   if (i1 >>> 0 > i9 >>> 0) {
    i1 = 2;
    break L9;
   }
   HEAP32[i8 >> 2] = i1;
   HEAP32[i11 >> 2] = i7 + 4;
  } while (0);
  HEAP32[i13 >> 2] = (HEAP32[i13 >> 2] | 0) + 4;
 }
 if ((i14 | 0) == 40) i1 = i1 & 1;
 return i1 | 0;
}

function __ZNSt3__227__insertion_sort_incompleteIRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEbT0_SL_T_(i9, i8, i1) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i10 = 0;
 switch (i8 - i9 >> 2 | 0) {
 case 1:
 case 0:
  {
   i1 = 1;
   break;
  }
 case 2:
  {
   i1 = i8 + -4 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   i3 = HEAP32[i9 >> 2] | 0;
   if (+HEAPF64[i2 + 16 >> 3] > +HEAPF64[i3 + 16 >> 3]) {
    HEAP32[i9 >> 2] = i2;
    HEAP32[i1 >> 2] = i3;
    i1 = 1;
   } else i1 = 1;
   break;
  }
 case 3:
  {
   __ZNSt3__27__sort3IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_T_(i9, i9 + 4 | 0, i8 + -4 | 0, i1) | 0;
   i1 = 1;
   break;
  }
 case 4:
  {
   __ZNSt3__27__sort4IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_SL_T_(i9, i9 + 4 | 0, i9 + 8 | 0, i8 + -4 | 0, i1) | 0;
   i1 = 1;
   break;
  }
 case 5:
  {
   __ZNSt3__27__sort5IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_SL_SL_T_(i9, i9 + 4 | 0, i9 + 8 | 0, i9 + 12 | 0, i8 + -4 | 0, i1) | 0;
   i1 = 1;
   break;
  }
 default:
  {
   i3 = i9 + 8 | 0;
   __ZNSt3__27__sort3IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_T_(i9, i9 + 4 | 0, i3, i1) | 0;
   i1 = 0;
   i7 = i9 + 12 | 0;
   while (1) {
    if ((i7 | 0) == (i8 | 0)) {
     i2 = 1;
     i1 = 0;
     break;
    }
    i2 = HEAP32[i7 >> 2] | 0;
    i6 = i2;
    if (+HEAPF64[i2 + 16 >> 3] > +HEAPF64[(HEAP32[i3 >> 2] | 0) + 16 >> 3]) {
     HEAP32[i7 >> 2] = 0;
     i5 = i2 + 16 | 0;
     i4 = i7;
     while (1) {
      i10 = HEAP32[i3 >> 2] | 0;
      HEAP32[i3 >> 2] = 0;
      i2 = HEAP32[i4 >> 2] | 0;
      HEAP32[i4 >> 2] = i10;
      if (i2 | 0) {
       __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i2);
       __ZdlPv(i2);
      }
      if ((i3 | 0) == (i9 | 0)) {
       i2 = i3;
       break;
      }
      i2 = i3 + -4 | 0;
      if (+HEAPF64[i5 >> 3] > +HEAPF64[(HEAP32[i2 >> 2] | 0) + 16 >> 3]) {
       i4 = i3;
       i3 = i2;
      } else {
       i2 = i3;
       break;
      }
     }
     i2 = HEAP32[i2 >> 2] | 0;
     HEAP32[i3 >> 2] = i6;
     if (i2 | 0) {
      __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i2);
      __ZdlPv(i2);
     }
     i1 = i1 + 1 | 0;
     if ((i1 | 0) == 8) {
      i2 = 0;
      i1 = (i7 + 4 | 0) == (i8 | 0);
      break;
     }
    }
    i3 = i7;
    i7 = i7 + 4 | 0;
   }
   i1 = i1 | i2;
  }
 }
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder9makeUnaryERNS_7ElementENS_7UnaryOpENS_8WasmTypeE(i1, i13, i2, i8) {
 i1 = i1 | 0;
 i13 = i13 | 0;
 i2 = i2 | 0;
 i8 = i8 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i12 = i3 + 60 | 0;
 i11 = i3 + 48 | 0;
 i9 = i3 + 36 | 0;
 i7 = i3 + 24 | 0;
 i6 = i3 + 12 | 0;
 i4 = i3;
 i5 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i1 + 4 >> 2] | 0) | 0;
 HEAP32[i5 + 8 >> 2] = i2;
 i1 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i1, __ZN4wasm7ElementixEj(i13, 1) | 0) | 0;
 i10 = i5 + 12 | 0;
 HEAP32[i10 >> 2] = i1;
 __ZN4wasm5Unary8finalizeEv(i5);
 if (i2 >>> 0 < 22 ? (i2 = HEAP32[(HEAP32[i10 >> 2] | 0) + 4 >> 2] | 0, !((i2 | 0) == 5 | (i2 | 0) == (i8 | 0))) : 0) {
  i3 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i4 >> 2] = 0;
  HEAP32[i4 + 4 >> 2] = 0;
  HEAP32[i4 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i4, 21956, 13);
  i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i4, __ZN4wasm17getExpressionNameEPNS_10ExpressionE(i5) | 0) | 0;
  HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i6 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i6 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i6, 19435) | 0;
  HEAP32[i7 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i7 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i7 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i7, __ZN4wasm13printWasmTypeENS_8WasmTypeE(i8) | 0) | 0;
  HEAP32[i9 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i9 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i9 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i9, 21970) | 0;
  HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i11 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i11 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i11, __ZN4wasm13printWasmTypeENS_8WasmTypeE(HEAP32[(HEAP32[i10 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
  HEAP32[i12 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i12 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i12 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  i11 = HEAP32[i13 + 28 >> 2] | 0;
  i13 = HEAP32[i13 + 32 >> 2] | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i3, i12);
  HEAP32[i3 + 12 >> 2] = i11;
  HEAP32[i3 + 16 >> 2] = i13;
  ___cxa_throw(i3 | 0, 64, 279);
 }
 STACKTOP = i3;
 return i5 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder8makeLoadERNS_7ElementENS_8WasmTypeE(i11, i7, i1) {
 i11 = i11 | 0;
 i7 = i7 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i12 + 12 | 0;
 i9 = i12;
 i3 = _strchr(__ZN4wasm7Element5c_strEv(__ZN4wasm7ElementixEj(i7, 0) | 0) | 0, 46) | 0;
 i4 = i3 + 5 | 0;
 i10 = __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(HEAP32[i11 + 4 >> 2] | 0) | 0;
 HEAP32[i10 + 4 >> 2] = i1;
 i1 = (__ZN4wasm15getWasmTypeSizeENS_8WasmTypeE(i1) | 0) & 255;
 i2 = i10 + 8 | 0;
 HEAP8[i2 >> 0] = i1;
 L1 : do switch (HEAP8[i4 >> 0] | 0) {
 case 56:
  {
   HEAP8[i2 >> 0] = 1;
   i6 = 1;
   i5 = i3 + 6 | 0;
   break;
  }
 case 49:
  {
   if ((HEAP8[i3 + 6 >> 0] | 0) == 54) {
    HEAP8[i2 >> 0] = 2;
    i6 = 2;
    i5 = i3 + 7 | 0;
    break L1;
   } else ___assert_fail(22370, 21446, 926, 22386);
   break;
  }
 case 51:
  {
   if ((HEAP8[i3 + 6 >> 0] | 0) == 50) {
    HEAP8[i2 >> 0] = 4;
    i6 = 4;
    i5 = i3 + 7 | 0;
    break L1;
   } else ___assert_fail(22395, 21446, 930, 22386);
   break;
  }
 default:
  {
   i6 = i1;
   i5 = i4;
  }
 } while (0);
 if (!(HEAP8[i5 >> 0] | 0)) i1 = 0; else i1 = (HEAP8[i5 + 1 >> 0] | 0) == 115 & 1;
 HEAP8[i10 + 9 >> 0] = i1;
 i4 = i10 + 12 | 0;
 HEAP32[i4 >> 2] = 0;
 i5 = i10 + 16 | 0;
 __ZN4wasm7AddressaSEy(i5, i6 & 255, 0) | 0;
 i3 = 1;
 L15 : while (1) {
  i6 = __ZN4wasm7ElementixEj(i7, i3) | 0;
  i6 = (HEAP8[i6 >> 0] | 0) == 0;
  i1 = __ZN4wasm7ElementixEj(i7, i3) | 0;
  if (!i6) {
   i2 = 22;
   break;
  }
  i2 = __ZN4wasm7Element5c_strEv(i1) | 0;
  i1 = _strchr(i2, 61) | 0;
  if (!i1) {
   i2 = 14;
   break;
  }
  i1 = i1 + 1 | 0;
  switch (HEAP8[i2 >> 0] | 0) {
  case 97:
   {
    i6 = _atoi(i1) | 0;
    __ZN4wasm7AddressaSEy(i5, i6, ((i6 | 0) < 0) << 31 >> 31) | 0;
    break;
   }
  case 111:
   {
    i1 = _atoll(i1) | 0;
    i6 = tempRet0;
    if (i6 >>> 0 > 0 | (i6 | 0) == 0 & i1 >>> 0 > 4294967295) {
     i2 = 18;
     break L15;
    }
    __ZN4wasm7AddressaSEy(i4, i1, 0) | 0;
    break;
   }
  default:
   {
    i2 = 20;
    break L15;
   }
  }
  i3 = i3 + 1 | 0;
 }
 if ((i2 | 0) == 14) ___assert_fail(22411, 21446, 941, 22386); else if ((i2 | 0) == 18) {
  i12 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i8 >> 2] = 0;
  HEAP32[i8 + 4 >> 2] = 0;
  HEAP32[i8 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i8, 22414, 10);
  __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i12, i8);
  ___cxa_throw(i12 | 0, 64, 279);
 } else if ((i2 | 0) == 20) {
  i12 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i9 >> 2] = 0;
  HEAP32[i9 + 4 >> 2] = 0;
  HEAP32[i9 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i9, 22425, 18);
  __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i12, i9);
  ___cxa_throw(i12 | 0, 64, 279);
 } else if ((i2 | 0) == 22) {
  i11 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i11, i1) | 0;
  HEAP32[i10 + 20 >> 2] = i11;
  STACKTOP = i12;
  return i10 | 0;
 }
 return 0;
}

function __ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe(i1, i13, i14, i2, i3, i15, i12) {
 i1 = i1 | 0;
 i13 = i13 | 0;
 i14 = i14 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i15 = i15 | 0;
 i12 = i12 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 576 | 0;
 i8 = i20 + 424 | 0;
 i11 = i20;
 i7 = i20 + 24 | 0;
 i19 = i20 + 16 | 0;
 i9 = i20 + 12 | 0;
 i16 = i20 + 8 | 0;
 i4 = i20 + 564 | 0;
 i5 = i20 + 4 | 0;
 i10 = i20 + 464 | 0;
 HEAP32[i19 >> 2] = i7;
 i18 = i19 + 4 | 0;
 HEAP32[i18 >> 2] = 300;
 i1 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
 HEAP32[i16 >> 2] = i1;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i16, 61712) | 0;
 HEAP8[i4 >> 0] = 0;
 HEAP32[i5 >> 2] = HEAP32[i14 >> 2];
 i6 = HEAP32[i3 + 4 >> 2] | 0;
 HEAP32[i8 >> 2] = HEAP32[i5 >> 2];
 if (__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_(i13, i8, i2, i16, i6, i15, i4, i1, i19, i9, i7 + 400 | 0) | 0) {
  FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 48 >> 2] & 7](i1, 54635, 54645, i8) | 0;
  i3 = HEAP32[i9 >> 2] | 0;
  i5 = HEAP32[i19 >> 2] | 0;
  i1 = i3 - i5 | 0;
  if ((i1 | 0) > 392) {
   i1 = _malloc((i1 >> 2) + 2 | 0) | 0;
   i2 = i1;
   if (!i1) i1 = 0;
  } else {
   i2 = 0;
   i1 = i10;
  }
  if (HEAP8[i4 >> 0] | 0) {
   HEAP8[i1 >> 0] = 45;
   i1 = i1 + 1 | 0;
  }
  i6 = i8 + 40 | 0;
  i7 = i8;
  while (1) {
   if (i5 >>> 0 >= i3 >>> 0) break;
   i4 = HEAP32[i5 >> 2] | 0;
   i3 = i8;
   while (1) {
    if ((i3 | 0) == (i6 | 0)) {
     i3 = i6;
     break;
    }
    if ((HEAP32[i3 >> 2] | 0) == (i4 | 0)) break;
    i3 = i3 + 4 | 0;
   }
   HEAP8[i1 >> 0] = HEAP8[54635 + (i3 - i7 >> 2) >> 0] | 0;
   i3 = HEAP32[i9 >> 2] | 0;
   i1 = i1 + 1 | 0;
   i5 = i5 + 4 | 0;
  }
  HEAP8[i1 >> 0] = 0;
  HEAP32[i11 >> 2] = i12;
  _sscanf(i10, 54536, i11) | 0;
  if (i2 | 0) _free(i2);
 }
 i1 = HEAP32[i13 >> 2] | 0;
 do if (i1) {
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i13 >> 2] = 0;
   i3 = 1;
   break;
  } else {
   i3 = (HEAP32[i13 >> 2] | 0) == 0;
   break;
  }
 } else i3 = 1; while (0);
 i1 = HEAP32[i14 >> 2] | 0;
 do if (i1) {
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) != -1) if (i3) break; else {
   i17 = 32;
   break;
  } else {
   HEAP32[i14 >> 2] = 0;
   i17 = 30;
   break;
  }
 } else i17 = 30; while (0);
 if ((i17 | 0) == 30 ? i3 : 0) i17 = 32;
 if ((i17 | 0) == 32) HEAP32[i15 >> 2] = HEAP32[i15 >> 2] | 2;
 i2 = HEAP32[i13 >> 2] | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(HEAP32[i16 >> 2] | 0) | 0;
 i1 = HEAP32[i19 >> 2] | 0;
 HEAP32[i19 >> 2] = 0;
 if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[i18 >> 2] & 511](i1);
 STACKTOP = i20;
 return i2 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i11, i10, i9) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i4 = i12 + 56 | 0;
 i3 = i12;
 i1 = i12 + 48 | 0;
 i6 = i12 + 40 | 0;
 i7 = i12 + 32 | 0;
 i8 = i12 + 24 | 0;
 i2 = i12 + 16 | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i10);
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i3, HEAP32[i10 >> 2] | 0);
 HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + (HEAP32[i3 + 8 >> 2] | 0);
 L1 : do switch (HEAP32[i3 + 12 >> 2] | 0) {
 case 0:
  {
   i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17parseAfterKeywordERNS3_4FragERPcPKc(i11, i3, i10, i9) | 0;
   break;
  }
 case 2:
  {
   i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseAfterIdentERNS3_4FragERPcPKc(i11, i3, i10, i9) | 0;
   break;
  }
 case 5:
 case 4:
 case 3:
  {
   i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseFragERNS3_4FragE(i11, i3) | 0;
   HEAP8[i1 >> 0] = 1;
   HEAP32[i1 + 4 >> 2] = i5;
   HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i4 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i11, i4, i10, i9) | 0;
   break;
  }
 case 6:
  {
   i1 = HEAP32[i3 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[14888] | 0)) {
    i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseAfterParenERPc(i11, i10) | 0;
    HEAP8[i6 >> 0] = 1;
    HEAP32[i6 + 4 >> 2] = i5;
    HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
    HEAP32[i4 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
    i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i11, i4, i10, i9) | 0;
    break L1;
   }
   if ((i1 | 0) == (HEAP32[14889] | 0)) {
    i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseAfterBraceERPc(i11, i10) | 0;
    HEAP8[i7 >> 0] = 1;
    HEAP32[i7 + 4 >> 2] = i5;
    HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
    HEAP32[i4 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
    i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i11, i4, i10, i9) | 0;
    break L1;
   }
   if ((i1 | 0) == (HEAP32[14890] | 0)) {
    i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseAfterCurlyERPc(i11, i10) | 0;
    HEAP8[i8 >> 0] = 1;
    HEAP32[i8 + 4 >> 2] = i5;
    HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
    HEAP32[i4 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
    i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i11, i4, i10, i9) | 0;
    break L1;
   } else _abort();
   break;
  }
 case 1:
  {
   i5 = HEAP32[i3 >> 2] | 0;
   HEAP8[i2 >> 0] = 0;
   HEAP32[i2 + 4 >> 2] = i5;
   HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i4 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseExpressionENS3_17ExpressionElementERPcPKc(i11, i4, i10, i9) | 0;
   break;
  }
 default:
  _abort();
 } while (0);
 STACKTOP = i12;
 return i5 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_123parse_prefix_expressionINS0_2DbEEEPKcS4_S4_RKNT_6StringERS5_(i3, i1, i5, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i8 = i12 + 36 | 0;
 i9 = i12 + 24 | 0;
 i10 = i12 + 12 | 0;
 i11 = i12;
 i1 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i3, i1, i2) | 0;
 if ((i1 | 0) != (i3 | 0) ? (i4 = i2 + 4 | 0, i7 = HEAP32[i4 >> 2] | 0, (HEAP32[i2 >> 2] | 0) != (i7 | 0)) : 0) {
  i6 = i7 + -24 | 0;
  __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EERKSB_PKS8_(i10, i5, 56964);
  __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i11, (HEAP32[i4 >> 2] | 0) + -24 | 0);
  i2 = HEAP8[i11 + 11 >> 0] | 0;
  i3 = i2 << 24 >> 24 < 0;
  i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i10, i3 ? HEAP32[i11 >> 2] | 0 : i11, i3 ? HEAP32[i11 + 4 >> 2] | 0 : i2 & 255) | 0;
  HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i9 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
  HEAP32[i9 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
  i3 = 0;
  while (1) {
   if ((i3 | 0) == 3) break;
   HEAP32[i2 + (i3 << 2) >> 2] = 0;
   i3 = i3 + 1 | 0;
  }
  i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i9, 56966) | 0;
  HEAP32[i8 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i8 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
  HEAP32[i8 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
  i3 = 0;
  while (1) {
   if ((i3 | 0) == 3) break;
   HEAP32[i2 + (i3 << 2) >> 2] = 0;
   i3 = i3 + 1 | 0;
  }
  i2 = i6 + 11 | 0;
  do if ((HEAP8[i2 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i6 >> 2] >> 0] = 0;
   i4 = i7 + -20 | 0;
   HEAP32[i4 >> 2] = 0;
   i3 = HEAP8[i2 >> 0] | 0;
   if (i3 << 24 >> 24 < 0) {
    if ((HEAP32[i7 + -16 >> 2] & 2147483647 | 0) == 11) break;
    i7 = HEAP32[i6 >> 2] | 0;
    HEAP8[i6 >> 0] = HEAP8[i7 >> 0] | 0;
    _free(i7);
    HEAP8[i2 >> 0] = 0;
    break;
   } else {
    i2 = i3 & 255;
    if ((i3 & 255) < 11) break;
    i3 = i2 + 16 & 496;
    i5 = _malloc(i3) | 0;
    _memcpy(i5 | 0, i6 | 0, i2 + 1 | 0) | 0;
    HEAP32[i7 + -16 >> 2] = i3 | -2147483648;
    HEAP32[i4 >> 2] = i2;
    HEAP32[i6 >> 2] = i5;
    break;
   }
  } else {
   HEAP8[i6 >> 0] = 0;
   HEAP8[i2 >> 0] = 0;
  } while (0);
  HEAP32[i6 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i6 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
  HEAP32[i6 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i8 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i9);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i11);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i10);
 } else i1 = i3;
 STACKTOP = i12;
 return i1 | 0;
}

function __ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE(i1, i11, i12, i4, i2, i13, i7) {
 i1 = i1 | 0;
 i11 = i11 | 0;
 i12 = i12 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i13 = i13 | 0;
 i7 = i7 | 0;
 var i3 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0, i10 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 432 | 0;
 i19 = i17 + 424 | 0;
 i1 = i17 + 24 | 0;
 i16 = i17 + 16 | 0;
 i6 = i17 + 8 | 0;
 i18 = i17 + 4 | 0;
 i5 = i17 + 428 | 0;
 i8 = i17;
 HEAP32[i16 >> 2] = i1;
 i15 = i16 + 4 | 0;
 HEAP32[i15 >> 2] = 300;
 i10 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i18 >> 2] = i10;
 i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i18, 61712) | 0;
 HEAP8[i5 >> 0] = 0;
 i9 = HEAP32[i12 >> 2] | 0;
 HEAP32[i8 >> 2] = i9;
 i2 = HEAP32[i2 + 4 >> 2] | 0;
 HEAP32[i19 >> 2] = HEAP32[i8 >> 2];
 i8 = i9;
 if (__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_(i11, i19, i4, i18, i2, i13, i5, i3, i16, i6, i1 + 400 | 0) | 0) {
  i1 = i7 + 8 + 3 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP32[HEAP32[i7 >> 2] >> 2] = 0;
   HEAP32[i7 + 4 >> 2] = 0;
  } else {
   HEAP32[i7 >> 2] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  if (HEAP8[i5 >> 0] | 0) __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw(i7, FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 44 >> 2] & 63](i3, 45) | 0);
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 44 >> 2] & 63](i3, 48) | 0;
  i4 = HEAP32[i6 >> 2] | 0;
  i2 = i4 + -4 | 0;
  i1 = HEAP32[i16 >> 2] | 0;
  while (1) {
   if (i1 >>> 0 >= i2 >>> 0) break;
   if ((HEAP32[i1 >> 2] | 0) != (i3 | 0)) break;
   i1 = i1 + 4 | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendIPwEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_(i7, i1, i4) | 0;
 }
 i1 = HEAP32[i11 >> 2] | 0;
 do if (i1) {
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i11 >> 2] = 0;
   i2 = 1;
   break;
  } else {
   i2 = (HEAP32[i11 >> 2] | 0) == 0;
   break;
  }
 } else i2 = 1; while (0);
 do if (i9) {
  i1 = HEAP32[i8 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i8 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i9 >> 2] | 0) + 36 >> 2] & 255](i8) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i14 = 27;
   break;
  } else {
   HEAP32[i12 >> 2] = 0;
   i14 = 25;
   break;
  }
 } else i14 = 25; while (0);
 if ((i14 | 0) == 25 ? i2 : 0) i14 = 27;
 if ((i14 | 0) == 27) HEAP32[i13 >> 2] = HEAP32[i13 >> 2] | 2;
 i2 = HEAP32[i11 >> 2] | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
 i1 = HEAP32[i16 >> 2] | 0;
 HEAP32[i16 >> 2] = 0;
 if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[i15 >> 2] & 511](i1);
 STACKTOP = i17;
 return i2 | 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner9visitHostEPNS_4HostE(i10, i9, i1) {
 i10 = i10 | 0;
 i9 = i9 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i11 = 0, i12 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i6 = i11 + 36 | 0;
 i5 = i11 + 32 | 0;
 i2 = i11;
 i7 = i11 + 28 | 0;
 i8 = i11 + 24 | 0;
 L1 : do switch (HEAP32[i1 + 8 >> 2] | 0) {
 case 0:
  {
   HEAP32[i10 >> 2] = 1;
   HEAP32[i10 + 8 >> 2] = 65536;
   HEAP32[i10 + 16 >> 2] = 0;
   break;
  }
 case 1:
  {
   i9 = HEAP32[(HEAP32[i9 >> 2] | 0) + 20 >> 2] | 0;
   HEAP32[i10 >> 2] = 1;
   HEAP32[i10 + 8 >> 2] = i9;
   HEAP32[i10 + 16 >> 2] = 0;
   break;
  }
 case 2:
  {
   i4 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1 + 16 | 0, 0) | 0;
   __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i2, i9, HEAP32[i4 >> 2] | 0);
   if (!(HEAP32[i2 + 16 >> 2] | 0)) {
    i4 = HEAP32[(HEAP32[i9 >> 2] | 0) + 20 >> 2] | 0;
    i3 = __ZNK4wasm7Literal6geti32Ev(i2) | 0;
    if (i3 >>> 0 > 65535) {
     i2 = HEAP32[(HEAP32[i9 >> 2] | 0) + 24 >> 2] | 0;
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i2, 29190);
    }
    i2 = HEAP32[i9 >> 2] | 0;
    i1 = HEAP32[i2 + 20 >> 2] | 0;
    if (i1 >>> 0 >= ~i3 >>> 0) {
     i2 = HEAP32[i2 + 24 >> 2] | 0;
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i2, 29227);
     i2 = HEAP32[i9 >> 2] | 0;
     i1 = HEAP32[i2 + 20 >> 2] | 0;
    }
    i3 = i1 + i3 | 0;
    if (i3 >>> 0 > (HEAP32[(HEAP32[i2 >> 2] | 0) + 64 >> 2] | 0) >>> 0) {
     i1 = HEAP32[i2 + 24 >> 2] | 0;
     FUNCTION_TABLE_vii[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 1023](i1, 29265);
     i1 = HEAP32[i9 >> 2] | 0;
     i2 = i1;
     i1 = HEAP32[i1 + 20 >> 2] | 0;
    }
    i2 = HEAP32[i2 + 24 >> 2] | 0;
    i12 = HEAP32[(HEAP32[i2 >> 2] | 0) + 16 >> 2] | 0;
    __ZN4wasm7AddressC2Ey(i7, i1 << 16, 0);
    __ZN4wasm7AddressC2Ey(i8, i3 << 16, 0);
    HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
    HEAP32[i6 >> 2] = HEAP32[i8 >> 2];
    FUNCTION_TABLE_viii[i12 & 31](i2, i5, i6);
    __ZN4wasm7AddressaSEy((HEAP32[i9 >> 2] | 0) + 20 | 0, i3, 0) | 0;
    HEAP32[i10 >> 2] = 1;
    HEAP32[i10 + 8 >> 2] = i4;
    HEAP32[i10 + 16 >> 2] = 0;
   } else {
    HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i10 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i10 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    HEAP32[i10 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
    HEAP32[i10 + 16 >> 2] = HEAP32[i2 + 16 >> 2];
    HEAP32[i10 + 20 >> 2] = HEAP32[i2 + 20 >> 2];
   }
   break;
  }
 case 3:
  {
   i12 = (HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[14807] | 0);
   HEAP32[i10 >> 2] = 1;
   i1 = i10 + 8 | 0;
   if (i12) {
    HEAP32[i1 >> 2] = 1;
    HEAP32[i10 + 16 >> 2] = 0;
    break L1;
   } else {
    HEAP32[i1 >> 2] = 0;
    HEAP32[i10 + 16 >> 2] = 0;
    break L1;
   }
  }
 default:
  _abort();
 } while (0);
 STACKTOP = i11;
 return;
}

function __ZN4wasm15Asm2WasmBuilder12checkLiteralEN6cashew3RefE(i3, i2, i4) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var d1 = 0.0;
 do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 0) | 0, 59348) | 0) {
  i4 = __ZN6cashew3RefixEj(i4, 1) | 0;
  i4 = __ZN6cashew5Value10getIntegerEv(HEAP32[i4 >> 2] | 0) | 0;
  HEAP32[i3 >> 2] = 1;
  HEAP32[i3 + 8 >> 2] = i4;
 } else {
  if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 0) | 0, 59396) | 0) {
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 1) | 0, 59428) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 0) | 0, 59348) | 0 : 0) {
    i4 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 1) | 0;
    i4 = __ZN6cashew5Value9getNumberEv(HEAP32[i4 >> 2] | 0) | 0;
    d1 = +HEAPF64[i4 >> 3];
    HEAP32[i3 >> 2] = 4;
    HEAPF64[i3 + 8 >> 3] = d1;
    break;
   }
   if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 1) | 0, 59432) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 0) | 0, 59348) | 0 : 0) {
    i2 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 1) | 0;
    i2 = __ZN6cashew5Value9getNumberEv(HEAP32[i2 >> 2] | 0) | 0;
    d1 = -+HEAPF64[i2 >> 3];
    if (__ZN4wasm12isSInteger32Ed(d1) | 0) {
     HEAP32[i3 >> 2] = 1;
     HEAP32[i3 + 8 >> 2] = ~~d1;
     break;
    }
    if (__ZN4wasm12isUInteger32Ed(d1) | 0) {
     HEAP32[i3 >> 2] = 1;
     HEAP32[i3 + 8 >> 2] = ~~d1 >>> 0;
     break;
    } else ___assert_fail(30372, 16311, 393, 30417);
   }
   if (((__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 1) | 0, 59428) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 0) | 0, 59396) | 0 : 0) ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 1) | 0, 59432) | 0 : 0) ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 2) | 0, 0) | 0, 59348) | 0 : 0) {
    i4 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 2) | 0, 1) | 0;
    i4 = __ZN6cashew5Value9getNumberEv(HEAP32[i4 >> 2] | 0) | 0;
    d1 = -+HEAPF64[i4 >> 3];
    HEAP32[i3 >> 2] = 4;
    HEAPF64[i3 + 8 >> 3] = d1;
    break;
   }
   if (((__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 1) | 0, 59432) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 0) | 0, 59396) | 0 : 0) ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 1) | 0, 59428) | 0 : 0) ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 2) | 0, 0) | 0, 59348) | 0 : 0) {
    i4 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i4, 2) | 0, 2) | 0, 1) | 0;
    i4 = __ZN6cashew5Value9getNumberEv(HEAP32[i4 >> 2] | 0) | 0;
    d1 = -+HEAPF64[i4 >> 3];
    HEAP32[i3 >> 2] = 4;
    HEAPF64[i3 + 8 >> 3] = d1;
    break;
   }
  }
  HEAP32[i3 >> 2] = 0;
  i4 = i3 + 8 | 0;
  HEAP32[i4 >> 2] = 0;
  HEAP32[i4 + 4 >> 2] = 0;
 } while (0);
 return;
}

function __ZN6cashew10IStringSetC2EPKc(i20, i1) {
 i20 = i20 | 0;
 i1 = i1 | 0;
 var i2 = 0, d3 = 0.0, d4 = 0.0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i21 = 0, i22 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i18 = i22;
 i19 = i20 + 16 | 0;
 HEAP32[i20 >> 2] = 0;
 HEAP32[i20 + 4 >> 2] = 0;
 HEAP32[i20 + 8 >> 2] = 0;
 HEAP32[i20 + 12 >> 2] = 0;
 HEAPF32[i19 >> 2] = 1.0;
 i15 = i20 + 20 | 0;
 HEAP32[i15 >> 2] = 0;
 HEAP32[i20 + 24 >> 2] = 0;
 HEAP32[i20 + 28 >> 2] = 0;
 i16 = (_strlen(i1) | 0) + 1 | 0;
 __ZNSt3__26vectorIcNS_9allocatorIcEEE6resizeEj(i15, i16);
 i15 = HEAP32[i15 >> 2] | 0;
 _strncpy(i15, i1, i16) | 0;
 i16 = i20 + 4 | 0;
 i17 = i20 + 12 | 0;
 i13 = i20 + 8 | 0;
 i1 = i15;
 while (1) {
  i14 = _strchr(i1, 32) | 0;
  i15 = (i14 | 0) != 0;
  if (i15) HEAP8[i14 >> 0] = 0;
  __ZN6cashew7IStringC2EPKcb(i18, i1, 1);
  i9 = HEAP32[i18 >> 2] | 0;
  i12 = i9 * 33 ^ 5381;
  i11 = HEAP32[i16 >> 2] | 0;
  i10 = (i11 | 0) == 0;
  i6 = i9;
  L6 : do if (!i10) {
   i7 = i11 + -1 | 0;
   i8 = (i7 & i11 | 0) == 0;
   if (i8) i1 = i7 & i12; else i1 = (i12 >>> 0) % (i11 >>> 0) | 0;
   i2 = HEAP32[(HEAP32[i20 >> 2] | 0) + (i1 << 2) >> 2] | 0;
   if (!i2) i21 = 15; else do {
    i2 = HEAP32[i2 >> 2] | 0;
    if (!i2) {
     i21 = 15;
     break L6;
    }
    i5 = HEAP32[i2 + 4 >> 2] | 0;
    if (i8) i5 = i5 & i7; else i5 = (i5 >>> 0) % (i11 >>> 0) | 0;
    if ((i5 | 0) != (i1 | 0)) {
     i21 = 15;
     break L6;
    }
   } while ((HEAP32[i2 + 8 >> 2] | 0) != (i6 | 0));
  } else {
   i1 = 0;
   i21 = 15;
  } while (0);
  if ((i21 | 0) == 15) {
   i21 = 0;
   i6 = __Znwj(12) | 0;
   HEAP32[i6 + 8 >> 2] = i9;
   HEAP32[i6 + 4 >> 2] = i12;
   HEAP32[i6 >> 2] = 0;
   d3 = +(((HEAP32[i17 >> 2] | 0) + 1 | 0) >>> 0);
   d4 = +HEAPF32[i19 >> 2];
   do if (i10 | d3 > +(i11 >>> 0) * d4) {
    if (i11 >>> 0 > 2) i1 = (i11 + -1 & i11 | 0) == 0; else i1 = 0;
    i1 = (i1 & 1 | i11 << 1) ^ 1;
    i2 = ~~+Math_ceil(+(d3 / d4)) >>> 0;
    __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE6rehashEj(i20, i1 >>> 0 < i2 >>> 0 ? i2 : i1);
    i1 = HEAP32[i16 >> 2] | 0;
    i2 = i1 + -1 | 0;
    if (!(i2 & i1)) {
     i5 = i1;
     i1 = i2 & i12;
     break;
    } else {
     i5 = i1;
     i1 = (i12 >>> 0) % (i1 >>> 0) | 0;
     break;
    }
   } else i5 = i11; while (0);
   i1 = (HEAP32[i20 >> 2] | 0) + (i1 << 2) | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if (!i2) {
    HEAP32[i6 >> 2] = HEAP32[i13 >> 2];
    HEAP32[i13 >> 2] = i6;
    HEAP32[i1 >> 2] = i13;
    i1 = HEAP32[i6 >> 2] | 0;
    if (i1 | 0) {
     i1 = HEAP32[i1 + 4 >> 2] | 0;
     i2 = i5 + -1 | 0;
     if (!(i2 & i5)) i1 = i1 & i2; else i1 = (i1 >>> 0) % (i5 >>> 0) | 0;
     HEAP32[(HEAP32[i20 >> 2] | 0) + (i1 << 2) >> 2] = i6;
    }
   } else {
    HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i2 >> 2] = i6;
   }
   HEAP32[i17 >> 2] = (HEAP32[i17 >> 2] | 0) + 1;
  }
  if (i15) i1 = i14 + 1 | 0; else break;
 }
 STACKTOP = i22;
 return;
}

function __ZZ11instantiateEN19JSExternalInterface5storeEPN4wasm5StoreENS0_7AddressENS0_7LiteralE(i10, i11, i2, i13) {
 i10 = i10 | 0;
 i11 = i11 | 0;
 i2 = i2 | 0;
 i13 = i13 | 0;
 var d1 = 0.0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i12 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i4 = i14 + 32 | 0;
 i3 = i14 + 84 | 0;
 i9 = i14 + 52 | 0;
 i5 = i14 + 80 | 0;
 i6 = i14 + 16 | 0;
 i7 = i14 + 48 | 0;
 i8 = i14;
 i12 = HEAP32[i2 >> 2] | 0;
 L1 : do if ((HEAP32[i13 >> 2] | 0) == 2) {
  HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
  HEAP32[i9 + 4 >> 2] = HEAP32[i11 + 4 >> 2];
  HEAP32[i9 + 8 >> 2] = HEAP32[i11 + 8 >> 2];
  HEAP32[i9 + 12 >> 2] = HEAP32[i11 + 12 >> 2];
  HEAP32[i9 + 16 >> 2] = HEAP32[i11 + 16 >> 2];
  HEAP32[i9 + 20 >> 2] = HEAP32[i11 + 20 >> 2];
  HEAP32[i9 + 24 >> 2] = HEAP32[i11 + 24 >> 2];
  HEAP8[i9 + 8 >> 0] = 4;
  HEAP32[i9 + 4 >> 2] = 1;
  i2 = __ZNK4wasm7Literal6geti64Ev(i13) | 0;
  i11 = tempRet0;
  i13 = HEAP32[(HEAP32[i10 >> 2] | 0) + 12 >> 2] | 0;
  __ZN4wasm7AddressC2Ey(i5, i12, 0);
  HEAP32[i6 >> 2] = 1;
  HEAP32[i6 + 8 >> 2] = i2;
  HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
  HEAP32[i4 + 12 >> 2] = HEAP32[i6 + 12 >> 2];
  FUNCTION_TABLE_viiii[i13 & 15](i10, i9, i3, i4);
  i13 = HEAP32[(HEAP32[i10 >> 2] | 0) + 12 >> 2] | 0;
  __ZN4wasm7AddressC2Ey(i7, i12 + 4 | 0, 0);
  HEAP32[i8 >> 2] = 1;
  HEAP32[i8 + 8 >> 2] = i11;
  HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
  HEAP32[i4 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
  FUNCTION_TABLE_viiii[i13 & 15](i10, i9, i3, i4);
 } else {
  i2 = HEAP8[i11 + 8 >> 0] | 0;
  i3 = i2 & 255;
  if ((HEAP32[i11 + 16 >> 2] | 0) >>> 0 >= i3 >>> 0 ? (i3 + -1 & i12 | 0) == 0 : 0) {
   if (((HEAP32[i11 + 4 >> 2] | 0) + -3 | 0) >>> 0 < 2) switch (i2 << 24 >> 24) {
   case 4:
    {
     +_emscripten_asm_const_did(3, i12 | 0, +(+__ZNK4wasm7Literal6getf32Ev(i13)));
     break L1;
    }
   case 8:
    {
     +_emscripten_asm_const_did(4, i12 | 0, +(+__ZNK4wasm7Literal6getf64Ev(i13)));
     break L1;
    }
   default:
    _abort();
   }
   switch (i2 << 24 >> 24) {
   case 1:
    {
     _emscripten_asm_const_iii(29, i12 | 0, __ZNK4wasm7Literal6geti32Ev(i13) | 0) | 0;
     break L1;
    }
   case 2:
    {
     _emscripten_asm_const_iii(30, i12 | 0, __ZNK4wasm7Literal6geti32Ev(i13) | 0) | 0;
     break L1;
    }
   case 4:
    {
     _emscripten_asm_const_iii(2, i12 | 0, __ZNK4wasm7Literal6geti32Ev(i13) | 0) | 0;
     break L1;
    }
   default:
    _abort();
   }
  }
  i2 = ((HEAP32[i11 + 4 >> 2] | 0) + -3 | 0) >>> 0 < 2;
  if (i2) d1 = +__ZN4wasm7Literal8getFloatEv(i13); else {
   i13 = __ZN4wasm7Literal10getIntegerEv(i13) | 0;
   d1 = +(i13 >>> 0) + 4294967296.0 * +(tempRet0 | 0);
  }
  +_emscripten_asm_const_diiid(28, i12 | 0, i3 | 0, i2 & 1 | 0, +d1);
 } while (0);
 STACKTOP = i14;
 return;
}

function __ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe(i1, i13, i14, i2, i3, i15, i12) {
 i1 = i1 | 0;
 i13 = i13 | 0;
 i14 = i14 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i15 = i15 | 0;
 i12 = i12 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 240 | 0;
 i8 = i20 + 24 | 0;
 i11 = i20;
 i7 = i20 + 140 | 0;
 i19 = i20 + 16 | 0;
 i9 = i20 + 12 | 0;
 i16 = i20 + 8 | 0;
 i4 = i20 + 136 | 0;
 i5 = i20 + 4 | 0;
 i10 = i20 + 36 | 0;
 HEAP32[i19 >> 2] = i7;
 i18 = i19 + 4 | 0;
 HEAP32[i18 >> 2] = 300;
 i1 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
 HEAP32[i16 >> 2] = i1;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i16, 61680) | 0;
 HEAP8[i4 >> 0] = 0;
 HEAP32[i5 >> 2] = HEAP32[i14 >> 2];
 i6 = HEAP32[i3 + 4 >> 2] | 0;
 HEAP32[i8 >> 2] = HEAP32[i5 >> 2];
 if (__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_(i13, i8, i2, i16, i6, i15, i4, i1, i19, i9, i7 + 100 | 0) | 0) {
  FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 32 >> 2] & 7](i1, 54525, 54535, i8) | 0;
  i3 = HEAP32[i9 >> 2] | 0;
  i5 = HEAP32[i19 >> 2] | 0;
  i1 = i3 - i5 | 0;
  if ((i1 | 0) > 98) {
   i1 = _malloc(i1 + 2 | 0) | 0;
   i2 = i1;
   if (!i1) i1 = 0;
  } else {
   i2 = 0;
   i1 = i10;
  }
  if (HEAP8[i4 >> 0] | 0) {
   HEAP8[i1 >> 0] = 45;
   i1 = i1 + 1 | 0;
  }
  i6 = i8 + 10 | 0;
  i7 = i8;
  while (1) {
   if (i5 >>> 0 >= i3 >>> 0) break;
   i4 = HEAP8[i5 >> 0] | 0;
   i3 = i8;
   while (1) {
    if ((i3 | 0) == (i6 | 0)) {
     i3 = i6;
     break;
    }
    if ((HEAP8[i3 >> 0] | 0) == i4 << 24 >> 24) break;
    i3 = i3 + 1 | 0;
   }
   HEAP8[i1 >> 0] = HEAP8[54525 + (i3 - i7) >> 0] | 0;
   i3 = HEAP32[i9 >> 2] | 0;
   i1 = i1 + 1 | 0;
   i5 = i5 + 1 | 0;
  }
  HEAP8[i1 >> 0] = 0;
  HEAP32[i11 >> 2] = i12;
  _sscanf(i10, 54536, i11) | 0;
  if (i2 | 0) _free(i2);
 }
 i1 = HEAP32[i13 >> 2] | 0;
 do if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
   HEAP32[i13 >> 2] = 0;
   i1 = 0;
   break;
  } else {
   i1 = HEAP32[i13 >> 2] | 0;
   break;
  }
 } else i1 = 0; while (0);
 i1 = (i1 | 0) == 0;
 i2 = HEAP32[i14 >> 2] | 0;
 do if (i2) {
  if ((HEAP32[i2 + 12 >> 2] | 0) == (HEAP32[i2 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) == -1 : 0) {
   HEAP32[i14 >> 2] = 0;
   i17 = 27;
   break;
  }
  if (!i1) i17 = 28;
 } else i17 = 27; while (0);
 if ((i17 | 0) == 27 ? i1 : 0) i17 = 28;
 if ((i17 | 0) == 28) HEAP32[i15 >> 2] = HEAP32[i15 >> 2] | 2;
 i2 = HEAP32[i13 >> 2] | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(HEAP32[i16 >> 2] | 0) | 0;
 i1 = HEAP32[i19 >> 2] | 0;
 HEAP32[i19 >> 2] = 0;
 if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[i18 >> 2] & 511](i1);
 STACKTOP = i20;
 return i2 | 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner17visitCallIndirectEPNS_12CallIndirectE(i8, i12, i10) {
 i8 = i8 | 0;
 i12 = i12 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i11 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i4 = i13 + 84 | 0;
 i1 = i13 + 40 | 0;
 i5 = i13 + 80 | 0;
 i9 = i13 + 68 | 0;
 i11 = i13 + 16 | 0;
 i6 = i13;
 i7 = i13 + 64 | 0;
 __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i1, i12, HEAP32[i10 + 28 >> 2] | 0);
 if (!(HEAP32[i1 + 16 >> 2] | 0)) {
  i3 = __ZNK4wasm7Literal6geti32Ev(i1) | 0;
  i2 = HEAP32[i12 >> 2] | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i1 + 52 >> 2] | 0) - (HEAP32[i1 + 48 >> 2] | 0) >> 2 >>> 0) i2 = i1; else {
   i2 = HEAP32[i2 + 24 >> 2] | 0;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i2, 28309);
   i2 = HEAP32[HEAP32[i12 >> 2] >> 2] | 0;
  }
  i1 = HEAP32[(HEAP32[i2 + 48 >> 2] | 0) + (i3 << 2) >> 2] | 0;
  HEAP32[i5 >> 2] = i1;
  HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
  i5 = (__ZN4wasm6Module11getFunctionENS_4NameE(i2, i4) | 0) + 32 | 0;
  i5 = HEAP32[i5 >> 2] | 0;
  if (i5 | 0 ? (i5 | 0) != (HEAP32[HEAP32[i10 + 24 >> 2] >> 2] | 0) : 0) {
   i5 = HEAP32[(HEAP32[i12 >> 2] | 0) + 24 >> 2] | 0;
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i5 >> 2] | 0) + 20 >> 2] & 1023](i5, 28332);
  }
  HEAP32[i9 >> 2] = 0;
  HEAP32[i9 + 4 >> 2] = 0;
  HEAP32[i9 + 8 >> 2] = 0;
  __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner17generateArgumentsERK11ArenaVectorIPNS_10ExpressionEES9_(i11, i12, i10 + 8 | 0, i9);
  if (!(HEAP32[i11 + 16 >> 2] | 0)) {
   i12 = HEAP32[i12 >> 2] | 0;
   HEAP32[i7 >> 2] = i1;
   HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
   __ZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEE(i6, i12, i4, i9);
   HEAP32[i8 >> 2] = HEAP32[i6 >> 2];
   HEAP32[i8 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
   HEAP32[i8 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
   HEAP32[i8 + 12 >> 2] = HEAP32[i6 + 12 >> 2];
   HEAP32[i8 + 16 >> 2] = 0;
  } else {
   HEAP32[i8 >> 2] = HEAP32[i11 >> 2];
   HEAP32[i8 + 4 >> 2] = HEAP32[i11 + 4 >> 2];
   HEAP32[i8 + 8 >> 2] = HEAP32[i11 + 8 >> 2];
   HEAP32[i8 + 12 >> 2] = HEAP32[i11 + 12 >> 2];
   HEAP32[i8 + 16 >> 2] = HEAP32[i11 + 16 >> 2];
   HEAP32[i8 + 20 >> 2] = HEAP32[i11 + 20 >> 2];
  }
  __ZNSt3__213__vector_baseIN4wasm7LiteralENS_9allocatorIS2_EEED2Ev(i9);
 } else {
  HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i8 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i8 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  HEAP32[i8 + 12 >> 2] = HEAP32[i1 + 12 >> 2];
  HEAP32[i8 + 16 >> 2] = HEAP32[i1 + 16 >> 2];
  HEAP32[i8 + 20 >> 2] = HEAP32[i1 + 20 >> 2];
 }
 STACKTOP = i13;
 return;
}

function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekoffExNS_8ios_base7seekdirEj(i11, i12, i5, i6, i4, i10) {
 i11 = i11 | 0;
 i12 = i12 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i4 = i4 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i7 = 0, i8 = 0, i9 = 0;
 i1 = i12 + 44 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 i8 = i12 + 24 | 0;
 i9 = HEAP32[i8 >> 2] | 0;
 i3 = i9;
 if (i2 >>> 0 < i9 >>> 0) {
  HEAP32[i1 >> 2] = i9;
  i7 = i3;
 } else i7 = i2;
 i1 = i10 & 24;
 L4 : do if (!i1) {
  i12 = i11;
  HEAP32[i12 >> 2] = 0;
  HEAP32[i12 + 4 >> 2] = 0;
  i12 = i11 + 8 | 0;
  HEAP32[i12 >> 2] = -1;
  HEAP32[i12 + 4 >> 2] = -1;
 } else {
  if ((i4 | 0) == 1 & (i1 | 0) == 24) {
   i12 = i11;
   HEAP32[i12 >> 2] = 0;
   HEAP32[i12 + 4 >> 2] = 0;
   i12 = i11 + 8 | 0;
   HEAP32[i12 >> 2] = -1;
   HEAP32[i12 + 4 >> 2] = -1;
   break;
  }
  L10 : do switch (i4 | 0) {
  case 0:
   {
    i1 = 0;
    i2 = 0;
    break;
   }
  case 1:
   if (!(i10 & 8)) {
    i2 = i3 - (HEAP32[i12 + 20 >> 2] | 0) | 0;
    i1 = i2;
    i2 = ((i2 | 0) < 0) << 31 >> 31;
    break L10;
   } else {
    i2 = (HEAP32[i12 + 12 >> 2] | 0) - (HEAP32[i12 + 8 >> 2] | 0) | 0;
    i1 = i2;
    i2 = ((i2 | 0) < 0) << 31 >> 31;
    break L10;
   }
  case 2:
   {
    i1 = i12 + 32 | 0;
    if ((HEAP8[i1 + 11 >> 0] | 0) < 0) i1 = HEAP32[i1 >> 2] | 0;
    i2 = i7 - i1 | 0;
    i1 = i2;
    i2 = ((i2 | 0) < 0) << 31 >> 31;
    break;
   }
  default:
   {
    i12 = i11;
    HEAP32[i12 >> 2] = 0;
    HEAP32[i12 + 4 >> 2] = 0;
    i12 = i11 + 8 | 0;
    HEAP32[i12 >> 2] = -1;
    HEAP32[i12 + 4 >> 2] = -1;
    break L4;
   }
  } while (0);
  i2 = _i64Add(i1 | 0, i2 | 0, i5 | 0, i6 | 0) | 0;
  i3 = tempRet0;
  if ((i3 | 0) >= 0) {
   i1 = i12 + 32 | 0;
   if ((HEAP8[i1 + 11 >> 0] | 0) < 0) i1 = HEAP32[i1 >> 2] | 0;
   i6 = i7 - i1 | 0;
   i5 = ((i6 | 0) < 0) << 31 >> 31;
   if (!((i5 | 0) < (i3 | 0) | (i5 | 0) == (i3 | 0) & i6 >>> 0 < i2 >>> 0)) {
    i1 = i10 & 8;
    if (!((i2 | 0) == 0 & (i3 | 0) == 0)) {
     if (i1 | 0 ? (HEAP32[i12 + 12 >> 2] | 0) == 0 : 0) {
      i12 = i11;
      HEAP32[i12 >> 2] = 0;
      HEAP32[i12 + 4 >> 2] = 0;
      i12 = i11 + 8 | 0;
      HEAP32[i12 >> 2] = -1;
      HEAP32[i12 + 4 >> 2] = -1;
      break;
     }
     if ((i10 & 16 | 0) != 0 & (i9 | 0) == 0) {
      i12 = i11;
      HEAP32[i12 >> 2] = 0;
      HEAP32[i12 + 4 >> 2] = 0;
      i12 = i11 + 8 | 0;
      HEAP32[i12 >> 2] = -1;
      HEAP32[i12 + 4 >> 2] = -1;
      break;
     }
    }
    if (i1 | 0) {
     HEAP32[i12 + 12 >> 2] = (HEAP32[i12 + 8 >> 2] | 0) + i2;
     HEAP32[i12 + 16 >> 2] = i7;
    }
    if (i10 & 16 | 0) HEAP32[i8 >> 2] = (HEAP32[i12 + 20 >> 2] | 0) + i2;
    i12 = i11;
    HEAP32[i12 >> 2] = 0;
    HEAP32[i12 + 4 >> 2] = 0;
    i12 = i11 + 8 | 0;
    HEAP32[i12 >> 2] = i2;
    HEAP32[i12 + 4 >> 2] = i3;
    break;
   }
  }
  i12 = i11;
  HEAP32[i12 >> 2] = 0;
  HEAP32[i12 + 4 >> 2] = 0;
  i12 = i11 + 8 | 0;
  HEAP32[i12 >> 2] = -1;
  HEAP32[i12 + 4 >> 2] = -1;
 } while (0);
 return;
}

function __ZN4wasm6Vacuum10visitBlockEPNS_5BlockE(i14, i13) {
 i14 = i14 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i15 = 0, i16 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i11 = i15 + 72 | 0;
 i9 = i15;
 __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEEC2ERKS6_(i11, i14 + 44 | 0);
 i10 = __ZN4wasm18ExpressionAnalyzer12isResultUsedENSt3__26vectorIPNS_10ExpressionENS1_9allocatorIS4_EEEEPNS_8FunctionE(i11, HEAP32[i14 + 36 >> 2] | 0) | 0;
 __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i11);
 i11 = i13 + 12 | 0;
 i12 = i13 + 20 | 0;
 i8 = HEAP32[i12 >> 2] | 0;
 i4 = i8 + -1 | 0;
 i5 = 0;
 i6 = 0;
 i7 = 0;
 L1 : while (1) {
  if (i7 >>> 0 >= i8 >>> 0) {
   i2 = 15;
   break;
  }
  i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i11, i7) | 0;
  i1 = __ZN4wasm6Vacuum8optimizeEPNS_10ExpressionEb(i14, HEAP32[i1 >> 2] | 0, i10 & (i7 | 0) == (i4 | 0)) | 0;
  do if (i1) {
   i3 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i11, i7) | 0;
   if ((i1 | 0) != (HEAP32[i3 >> 2] | 0)) {
    i3 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i11, i7) | 0;
    HEAP32[i3 >> 2] = i1;
   }
   if ((i6 | 0) > 0) {
    i2 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i11, i7) | 0;
    i2 = HEAP32[i2 >> 2] | 0;
    i1 = i7 - i6 | 0;
    i3 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i11, i1) | 0;
    HEAP32[i3 >> 2] = i2;
   } else i1 = i7 - i6 | 0;
   i2 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i11, i1) | 0;
   i2 = HEAP32[i2 >> 2] | 0;
   i16 = HEAP32[i2 >> 2] | 0;
   i3 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i11, i1) | 0;
   i3 = HEAP32[i3 >> 2] | 0;
   i3 = (HEAP32[i3 >> 2] | 0) == 5 ? i3 : 0;
   if ((i2 | 0) == 0 | (i16 | 0) != 4) if (!i3) {
    i1 = i5;
    i2 = i6;
    break;
   } else {
    i2 = 13;
    break L1;
   } else if ((i3 | 0) != 0 | (HEAP32[i2 + 16 >> 2] | 0) == 0) {
    i2 = 13;
    break L1;
   } else {
    i1 = i5;
    i2 = i6;
    break;
   }
  } else {
   i1 = 1;
   i2 = i6 + 1 | 0;
  } while (0);
  i5 = i1;
  i6 = i2;
  i7 = i7 + 1 | 0;
 }
 if ((i2 | 0) == 13) __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i11, i1 + 1 | 0); else if ((i2 | 0) == 15 ? i5 : 0) __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i11, i8 - i6 | 0);
 L23 : do if (!(HEAP32[i13 + 8 >> 2] | 0)) {
  switch (HEAP32[i12 >> 2] | 0) {
  case 1:
   break;
  case 0:
   {
    HEAP32[i13 >> 2] = 19;
    HEAP32[i13 + 4 >> 2] = 0;
    break L23;
   }
  default:
   break L23;
  }
  if (!i10 ? (i16 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i11, 0) | 0, __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i9, HEAP32[i16 >> 2] | 0), i16 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i9) | 0, __ZN4wasm14EffectAnalyzerD2Ev(i9), !i16) : 0) {
   HEAP32[i13 >> 2] = 19;
   HEAP32[i13 + 4 >> 2] = 0;
   break;
  }
  i16 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i11, 0) | 0;
  HEAP32[i14 + 20 >> 2] = HEAP32[i16 >> 2];
 } while (0);
 STACKTOP = i15;
 return;
}

function __ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE(i1, i11, i12, i4, i2, i13, i7) {
 i1 = i1 | 0;
 i11 = i11 | 0;
 i12 = i12 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i13 = i13 | 0;
 i7 = i7 | 0;
 var i3 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0, i10 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 144 | 0;
 i19 = i17 + 24 | 0;
 i1 = i17 + 32 | 0;
 i16 = i17 + 16 | 0;
 i6 = i17 + 8 | 0;
 i18 = i17 + 4 | 0;
 i5 = i17 + 28 | 0;
 i8 = i17;
 HEAP32[i16 >> 2] = i1;
 i15 = i16 + 4 | 0;
 HEAP32[i15 >> 2] = 300;
 i10 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i18 >> 2] = i10;
 i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i18, 61680) | 0;
 HEAP8[i5 >> 0] = 0;
 i9 = HEAP32[i12 >> 2] | 0;
 HEAP32[i8 >> 2] = i9;
 i2 = HEAP32[i2 + 4 >> 2] | 0;
 HEAP32[i19 >> 2] = HEAP32[i8 >> 2];
 i8 = i9;
 if (__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_(i11, i19, i4, i18, i2, i13, i5, i3, i16, i6, i1 + 100 | 0) | 0) {
  i1 = i7 + 11 | 0;
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i7 >> 2] >> 0] = 0;
   HEAP32[i7 + 4 >> 2] = 0;
  } else {
   HEAP8[i7 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  if (HEAP8[i5 >> 0] | 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i7, FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 45) | 0);
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 48) | 0;
  i4 = HEAP32[i6 >> 2] | 0;
  i2 = i4 + -1 | 0;
  i1 = HEAP32[i16 >> 2] | 0;
  while (1) {
   if (i1 >>> 0 >= i2 >>> 0) break;
   if ((HEAP8[i1 >> 0] | 0) != i3 << 24 >> 24) break;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendIPcEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_(i7, i1, i4) | 0;
 }
 i1 = HEAP32[i11 >> 2] | 0;
 do if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
   HEAP32[i11 >> 2] = 0;
   i1 = 0;
   break;
  } else {
   i1 = HEAP32[i11 >> 2] | 0;
   break;
  }
 } else i1 = 0; while (0);
 i1 = (i1 | 0) == 0;
 do if (i9) {
  if ((HEAP32[i8 + 12 >> 2] | 0) == (HEAP32[i8 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i9 >> 2] | 0) + 36 >> 2] & 255](i8) | 0) == -1 : 0) {
   HEAP32[i12 >> 2] = 0;
   i14 = 22;
   break;
  }
  if (!i1) i14 = 23;
 } else i14 = 22; while (0);
 if ((i14 | 0) == 22 ? i1 : 0) i14 = 23;
 if ((i14 | 0) == 23) HEAP32[i13 >> 2] = HEAP32[i13 >> 2] | 2;
 i2 = HEAP32[i11 >> 2] | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
 i1 = HEAP32[i16 >> 2] | 0;
 HEAP32[i16 >> 2] = 0;
 if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[i15 >> 2] & 511](i1);
 STACKTOP = i17;
 return i2 | 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner10visitBlockEPNS_5BlockE(i12, i14, i1) {
 i12 = i12 | 0;
 i14 = i14 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i8 = i15 + 24 | 0;
 i13 = i15 + 28 | 0;
 i9 = i15;
 HEAP32[i8 >> 2] = i1;
 HEAP32[i13 >> 2] = 0;
 i10 = i13 + 4 | 0;
 HEAP32[i10 >> 2] = 0;
 HEAP32[i13 + 8 >> 2] = 0;
 i3 = i13 + 8 | 0;
 __ZNSt3__26vectorIPN4wasm5BlockENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i13, i8);
 while (1) {
  if (!(HEAP32[i1 + 20 >> 2] | 0)) break;
  i7 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1 + 12 | 0, 0) | 0;
  if ((HEAP32[HEAP32[i7 >> 2] >> 2] | 0) != 1) break;
  i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1 + 12 | 0, 0) | 0;
  i1 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
  HEAP32[i8 >> 2] = i1;
  i2 = HEAP32[i10 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i3 >> 2] | 0)) {
   __ZNSt3__26vectorIPN4wasm5BlockENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i13, i8);
   continue;
  } else {
   HEAP32[i2 >> 2] = i1;
   HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
   continue;
  }
 }
 HEAP32[i12 >> 2] = 0;
 i6 = i12 + 8 | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i6 + 4 >> 2] = 0;
 i6 = i12 + 16 | 0;
 HEAP32[i6 >> 2] = 0;
 i4 = HEAP32[i10 >> 2] | 0;
 i7 = HEAP32[i4 + -4 >> 2] | 0;
 i2 = i4;
 i1 = 0;
 while (1) {
  if ((i2 | 0) == (HEAP32[i13 >> 2] | 0)) break;
  i3 = i4 + -4 | 0;
  i5 = HEAP32[i3 >> 2] | 0;
  HEAP32[i8 >> 2] = i5;
  i2 = i4;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i10 >> 2] = i4;
   i2 = i4;
  }
  L16 : do if (!i1) {
   i1 = i5 + 12 | 0;
   i2 = i5 + 20 | 0;
   i3 = (i5 | 0) != (i7 | 0);
   i4 = 0;
   while (1) {
    if (i4 >>> 0 >= (HEAP32[i2 >> 2] | 0) >>> 0) {
     i1 = 0;
     break L16;
    }
    if (!((i4 | 0) == 0 & i3) ? (i11 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i4) | 0, __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i9, i14, HEAP32[i11 >> 2] | 0), HEAP32[i12 >> 2] = HEAP32[i9 >> 2], HEAP32[i12 + 4 >> 2] = HEAP32[i9 + 4 >> 2], HEAP32[i12 + 8 >> 2] = HEAP32[i9 + 8 >> 2], HEAP32[i12 + 12 >> 2] = HEAP32[i9 + 12 >> 2], HEAP32[i12 + 16 >> 2] = HEAP32[i9 + 16 >> 2], i11 = HEAP32[i6 >> 2] | 0, i11 | 0) : 0) {
     i1 = i11;
     break;
    }
    i4 = i4 + 1 | 0;
   }
   if ((i1 | 0) == (HEAP32[i5 + 8 >> 2] | 0)) {
    HEAP32[i6 >> 2] = 0;
    i1 = 0;
   }
  } else if ((i1 | 0) == (HEAP32[i5 + 8 >> 2] | 0)) {
   HEAP32[i6 >> 2] = 0;
   i1 = 0;
  } while (0);
  i4 = HEAP32[i10 >> 2] | 0;
  i2 = i4;
 }
 __ZNSt3__213__vector_baseIPN4wasm5BlockENS_9allocatorIS3_EEED2Ev(i13);
 STACKTOP = i15;
 return;
}

function __ZNKSt3__220__time_get_c_storageIcE8__monthsEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if ((HEAP8[58576] | 0) == 0 ? ___cxa_guard_acquire(58576) | 0 : 0) {
  if ((HEAP8[58584] | 0) == 0 ? ___cxa_guard_acquire(58584) | 0 : 0) {
   i1 = 61924;
   do {
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i1 = i1 + 12 | 0;
   } while ((i1 | 0) != 62212);
   ___cxa_atexit(293, 0, ___dso_handle | 0) | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61924, 53848) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61936, 53856) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61948, 53865) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61960, 53871) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61972, 53877) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61984, 53881) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61996, 53886) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62008, 53891) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62020, 53898) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62032, 53908) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62044, 53916) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62056, 53925) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62068, 53934) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62080, 53938) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62092, 53942) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62104, 53946) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62116, 53877) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62128, 53950) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62140, 53954) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62152, 53958) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62164, 53962) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62176, 53966) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62188, 53970) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62200, 53974) | 0;
  HEAP32[15553] = 61924;
 }
 return HEAP32[15553] | 0;
}

function __ZNKSt3__220__time_get_c_storageIwE8__monthsEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if ((HEAP8[58656] | 0) == 0 ? ___cxa_guard_acquire(58656) | 0 : 0) {
  if ((HEAP8[58664] | 0) == 0 ? ___cxa_guard_acquire(58664) | 0 : 0) {
   i1 = 62736;
   do {
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i1 = i1 + 12 | 0;
   } while ((i1 | 0) != 63024);
   ___cxa_atexit(297, 0, ___dso_handle | 0) | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62736, 13568) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62748, 13600) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62760, 13636) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62772, 13660) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62784, 13684) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62796, 13700) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62808, 13720) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62820, 13740) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62832, 13768) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62844, 13808) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62856, 13840) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62868, 13876) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62880, 13912) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62892, 13928) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62904, 13944) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62916, 13960) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62928, 13684) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62940, 13976) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62952, 13992) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62964, 14008) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62976, 14024) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62988, 14040) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(63e3, 14056) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(63012, 14072) | 0;
  HEAP32[15756] = 62736;
 }
 return HEAP32[15756] | 0;
}

function __ZN4wasm17WasmBinaryBuilder15maybeVisitStoreERPNS_10ExpressionEh(i5, i4, i1) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i6 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i7;
 switch (i1 & 255 | 0) {
 case 46:
  {
   i3 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 1;
   HEAP32[i3 + 4 >> 2] = 1;
   i1 = 1;
   i6 = 11;
   break;
  }
 case 47:
  {
   i3 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 2;
   HEAP32[i3 + 4 >> 2] = 1;
   i1 = 2;
   i6 = 11;
   break;
  }
 case 51:
  {
   i3 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 4;
   HEAP32[i3 + 4 >> 2] = 1;
   i1 = 4;
   i6 = 11;
   break;
  }
 case 48:
  {
   i3 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 1;
   HEAP32[i3 + 4 >> 2] = 2;
   i1 = 1;
   i6 = 11;
   break;
  }
 case 49:
  {
   i3 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 2;
   HEAP32[i3 + 4 >> 2] = 2;
   i1 = 2;
   i6 = 11;
   break;
  }
 case 50:
  {
   i3 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 4;
   HEAP32[i3 + 4 >> 2] = 2;
   i1 = 4;
   i6 = 11;
   break;
  }
 case 52:
  {
   i3 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 8;
   HEAP32[i3 + 4 >> 2] = 2;
   i1 = 8;
   i6 = 11;
   break;
  }
 case 53:
  {
   i3 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 4;
   HEAP32[i3 + 4 >> 2] = 3;
   i1 = 4;
   i6 = 11;
   break;
  }
 case 54:
  {
   i3 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   HEAP8[i3 + 8 >> 0] = 8;
   HEAP32[i3 + 4 >> 2] = 4;
   i1 = 8;
   i6 = 11;
   break;
  }
 default:
  i1 = 0;
 }
 if ((i6 | 0) == 11) {
  if (HEAP8[i5 + 12 >> 0] | 0) {
   i1 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25163) | 0;
   i6 = __ZNKSt3__28ios_base6getlocEv(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i2 >> 2] = i6;
   i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
   i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
   __ZNSt3__26localeD2Ev(i2);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i1, i6) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i1) | 0;
   i1 = HEAP8[i3 + 8 >> 0] | 0;
  }
  __ZN4wasm17WasmBinaryBuilder16readMemoryAccessERNS_7AddressEjS2_(i5, i3 + 16 | 0, i1 & 255, i3 + 12 | 0);
  i1 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i5) | 0;
  HEAP32[i3 + 24 >> 2] = i1;
  i1 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i5) | 0;
  HEAP32[i3 + 20 >> 2] = i1;
  HEAP32[i4 >> 2] = i3;
  i1 = 1;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm17WasmBinaryBuilder15getInlineStringEv(i11) {
 i11 = i11 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i12 + 28 | 0;
 i6 = i12 + 24 | 0;
 i10 = i12 + 12 | 0;
 i8 = i12;
 i9 = i11 + 12 | 0;
 if (HEAP8[i9 >> 0] | 0) {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23002) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i5 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i5);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
 }
 i7 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i11) | 0;
 HEAP32[i10 >> 2] = 0;
 HEAP32[i10 + 4 >> 2] = 0;
 HEAP32[i10 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i10 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i1 = i10 + 11 | 0;
 i2 = i10 + 4 | 0;
 i4 = 0;
 while (1) {
  if (i4 >>> 0 >= i7 >>> 0) break;
  __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_S6_(i8, i10, __ZN4wasm17WasmBinaryBuilder7getInt8Ev(i11) | 0);
  if ((HEAP8[i1 >> 0] | 0) < 0) {
   HEAP8[HEAP32[i10 >> 2] >> 0] = 0;
   HEAP32[i2 >> 2] = 0;
  } else {
   HEAP8[i10 >> 0] = 0;
   HEAP8[i1 >> 0] = 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i10, 0);
  HEAP32[i10 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i10 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
  HEAP32[i10 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
  i3 = 0;
  while (1) {
   if ((i3 | 0) == 3) break;
   HEAP32[i8 + (i3 << 2) >> 2] = 0;
   i3 = i3 + 1 | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i8);
  i4 = i4 + 1 | 0;
 }
 if (HEAP8[i9 >> 0] | 0) {
  i11 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_13basic_ostreamIT_T0_EES9_RKNS_12basic_stringIS6_S7_T1_EE(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23707) | 0, i10) | 0, 23017) | 0;
  i9 = __ZNKSt3__28ios_base6getlocEv(i11 + (HEAP32[(HEAP32[i11 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i5 >> 2] = i9;
  i9 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
  i9 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i9 >> 2] | 0) + 28 >> 2] & 63](i9, 10) | 0;
  __ZNSt3__26localeD2Ev(i5);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i11, i9) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i11) | 0;
 }
 __ZN4wasm4NameC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i6, i10);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i10);
 STACKTOP = i12;
 return HEAP32[i6 >> 2] | 0;
}

function __ZN4wasm22SExpressionWasmBuilder8makeLoopERNS_7ElementE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i10 + 12 | 0;
 i2 = i10;
 i9 = __ZN10MixedArena5allocIN4wasm4LoopEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
 i8 = (__ZN4wasm7Element4listEv(i6) | 0) + 8 | 0;
 if (((HEAP32[i8 >> 2] | 0) >>> 0 > 2 ? (i8 = __ZN4wasm7ElementixEj(i6, 1) | 0, (HEAP8[i8 >> 0] | 0) == 0) : 0) ? (i8 = __ZN4wasm7ElementixEj(i6, 2) | 0, (HEAP8[i8 >> 0] | 0) == 0) : 0) {
  i1 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i6, 1) | 0) | 0;
  HEAP32[i9 + 8 >> 2] = i1;
  i1 = 2;
 } else {
  HEAP32[i1 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = 0;
  HEAP32[i1 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 22780, 8);
  i8 = __ZN4wasm22SExpressionWasmBuilder15getPrefixedNameENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i7, i1) | 0;
  HEAP32[i9 + 8 >> 2] = i8;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1);
  i1 = 1;
 }
 i8 = (__ZN4wasm7Element4listEv(i6) | 0) + 8 | 0;
 if ((HEAP32[i8 >> 2] | 0) >>> 0 > i1 >>> 0 ? (i8 = __ZN4wasm7ElementixEj(i6, i1) | 0, (HEAP8[i8 >> 0] | 0) == 0) : 0) {
  i8 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i6, i1) | 0) | 0;
  HEAP32[i9 + 12 >> 2] = i8;
  i1 = i1 + 1 | 0;
 } else {
  HEAP32[i2 >> 2] = 0;
  HEAP32[i2 + 4 >> 2] = 0;
  HEAP32[i2 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i2, 22789, 7);
  i8 = __ZN4wasm22SExpressionWasmBuilder15getPrefixedNameENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i7, i2) | 0;
  HEAP32[i9 + 12 >> 2] = i8;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i2);
 }
 i4 = i7 + 64 | 0;
 i2 = i9 + 8 | 0;
 i8 = i7 + 68 | 0;
 i3 = HEAP32[i8 >> 2] | 0;
 i5 = i7 + 72 | 0;
 if ((i3 | 0) == (HEAP32[i5 >> 2] | 0)) {
  __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4, i2);
  i3 = HEAP32[i8 >> 2] | 0;
 } else {
  HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
  i3 = (HEAP32[i8 >> 2] | 0) + 4 | 0;
  HEAP32[i8 >> 2] = i3;
 }
 i2 = i9 + 12 | 0;
 if ((i3 | 0) == (HEAP32[i5 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4, i2); else {
  HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + 4;
 }
 i2 = __ZN4wasm22SExpressionWasmBuilder14makeMaybeBlockERNS_7ElementEjj(i7, i6, i1, -1) | 0;
 HEAP32[i9 + 16 >> 2] = i2;
 i2 = HEAP32[i8 >> 2] | 0;
 i1 = i2 + -4 | 0;
 i3 = i2;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i7 = i3 + -4 | 0;
  HEAP32[i8 >> 2] = i7;
  i3 = i7;
 }
 i2 = i2 + -8 | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i7 = i1 + -4 | 0;
  HEAP32[i8 >> 2] = i7;
  i1 = i7;
 }
 __ZN4wasm4Loop8finalizeEv(i9);
 STACKTOP = i10;
 return i9 | 0;
}

function __ZN4wasm17SExpressionParser5parseEv(i15) {
 i15 = i15 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i16 = 0, i17 = 0, i18 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i14 = i17 + 16 | 0;
 i13 = i17 + 12 | 0;
 i7 = i17;
 HEAP32[i14 >> 2] = 0;
 i8 = i14 + 4 | 0;
 HEAP32[i8 >> 2] = 0;
 HEAP32[i14 + 8 >> 2] = 0;
 i9 = i15 + 12 | 0;
 i1 = __ZN10MixedArena5allocIN4wasm7ElementEEEPT_v(i9) | 0;
 HEAP32[i13 >> 2] = i1;
 i10 = i14 + 8 | 0;
 i11 = i15 + 4 | 0;
 i12 = i15 + 8 | 0;
 i5 = i1;
 L1 : while (1) {
  i3 = i5;
  i2 = i1;
  L3 : while (1) {
   __ZN4wasm17SExpressionParser14skipWhitespaceEv(i15);
   i1 = HEAP32[i15 >> 2] | 0;
   switch (HEAP8[i1 >> 0] | 0) {
   case 0:
    {
     i6 = i5;
     break L1;
    }
   case 40:
    {
     i16 = 4;
     break L3;
    }
   case 41:
    {
     i16 = 8;
     break L3;
    }
   default:
    {}
   }
   i2 = __ZN4wasm7Element4listEv(i5) | 0;
   __ZN11ArenaVectorIPN4wasm7ElementEE9push_backES2_(i2, __ZN4wasm17SExpressionParser11parseStringEv(i15) | 0);
   i2 = i3;
  }
  if ((i16 | 0) == 4) {
   i16 = 0;
   HEAP32[i15 >> 2] = i1 + 1;
   i1 = HEAP32[i8 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i10 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm7ElementENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i14, i13); else {
    HEAP32[i1 >> 2] = i2;
    HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + 4;
   }
   i1 = __ZN10MixedArena5allocIN4wasm7ElementEEEPT_v(i9) | 0;
   i5 = (HEAP32[i15 >> 2] | 0) + -1 - (HEAP32[i12 >> 2] | 0) | 0;
   HEAP32[i1 + 28 >> 2] = HEAP32[i11 >> 2];
   HEAP32[i1 + 32 >> 2] = i5;
   HEAP32[i13 >> 2] = i1;
   i5 = i1;
   continue;
  } else if ((i16 | 0) == 8) {
   i16 = 0;
   HEAP32[i15 >> 2] = i1 + 1;
   i2 = HEAP32[i8 >> 2] | 0;
   i3 = i2 + -4 | 0;
   i1 = HEAP32[i3 >> 2] | 0;
   HEAP32[i13 >> 2] = i1;
   i4 = i1;
   if ((i2 | 0) == (HEAP32[i14 >> 2] | 0)) {
    i16 = 9;
    break;
   }
   while (1) {
    if ((i2 | 0) == (i3 | 0)) break;
    i18 = i2 + -4 | 0;
    HEAP32[i8 >> 2] = i18;
    i2 = i18;
   }
   __ZN11ArenaVectorIPN4wasm7ElementEE9push_backES2_(__ZN4wasm7Element4listEv(i4) | 0, i5);
   i5 = i4;
   continue;
  }
 }
 if ((i16 | 0) == 9) ___assert_fail(21433, 21446, 169, 21466);
 if ((HEAP32[i8 >> 2] | 0) == (HEAP32[i14 >> 2] | 0)) {
  __ZNSt3__213__vector_baseIPN4wasm7ElementENS_9allocatorIS3_EEED2Ev(i14);
  STACKTOP = i17;
  return i6 | 0;
 } else {
  i18 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i7 + 4 >> 2] = 0;
  HEAP32[i7 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i7, 21472, 18);
  i16 = HEAP32[i6 + 28 >> 2] | 0;
  i17 = HEAP32[i6 + 32 >> 2] | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i18, i7);
  HEAP32[i18 + 12 >> 2] = i16;
  HEAP32[i18 + 16 >> 2] = i17;
  ___cxa_throw(i18 | 0, 64, 279);
 }
 return 0;
}

function __ZN4wasm15Asm2WasmBuilder16parseAsmBinaryOpEN6cashew7IStringENS1_3RefES3_PNS_10ExpressionES5_(i12, i3, i10, i11, i2, i1) {
 i12 = i12 | 0;
 i3 = i3 | 0;
 i10 = i10 | 0;
 i11 = i11 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i13 + 24 | 0;
 i1 = i13 + 20 | 0;
 i4 = i13 + 16 | 0;
 i8 = i13 + 4 | 0;
 i9 = i13;
 i5 = HEAP32[i2 + 4 >> 2] | 0;
 i6 = (i5 | 0) == 1;
 i3 = HEAP32[i3 >> 2] | 0;
 i2 = i3;
 do if ((i3 | 0) != (HEAP32[14857] | 0)) {
  if ((i3 | 0) == (HEAP32[14858] | 0)) {
   i1 = i6 ? 1 : (i5 | 0) == 3 ? 51 : 64;
   break;
  }
  if ((i3 | 0) == (HEAP32[14872] | 0)) {
   i1 = i6 ? 2 : (i5 | 0) == 3 ? 52 : 65;
   break;
  }
  if ((i3 | 0) != (HEAP32[14860] | 0)) if ((i3 | 0) != (HEAP32[14859] | 0)) if ((i3 | 0) != (HEAP32[14861] | 0)) if ((i3 | 0) != (HEAP32[14874] | 0)) if ((i3 | 0) != (HEAP32[14873] | 0)) if ((i3 | 0) != (HEAP32[14875] | 0)) {
   if ((i3 | 0) == (HEAP32[14868] | 0)) {
    i1 = i6 ? 15 : (i5 | 0) == 3 ? 57 : 70;
    break;
   }
   if ((i3 | 0) == (HEAP32[14869] | 0)) {
    i1 = i6 ? 16 : (i5 | 0) == 3 ? 58 : 71;
    break;
   }
   HEAP32[i1 >> 2] = HEAP32[i10 >> 2];
   HEAP32[i7 >> 2] = HEAP32[i1 >> 2];
   if (__ZN4wasm15Asm2WasmBuilder18isUnsignedCoercionEN6cashew3RefE(i12, i7) | 0) i1 = 1; else {
    HEAP32[i4 >> 2] = HEAP32[i11 >> 2];
    HEAP32[i7 >> 2] = HEAP32[i4 >> 2];
    i1 = __ZN4wasm15Asm2WasmBuilder18isUnsignedCoercionEN6cashew3RefE(i12, i7) | 0;
   }
   if ((i3 | 0) == (HEAP32[14870] | 0)) if (i6) {
    i1 = i1 ? 4 : 3;
    break;
   } else {
    i1 = (i5 | 0) == 3 ? 53 : 66;
    break;
   }
   if ((i3 | 0) == (HEAP32[14871] | 0)) {
    STACKTOP = i13;
    return (i6 & i1 ? 6 : 5) | 0;
   }
   if ((i3 | 0) == (HEAP32[14865] | 0)) if (i6) {
    i1 = i1 ? 24 : 23;
    break;
   } else {
    i1 = (i5 | 0) == 3 ? 62 : 75;
    break;
   }
   if ((i3 | 0) == (HEAP32[14867] | 0)) if (i6) {
    i1 = i1 ? 22 : 21;
    break;
   } else {
    i1 = (i5 | 0) == 3 ? 61 : 74;
    break;
   }
   if ((i3 | 0) == (HEAP32[14866] | 0)) if (i6) {
    i1 = i1 ? 20 : 19;
    break;
   } else {
    i1 = (i5 | 0) == 3 ? 60 : 73;
    break;
   }
   if ((i3 | 0) != (HEAP32[14864] | 0)) {
    HEAP32[i8 >> 2] = 0;
    HEAP32[i8 + 4 >> 2] = 0;
    HEAP32[i8 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i8, 30353, 18);
    HEAP32[i9 >> 2] = i2;
    HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
    __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew7IStringE(i8, i7);
   }
   if (i6) {
    i1 = i1 ? 18 : 17;
    break;
   } else {
    i1 = (i5 | 0) == 3 ? 59 : 72;
    break;
   }
  } else i1 = 11; else i1 = 12; else i1 = 10; else i1 = 9; else i1 = 8; else i1 = 7;
 } else i1 = i6 ? 0 : (i5 | 0) == 3 ? 50 : 63; while (0);
 STACKTOP = i13;
 return i1 | 0;
}

function __ZN4wasm14CoalesceLocals12applyIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEEPNS_10ExpressionE(i8, i11, i1) {
 i8 = i8 | 0;
 i11 = i11 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i12 = 0, i13 = 0, i14 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i12 = i13;
 i9 = i11 + 4 | 0;
 i10 = i8 + 112 | 0;
 if (((HEAP32[i9 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2 | 0) != (HEAP32[i10 >> 2] | 0)) ___assert_fail(46783, 46670, 419, 46811);
 i3 = HEAP32[i8 + 52 >> 2] | 0;
 i6 = HEAP32[i8 + 48 >> 2] | 0;
 while (1) {
  if ((i6 | 0) == (i3 | 0)) break;
  i7 = HEAP32[i6 >> 2] | 0;
  i4 = HEAP32[i7 + 28 >> 2] | 0;
  i7 = HEAP32[i7 + 24 >> 2] | 0;
  while (1) {
   if ((i7 | 0) == (i4 | 0)) break;
   i5 = i7 + 8 | 0;
   i1 = HEAP32[HEAP32[i5 >> 2] >> 2] | 0;
   do if (HEAP32[i7 >> 2] | 0) {
    i1 = __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i1) | 0;
    i2 = i1 + 8 | 0;
    i14 = HEAP32[(HEAP32[i11 >> 2] | 0) + (HEAP32[i2 >> 2] << 2) >> 2] | 0;
    HEAP32[i2 >> 2] = i14;
    i1 = HEAP32[i1 + 12 >> 2] | 0;
    i2 = i1;
    if (!((i1 | 0) == 0 | (HEAP32[i1 >> 2] | 0) != 9) ? (HEAP32[i1 + 8 >> 2] | 0) == (i14 | 0) : 0) {
     HEAP32[HEAP32[i5 >> 2] >> 2] = i1;
     break;
    }
    if (!(HEAP8[i7 + 12 >> 0] | 0)) HEAP32[HEAP32[i5 >> 2] >> 2] = i2;
   } else {
    i14 = (__ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(i1) | 0) + 8 | 0;
    HEAP32[i14 >> 2] = HEAP32[(HEAP32[i11 >> 2] | 0) + (HEAP32[i14 >> 2] << 2) >> 2];
   } while (0);
   i7 = i7 + 16 | 0;
  }
  i6 = i6 + 4 | 0;
 }
 i7 = i8 + 36 | 0;
 i5 = HEAP32[i7 >> 2] | 0;
 i4 = (HEAP32[i5 + 12 >> 2] | 0) - (HEAP32[i5 + 8 >> 2] | 0) | 0;
 i2 = HEAP32[i9 >> 2] | 0;
 i3 = HEAP32[i11 >> 2] | 0;
 i1 = 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  i14 = (HEAP32[i3 >> 2] | 0) + 1 | 0;
  i3 = i3 + 4 | 0;
  i1 = i1 >>> 0 < i14 >>> 0 ? i14 : i1;
 }
 i6 = i4 >> 2;
 __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEEC2ERKS5_(i12, i5 + 20 | 0);
 __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE6resizeEj((HEAP32[i7 >> 2] | 0) + 20 | 0, i1 - i6 | 0);
 i5 = HEAP32[i10 >> 2] | 0;
 i1 = HEAP32[i11 >> 2] | 0;
 i2 = HEAP32[i12 >> 2] | 0;
 i4 = i6;
 while (1) {
  if (i4 >>> 0 >= i5 >>> 0) break;
  i3 = HEAP32[i1 + (i4 << 2) >> 2] | 0;
  if (i3 >>> 0 >= i6 >>> 0) HEAP32[(HEAP32[(HEAP32[i7 >> 2] | 0) + 20 >> 2] | 0) + (i3 - i6 << 2) >> 2] = HEAP32[i2 + (i4 - i6 << 2) >> 2];
  i4 = i4 + 1 | 0;
 }
 i1 = HEAP32[i7 >> 2] | 0;
 i2 = HEAP32[i1 + 40 >> 2] | 0;
 i3 = i1 + 44 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i4 | 0) == (i2 | 0)) break;
  i14 = i4 + -4 | 0;
  HEAP32[i3 >> 2] = i14;
  i4 = i14;
 }
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE5clearEv(i1 + 52 | 0);
 __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i12);
 STACKTOP = i13;
 return;
}

function __ZNSt3__216__copy_unalignedINS_6vectorIbNS_9allocatorIbEEEELb0EEENS_14__bit_iteratorIT_Lb0EXLi0EEEENS5_IS6_XT0_EXLi0EEEES8_S7_(i18, i8, i1, i17) {
 i18 = i18 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i17 = i17 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i19 = 0;
 i3 = HEAP32[i8 >> 2] | 0;
 i7 = i8 + 4 | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i11 = ((HEAP32[i1 >> 2] | 0) - i3 << 3) + (HEAP32[i1 + 4 >> 2] | 0) - i2 | 0;
 if ((i11 | 0) > 0) {
  if (!i2) {
   i2 = i17 + 4 | 0;
   i9 = i8;
   i12 = i17;
   i1 = i2;
   i2 = HEAP32[i2 >> 2] | 0;
   i7 = i11;
  } else {
   i1 = 32 - i2 | 0;
   i10 = (i11 | 0) < (i1 | 0) ? i11 : i1;
   i3 = -1 >>> (i1 - i10 | 0) & -1 << i2 & HEAP32[i3 >> 2];
   i1 = i17 + 4 | 0;
   i12 = HEAP32[i1 >> 2] | 0;
   i2 = 32 - i12 | 0;
   i4 = i2 >>> 0 < i10 >>> 0 ? i2 : i10;
   i5 = HEAP32[i17 >> 2] | 0;
   i12 = HEAP32[i5 >> 2] & ~(-1 >>> (i2 - i4 | 0) & -1 << i12);
   HEAP32[i5 >> 2] = i12;
   i2 = HEAP32[i1 >> 2] | 0;
   i6 = HEAP32[i7 >> 2] | 0;
   HEAP32[i5 >> 2] = i12 | (i2 >>> 0 > i6 >>> 0 ? i3 << i2 - i6 : i3 >>> (i6 - i2 | 0));
   i2 = (HEAP32[i1 >> 2] | 0) + i4 | 0;
   i5 = i5 + (i2 >>> 5 << 2) | 0;
   HEAP32[i17 >> 2] = i5;
   i2 = i2 & 31;
   HEAP32[i1 >> 2] = i2;
   i6 = i10 - i4 | 0;
   if ((i6 | 0) > 0) {
    i2 = HEAP32[i5 >> 2] & ~(-1 >>> (32 - i6 | 0));
    HEAP32[i5 >> 2] = i2;
    HEAP32[i5 >> 2] = i2 | i3 >>> ((HEAP32[i7 >> 2] | 0) + i4 | 0);
    HEAP32[i1 >> 2] = i6;
    i2 = i6;
   }
   i3 = (HEAP32[i8 >> 2] | 0) + 4 | 0;
   HEAP32[i8 >> 2] = i3;
   i9 = i8;
   i12 = i17;
   i7 = i11 - i10 | 0;
  }
  i8 = 32 - i2 | 0;
  i4 = -1 << i2;
  i5 = ~i4;
  i6 = i7 + ~(i7 >>> 0 < 31 ? i7 : 31) + 32 & -32;
  i2 = i7;
  while (1) {
   if (i2 >>> 0 <= 31) break;
   i10 = HEAP32[i3 >> 2] | 0;
   i11 = HEAP32[i12 >> 2] | 0;
   i19 = HEAP32[i11 >> 2] & i5;
   HEAP32[i11 >> 2] = i19;
   HEAP32[i11 >> 2] = i19 | i10 << HEAP32[i1 >> 2];
   i11 = i11 + 4 | 0;
   HEAP32[i12 >> 2] = i11;
   HEAP32[i11 >> 2] = HEAP32[i11 >> 2] & i4 | i10 >>> i8;
   i11 = (HEAP32[i9 >> 2] | 0) + 4 | 0;
   HEAP32[i9 >> 2] = i11;
   i3 = i11;
   i2 = i2 + -32 | 0;
  }
  i2 = i7 - i6 | 0;
  if ((i2 | 0) > 0 ? (i15 = HEAP32[i3 >> 2] & -1 >>> (32 - i2 | 0), i16 = (i8 | 0) < (i2 | 0) ? i8 : i2, i13 = HEAP32[i12 >> 2] | 0, i14 = HEAP32[i13 >> 2] & ~(-1 << HEAP32[i1 >> 2] & -1 >>> (i8 - i16 | 0)), HEAP32[i13 >> 2] = i14, HEAP32[i13 >> 2] = i14 | i15 << HEAP32[i1 >> 2], i14 = (HEAP32[i1 >> 2] | 0) + i16 | 0, i13 = i13 + (i14 >>> 5 << 2) | 0, HEAP32[i12 >> 2] = i13, HEAP32[i1 >> 2] = i14 & 31, i14 = i2 - i16 | 0, (i14 | 0) > 0) : 0) {
   HEAP32[i13 >> 2] = HEAP32[i13 >> 2] & ~(-1 >>> (32 - i14 | 0)) | i15 >>> i16;
   HEAP32[i1 >> 2] = i14;
  }
 } else i1 = i17 + 4 | 0;
 HEAP32[i18 >> 2] = HEAP32[i17 >> 2];
 HEAP32[i18 + 4 >> 2] = HEAP32[i1 >> 2];
 return;
}

function __ZN4wasm16PrintSExpression10visitBlockEPNS_5BlockE(i12, i1) {
 i12 = i12 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i13 + 20 | 0;
 i9 = i13 + 4 | 0;
 i11 = i13 + 8 | 0;
 i6 = i13;
 HEAP32[i9 >> 2] = i1;
 HEAP32[i11 >> 2] = 0;
 i10 = i11 + 4 | 0;
 HEAP32[i10 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 i7 = i11 + 8 | 0;
 i8 = i12 + 4 | 0;
 i2 = 0;
 i3 = 0;
 i4 = 0;
 while (1) {
  if ((i3 | 0) != (i4 | 0)) {
   __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i12 >> 2] | 0, HEAP32[i8 >> 2] | 0) | 0;
   i2 = HEAP32[i10 >> 2] | 0;
  }
  if ((i2 | 0) == (HEAP32[i7 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm5BlockENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i11, i9); else {
   HEAP32[i2 >> 2] = i1;
   HEAP32[i10 >> 2] = (HEAP32[i10 >> 2] | 0) + 4;
  }
  __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i12 >> 2] | 0, 49182, 0) | 0;
  i1 = HEAP32[i9 >> 2] | 0;
  if (HEAP32[i1 + 8 >> 2] | 0) {
   i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i12 >> 2] | 0, 32) | 0;
   HEAP32[i6 >> 2] = HEAP32[i1 + 8 >> 2];
   HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
   __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i4, i5) | 0;
  }
  __ZN4wasm16PrintSExpression9incIndentEv(i12);
  if (!(HEAP32[i1 + 20 >> 2] | 0)) break;
  i1 = i1 + 12 | 0;
  i4 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, 0) | 0;
  if ((HEAP32[HEAP32[i4 >> 2] >> 2] | 0) != 1) break;
  i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, 0) | 0;
  i1 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
  HEAP32[i9 >> 2] = i1;
  i3 = HEAP32[i10 >> 2] | 0;
  i2 = i3;
  i4 = HEAP32[i11 >> 2] | 0;
 }
 i3 = HEAP32[i10 >> 2] | 0;
 i6 = HEAP32[i3 + -4 >> 2] | 0;
 i1 = i3;
 while (1) {
  if ((i1 | 0) == (HEAP32[i11 >> 2] | 0)) break;
  i2 = i3 + -4 | 0;
  i5 = HEAP32[i2 >> 2] | 0;
  HEAP32[i9 >> 2] = i5;
  i1 = i3;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i8 = i1 + -4 | 0;
   HEAP32[i10 >> 2] = i8;
   i1 = i8;
  }
  i3 = i5 + 12 | 0;
  i4 = i5 + 20 | 0;
  i1 = (i5 | 0) != (i6 | 0);
  i2 = 0;
  while (1) {
   if (i2 >>> 0 >= (HEAP32[i4 >> 2] | 0) >>> 0) break;
   if ((i2 | 0) == 0 & i1) {
    __ZN4wasm16PrintSExpression9decIndentEv(i12);
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i12 >> 2] | 0, 10) | 0;
   } else {
    i8 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, i2) | 0;
    __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i12, HEAP32[i8 >> 2] | 0);
   }
   i2 = i2 + 1 | 0;
  }
  i3 = HEAP32[i10 >> 2] | 0;
  i1 = i3;
 }
 __ZN4wasm16PrintSExpression9decIndentEv(i12);
 __ZNSt3__213__vector_baseIPN4wasm5BlockENS_9allocatorIS3_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm14SimplifyLocals15doNoteNonLinearEPS0_PPNS_10ExpressionE(i8, i1) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9 + 24 | 0;
 i5 = i9 + 8 | 0;
 i6 = i9;
 i1 = HEAP32[i1 >> 2] | 0;
 L1 : do switch (HEAP32[i1 >> 2] | 0) {
 case 4:
  {
   i1 = __ZN4wasm10Expression4castINS_5BreakEEEPT_v(i1) | 0;
   if (HEAP32[i1 + 12 >> 2] | 0) {
    i2 = i1 + 8 | 0;
    __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i7, i8 + 68 | 0, i2, i2);
    i2 = 14;
    break L1;
   }
   i4 = __ZNSt3__23mapIN4wasm4NameENS_6vectorINS1_14SimplifyLocals10BlockBreakENS_9allocatorIS5_EEEENS_4lessIS2_EENS6_INS_4pairIKS2_S8_EEEEEixERSC_(i8 + 56 | 0, i1 + 8 | 0) | 0;
   HEAP32[i5 >> 2] = i1;
   i1 = i5 + 4 | 0;
   __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEEC2EOSC_(i1, i8 + 44 | 0);
   i2 = i4 + 4 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   if (i3 >>> 0 < (HEAP32[i4 + 8 >> 2] | 0) >>> 0) {
    __ZN4wasm14SimplifyLocals10BlockBreakC2EOS1_(i3, i5);
    HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 16;
   } else __ZNSt3__26vectorIN4wasm14SimplifyLocals10BlockBreakENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i4, i5);
   __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEED2Ev(i1);
   i2 = 14;
   break;
  }
 case 1:
  break;
 case 2:
  {
   i7 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i1) | 0) + 16 | 0;
   if (!(HEAP32[i7 >> 2] | 0)) i2 = 14; else ___assert_fail(42242, 41949, 122, 42269);
   break;
  }
 case 5:
  {
   i1 = __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i1) | 0;
   i2 = i1 + 8 | 0;
   i3 = HEAP32[i1 + 16 >> 2] | 0;
   i4 = i8 + 68 | 0;
   i5 = 0;
   while (1) {
    if ((i5 | 0) == (i3 | 0)) break;
    i10 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i2, i5) | 0;
    HEAP32[i6 >> 2] = HEAP32[i10 >> 2];
    __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i7, i4, i6, i6);
    i5 = i5 + 1 | 0;
   }
   i2 = i1 + 24 | 0;
   __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i7, i4, i2, i2);
   i2 = 14;
   break;
  }
 default:
  i2 = 14;
 } while (0);
 if ((i2 | 0) == 14) __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5clearEv(i8 + 44 | 0);
 STACKTOP = i9;
 return;
}

function __ZN4wasm17WasmBinaryBuilder11readExportsEv(i9) {
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i10 = 0, i11 = 0, i12 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i10;
 i2 = i9 + 12 | 0;
 if (HEAP8[i2 >> 0] | 0) {
  i8 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25233) | 0;
  i7 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i7) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
 }
 i3 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i9) | 0;
 if (HEAP8[i2 >> 0] | 0) {
  i8 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23493) | 0, i3) | 0;
  i7 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i7) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
 }
 i4 = i9 + 24 | 0;
 i5 = i9 + 28 | 0;
 i6 = i9 + 72 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i3 >>> 0) {
   i1 = 7;
   break;
  }
  if (HEAP8[i2 >> 0] | 0) {
   i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23499) | 0;
   i11 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i1 >> 2] = i11;
   i11 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
   i11 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i11 >> 2] | 0) + 28 >> 2] & 63](i11, 10) | 0;
   __ZNSt3__26localeD2Ev(i1);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i11) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
  }
  i7 = __Znwj(8) | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i7 + 4 >> 2] = 0;
  HEAP32[i1 >> 2] = i7;
  i7 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i9) | 0;
  if (i7 >>> 0 >= (HEAP32[i5 >> 2] | 0) - (HEAP32[i4 >> 2] | 0) >> 2 >>> 0) {
   i1 = 11;
   break;
  }
  i11 = HEAP32[i1 >> 2] | 0;
  i12 = __ZN4wasm17WasmBinaryBuilder15getInlineStringEv(i9) | 0;
  HEAP32[i11 >> 2] = i12;
  i11 = __ZNSt3__23mapIPN4wasm6ExportEjNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_jEEEEEixERS8_(i6, i1) | 0;
  HEAP32[i11 >> 2] = i7;
  i8 = i8 + 1 | 0;
 }
 if ((i1 | 0) == 7) {
  STACKTOP = i10;
  return;
 } else if ((i1 | 0) == 11) ___assert_fail(25248, 22948, 1544, 25277);
}

function _load_asm2wasm(i1) {
 i1 = i1 | 0;
 var d2 = 0.0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i7 = i10 + 28 | 0;
 i6 = i10 + 32 | 0;
 i9 = i10 + 8 | 0;
 i3 = i10 + 4 | 0;
 i8 = i10;
 __ZL12prepare2wasmv();
 HEAP8[i6 >> 0] = 0;
 i1 = __ZN4wasm20Asm2WasmPreProcessor7processEPc(i6, i1) | 0;
 if (HEAP8[63612] | 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17294) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEEC2Ev(i9);
 i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseToplevelEPc(i9, i1) | 0;
 i1 = __Znwj(180) | 0;
 __ZN4wasm6ModuleC2Ev(i1);
 HEAP32[14814] = i1;
 i1 = _emscripten_asm_const_i(0) | 0;
 if (i1 & 65535 | 0) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17352) | 0;
  _exit(1);
 }
 i4 = HEAP32[14814] | 0;
 __ZN4wasm7AddressC2Ey(i3, i1 >>> 16, 0);
 HEAP32[i4 + 60 >> 2] = HEAP32[i3 >> 2];
 i4 = HEAP32[14814] | 0;
 i3 = HEAP8[i6 >> 0] | 0;
 if (!(i3 << 24 >> 24)) i1 = HEAP32[i4 + 60 >> 2] | 0; else i1 = 65535;
 HEAP32[i4 + 64 >> 2] = i1;
 if (HEAP8[63612] | 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17420) | 0;
 i6 = __Znwj(152) | 0;
 __ZN4wasm15Asm2WasmBuilderC2ERNS_6ModuleEbbb(i6, HEAP32[14814] | 0, i3 << 24 >> 24 != 0, (HEAP32[14809] | 0) != 0, 0);
 HEAP32[14810] = i6;
 HEAP32[i8 >> 2] = i5;
 HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
 __ZN4wasm15Asm2WasmBuilder10processAsmEN6cashew3RefE(i6, i7);
 if (HEAP8[63612] | 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17432) | 0;
 __ZN4wasm15Asm2WasmBuilder8optimizeEv(HEAP32[14810] | 0);
 if (HEAP8[63612] | 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17447) | 0;
 i4 = HEAP32[14810] | 0;
 i1 = i4 + 52 | 0;
 i4 = HEAP32[i4 + 48 >> 2] | 0;
 L19 : while (1) {
  if ((i4 | 0) == (i1 | 0)) {
   i1 = 15;
   break;
  }
  L22 : do if (HEAP8[i4 + 28 >> 0] | 0) {
   d2 = +_emscripten_asm_const_dii(1, HEAP32[i4 + 32 >> 2] | 0, HEAP32[i4 + 36 >> 2] | 0);
   i3 = HEAP32[i4 + 20 >> 2] | 0;
   switch (HEAP32[i4 + 24 >> 2] | 0) {
   case 1:
    {
     _emscripten_asm_const_iid(2, i3 | 0, +d2) | 0;
     break L22;
    }
   case 3:
    {
     _emscripten_asm_const_iid(3, i3 | 0, +d2) | 0;
     break L22;
    }
   case 4:
    {
     _emscripten_asm_const_iid(4, i3 | 0, +d2) | 0;
     break L22;
    }
   default:
    {
     i1 = 21;
     break L19;
    }
   }
  } while (0);
  i4 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i4) | 0;
 }
 if ((i1 | 0) == 15) {
  __ZNSt3__213__vector_baseINS_6vectorIN6cashew6ParserINS2_3RefENS2_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS7_EEEENS8_ISA_EEED2Ev(i9);
  STACKTOP = i10;
  return;
 } else if ((i1 | 0) == 21) _abort();
}

function __ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_(i4, i9, i12, i7, i10, i2, i3, i8, i13, i14, i11, i5) {
 i4 = i4 | 0;
 i9 = i9 | 0;
 i12 = i12 | 0;
 i7 = i7 | 0;
 i10 = i10 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i8 = i8 | 0;
 i13 = i13 | 0;
 i14 = i14 | 0;
 i11 = i11 | 0;
 i5 = i5 | 0;
 var i1 = 0, i6 = 0;
 L1 : do if (i4 << 24 >> 24 == i2 << 24 >> 24) if (HEAP8[i9 >> 0] | 0) {
  HEAP8[i9 >> 0] = 0;
  i12 = HEAP32[i10 >> 2] | 0;
  HEAP32[i10 >> 2] = i12 + 1;
  HEAP8[i12 >> 0] = 46;
  i12 = HEAP8[i8 + 11 >> 0] | 0;
  if (((i12 << 24 >> 24 < 0 ? HEAP32[i8 + 4 >> 2] | 0 : i12 & 255) | 0) != 0 ? (i1 = HEAP32[i14 >> 2] | 0, (i1 - i13 | 0) < 160) : 0) {
   i13 = HEAP32[i11 >> 2] | 0;
   HEAP32[i14 >> 2] = i1 + 4;
   HEAP32[i1 >> 2] = i13;
   i1 = 0;
  } else i1 = 0;
 } else i1 = -1; else {
  if (i4 << 24 >> 24 == i3 << 24 >> 24 ? (i3 = HEAP8[i8 + 11 >> 0] | 0, (i3 << 24 >> 24 < 0 ? HEAP32[i8 + 4 >> 2] | 0 : i3 & 255) | 0) : 0) {
   if (!(HEAP8[i9 >> 0] | 0)) {
    i1 = -1;
    break;
   }
   i1 = HEAP32[i14 >> 2] | 0;
   if ((i1 - i13 | 0) >= 160) {
    i1 = 0;
    break;
   }
   i13 = HEAP32[i11 >> 2] | 0;
   HEAP32[i14 >> 2] = i1 + 4;
   HEAP32[i1 >> 2] = i13;
   HEAP32[i11 >> 2] = 0;
   i1 = 0;
   break;
  }
  i2 = i5 + 32 | 0;
  i1 = i5;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) {
    i1 = i2;
    break;
   }
   if ((HEAP8[i1 >> 0] | 0) == i4 << 24 >> 24) break;
   i1 = i1 + 1 | 0;
  }
  i2 = i1 - i5 | 0;
  if ((i2 | 0) > 31) i1 = -1; else {
   i3 = HEAP8[53246 + i2 >> 0] | 0;
   switch (i2 | 0) {
   case 24:
   case 25:
    {
     i1 = HEAP32[i10 >> 2] | 0;
     if ((i1 | 0) != (i7 | 0) ? (HEAPU8[i1 + -1 >> 0] & 95 | 0) != (HEAPU8[i12 >> 0] & 127 | 0) : 0) {
      i1 = -1;
      break L1;
     }
     HEAP32[i10 >> 2] = i1 + 1;
     HEAP8[i1 >> 0] = i3;
     i1 = 0;
     break L1;
    }
   case 23:
   case 22:
    {
     HEAP8[i12 >> 0] = 80;
     i1 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i1 + 1;
     HEAP8[i1 >> 0] = i3;
     i1 = 0;
     break L1;
    }
   default:
    {
     i1 = i3 & 95;
     if ((((i1 | 0) == (HEAP8[i12 >> 0] | 0) ? (HEAP8[i12 >> 0] = i1 | 128, HEAP8[i9 >> 0] | 0) : 0) ? (HEAP8[i9 >> 0] = 0, i12 = HEAP8[i8 + 11 >> 0] | 0, (i12 << 24 >> 24 < 0 ? HEAP32[i8 + 4 >> 2] | 0 : i12 & 255) | 0) : 0) ? (i6 = HEAP32[i14 >> 2] | 0, (i6 - i13 | 0) < 160) : 0) {
      i13 = HEAP32[i11 >> 2] | 0;
      HEAP32[i14 >> 2] = i6 + 4;
      HEAP32[i6 >> 2] = i13;
     }
     i14 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i14 + 1;
     HEAP8[i14 >> 0] = i3;
     if ((i2 | 0) > 21) {
      i1 = 0;
      break L1;
     }
     HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) + 1;
     i1 = 0;
     break L1;
    }
   }
  }
 } while (0);
 return i1 | 0;
}

function __ZN6cashew12ValueBuilder10makeBinaryENS_3RefENS_7IStringES1_(i14, i15, i16) {
 i14 = i14 | 0;
 i15 = i15 | 0;
 i16 = i16 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i17 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i1 = i17 + 44 | 0;
 i2 = i17 + 40 | 0;
 i3 = i17 + 36 | 0;
 i6 = i17 + 32 | 0;
 i7 = i17 + 28 | 0;
 i8 = i17 + 24 | 0;
 i9 = i17 + 20 | 0;
 i10 = i17 + 16 | 0;
 i11 = i17 + 12 | 0;
 i12 = i17 + 8 | 0;
 i13 = i17 + 4 | 0;
 i4 = i17;
 i5 = HEAP32[i15 >> 2] | 0;
 do if ((i5 | 0) != (HEAP32[14903] | 0)) if ((i5 | 0) == (HEAP32[14892] | 0)) {
  i15 = __ZN6cashew12ValueBuilder12makeRawArrayEi(3) | 0;
  i13 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59336) | 0;
  HEAP32[i8 >> 2] = i13;
  HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
  i15 = __ZN6cashew5Value9push_backENS_3RefE(i15, i1) | 0;
  HEAP32[i9 >> 2] = HEAP32[i14 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i9 >> 2];
  i15 = __ZN6cashew5Value9push_backENS_3RefE(i15, i1) | 0;
  HEAP32[i10 >> 2] = HEAP32[i16 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i10 >> 2];
  i1 = __ZN6cashew5Value9push_backENS_3RefE(i15, i1) | 0;
  break;
 } else {
  i10 = __ZN6cashew12ValueBuilder12makeRawArrayEi(4) | 0;
  i9 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59308) | 0;
  HEAP32[i11 >> 2] = i9;
  HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
  i11 = __ZN6cashew5Value9push_backENS_3RefE(i10, i1) | 0;
  i15 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i15) | 0;
  HEAP32[i12 >> 2] = i15;
  HEAP32[i1 >> 2] = HEAP32[i12 >> 2];
  i15 = __ZN6cashew5Value9push_backENS_3RefE(i11, i1) | 0;
  HEAP32[i13 >> 2] = HEAP32[i14 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i13 >> 2];
  i15 = __ZN6cashew5Value9push_backENS_3RefE(i15, i1) | 0;
  HEAP32[i4 >> 2] = HEAP32[i16 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
  i1 = __ZN6cashew5Value9push_backENS_3RefE(i15, i1) | 0;
  break;
 } else {
  i15 = __ZN6cashew12ValueBuilder12makeRawArrayEi(4) | 0;
  i13 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59288) | 0;
  HEAP32[i2 >> 2] = i13;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  i15 = __ZN6cashew5Value9push_backENS_3RefE(i15, i1) | 0;
  i13 = __ZN6cashew5Arena5allocEv(59672) | 0;
  __ZN6cashew5Value4freeEv(i13);
  HEAP32[i13 >> 2] = 4;
  HEAP8[i13 + 8 >> 0] = 1;
  HEAP32[i3 >> 2] = i13;
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  i15 = __ZN6cashew5Value9push_backENS_3RefE(i15, i1) | 0;
  HEAP32[i6 >> 2] = HEAP32[i14 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i6 >> 2];
  i15 = __ZN6cashew5Value9push_backENS_3RefE(i15, i1) | 0;
  HEAP32[i7 >> 2] = HEAP32[i16 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i7 >> 2];
  i1 = __ZN6cashew5Value9push_backENS_3RefE(i15, i1) | 0;
 } while (0);
 STACKTOP = i17;
 return i1 | 0;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE(i1, i7, i8, i9, i4) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 i9 = i9 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0;
 i1 = HEAP32[i7 >> 2] | 0;
 do if (i1) {
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i7 >> 2] = 0;
   i3 = 1;
   break;
  } else {
   i3 = (HEAP32[i7 >> 2] | 0) == 0;
   break;
  }
 } else i3 = 1; while (0);
 i2 = HEAP32[i8 >> 2] | 0;
 do if (i2) {
  i1 = HEAP32[i2 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i3) {
   i5 = i2;
   i6 = 17;
   break;
  } else {
   i6 = 16;
   break;
  } else {
   HEAP32[i8 >> 2] = 0;
   i6 = 14;
   break;
  }
 } else i6 = 14; while (0);
 if ((i6 | 0) == 14) if (i3) i6 = 16; else {
  i5 = 0;
  i6 = 17;
 }
 L22 : do if ((i6 | 0) == 16) HEAP32[i9 >> 2] = HEAP32[i9 >> 2] | 6; else if ((i6 | 0) == 17) {
  i1 = HEAP32[i7 >> 2] | 0;
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
  if ((FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i4 >> 2] | 0) + 52 >> 2] & 31](i4, i1, 0) | 0) << 24 >> 24 != 37) {
   HEAP32[i9 >> 2] = HEAP32[i9 >> 2] | 4;
   break;
  }
  i1 = HEAP32[i7 >> 2] | 0;
  i2 = i1 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   i1 = HEAP32[i7 >> 2] | 0;
   if (!i1) i2 = 1; else i6 = 25;
  } else {
   HEAP32[i2 >> 2] = i3 + 4;
   i6 = 25;
  }
  do if ((i6 | 0) == 25) {
   i2 = HEAP32[i1 + 12 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i7 >> 2] = 0;
    i2 = 1;
    break;
   } else {
    i2 = (HEAP32[i7 >> 2] | 0) == 0;
    break;
   }
  } while (0);
  do if (i5) {
   i1 = HEAP32[i5 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i5 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 36 >> 2] & 255](i5) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i2) break L22; else break; else {
    HEAP32[i8 >> 2] = 0;
    i6 = 37;
    break;
   }
  } else i6 = 37; while (0);
  if ((i6 | 0) == 37 ? !i2 : 0) break;
  HEAP32[i9 >> 2] = HEAP32[i9 >> 2] | 2;
 } while (0);
 return;
}

function __ZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEE(i12, i9, i4, i7) {
 i12 = i12 | 0;
 i9 = i9 | 0;
 i4 = i4 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i6 = 0, i8 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i16 = i17 + 40 | 0;
 i3 = i17 + 36 | 0;
 i5 = i17 + 32 | 0;
 i8 = i17;
 i6 = i17 + 24 | 0;
 i13 = i9 + 4 | 0;
 i1 = HEAP32[i13 >> 2] | 0;
 if (i1 >>> 0 > 250) {
  i10 = HEAP32[i9 + 24 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i10 >> 2] | 0) + 20 >> 2] & 1023](i10, 28031);
  i10 = HEAP32[i13 >> 2] | 0;
 } else i10 = i1;
 HEAP32[i13 >> 2] = i10 + 1;
 i11 = i9 + 8 | 0;
 i14 = i9 + 12 | 0;
 i2 = HEAP32[i14 >> 2] | 0;
 i15 = i2 - (HEAP32[i11 >> 2] | 0) | 0;
 i1 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = i1;
 if (i2 >>> 0 < (HEAP32[i9 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i2 >> 2] = i1;
  HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) + 4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i11, i3);
 i4 = HEAP32[i9 >> 2] | 0;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i16 >> 2] = HEAP32[i5 >> 2];
 i1 = __ZN4wasm6Module11getFunctionENS_4NameE(i4, i16) | 0;
 if (!i1) ___assert_fail(47951, 28043, 712, 28066);
 __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN13FunctionScopeC2EPNS_8FunctionES9_(i16, i1, i7);
 HEAP32[i6 >> 2] = i9;
 HEAP32[i6 + 4 >> 2] = i16;
 __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i8, i6, HEAP32[i1 + 36 >> 2] | 0);
 i9 = HEAP32[i8 + 16 >> 2] | 0;
 if (!((i9 | 0) == 0 | (i9 | 0) == (HEAP32[14808] | 0))) ___assert_fail(28087, 28043, 720, 28066);
 HEAP32[i12 >> 2] = HEAP32[i8 >> 2];
 HEAP32[i12 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
 HEAP32[i12 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
 HEAP32[i12 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
 i2 = HEAP32[i1 + 4 >> 2] | 0;
 if (!i2) {
  HEAP32[i12 >> 2] = 0;
  i1 = i12 + 8 | 0;
  HEAP32[i1 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = 0;
  i1 = 0;
 } else i1 = HEAP32[i12 >> 2] | 0;
 if ((i2 | 0) != (i1 | 0)) ___assert_fail(28135, 28043, 723, 28066);
 HEAP32[i13 >> 2] = i10;
 i3 = HEAP32[i11 >> 2] | 0;
 i2 = HEAP32[i14 >> 2] | 0;
 i1 = i2;
 while (1) {
  if ((i1 - i3 | 0) >>> 0 <= i15 >>> 0) break;
  i4 = i2 + -4 | 0;
  i1 = i2;
  while (1) {
   if ((i1 | 0) == (i4 | 0)) break;
   i13 = i1 + -4 | 0;
   HEAP32[i14 >> 2] = i13;
   i1 = i13;
  }
  i2 = i4;
 }
 __ZNSt3__213__vector_baseIN4wasm7LiteralENS_9allocatorIS2_EEED2Ev(i16);
 STACKTOP = i17;
 return;
}

function __ZNSt3__26vectorIbNS_9allocatorIbEEE6resizeEjb(i11, i14, i15) {
 i11 = i11 | 0;
 i14 = i14 | 0;
 i15 = i15 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0, i13 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i21 = 0;
 i18 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i17 = i18 + 56 | 0;
 i16 = i18 + 48 | 0;
 i2 = i18 + 16 | 0;
 i3 = i18 + 8 | 0;
 i5 = i18 + 40 | 0;
 i10 = i18 + 24 | 0;
 i7 = i18;
 i8 = i11 + 4 | 0;
 i13 = HEAP32[i8 >> 2] | 0;
 if (i13 >>> 0 < i14 >>> 0) {
  i9 = i11 + 8 | 0;
  i1 = HEAP32[i9 >> 2] | 0;
  i6 = i1 << 5;
  i12 = i14 - i13 | 0;
  if (i6 >>> 0 < i12 >>> 0 | i13 >>> 0 > (i6 - i12 | 0) >>> 0) {
   HEAP32[i10 >> 2] = 0;
   i4 = i10 + 4 | 0;
   HEAP32[i4 >> 2] = 0;
   i6 = i10 + 8 | 0;
   HEAP32[i6 >> 2] = 0;
   if ((i14 | 0) < 0) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i11);
   if (i1 << 5 >>> 0 > 1073741822) i1 = 2147483647; else {
    i1 = i1 << 6;
    i19 = i14 + 31 & -32;
    i1 = i1 >>> 0 < i19 >>> 0 ? i19 : i1;
   }
   __ZNSt3__26vectorIbNS_9allocatorIbEEE7reserveEj(i10, i1);
   i20 = HEAP32[i8 >> 2] | 0;
   i1 = HEAP32[i11 >> 2] | 0;
   i21 = HEAP32[i10 >> 2] | 0;
   i19 = i2;
   HEAP32[i19 >> 2] = i1;
   HEAP32[i19 + 4 >> 2] = 0;
   HEAP32[i3 >> 2] = i1 + (i20 >>> 5 << 2);
   HEAP32[i3 + 4 >> 2] = i20 & 31;
   HEAP32[i5 >> 2] = i21;
   HEAP32[i5 + 4 >> 2] = 0;
   HEAP32[i16 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i16 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   HEAP32[i17 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i17 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
   __ZNSt3__214__copy_alignedINS_6vectorIbNS_9allocatorIbEEEELb1EEENS_14__bit_iteratorIT_Lb0EXLi0EEEENS5_IS6_XT0_EXLi0EEEES8_S7_(i7, i16, i17, i5);
   i2 = i7;
   i1 = HEAP32[i2 >> 2] | 0;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
   i19 = HEAP32[i11 >> 2] | 0;
   HEAP32[i11 >> 2] = i21;
   HEAP32[i10 >> 2] = i19;
   i19 = HEAP32[i8 >> 2] | 0;
   HEAP32[i8 >> 2] = i20 + i12;
   HEAP32[i4 >> 2] = i19;
   i19 = HEAP32[i9 >> 2] | 0;
   HEAP32[i9 >> 2] = HEAP32[i6 >> 2];
   HEAP32[i6 >> 2] = i19;
   __ZNSt3__26vectorIbNS_9allocatorIbEEED2Ev(i10);
  } else {
   i1 = (HEAP32[i11 >> 2] | 0) + (i13 >>> 5 << 2) | 0;
   HEAP32[i8 >> 2] = i14;
   i2 = i13 & 31;
  }
  do if ((i13 | 0) != (i14 | 0)) if (i15) {
   HEAP32[i17 >> 2] = i1;
   HEAP32[i17 + 4 >> 2] = i2;
   __ZNSt3__213__fill_n_trueINS_6vectorIbNS_9allocatorIbEEEEEEvNS_14__bit_iteratorIT_Lb0EXLi0EEEENS6_9size_typeE(i17, i12);
   break;
  } else {
   HEAP32[i16 >> 2] = i1;
   HEAP32[i16 + 4 >> 2] = i2;
   __ZNSt3__214__fill_n_falseINS_6vectorIbNS_9allocatorIbEEEEEEvNS_14__bit_iteratorIT_Lb0EXLi0EEEENS6_9size_typeE(i16, i12);
   break;
  } while (0);
 } else HEAP32[i8 >> 2] = i14;
 STACKTOP = i18;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseFunctionERPcPKc(i15, i14, i1) {
 i15 = i15 | 0;
 i14 = i14 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i16 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i9 = i13 + 56 | 0;
 i8 = i13 + 52 | 0;
 i2 = i13 + 16 | 0;
 i1 = i13 + 48 | 0;
 i7 = i13;
 i5 = i13 + 44 | 0;
 i6 = i13 + 40 | 0;
 i10 = i13 + 36 | 0;
 i12 = i13 + 32 | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i2, HEAP32[i14 >> 2] | 0);
 switch (HEAP32[i2 + 12 >> 2] | 0) {
 case 2:
  {
   HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) + (HEAP32[i2 + 8 >> 2] | 0);
   i3 = HEAP32[i2 >> 2] | 0;
   break;
  }
 case 6:
  {
   if ((HEAP8[HEAP32[i2 >> 2] >> 0] | 0) == 40) {
    HEAP32[i2 >> 2] = 0;
    i3 = 0;
   } else i16 = 4;
   break;
  }
 default:
  i16 = 4;
 }
 if ((i16 | 0) == 4) ___assert_fail(31272, 31173, 403, 21932);
 HEAP32[i1 >> 2] = i3;
 HEAP32[i9 >> 2] = HEAP32[i1 >> 2];
 i4 = __ZN6cashew12ValueBuilder12makeFunctionENS_7IStringE(i9) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
 i1 = HEAP32[i14 >> 2] | 0;
 if ((HEAP8[i1 >> 0] | 0) != 40) ___assert_fail(31317, 31173, 408, 21932);
 HEAP32[i14 >> 2] = i1 + 1;
 i2 = i7 + 12 | 0;
 i3 = i7 + 8 | 0;
 L11 : while (1) {
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
  i1 = HEAP32[i14 >> 2] | 0;
  if ((HEAP8[i1 >> 0] | 0) == 41) {
   i11 = i1;
   break;
  }
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i7, i1);
  if ((HEAP32[i2 >> 2] | 0) != 2) {
   i16 = 11;
   break;
  }
  HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) + (HEAP32[i3 >> 2] | 0);
  HEAP32[i5 >> 2] = i4;
  HEAP32[i6 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i8 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i9 >> 2] = HEAP32[i6 >> 2];
  __ZN6cashew12ValueBuilder24appendArgumentToFunctionENS_3RefENS_7IStringE(i8, i9);
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
  i1 = HEAP32[i14 >> 2] | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 41:
   {
    i16 = 15;
    break L11;
   }
  case 44:
   break;
  default:
   {
    i16 = 14;
    break L11;
   }
  }
  HEAP32[i14 >> 2] = i1 + 1;
 }
 if ((i16 | 0) == 11) ___assert_fail(31329, 31173, 414, 21932); else if ((i16 | 0) == 14) _abort(); else if ((i16 | 0) == 15) i11 = i1;
 HEAP32[i14 >> 2] = i11 + 1;
 HEAP32[i10 >> 2] = i4;
 i16 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseBracketedBlockERPc(i15, i14) | 0;
 HEAP32[i12 >> 2] = i16;
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i12 >> 2];
 __ZN6cashew12ValueBuilder15setBlockContentENS_3RefES1_(i8, i9);
 STACKTOP = i13;
 return i4 | 0;
}

function __ZNKSt3__27codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_(i4, i7, i1, i10, i14, i2, i9, i13) {
 i4 = i4 | 0;
 i7 = i7 | 0;
 i1 = i1 | 0;
 i10 = i10 | 0;
 i14 = i14 | 0;
 i2 = i2 | 0;
 i9 = i9 | 0;
 i13 = i13 | 0;
 var i3 = 0, i5 = 0, i6 = 0, i8 = 0, i11 = 0, i12 = 0, i15 = 0, i16 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i12 = i15;
 i8 = i15 + 8 | 0;
 i3 = i1;
 while (1) {
  if ((i3 | 0) == (i10 | 0)) {
   i3 = i10;
   break;
  }
  if (!(HEAP32[i3 >> 2] | 0)) break;
  i3 = i3 + 4 | 0;
 }
 HEAP32[i13 >> 2] = i2;
 HEAP32[i14 >> 2] = i1;
 i6 = i9;
 i11 = i4 + 8 | 0;
 L6 : while (1) {
  if ((i2 | 0) == (i9 | 0) | (i1 | 0) == (i10 | 0)) {
   i3 = 35;
   break;
  }
  i16 = i7;
  i5 = HEAP32[i16 + 4 >> 2] | 0;
  i4 = i12;
  HEAP32[i4 >> 2] = HEAP32[i16 >> 2];
  HEAP32[i4 + 4 >> 2] = i5;
  i4 = _uselocale(HEAP32[i11 >> 2] | 0) | 0;
  i5 = _wcsnrtombs(i2, i14, i3 - i1 >> 2, i6 - i2 | 0, i7) | 0;
  if (i4 | 0) _uselocale(i4) | 0;
  switch (i5 | 0) {
  case -1:
   {
    i3 = 10;
    break L6;
   }
  case 0:
   {
    i1 = 1;
    i3 = 32;
    break L6;
   }
  default:
   {}
  }
  i2 = (HEAP32[i13 >> 2] | 0) + i5 | 0;
  HEAP32[i13 >> 2] = i2;
  if ((i2 | 0) == (i9 | 0)) {
   i3 = 33;
   break;
  }
  if ((i3 | 0) == (i10 | 0)) {
   i1 = HEAP32[i14 >> 2] | 0;
   i3 = i10;
  } else {
   i1 = _uselocale(HEAP32[i11 >> 2] | 0) | 0;
   i2 = _wcrtomb(i8, 0, i7) | 0;
   if (i1 | 0) _uselocale(i1) | 0;
   if ((i2 | 0) == -1) {
    i1 = 2;
    i3 = 31;
    break;
   }
   if (i2 >>> 0 > (i6 - (HEAP32[i13 >> 2] | 0) | 0) >>> 0) {
    i1 = 1;
    i3 = 31;
    break;
   } else i1 = i8;
   while (1) {
    if (!i2) break;
    i5 = HEAP8[i1 >> 0] | 0;
    i16 = HEAP32[i13 >> 2] | 0;
    HEAP32[i13 >> 2] = i16 + 1;
    HEAP8[i16 >> 0] = i5;
    i2 = i2 + -1 | 0;
    i1 = i1 + 1 | 0;
   }
   i1 = (HEAP32[i14 >> 2] | 0) + 4 | 0;
   HEAP32[i14 >> 2] = i1;
   i3 = i1;
   while (1) {
    if ((i3 | 0) == (i10 | 0)) {
     i3 = i10;
     break;
    }
    if (!(HEAP32[i3 >> 2] | 0)) break;
    i3 = i3 + 4 | 0;
   }
   i2 = HEAP32[i13 >> 2] | 0;
  }
 }
 if ((i3 | 0) == 10) {
  HEAP32[i13 >> 2] = i2;
  while (1) {
   if ((i1 | 0) == (HEAP32[i14 >> 2] | 0)) break;
   i16 = HEAP32[i1 >> 2] | 0;
   i3 = _uselocale(HEAP32[i11 >> 2] | 0) | 0;
   i2 = _wcrtomb(i2, i16, i12) | 0;
   if (i3 | 0) _uselocale(i3) | 0;
   if ((i2 | 0) == -1) break;
   i2 = (HEAP32[i13 >> 2] | 0) + i2 | 0;
   HEAP32[i13 >> 2] = i2;
   i1 = i1 + 4 | 0;
  }
  HEAP32[i14 >> 2] = i1;
  i1 = 2;
  i3 = 32;
 } else if ((i3 | 0) == 31) i3 = 32; else if ((i3 | 0) == 33) {
  i1 = HEAP32[i14 >> 2] | 0;
  i3 = 35;
 }
 if ((i3 | 0) != 32) if ((i3 | 0) == 35) i1 = (i1 | 0) != (i10 | 0) & 1;
 STACKTOP = i15;
 return i1 | 0;
}

function __ZNKSt3__27codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_(i4, i8, i1, i13, i14, i2, i9, i12) {
 i4 = i4 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i13 = i13 | 0;
 i14 = i14 | 0;
 i2 = i2 | 0;
 i9 = i9 | 0;
 i12 = i12 | 0;
 var i3 = 0, i5 = 0, i6 = 0, i7 = 0, i10 = 0, i11 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i11 = i15;
 i3 = i1;
 while (1) {
  if ((i3 | 0) == (i13 | 0)) {
   i3 = i13;
   break;
  }
  if (!(HEAP8[i3 >> 0] | 0)) break;
  i3 = i3 + 1 | 0;
 }
 HEAP32[i12 >> 2] = i2;
 HEAP32[i14 >> 2] = i1;
 i7 = i9;
 i10 = i4 + 8 | 0;
 while (1) {
  if ((i2 | 0) == (i9 | 0) | (i1 | 0) == (i13 | 0)) {
   i3 = 34;
   break;
  }
  i6 = i8;
  i5 = HEAP32[i6 + 4 >> 2] | 0;
  i4 = i11;
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i4 + 4 >> 2] = i5;
  i4 = i3;
  i5 = _uselocale(HEAP32[i10 >> 2] | 0) | 0;
  i6 = _mbsnrtowcs(i2, i14, i4 - i1 | 0, i7 - i2 >> 2, i8) | 0;
  if (i5 | 0) _uselocale(i5) | 0;
  if ((i6 | 0) == -1) {
   i3 = 10;
   break;
  }
  i2 = (HEAP32[i12 >> 2] | 0) + (i6 << 2) | 0;
  HEAP32[i12 >> 2] = i2;
  if ((i2 | 0) == (i9 | 0)) {
   i3 = 31;
   break;
  }
  i1 = HEAP32[i14 >> 2] | 0;
  if ((i3 | 0) == (i13 | 0)) i3 = i13; else {
   i3 = _uselocale(HEAP32[i10 >> 2] | 0) | 0;
   i1 = _mbrtowc(i2, i1, 1, i8) | 0;
   if (i3 | 0) _uselocale(i3) | 0;
   if (i1 | 0) {
    i1 = 2;
    i3 = 30;
    break;
   }
   HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) + 4;
   i1 = (HEAP32[i14 >> 2] | 0) + 1 | 0;
   HEAP32[i14 >> 2] = i1;
   i3 = i1;
   while (1) {
    if ((i3 | 0) == (i13 | 0)) {
     i3 = i13;
     break;
    }
    if (!(HEAP8[i3 >> 0] | 0)) break;
    i3 = i3 + 1 | 0;
   }
   i2 = HEAP32[i12 >> 2] | 0;
  }
 }
 do if ((i3 | 0) == 10) {
  L29 : while (1) {
   HEAP32[i12 >> 2] = i2;
   if ((i1 | 0) == (HEAP32[i14 >> 2] | 0)) {
    i3 = 20;
    break;
   }
   i3 = _uselocale(HEAP32[i10 >> 2] | 0) | 0;
   i2 = _mbrtowc(i2, i1, i4 - i1 | 0, i11) | 0;
   if (i3 | 0) _uselocale(i3) | 0;
   switch (i2 | 0) {
   case -1:
    {
     i3 = 16;
     break L29;
    }
   case -2:
    {
     i3 = 17;
     break L29;
    }
   case 0:
    {
     i1 = i1 + 1 | 0;
     break;
    }
   default:
    i1 = i1 + i2 | 0;
   }
   i2 = (HEAP32[i12 >> 2] | 0) + 4 | 0;
  }
  if ((i3 | 0) == 16) {
   HEAP32[i14 >> 2] = i1;
   i1 = 2;
   i3 = 30;
   break;
  } else if ((i3 | 0) == 17) {
   HEAP32[i14 >> 2] = i1;
   i1 = 1;
   i3 = 30;
   break;
  } else if ((i3 | 0) == 20) {
   HEAP32[i14 >> 2] = i1;
   i1 = (i1 | 0) != (i13 | 0) & 1;
   i3 = 30;
   break;
  }
 } else if ((i3 | 0) == 31) {
  i1 = HEAP32[i14 >> 2] | 0;
  i3 = 34;
 } while (0);
 if ((i3 | 0) != 30) if ((i3 | 0) == 34) i1 = (i1 | 0) != (i13 | 0) & 1;
 STACKTOP = i15;
 return i1 | 0;
}

function __ZN4wasm17WasmBinaryBuilder22readFunctionSignaturesEv(i11) {
 i11 = i11 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i12 + 4 | 0;
 i2 = i12;
 i4 = i11 + 12 | 0;
 if (HEAP8[i4 >> 0] | 0) {
  i10 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23725) | 0;
  i9 = __ZNKSt3__28ios_base6getlocEv(i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i9;
  i9 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i9 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i9 >> 2] | 0) + 28 >> 2] & 63](i9, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i10, i9) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i10) | 0;
 }
 i3 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i11) | 0;
 if (HEAP8[i4 >> 0] | 0) {
  i10 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23493) | 0, i3) | 0;
  i9 = __ZNKSt3__28ios_base6getlocEv(i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i9;
  i9 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i9 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i9 >> 2] | 0) + 28 >> 2] & 63](i9, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i10, i9) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i10) | 0;
 }
 i5 = i11 + 28 | 0;
 i6 = i11 + 32 | 0;
 i7 = i11 + 24 | 0;
 i10 = 0;
 while (1) {
  if (i10 >>> 0 >= i3 >>> 0) break;
  if (HEAP8[i4 >> 0] | 0) {
   i9 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23499) | 0;
   i8 = __ZNKSt3__28ios_base6getlocEv(i9 + (HEAP32[(HEAP32[i9 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i1 >> 2] = i8;
   i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
   i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i8 >> 2] | 0) + 28 >> 2] & 63](i8, 10) | 0;
   __ZNSt3__26localeD2Ev(i1);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i9, i8) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i9) | 0;
  }
  i8 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i11) | 0;
  i8 = __ZN4wasm6Module15getFunctionTypeEj(HEAP32[i11 >> 2] | 0, i8) | 0;
  HEAP32[i2 >> 2] = i8;
  i9 = HEAP32[i5 >> 2] | 0;
  if (i9 >>> 0 < (HEAP32[i6 >> 2] | 0) >>> 0) {
   HEAP32[i9 >> 2] = i8;
   HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
  } else __ZNSt3__26vectorIPN4wasm12FunctionTypeENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i7, i2);
  i10 = i10 + 1 | 0;
 }
 STACKTOP = i12;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE11doEndSwitchEPS1_PPNS_10ExpressionE(i14, i12) {
 i14 = i14 | 0;
 i12 = i12 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i15 + 16 | 0;
 i13 = i15 + 4 | 0;
 i9 = i15;
 i5 = __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i12 >> 2] | 0) | 0;
 HEAP32[i13 + 4 >> 2] = 0;
 HEAP32[i13 + 8 >> 2] = 0;
 HEAP32[i13 >> 2] = i13 + 4;
 i6 = i5 + 8 | 0;
 i7 = HEAP32[i5 + 16 >> 2] | 0;
 i10 = i14 + 64 | 0;
 i11 = i14 + 60 | 0;
 i8 = 0;
 while (1) {
  if ((i8 | 0) == (i7 | 0)) break;
  i4 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i6, i8) | 0;
  HEAP32[i9 >> 2] = HEAP32[i4 >> 2];
  if (!(__ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(i13, i9) | 0)) {
   i2 = __ZNSt3__23mapIN4wasm4NameENS_6vectorIPNS1_9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS5_vEENS1_8LivenessEE10BasicBlockENS_9allocatorISB_EEEENS_4lessIS2_EENSC_INS_4pairIKS2_SE_EEEEEixERSI_(i10, i9) | 0;
   i3 = i2 + 4 | 0;
   i4 = HEAP32[i3 >> 2] | 0;
   if ((i4 | 0) == (HEAP32[i2 + 8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE21__push_back_slow_pathIRKS9_EEvOT_(i2, i11); else {
    HEAP32[i4 >> 2] = HEAP32[i11 >> 2];
    HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 4;
   }
   __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i1, i13, i9, i9);
  }
  i8 = i8 + 1 | 0;
 }
 i1 = i5 + 24 | 0;
 do if (!(__ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(i13, i1) | 0)) {
  i1 = __ZNSt3__23mapIN4wasm4NameENS_6vectorIPNS1_9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS5_vEENS1_8LivenessEE10BasicBlockENS_9allocatorISB_EEEENS_4lessIS2_EENSC_INS_4pairIKS2_SE_EEEEEixERSI_(i10, i1) | 0;
  i2 = i1 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i1 + 8 >> 2] | 0)) {
   __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE21__push_back_slow_pathIRKS9_EEvOT_(i1, i11);
   break;
  } else {
   HEAP32[i3 >> 2] = HEAP32[i11 >> 2];
   HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
   break;
  }
 } while (0);
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i14, i12);
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEED2Ev(i13);
 STACKTOP = i15;
 return;
}

function __ZN4wasm17WasmBinaryBuilder15visitCallImportEPNS_10CallImportE(i10, i9) {
 i10 = i10 | 0;
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i11 = 0, i12 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i11 + 12 | 0;
 i1 = i11 + 8 | 0;
 i3 = i11 + 4 | 0;
 i5 = i11;
 i6 = i10 + 12 | 0;
 if (HEAP8[i6 >> 0] | 0) {
  i8 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24336) | 0;
  i7 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i2 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
  i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
  __ZNSt3__26localeD2Ev(i2);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i7) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
 }
 i8 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i10) | 0;
 i4 = i9 + 24 | 0;
 i7 = HEAP32[i10 >> 2] | 0;
 i12 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i10) | 0;
 i12 = HEAP32[HEAP32[(HEAP32[i7 + 12 >> 2] | 0) + (i12 << 2) >> 2] >> 2] | 0;
 HEAP32[i4 >> 2] = i12;
 i7 = HEAP32[i10 >> 2] | 0;
 HEAP32[i1 >> 2] = i12;
 HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
 i7 = (__ZN4wasm6Module9getImportENS_4NameE(i7, i2) | 0) + 12 | 0;
 i7 = HEAP32[i7 >> 2] | 0;
 if (!i7) ___assert_fail(49146, 22948, 1822, 24356);
 if (((HEAP32[i7 + 12 >> 2] | 0) - (HEAP32[i7 + 8 >> 2] | 0) >> 2 | 0) != (i8 | 0)) ___assert_fail(24313, 22948, 1824, 24356);
 if (HEAP8[i6 >> 0] | 0) {
  i12 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24372) | 0;
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  i12 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i12, i2) | 0, 24393) | 0;
  HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i5 >> 2];
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i12, i2) | 0, 24405) | 0, i8) | 0, 24411) | 0;
 }
 i1 = i9 + 8 | 0;
 __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i1, i8);
 i2 = i8 + -1 | 0;
 i3 = 0;
 while (1) {
  if ((i3 | 0) == (i8 | 0)) break;
  i6 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i10) | 0;
  i12 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i2 - i3 | 0) | 0;
  HEAP32[i12 >> 2] = i6;
  i3 = i3 + 1 | 0;
 }
 HEAP32[i9 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
 STACKTOP = i11;
 return;
}

function __ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw(i4, i9, i12, i7, i10, i2, i3, i8, i13, i14, i11, i5) {
 i4 = i4 | 0;
 i9 = i9 | 0;
 i12 = i12 | 0;
 i7 = i7 | 0;
 i10 = i10 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i8 = i8 | 0;
 i13 = i13 | 0;
 i14 = i14 | 0;
 i11 = i11 | 0;
 i5 = i5 | 0;
 var i1 = 0, i6 = 0;
 L1 : do if ((i4 | 0) == (i2 | 0)) if (HEAP8[i9 >> 0] | 0) {
  HEAP8[i9 >> 0] = 0;
  i12 = HEAP32[i10 >> 2] | 0;
  HEAP32[i10 >> 2] = i12 + 1;
  HEAP8[i12 >> 0] = 46;
  i12 = HEAP8[i8 + 11 >> 0] | 0;
  if (((i12 << 24 >> 24 < 0 ? HEAP32[i8 + 4 >> 2] | 0 : i12 & 255) | 0) != 0 ? (i1 = HEAP32[i14 >> 2] | 0, (i1 - i13 | 0) < 160) : 0) {
   i13 = HEAP32[i11 >> 2] | 0;
   HEAP32[i14 >> 2] = i1 + 4;
   HEAP32[i1 >> 2] = i13;
   i1 = 0;
  } else i1 = 0;
 } else i1 = -1; else {
  if ((i4 | 0) == (i3 | 0) ? (i3 = HEAP8[i8 + 11 >> 0] | 0, (i3 << 24 >> 24 < 0 ? HEAP32[i8 + 4 >> 2] | 0 : i3 & 255) | 0) : 0) {
   if (!(HEAP8[i9 >> 0] | 0)) {
    i1 = -1;
    break;
   }
   i1 = HEAP32[i14 >> 2] | 0;
   if ((i1 - i13 | 0) >= 160) {
    i1 = 0;
    break;
   }
   i13 = HEAP32[i11 >> 2] | 0;
   HEAP32[i14 >> 2] = i1 + 4;
   HEAP32[i1 >> 2] = i13;
   HEAP32[i11 >> 2] = 0;
   i1 = 0;
   break;
  }
  i2 = i5 + 128 | 0;
  i1 = i5;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) {
    i1 = i2;
    break;
   }
   if ((HEAP32[i1 >> 2] | 0) == (i4 | 0)) break;
   i1 = i1 + 4 | 0;
  }
  i2 = i1 - i5 | 0;
  i1 = i2 >> 2;
  if ((i2 | 0) <= 124) {
   i3 = HEAP8[53246 + i1 >> 0] | 0;
   switch (i1 | 0) {
   case 24:
   case 25:
    {
     i1 = HEAP32[i10 >> 2] | 0;
     if ((i1 | 0) != (i7 | 0) ? (HEAPU8[i1 + -1 >> 0] & 95 | 0) != (HEAPU8[i12 >> 0] & 127 | 0) : 0) {
      i1 = -1;
      break L1;
     }
     HEAP32[i10 >> 2] = i1 + 1;
     HEAP8[i1 >> 0] = i3;
     i1 = 0;
     break L1;
    }
   case 23:
   case 22:
    {
     HEAP8[i12 >> 0] = 80;
     break;
    }
   default:
    {
     i1 = i3 & 95;
     if ((((i1 | 0) == (HEAP8[i12 >> 0] | 0) ? (HEAP8[i12 >> 0] = i1 | 128, HEAP8[i9 >> 0] | 0) : 0) ? (HEAP8[i9 >> 0] = 0, i12 = HEAP8[i8 + 11 >> 0] | 0, (i12 << 24 >> 24 < 0 ? HEAP32[i8 + 4 >> 2] | 0 : i12 & 255) | 0) : 0) ? (i6 = HEAP32[i14 >> 2] | 0, (i6 - i13 | 0) < 160) : 0) {
      i13 = HEAP32[i11 >> 2] | 0;
      HEAP32[i14 >> 2] = i6 + 4;
      HEAP32[i6 >> 2] = i13;
     }
    }
   }
   i14 = HEAP32[i10 >> 2] | 0;
   HEAP32[i10 >> 2] = i14 + 1;
   HEAP8[i14 >> 0] = i3;
   if ((i2 | 0) > 84) i1 = 0; else {
    HEAP32[i11 >> 2] = (HEAP32[i11 >> 2] | 0) + 1;
    i1 = 0;
   }
  } else i1 = -1;
 } while (0);
 return i1 | 0;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE(i1, i5, i6, i7, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i8 = 0;
 L1 : while (1) {
  i1 = HEAP32[i5 >> 2] | 0;
  do if (i1) {
   i2 = HEAP32[i1 + 12 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
   if ((i1 | 0) == -1) {
    HEAP32[i5 >> 2] = 0;
    i3 = 1;
    break;
   } else {
    i3 = (HEAP32[i5 >> 2] | 0) == 0;
    break;
   }
  } else i3 = 1; while (0);
  i2 = HEAP32[i6 >> 2] | 0;
  do if (i2) {
   i1 = HEAP32[i2 + 12 >> 2] | 0;
   if ((i1 | 0) == (HEAP32[i2 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i1 = HEAP32[i1 >> 2] | 0;
   if ((i1 | 0) != -1) if (i3) {
    i3 = i2;
    break;
   } else {
    i3 = i2;
    break L1;
   } else {
    HEAP32[i6 >> 2] = 0;
    i8 = 15;
    break;
   }
  } else i8 = 15; while (0);
  if ((i8 | 0) == 15) {
   i8 = 0;
   if (i3) {
    i3 = 0;
    break;
   } else i3 = 0;
  }
  i1 = HEAP32[i5 >> 2] | 0;
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
  if (!(FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i4 >> 2] | 0) + 12 >> 2] & 31](i4, 8192, i1) | 0)) break;
  i1 = HEAP32[i5 >> 2] | 0;
  i2 = i1 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i2 >> 2] = i3 + 4;
   continue;
  }
 }
 i1 = HEAP32[i5 >> 2] | 0;
 do if (i1) {
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   HEAP32[i5 >> 2] = 0;
   i2 = 1;
   break;
  } else {
   i2 = (HEAP32[i5 >> 2] | 0) == 0;
   break;
  }
 } else i2 = 1; while (0);
 do if (i3) {
  i1 = HEAP32[i3 + 12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 255](i3) | 0; else i1 = HEAP32[i1 >> 2] | 0;
  if ((i1 | 0) != -1) if (i2) break; else {
   i8 = 39;
   break;
  } else {
   HEAP32[i6 >> 2] = 0;
   i8 = 37;
   break;
  }
 } else i8 = 37; while (0);
 if ((i8 | 0) == 37 ? i2 : 0) i8 = 39;
 if ((i8 | 0) == 39) HEAP32[i7 >> 2] = HEAP32[i7 >> 2] | 2;
 return;
}

function __ZN4wasm7Builder12makeFunctionENS_4NameEONSt3__26vectorINS_8NameTypeENS2_9allocatorIS4_EEEENS_8WasmTypeES8_PNS_10ExpressionE(i1, i5, i8, i6, i9, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i8 = i8 | 0;
 i6 = i6 | 0;
 i9 = i9 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i7 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0;
 i10 = __Znwj(64) | 0;
 i11 = i10 + 40 | 0;
 HEAP32[i11 >> 2] = 0;
 i12 = i10 + 44 | 0;
 HEAP32[i12 >> 2] = 0;
 i13 = i10 + 48 | 0;
 HEAP32[i13 >> 2] = 0;
 i14 = i10 + 52 | 0;
 i1 = i10 + 56 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i10 + 60 >> 2] = 0;
 i2 = i10;
 i3 = i2 + 36 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 HEAP32[i14 >> 2] = i1;
 HEAP32[i10 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i10 + 4 >> 2] = i6;
 HEAP32[i10 + 36 >> 2] = i4;
 i4 = HEAP32[i8 + 4 >> 2] | 0;
 i5 = i10 + 12 | 0;
 i6 = i10 + 16 | 0;
 i7 = i10 + 8 | 0;
 i3 = HEAP32[i8 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i4 | 0)) break;
  i1 = i3 + 4 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i7, i1); else {
   HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i5 >> 2] = i2 + 4;
  }
  i8 = (HEAP32[i12 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2;
  i1 = __ZNSt3__23mapIN4wasm4NameEjNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_jEEEEEixERS7_(i14, i3) | 0;
  HEAP32[i1 >> 2] = i8;
  i1 = HEAP32[i12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i13 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i11, i3); else {
   HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) + 4;
  }
  i3 = i3 + 8 | 0;
 }
 i4 = HEAP32[i9 + 4 >> 2] | 0;
 i5 = i10 + 24 | 0;
 i6 = i10 + 28 | 0;
 i7 = i10 + 20 | 0;
 i3 = HEAP32[i9 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i4 | 0)) break;
  i1 = i3 + 4 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i6 >> 2] | 0)) __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i7, i1); else {
   HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i5 >> 2] = i2 + 4;
  }
  i9 = (HEAP32[i12 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2;
  i1 = __ZNSt3__23mapIN4wasm4NameEjNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_jEEEEEixERS7_(i14, i3) | 0;
  HEAP32[i1 >> 2] = i9;
  i1 = HEAP32[i12 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i13 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i11, i3); else {
   HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) + 4;
  }
  i3 = i3 + 8 | 0;
 }
 return i10 | 0;
}

function __ZN4wasm17SExpressionParser11parseStringEv(i8) {
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i9 + 8 | 0;
 i3 = i9 + 4 | 0;
 i4 = i9;
 i2 = HEAP32[i8 >> 2] | 0;
 i1 = HEAP8[i2 >> 0] | 0;
 if (i1 << 24 >> 24 == 36) {
  i6 = i2 + 1 | 0;
  HEAP32[i8 >> 2] = i6;
  i1 = HEAP8[i6 >> 0] | 0;
  i7 = 1;
 } else {
  i6 = i2;
  i7 = 0;
 }
 if (i1 << 24 >> 24 == 34) {
  i1 = i6 + 1 | 0;
  HEAP32[i8 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
  HEAP32[i5 + 4 >> 2] = 0;
  HEAP32[i5 + 8 >> 2] = 0;
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i5 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  L9 : while (1) {
   i2 = HEAP8[i1 >> 0] | 0;
   switch (i2 << 24 >> 24) {
   case 34:
    break L9;
   case 92:
    {
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i5, 92);
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i5, HEAP8[(HEAP32[i8 >> 2] | 0) + 1 >> 0] | 0);
     i1 = (HEAP32[i8 >> 2] | 0) + 2 | 0;
     break;
    }
   default:
    {
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i5, i2);
     i1 = (HEAP32[i8 >> 2] | 0) + 1 | 0;
    }
   }
   HEAP32[i8 >> 2] = i1;
  }
  HEAP32[i8 >> 2] = i1 + 1;
  i1 = __ZN10MixedArena5allocIN4wasm7ElementEEEPT_v(i8 + 12 | 0) | 0;
  __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i5 + 11 >> 0] | 0) < 0 ? HEAP32[i5 >> 2] | 0 : i5, 0);
  i4 = HEAP32[i3 >> 2] | 0;
  HEAP8[i1 >> 0] = 0;
  HEAP32[i1 + 20 >> 2] = i4;
  HEAP8[i1 + 24 >> 0] = i7;
  i7 = i6 - (HEAP32[i8 + 8 >> 2] | 0) | 0;
  HEAP32[i1 + 28 >> 2] = HEAP32[i8 + 4 >> 2];
  HEAP32[i1 + 32 >> 2] = i7;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
 } else {
  i2 = i6;
  L16 : while (1) {
   if (!(i1 << 24 >> 24)) {
    i1 = i2;
    i2 = 0;
    break;
   }
   i5 = (_isspace(i1 << 24 >> 24) | 0) == 0;
   i1 = HEAP32[i8 >> 2] | 0;
   i2 = HEAP8[i1 >> 0] | 0;
   if (!i5) break;
   switch (i2 << 24 >> 24) {
   case 59:
   case 40:
   case 41:
    break L16;
   default:
    {}
   }
   i2 = i1 + 1 | 0;
   HEAP32[i8 >> 2] = i2;
   i1 = HEAP8[i2 >> 0] | 0;
  }
  HEAP8[i1 >> 0] = 0;
  i1 = __ZN10MixedArena5allocIN4wasm7ElementEEEPT_v(i8 + 12 | 0) | 0;
  __ZN6cashew7IStringC2EPKcb(i4, i6, 0);
  i5 = HEAP32[i4 >> 2] | 0;
  HEAP8[i1 >> 0] = 0;
  HEAP32[i1 + 20 >> 2] = i5;
  HEAP8[i1 + 24 >> 0] = i7;
  i7 = i6 - (HEAP32[i8 + 8 >> 2] | 0) | 0;
  HEAP32[i1 + 28 >> 2] = HEAP32[i8 + 4 >> 2];
  HEAP32[i1 + 32 >> 2] = i7;
  HEAP8[HEAP32[i8 >> 2] >> 0] = i2;
 }
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe(i1, i20, i18, i17, d8) {
 i1 = i1 | 0;
 i20 = i20 | 0;
 i18 = i18 | 0;
 i17 = i17 | 0;
 d8 = +d8;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i19 = 0;
 i19 = STACKTOP;
 STACKTOP = STACKTOP + 352 | 0;
 i12 = i19 + 304 | 0;
 i7 = i19 + 48 | 0;
 i6 = i19 + 32 | 0;
 i3 = i19 + 24 | 0;
 i2 = i19 + 8 | 0;
 i5 = i19;
 i9 = i19 + 308 | 0;
 i10 = i19 + 300 | 0;
 i11 = i19 + 72 | 0;
 i16 = i19 + 68 | 0;
 i15 = i19 + 64 | 0;
 i13 = i19 + 60 | 0;
 i14 = i19 + 56 | 0;
 i4 = i5;
 HEAP32[i4 >> 2] = 37;
 HEAP32[i4 + 4 >> 2] = 0;
 i4 = __ZNSt3__214__num_put_base14__format_floatEPcPKcj(i5 + 1 | 0, 53495, HEAP32[i18 + 4 >> 2] | 0) | 0;
 HEAP32[i10 >> 2] = i9;
 i1 = __ZNSt3__26__clocEv() | 0;
 if (i4) {
  HEAP32[i2 >> 2] = HEAP32[i18 + 8 >> 2];
  HEAPF64[i2 + 8 >> 3] = d8;
  i2 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i9, 30, i1, i5, i2) | 0;
 } else {
  HEAPF64[i3 >> 3] = d8;
  i2 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i9, 30, i1, i5, i3) | 0;
 }
 if ((i2 | 0) > 29) {
  i1 = __ZNSt3__26__clocEv() | 0;
  if (i4) {
   HEAP32[i6 >> 2] = HEAP32[i18 + 8 >> 2];
   HEAPF64[i6 + 8 >> 3] = d8;
   i2 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i10, i1, i5, i6) | 0;
  } else {
   HEAPF64[i7 >> 3] = d8;
   i2 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i10, i1, i5, i7) | 0;
  }
  i1 = HEAP32[i10 >> 2] | 0;
  if (!i1) {
   i6 = HEAP32[i10 >> 2] | 0;
   i3 = i6;
  } else {
   i3 = i1;
   i6 = i1;
  }
 } else {
  i3 = HEAP32[i10 >> 2] | 0;
  i6 = 0;
 }
 i4 = i3 + i2 | 0;
 i5 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i3, i4, i18) | 0;
 if ((i3 | 0) != (i9 | 0)) {
  i2 = _malloc(i2 << 3) | 0;
  if (!i2) {
   i3 = HEAP32[i10 >> 2] | 0;
   i1 = i2;
  } else i1 = i2;
 } else {
  i3 = i9;
  i1 = i11;
  i2 = 0;
 }
 i11 = __ZNKSt3__28ios_base6getlocEv(i18) | 0;
 HEAP32[i13 >> 2] = i11;
 __ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE(i3, i5, i4, i1, i16, i15, i13);
 __ZNSt3__214__shared_count16__release_sharedEv(i11) | 0;
 HEAP32[i14 >> 2] = HEAP32[i20 >> 2];
 i13 = HEAP32[i16 >> 2] | 0;
 i16 = HEAP32[i15 >> 2] | 0;
 HEAP32[i12 >> 2] = HEAP32[i14 >> 2];
 i1 = __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i12, i1, i13, i16, i18, i17) | 0;
 HEAP32[i20 >> 2] = i1;
 if (i2 | 0) _free(i2);
 _free(i6);
 STACKTOP = i19;
 return i1 | 0;
}

function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd(i1, i20, i18, i17, d8) {
 i1 = i1 | 0;
 i20 = i20 | 0;
 i18 = i18 | 0;
 i17 = i17 | 0;
 d8 = +d8;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i19 = 0;
 i19 = STACKTOP;
 STACKTOP = STACKTOP + 352 | 0;
 i12 = i19 + 304 | 0;
 i7 = i19 + 48 | 0;
 i6 = i19 + 32 | 0;
 i3 = i19 + 24 | 0;
 i2 = i19 + 8 | 0;
 i5 = i19;
 i9 = i19 + 308 | 0;
 i10 = i19 + 300 | 0;
 i11 = i19 + 72 | 0;
 i16 = i19 + 68 | 0;
 i15 = i19 + 64 | 0;
 i13 = i19 + 60 | 0;
 i14 = i19 + 56 | 0;
 i4 = i5;
 HEAP32[i4 >> 2] = 37;
 HEAP32[i4 + 4 >> 2] = 0;
 i4 = __ZNSt3__214__num_put_base14__format_floatEPcPKcj(i5 + 1 | 0, 67717, HEAP32[i18 + 4 >> 2] | 0) | 0;
 HEAP32[i10 >> 2] = i9;
 i1 = __ZNSt3__26__clocEv() | 0;
 if (i4) {
  HEAP32[i2 >> 2] = HEAP32[i18 + 8 >> 2];
  HEAPF64[i2 + 8 >> 3] = d8;
  i2 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i9, 30, i1, i5, i2) | 0;
 } else {
  HEAPF64[i3 >> 3] = d8;
  i2 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i9, 30, i1, i5, i3) | 0;
 }
 if ((i2 | 0) > 29) {
  i1 = __ZNSt3__26__clocEv() | 0;
  if (i4) {
   HEAP32[i6 >> 2] = HEAP32[i18 + 8 >> 2];
   HEAPF64[i6 + 8 >> 3] = d8;
   i2 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i10, i1, i5, i6) | 0;
  } else {
   HEAPF64[i7 >> 3] = d8;
   i2 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i10, i1, i5, i7) | 0;
  }
  i1 = HEAP32[i10 >> 2] | 0;
  if (!i1) {
   i6 = HEAP32[i10 >> 2] | 0;
   i3 = i6;
  } else {
   i3 = i1;
   i6 = i1;
  }
 } else {
  i3 = HEAP32[i10 >> 2] | 0;
  i6 = 0;
 }
 i4 = i3 + i2 | 0;
 i5 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i3, i4, i18) | 0;
 if ((i3 | 0) != (i9 | 0)) {
  i2 = _malloc(i2 << 3) | 0;
  if (!i2) {
   i3 = HEAP32[i10 >> 2] | 0;
   i1 = i2;
  } else i1 = i2;
 } else {
  i3 = i9;
  i1 = i11;
  i2 = 0;
 }
 i11 = __ZNKSt3__28ios_base6getlocEv(i18) | 0;
 HEAP32[i13 >> 2] = i11;
 __ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE(i3, i5, i4, i1, i16, i15, i13);
 __ZNSt3__214__shared_count16__release_sharedEv(i11) | 0;
 HEAP32[i14 >> 2] = HEAP32[i20 >> 2];
 i13 = HEAP32[i16 >> 2] | 0;
 i16 = HEAP32[i15 >> 2] | 0;
 HEAP32[i12 >> 2] = HEAP32[i14 >> 2];
 i1 = __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i12, i1, i13, i16, i18, i17) | 0;
 HEAP32[i20 >> 2] = i1;
 if (i2 | 0) _free(i2);
 _free(i6);
 STACKTOP = i19;
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder9makeStoreERNS_7ElementENS_8WasmTypeE(i10, i9, i1) {
 i10 = i10 | 0;
 i9 = i9 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i11;
 i3 = _strchr(__ZN4wasm7Element5c_strEv(__ZN4wasm7ElementixEj(i9, 0) | 0) | 0, 46) | 0;
 i8 = __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(HEAP32[i10 + 4 >> 2] | 0) | 0;
 HEAP32[i8 + 4 >> 2] = i1;
 i1 = (__ZN4wasm15getWasmTypeSizeENS_8WasmTypeE(i1) | 0) & 255;
 i2 = i8 + 8 | 0;
 HEAP8[i2 >> 0] = i1;
 L1 : do switch (HEAP8[i3 + 6 >> 0] | 0) {
 case 56:
  {
   HEAP8[i2 >> 0] = 1;
   i4 = 1;
   break;
  }
 case 49:
  {
   if ((HEAP8[i3 + 7 >> 0] | 0) == 54) {
    HEAP8[i2 >> 0] = 2;
    i4 = 2;
    break L1;
   } else ___assert_fail(22370, 21446, 965, 22444);
   break;
  }
 case 51:
  {
   if ((HEAP8[i3 + 7 >> 0] | 0) == 50) {
    HEAP8[i2 >> 0] = 4;
    i4 = 4;
    break L1;
   } else ___assert_fail(22395, 21446, 969, 22444);
   break;
  }
 default:
  i4 = i1;
 } while (0);
 i5 = i8 + 12 | 0;
 HEAP32[i5 >> 2] = 0;
 i6 = i8 + 16 | 0;
 __ZN4wasm7AddressaSEy(i6, i4 & 255, 0) | 0;
 i1 = 1;
 L12 : while (1) {
  i4 = __ZN4wasm7ElementixEj(i9, i1) | 0;
  i4 = (HEAP8[i4 >> 0] | 0) == 0;
  i2 = __ZN4wasm7ElementixEj(i9, i1) | 0;
  if (!i4) {
   i3 = 18;
   break;
  }
  i3 = __ZN4wasm7Element5c_strEv(i2) | 0;
  i2 = _strchr(i3, 61) | 0;
  if (!i2) {
   i3 = 12;
   break;
  }
  i2 = i2 + 1 | 0;
  switch (HEAP8[i3 >> 0] | 0) {
  case 97:
   {
    i4 = _atoi(i2) | 0;
    __ZN4wasm7AddressaSEy(i6, i4, ((i4 | 0) < 0) << 31 >> 31) | 0;
    break;
   }
  case 111:
   {
    i4 = _atoi(i2) | 0;
    __ZN4wasm7AddressaSEy(i5, i4, ((i4 | 0) < 0) << 31 >> 31) | 0;
    break;
   }
  default:
   {
    i3 = 16;
    break L12;
   }
  }
  i1 = i1 + 1 | 0;
 }
 if ((i3 | 0) == 12) ___assert_fail(22411, 21446, 979, 22444); else if ((i3 | 0) == 16) {
  i11 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i7 + 4 >> 2] = 0;
  HEAP32[i7 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i7, 22454, 19);
  __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i11, i7);
  ___cxa_throw(i11 | 0, 64, 279);
 } else if ((i3 | 0) == 18) {
  i7 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i10, i2) | 0;
  HEAP32[i8 + 20 >> 2] = i7;
  i10 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i10, __ZN4wasm7ElementixEj(i9, i1 + 1 | 0) | 0) | 0;
  HEAP32[i8 + 24 >> 2] = i10;
  STACKTOP = i11;
  return i8 | 0;
 }
 return 0;
}

function __ZN4wasm17WasmBinaryBuilder16readDataSegmentsEv(i21) {
 i21 = i21 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0, i20 = 0, i22 = 0;
 i22 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i6 = i22 + 52 | 0;
 i5 = i22 + 48 | 0;
 i7 = i22 + 44 | 0;
 i8 = i22 + 40 | 0;
 i17 = i22 + 24 | 0;
 i19 = i22 + 20 | 0;
 i20 = i22 + 16 | 0;
 i16 = i22;
 i12 = i22 + 12 | 0;
 if (HEAP8[i21 + 12 >> 0] | 0) {
  i18 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25289) | 0;
  i15 = __ZNKSt3__28ios_base6getlocEv(i18 + (HEAP32[(HEAP32[i18 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i6 >> 2] = i15;
  i15 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61680) | 0;
  i15 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i15 >> 2] | 0) + 28 >> 2] & 63](i15, 10) | 0;
  __ZNSt3__26localeD2Ev(i6);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i18, i15) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i18) | 0;
 }
 i9 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i21) | 0;
 i10 = i16 + 4 | 0;
 i11 = i16 + 8 | 0;
 i13 = i17 + 4 | 0;
 i18 = 0;
 while (1) {
  if (i18 >>> 0 >= i9 >>> 0) break;
  HEAP32[i17 >> 2] = 0;
  HEAP32[i17 + 4 >> 2] = 0;
  HEAP32[i17 + 8 >> 2] = 0;
  HEAP32[i17 + 12 >> 2] = 0;
  i14 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i21) | 0;
  HEAP32[i19 >> 2] = i14;
  i15 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i21) | 0;
  HEAP32[i20 >> 2] = i15;
  HEAP32[i16 >> 2] = 0;
  HEAP32[i10 >> 2] = 0;
  HEAP32[i11 >> 2] = 0;
  __ZNSt3__26vectorIcNS_9allocatorIcEEE6resizeEj(i16, i15);
  i1 = 0;
  while (1) {
   if (i1 >>> 0 >= i15 >>> 0) break;
   i4 = __ZN4wasm17WasmBinaryBuilder7getInt8Ev(i21) | 0;
   HEAP8[(HEAP32[i16 >> 2] | 0) + i1 >> 0] = i4;
   i1 = i1 + 1 | 0;
  }
  i1 = HEAP32[i21 >> 2] | 0;
  i2 = HEAP32[i16 >> 2] | 0;
  HEAP32[i12 >> 2] = i2;
  i3 = i1 + 72 | 0;
  i4 = HEAP32[i3 >> 2] | 0;
  if (i4 >>> 0 < (HEAP32[i1 + 76 >> 2] | 0) >>> 0) {
   __ZN4wasm7AddressC2Ey(i7, i14, 0);
   __ZN4wasm7AddressC2Ey(i8, i15, 0);
   HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
   HEAP32[i6 >> 2] = HEAP32[i8 >> 2];
   __ZN4wasm6Memory7SegmentC2ENS_7AddressEPKcS2_(i4, i5, i2, i6);
   HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 16;
  } else __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE24__emplace_back_slow_pathIJRjPKcS8_EEEvDpOT_(i1 + 68 | 0, i19, i12, i20);
  __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i16);
  __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i13);
  i18 = i18 + 1 | 0;
 }
 STACKTOP = i22;
 return;
}

function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce(i1, i20, i19, i18, d8) {
 i1 = i1 | 0;
 i20 = i20 | 0;
 i19 = i19 | 0;
 i18 = i18 | 0;
 d8 = +d8;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 176 | 0;
 i12 = i17 + 76 | 0;
 i7 = i17 + 48 | 0;
 i6 = i17 + 32 | 0;
 i3 = i17 + 24 | 0;
 i2 = i17 + 8 | 0;
 i5 = i17;
 i9 = i17 + 138 | 0;
 i10 = i17 + 72 | 0;
 i11 = i17 + 80 | 0;
 i16 = i17 + 68 | 0;
 i15 = i17 + 64 | 0;
 i13 = i17 + 60 | 0;
 i14 = i17 + 56 | 0;
 i4 = i5;
 HEAP32[i4 >> 2] = 37;
 HEAP32[i4 + 4 >> 2] = 0;
 i4 = __ZNSt3__214__num_put_base14__format_floatEPcPKcj(i5 + 1 | 0, 53495, HEAP32[i19 + 4 >> 2] | 0) | 0;
 HEAP32[i10 >> 2] = i9;
 i1 = __ZNSt3__26__clocEv() | 0;
 if (i4) {
  HEAP32[i2 >> 2] = HEAP32[i19 + 8 >> 2];
  HEAPF64[i2 + 8 >> 3] = d8;
  i2 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i9, 30, i1, i5, i2) | 0;
 } else {
  HEAPF64[i3 >> 3] = d8;
  i2 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i9, 30, i1, i5, i3) | 0;
 }
 if ((i2 | 0) > 29) {
  i1 = __ZNSt3__26__clocEv() | 0;
  if (i4) {
   HEAP32[i6 >> 2] = HEAP32[i19 + 8 >> 2];
   HEAPF64[i6 + 8 >> 3] = d8;
   i2 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i10, i1, i5, i6) | 0;
  } else {
   HEAPF64[i7 >> 3] = d8;
   i2 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i10, i1, i5, i7) | 0;
  }
  i1 = HEAP32[i10 >> 2] | 0;
  if (!i1) {
   i6 = HEAP32[i10 >> 2] | 0;
   i3 = i6;
  } else {
   i3 = i1;
   i6 = i1;
  }
 } else {
  i3 = HEAP32[i10 >> 2] | 0;
  i6 = 0;
 }
 i4 = i3 + i2 | 0;
 i5 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i3, i4, i19) | 0;
 if ((i3 | 0) != (i9 | 0)) {
  i1 = _malloc(i2 << 1) | 0;
  if (!i1) {
   i3 = HEAP32[i10 >> 2] | 0;
   i2 = 0;
   i1 = 0;
  } else i2 = i1;
 } else {
  i3 = i9;
  i2 = i11;
  i1 = 0;
 }
 i11 = __ZNKSt3__28ios_base6getlocEv(i19) | 0;
 HEAP32[i13 >> 2] = i11;
 __ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE(i3, i5, i4, i2, i16, i15, i13);
 __ZNSt3__214__shared_count16__release_sharedEv(i11) | 0;
 HEAP32[i14 >> 2] = HEAP32[i20 >> 2];
 i16 = HEAP32[i16 >> 2] | 0;
 i20 = HEAP32[i15 >> 2] | 0;
 HEAP32[i12 >> 2] = HEAP32[i14 >> 2];
 i20 = __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i12, i2, i16, i20, i19, i18) | 0;
 _free(i1);
 _free(i6);
 STACKTOP = i17;
 return i20 | 0;
}

function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd(i1, i20, i19, i18, d8) {
 i1 = i1 | 0;
 i20 = i20 | 0;
 i19 = i19 | 0;
 i18 = i18 | 0;
 d8 = +d8;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 176 | 0;
 i12 = i17 + 76 | 0;
 i7 = i17 + 48 | 0;
 i6 = i17 + 32 | 0;
 i3 = i17 + 24 | 0;
 i2 = i17 + 8 | 0;
 i5 = i17;
 i9 = i17 + 138 | 0;
 i10 = i17 + 72 | 0;
 i11 = i17 + 80 | 0;
 i16 = i17 + 68 | 0;
 i15 = i17 + 64 | 0;
 i13 = i17 + 60 | 0;
 i14 = i17 + 56 | 0;
 i4 = i5;
 HEAP32[i4 >> 2] = 37;
 HEAP32[i4 + 4 >> 2] = 0;
 i4 = __ZNSt3__214__num_put_base14__format_floatEPcPKcj(i5 + 1 | 0, 67717, HEAP32[i19 + 4 >> 2] | 0) | 0;
 HEAP32[i10 >> 2] = i9;
 i1 = __ZNSt3__26__clocEv() | 0;
 if (i4) {
  HEAP32[i2 >> 2] = HEAP32[i19 + 8 >> 2];
  HEAPF64[i2 + 8 >> 3] = d8;
  i2 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i9, 30, i1, i5, i2) | 0;
 } else {
  HEAPF64[i3 >> 3] = d8;
  i2 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i9, 30, i1, i5, i3) | 0;
 }
 if ((i2 | 0) > 29) {
  i1 = __ZNSt3__26__clocEv() | 0;
  if (i4) {
   HEAP32[i6 >> 2] = HEAP32[i19 + 8 >> 2];
   HEAPF64[i6 + 8 >> 3] = d8;
   i2 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i10, i1, i5, i6) | 0;
  } else {
   HEAPF64[i7 >> 3] = d8;
   i2 = __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i10, i1, i5, i7) | 0;
  }
  i1 = HEAP32[i10 >> 2] | 0;
  if (!i1) {
   i6 = HEAP32[i10 >> 2] | 0;
   i3 = i6;
  } else {
   i3 = i1;
   i6 = i1;
  }
 } else {
  i3 = HEAP32[i10 >> 2] | 0;
  i6 = 0;
 }
 i4 = i3 + i2 | 0;
 i5 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i3, i4, i19) | 0;
 if ((i3 | 0) != (i9 | 0)) {
  i1 = _malloc(i2 << 1) | 0;
  if (!i1) {
   i3 = HEAP32[i10 >> 2] | 0;
   i2 = 0;
   i1 = 0;
  } else i2 = i1;
 } else {
  i3 = i9;
  i2 = i11;
  i1 = 0;
 }
 i11 = __ZNKSt3__28ios_base6getlocEv(i19) | 0;
 HEAP32[i13 >> 2] = i11;
 __ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE(i3, i5, i4, i2, i16, i15, i13);
 __ZNSt3__214__shared_count16__release_sharedEv(i11) | 0;
 HEAP32[i14 >> 2] = HEAP32[i20 >> 2];
 i16 = HEAP32[i16 >> 2] | 0;
 i20 = HEAP32[i15 >> 2] | 0;
 HEAP32[i12 >> 2] = HEAP32[i14 >> 2];
 i20 = __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i12, i2, i16, i20, i19, i18) | 0;
 _free(i1);
 _free(i6);
 STACKTOP = i17;
 return i20 | 0;
}

function __ZNSt3__26vectorINS_10unique_ptrIZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNS0_IjNS_9allocatorIjEEEEE5OrderNS_14default_deleteIS8_EEEENS4_ISB_EEE6resizeEj(i13, i5) {
 i13 = i13 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0;
 i14 = i13 + 4 | 0;
 i4 = HEAP32[i14 >> 2] | 0;
 i11 = HEAP32[i13 >> 2] | 0;
 i2 = i4 - i11 >> 2;
 i3 = i11;
 i1 = i4;
 L1 : do if (i2 >>> 0 < i5 >>> 0) {
  i9 = i5 - i2 | 0;
  i12 = i13 + 8 | 0;
  i1 = HEAP32[i12 >> 2] | 0;
  if (i1 - i4 >> 2 >>> 0 >= i9 >>> 0) {
   _memset(i4 | 0, 0, i9 << 2 | 0) | 0;
   HEAP32[i14 >> 2] = i4 + (i9 << 2);
   break;
  }
  if (i5 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i13);
  i4 = i11;
  i1 = i1 - i11 | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i5 >>> 0 ? i5 : i1;
   i3 = HEAP32[i14 >> 2] | 0;
   i2 = i3 - i11 >> 2;
   if (i1) if (i1 >>> 0 > 1073741823) {
    i14 = ___cxa_allocate_exception(4) | 0;
    __ZNSt9bad_allocC2Ev(i14);
    ___cxa_throw(i14 | 0, 4128, 273);
   } else i10 = 11; else {
    i8 = 0;
    i7 = 0;
    i6 = i2;
    i1 = i3;
   }
  } else {
   i2 = HEAP32[i14 >> 2] | 0;
   i1 = 1073741823;
   i3 = i2;
   i2 = i2 - i11 >> 2;
   i10 = 11;
  }
  if ((i10 | 0) == 11) {
   i8 = i1;
   i7 = __Znwj(i1 << 2) | 0;
   i6 = i2;
   i1 = i3;
  }
  i2 = i7 + (i6 << 2) | 0;
  _memset(i2 | 0, 0, i9 << 2 | 0) | 0;
  i5 = i7 + (i6 + i9 << 2) | 0;
  i3 = (i1 + (0 - i11) | 0) >>> 2;
  while (1) {
   if ((i1 | 0) == (i4 | 0)) break;
   i11 = i2 + -4 | 0;
   i10 = i1 + -4 | 0;
   i9 = HEAP32[i10 >> 2] | 0;
   HEAP32[i10 >> 2] = 0;
   HEAP32[i11 >> 2] = i9;
   i1 = i10;
   i2 = i11;
  }
  i4 = HEAP32[i13 >> 2] | 0;
  HEAP32[i13 >> 2] = i7 + (i6 - i3 << 2);
  i1 = HEAP32[i14 >> 2] | 0;
  HEAP32[i14 >> 2] = i5;
  HEAP32[i12 >> 2] = i7 + (i8 << 2);
  while (1) {
   if ((i1 | 0) == (i4 | 0)) break;
   i14 = i1 + -4 | 0;
   i1 = i14;
   i2 = HEAP32[i14 >> 2] | 0;
   HEAP32[i14 >> 2] = 0;
   if (!i2) continue;
   __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i2);
   __ZdlPv(i2);
  }
  if (i4 | 0) __ZdlPv(i4);
 } else if (i2 >>> 0 > i5 >>> 0) {
  i2 = i3 + (i5 << 2) | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break L1;
   i13 = i1 + -4 | 0;
   HEAP32[i14 >> 2] = i13;
   i1 = HEAP32[i13 >> 2] | 0;
   HEAP32[i13 >> 2] = 0;
   if (i1 | 0) {
    __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1);
    __ZdlPv(i1);
   }
   i1 = HEAP32[i14 >> 2] | 0;
  }
 } while (0);
 return;
}

function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b(i15, i14, i6) {
 i15 = i15 | 0;
 i14 = i14 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i16;
 HEAP8[i15 >> 0] = 0;
 i1 = i14 + (HEAP32[(HEAP32[i14 >> 2] | 0) + -12 >> 2] | 0) | 0;
 i2 = i1 + 16 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (!i3) {
  i1 = HEAP32[i1 + 72 >> 2] | 0;
  if (i1 | 0) __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i1) | 0;
  do if (!i6 ? (i5 = i14 + (HEAP32[(HEAP32[i14 >> 2] | 0) + -12 >> 2] | 0) | 0, HEAP32[i5 + 4 >> 2] & 4096 | 0) : 0) {
   i5 = __ZNKSt3__28ios_base6getlocEv(i5) | 0;
   HEAP32[i4 >> 2] = i5;
   i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i4, 61680) | 0;
   __ZNSt3__26localeD2Ev(i4);
   i1 = HEAP32[i14 + (HEAP32[(HEAP32[i14 >> 2] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0;
   i4 = i5 + 8 | 0;
   i5 = i1;
   i6 = (i1 | 0) == 0;
   i7 = i5 + 12 | 0;
   i8 = i5 + 16 | 0;
   i9 = i1;
   i2 = i1;
   i10 = i2 + 12 | 0;
   i11 = i2 + 16 | 0;
   i12 = i1;
   i13 = i1;
   while (1) {
    if (i6) {
     i2 = 0;
     i1 = 0;
     break;
    }
    if ((HEAP32[i7 >> 2] | 0) == (HEAP32[i8 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i9 >> 2] | 0) + 36 >> 2] & 255](i5) | 0) == -1 : 0) {
     i2 = 0;
     i1 = 0;
     break;
    }
    i3 = HEAP32[i10 >> 2] | 0;
    if ((i3 | 0) == (HEAP32[i11 >> 2] | 0)) i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i12 >> 2] | 0) + 36 >> 2] & 255](i2) | 0; else i3 = HEAPU8[i3 >> 0] | 0;
    if ((i3 & 255) << 24 >> 24 <= -1) break;
    if (!(HEAP16[(HEAP32[i4 >> 2] | 0) + (i3 << 24 >> 24 << 1) >> 1] & 8192)) break;
    i3 = HEAP32[i10 >> 2] | 0;
    if ((i3 | 0) == (HEAP32[i11 >> 2] | 0)) {
     FUNCTION_TABLE_ii[HEAP32[(HEAP32[i13 >> 2] | 0) + 40 >> 2] & 255](i2) | 0;
     continue;
    } else {
     HEAP32[i10 >> 2] = i3 + 1;
     continue;
    }
   }
   if (i1 | 0) {
    if ((HEAP32[i2 + 12 >> 2] | 0) != (HEAP32[i2 + 16 >> 2] | 0)) break;
    if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) != -1) break;
   }
   i12 = i14 + (HEAP32[(HEAP32[i14 >> 2] | 0) + -12 >> 2] | 0) | 0;
   i13 = i12 + 16 | 0;
   HEAP32[i13 >> 2] = HEAP32[i13 >> 2] | (HEAP32[i12 + 24 >> 2] | 0) == 0 | 6;
  } while (0);
  HEAP8[i15 >> 0] = (HEAP32[i14 + (HEAP32[(HEAP32[i14 >> 2] | 0) + -12 >> 2] | 0) + 16 >> 2] | 0) == 0 & 1;
 } else HEAP32[i2 >> 2] = i3 | (HEAP32[i1 + 24 >> 2] | 0) == 0 | 4;
 STACKTOP = i16;
 return;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner10visitStoreEPNS_5StoreE(i3, i6, i4) {
 i3 = i3 | 0;
 i6 = i6 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i7 = i9 + 48 | 0;
 i1 = i9 + 68 | 0;
 i5 = i9 + 24 | 0;
 i8 = i9;
 i2 = i9 + 64 | 0;
 __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i5, i6, HEAP32[i4 + 20 >> 2] | 0);
 if (!(HEAP32[i5 + 16 >> 2] | 0)) {
  __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i8, i6, HEAP32[i4 + 24 >> 2] | 0);
  if (!(HEAP32[i8 + 16 >> 2] | 0)) {
   i11 = HEAP32[i6 >> 2] | 0;
   i6 = HEAP32[i11 + 24 >> 2] | 0;
   i10 = HEAP32[(HEAP32[i6 >> 2] | 0) + 12 >> 2] | 0;
   HEAP32[i7 >> 2] = HEAP32[i5 >> 2];
   HEAP32[i7 + 4 >> 2] = HEAP32[i5 + 4 >> 2];
   HEAP32[i7 + 8 >> 2] = HEAP32[i5 + 8 >> 2];
   HEAP32[i7 + 12 >> 2] = HEAP32[i5 + 12 >> 2];
   i5 = __ZN4wasm14ModuleInstance15getFinalAddressINS_5StoreEEENS_7AddressEPT_NS_7LiteralE(i11, i4, i7) | 0;
   HEAP32[i2 >> 2] = i5;
   HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i7 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
   HEAP32[i7 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
   HEAP32[i7 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
   FUNCTION_TABLE_viiii[i10 & 15](i6, i4, i1, i7);
   HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i3 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
   HEAP32[i3 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
   HEAP32[i3 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
   HEAP32[i3 + 16 >> 2] = HEAP32[i8 + 16 >> 2];
   HEAP32[i3 + 20 >> 2] = HEAP32[i8 + 20 >> 2];
  } else {
   HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i3 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
   HEAP32[i3 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
   HEAP32[i3 + 12 >> 2] = HEAP32[i8 + 12 >> 2];
   HEAP32[i3 + 16 >> 2] = HEAP32[i8 + 16 >> 2];
   HEAP32[i3 + 20 >> 2] = HEAP32[i8 + 20 >> 2];
  }
 } else {
  HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i3 + 4 >> 2] = HEAP32[i5 + 4 >> 2];
  HEAP32[i3 + 8 >> 2] = HEAP32[i5 + 8 >> 2];
  HEAP32[i3 + 12 >> 2] = HEAP32[i5 + 12 >> 2];
  HEAP32[i3 + 16 >> 2] = HEAP32[i5 + 16 >> 2];
  HEAP32[i3 + 20 >> 2] = HEAP32[i5 + 20 >> 2];
 }
 STACKTOP = i9;
 return;
}

function __ZN4wasm14ModuleInstance18printFunctionStackEv(i11, i1) {
 i11 = i11 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i4 = i12 + 36 | 0;
 i5 = i12 + 24 | 0;
 i8 = i12 + 12 | 0;
 i9 = i12;
 HEAP32[i11 >> 2] = 0;
 HEAP32[i11 + 4 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i11, 29289, 39);
 i10 = i1 + 8 | 0;
 i6 = i4 + 11 | 0;
 i7 = i4 + 4 | 0;
 i1 = (HEAP32[i1 + 12 >> 2] | 0) - (HEAP32[i10 >> 2] | 0) >> 2;
 while (1) {
  i3 = i1 + -1 | 0;
  if ((i1 | 0) <= 0) break;
  HEAP32[i8 >> 2] = 0;
  HEAP32[i8 + 4 >> 2] = 0;
  HEAP32[i8 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i8, 29329, 3);
  i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i8, HEAP32[(HEAP32[i10 >> 2] | 0) + (i3 << 2) >> 2] | 0) | 0;
  HEAP32[i5 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i5 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i5 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i5, 34477) | 0;
  HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  i1 = HEAP8[i6 >> 0] | 0;
  i2 = i1 << 24 >> 24 < 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj(i11, i2 ? HEAP32[i4 >> 2] | 0 : i4, i2 ? HEAP32[i7 >> 2] | 0 : i1 & 255) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i8);
  i1 = i3;
 }
 HEAP32[i9 >> 2] = 0;
 HEAP32[i9 + 4 >> 2] = 0;
 HEAP32[i9 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i9, 29333, 4);
 i10 = HEAP8[i9 + 11 >> 0] | 0;
 i8 = i10 << 24 >> 24 < 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj(i11, i8 ? HEAP32[i9 >> 2] | 0 : i9, i8 ? HEAP32[i9 + 4 >> 2] | 0 : i10 & 255) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i9);
 STACKTOP = i12;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE9doEndLoopEPS1_PPNS_10ExpressionE(i7, i1) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = i7 + 16 | 0;
 i6 = i7 + 60 | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i7, i1);
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i8, i2, HEAP32[i6 >> 2] | 0);
 i2 = __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 i3 = i2 + 8 | 0;
 if (HEAP32[i3 >> 2] | 0) {
  i4 = i7 + 64 | 0;
  i5 = __ZNSt3__23mapIN4wasm4NameENS_6vectorIPNS1_9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS5_vEENS1_8LivenessEE10BasicBlockENS_9allocatorISB_EEEENS_4lessIS2_EENSC_INS_4pairIKS2_SE_EEEEEixERSI_(i4, i3) | 0;
  i1 = HEAP32[i5 + 4 >> 2] | 0;
  i5 = HEAP32[i5 >> 2] | 0;
  while (1) {
   if ((i5 | 0) == (i1 | 0)) break;
   __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i8, HEAP32[i5 >> 2] | 0, HEAP32[i6 >> 2] | 0);
   i5 = i5 + 4 | 0;
  }
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE14__erase_uniqueIS3_EEjRKT_(i4, i3) | 0;
 }
 i4 = i2 + 12 | 0;
 i6 = i7 + 92 | 0;
 if (HEAP32[i4 >> 2] | 0) {
  i5 = HEAP32[(HEAP32[i6 >> 2] | 0) + -4 >> 2] | 0;
  i1 = i7 + 64 | 0;
  i3 = __ZNSt3__23mapIN4wasm4NameENS_6vectorIPNS1_9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS5_vEENS1_8LivenessEE10BasicBlockENS_9allocatorISB_EEEENS_4lessIS2_EENSC_INS_4pairIKS2_SE_EEEEEixERSI_(i1, i4) | 0;
  i2 = HEAP32[i3 + 4 >> 2] | 0;
  i3 = HEAP32[i3 >> 2] | 0;
  while (1) {
   if ((i3 | 0) == (i2 | 0)) break;
   __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i8, HEAP32[i3 >> 2] | 0, i5);
   i3 = i3 + 4 | 0;
  }
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE14__erase_uniqueIS3_EEjRKT_(i1, i4) | 0;
 }
 i2 = HEAP32[i6 >> 2] | 0;
 i1 = i2 + -4 | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  i8 = i2 + -4 | 0;
  HEAP32[i6 >> 2] = i8;
  i2 = i8;
 }
 return;
}

function __ZNSt3__210__stdinbufIcE9__getcharEb(i11, i14) {
 i11 = i11 | 0;
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0, i13 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i13 = i16 + 16 | 0;
 i12 = i16 + 8 | 0;
 i8 = i16 + 4 | 0;
 i9 = i16;
 i3 = i11 + 52 | 0;
 if (HEAP8[i3 >> 0] | 0) {
  i2 = i11 + 48 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if (i14) {
   HEAP32[i2 >> 2] = -1;
   HEAP8[i3 >> 0] = 0;
  }
 } else {
  i1 = HEAP32[i11 + 44 >> 2] | 0;
  i1 = (i1 | 0) > 1 ? i1 : 1;
  i10 = i11 + 32 | 0;
  i3 = 0;
  while (1) {
   if ((i3 | 0) >= (i1 | 0)) {
    i15 = 8;
    break;
   }
   i2 = _getc(HEAP32[i10 >> 2] | 0) | 0;
   if ((i2 | 0) == -1) {
    i1 = -1;
    break;
   }
   HEAP8[i13 + i3 >> 0] = i2;
   i3 = i3 + 1 | 0;
  }
  if ((i15 | 0) == 8) {
   do if (!(HEAP8[i11 + 53 >> 0] | 0)) {
    i5 = i11 + 40 | 0;
    i6 = i11 + 36 | 0;
    i7 = i12 + 1 | 0;
    L11 : while (1) {
     i17 = HEAP32[i5 >> 2] | 0;
     i3 = i17;
     i2 = HEAP32[i3 >> 2] | 0;
     i3 = HEAP32[i3 + 4 >> 2] | 0;
     i18 = HEAP32[i6 >> 2] | 0;
     i4 = i13 + i1 | 0;
     switch (FUNCTION_TABLE_iiiiiiiii[HEAP32[(HEAP32[i18 >> 2] | 0) + 16 >> 2] & 15](i18, i17, i13, i4, i8, i12, i7, i9) | 0) {
     case 3:
      {
       i15 = 15;
       break L11;
      }
     case 2:
      {
       i15 = 17;
       break L11;
      }
     case 1:
      break;
     default:
      break L11;
     }
     i18 = HEAP32[i5 >> 2] | 0;
     HEAP32[i18 >> 2] = i2;
     HEAP32[i18 + 4 >> 2] = i3;
     if ((i1 | 0) == 8) {
      i15 = 17;
      break;
     }
     i2 = _getc(HEAP32[i10 >> 2] | 0) | 0;
     if ((i2 | 0) == -1) {
      i15 = 17;
      break;
     }
     HEAP8[i4 >> 0] = i2;
     i1 = i1 + 1 | 0;
    }
    if ((i15 | 0) == 15) HEAP8[i12 >> 0] = HEAP8[i13 >> 0] | 0; else if ((i15 | 0) == 17) {
     i1 = -1;
     break;
    }
    i15 = 18;
   } else {
    HEAP8[i12 >> 0] = HEAP8[i13 >> 0] | 0;
    i15 = 18;
   } while (0);
   L21 : do if ((i15 | 0) == 18) {
    if (i14) {
     i1 = HEAP8[i12 >> 0] | 0;
     HEAP32[i11 + 48 >> 2] = i1 & 255;
    } else {
     while (1) {
      if ((i1 | 0) <= 0) break;
      i1 = i1 + -1 | 0;
      if ((_ungetc(HEAPU8[i13 + i1 >> 0] | 0, HEAP32[i10 >> 2] | 0) | 0) == -1) {
       i1 = -1;
       break L21;
      }
     }
     i1 = HEAP8[i12 >> 0] | 0;
    }
    i1 = i1 & 255;
   } while (0);
  }
 }
 STACKTOP = i16;
 return i1 | 0;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE(i1, i6, i7, i8, i3) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i5 = 0;
 i1 = HEAP32[i6 >> 2] | 0;
 do if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
   HEAP32[i6 >> 2] = 0;
   i1 = 0;
   break;
  } else {
   i1 = HEAP32[i6 >> 2] | 0;
   break;
  }
 } else i1 = 0; while (0);
 i2 = (i1 | 0) == 0;
 i1 = HEAP32[i7 >> 2] | 0;
 do if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1 : 0) {
   HEAP32[i7 >> 2] = 0;
   i5 = 11;
   break;
  }
  if (i2) {
   i4 = i1;
   i5 = 13;
  } else i5 = 12;
 } else i5 = 11; while (0);
 if ((i5 | 0) == 11) if (i2) i5 = 12; else {
  i4 = 0;
  i5 = 13;
 }
 L16 : do if ((i5 | 0) == 12) HEAP32[i8 >> 2] = HEAP32[i8 >> 2] | 6; else if ((i5 | 0) == 13) {
  i1 = HEAP32[i6 >> 2] | 0;
  i2 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAPU8[i2 >> 0] | 0;
  if ((FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i3 >> 2] | 0) + 36 >> 2] & 31](i3, i1 & 255, 0) | 0) << 24 >> 24 != 37) {
   HEAP32[i8 >> 2] = HEAP32[i8 >> 2] | 4;
   break;
  }
  i1 = HEAP32[i6 >> 2] | 0;
  i2 = i1 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   i1 = HEAP32[i6 >> 2] | 0;
   if (!i1) i1 = 0; else i5 = 21;
  } else {
   HEAP32[i2 >> 2] = i3 + 1;
   i5 = 21;
  }
  do if ((i5 | 0) == 21) if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
   HEAP32[i6 >> 2] = 0;
   i1 = 0;
   break;
  } else {
   i1 = HEAP32[i6 >> 2] | 0;
   break;
  } while (0);
  i1 = (i1 | 0) == 0;
  do if (i4) {
   if ((HEAP32[i4 + 12 >> 2] | 0) == (HEAP32[i4 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 36 >> 2] & 255](i4) | 0) == -1 : 0) {
    HEAP32[i7 >> 2] = 0;
    i5 = 30;
    break;
   }
   if (i1) break L16;
  } else i5 = 30; while (0);
  if ((i5 | 0) == 30 ? !i1 : 0) break;
  HEAP32[i8 >> 2] = HEAP32[i8 >> 2] | 2;
 } while (0);
 return;
}

function __ZNSt3__213unordered_mapIN6cashew7IStringEN7AsmData5LocalENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERSB_(i15, i1) {
 i15 = i15 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, d4 = 0.0, d5 = 0.0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0;
 i10 = HEAP32[i1 >> 2] | 0;
 i14 = i10 * 33 ^ 5381;
 i13 = i15 + 4 | 0;
 i6 = HEAP32[i13 >> 2] | 0;
 i12 = (i6 | 0) == 0;
 i7 = i10;
 L1 : do if (!i12) {
  i8 = i6 + -1 | 0;
  i9 = (i8 & i6 | 0) == 0;
  if (i9) i2 = i8 & i14; else i2 = (i14 >>> 0) % (i6 >>> 0) | 0;
  i1 = HEAP32[(HEAP32[i15 >> 2] | 0) + (i2 << 2) >> 2] | 0;
  if (!i1) i11 = 12; else do {
   i1 = HEAP32[i1 >> 2] | 0;
   if (!i1) {
    i11 = 12;
    break L1;
   }
   i3 = HEAP32[i1 + 4 >> 2] | 0;
   if (i9) i3 = i3 & i8; else i3 = (i3 >>> 0) % (i6 >>> 0) | 0;
   if ((i3 | 0) != (i2 | 0)) {
    i11 = 12;
    break L1;
   }
  } while ((HEAP32[i1 + 8 >> 2] | 0) != (i7 | 0));
 } else {
  i2 = 0;
  i11 = 12;
 } while (0);
 if ((i11 | 0) == 12) {
  i1 = __Znwj(20) | 0;
  HEAP32[i1 + 8 >> 2] = i10;
  HEAP32[i1 + 4 >> 2] = i14;
  HEAP32[i1 >> 2] = 0;
  i7 = i15 + 12 | 0;
  d4 = +(((HEAP32[i7 >> 2] | 0) + 1 | 0) >>> 0);
  d5 = +HEAPF32[i15 + 16 >> 2];
  do if (i12 | d4 > +(i6 >>> 0) * d5) {
   if (i6 >>> 0 > 2) i2 = (i6 + -1 & i6 | 0) == 0; else i2 = 0;
   i2 = (i2 & 1 | i6 << 1) ^ 1;
   i3 = ~~+Math_ceil(+(d4 / d5)) >>> 0;
   __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE6rehashEj(i15, i2 >>> 0 < i3 >>> 0 ? i3 : i2);
   i2 = HEAP32[i13 >> 2] | 0;
   i3 = i2 + -1 | 0;
   if (!(i3 & i2)) {
    i6 = i2;
    i2 = i3 & i14;
    break;
   } else {
    i6 = i2;
    i2 = (i14 >>> 0) % (i2 >>> 0) | 0;
    break;
   }
  } while (0);
  i2 = (HEAP32[i15 >> 2] | 0) + (i2 << 2) | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (!i3) {
   i14 = i15 + 8 | 0;
   HEAP32[i1 >> 2] = HEAP32[i14 >> 2];
   HEAP32[i14 >> 2] = i1;
   HEAP32[i2 >> 2] = i14;
   i2 = HEAP32[i1 >> 2] | 0;
   if (i2 | 0) {
    i2 = HEAP32[i2 + 4 >> 2] | 0;
    i3 = i6 + -1 | 0;
    if (!(i3 & i6)) i2 = i2 & i3; else i2 = (i2 >>> 0) % (i6 >>> 0) | 0;
    HEAP32[(HEAP32[i15 >> 2] | 0) + (i2 << 2) >> 2] = i1;
   }
  } else {
   HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i3 >> 2] = i1;
  }
  HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 1;
 }
 return i1 + 12 | 0;
}

function __ZNSt3__213unordered_mapIN6cashew7IStringEiNS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorINS_4pairIKS2_iEEEEEixERS9_(i15, i1) {
 i15 = i15 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, d4 = 0.0, d5 = 0.0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0;
 i10 = HEAP32[i1 >> 2] | 0;
 i14 = i10 * 33 ^ 5381;
 i13 = i15 + 4 | 0;
 i6 = HEAP32[i13 >> 2] | 0;
 i12 = (i6 | 0) == 0;
 i7 = i10;
 L1 : do if (!i12) {
  i8 = i6 + -1 | 0;
  i9 = (i8 & i6 | 0) == 0;
  if (i9) i2 = i8 & i14; else i2 = (i14 >>> 0) % (i6 >>> 0) | 0;
  i1 = HEAP32[(HEAP32[i15 >> 2] | 0) + (i2 << 2) >> 2] | 0;
  if (!i1) i11 = 12; else do {
   i1 = HEAP32[i1 >> 2] | 0;
   if (!i1) {
    i11 = 12;
    break L1;
   }
   i3 = HEAP32[i1 + 4 >> 2] | 0;
   if (i9) i3 = i3 & i8; else i3 = (i3 >>> 0) % (i6 >>> 0) | 0;
   if ((i3 | 0) != (i2 | 0)) {
    i11 = 12;
    break L1;
   }
  } while ((HEAP32[i1 + 8 >> 2] | 0) != (i7 | 0));
 } else {
  i2 = 0;
  i11 = 12;
 } while (0);
 if ((i11 | 0) == 12) {
  i1 = __Znwj(16) | 0;
  HEAP32[i1 + 8 >> 2] = i10;
  HEAP32[i1 + 12 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = i14;
  HEAP32[i1 >> 2] = 0;
  i7 = i15 + 12 | 0;
  d4 = +(((HEAP32[i7 >> 2] | 0) + 1 | 0) >>> 0);
  d5 = +HEAPF32[i15 + 16 >> 2];
  do if (i12 | d4 > +(i6 >>> 0) * d5) {
   if (i6 >>> 0 > 2) i2 = (i6 + -1 & i6 | 0) == 0; else i2 = 0;
   i2 = (i2 & 1 | i6 << 1) ^ 1;
   i3 = ~~+Math_ceil(+(d4 / d5)) >>> 0;
   __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEE6rehashEj(i15, i2 >>> 0 < i3 >>> 0 ? i3 : i2);
   i2 = HEAP32[i13 >> 2] | 0;
   i3 = i2 + -1 | 0;
   if (!(i3 & i2)) {
    i6 = i2;
    i2 = i3 & i14;
    break;
   } else {
    i6 = i2;
    i2 = (i14 >>> 0) % (i2 >>> 0) | 0;
    break;
   }
  } while (0);
  i2 = (HEAP32[i15 >> 2] | 0) + (i2 << 2) | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (!i3) {
   i14 = i15 + 8 | 0;
   HEAP32[i1 >> 2] = HEAP32[i14 >> 2];
   HEAP32[i14 >> 2] = i1;
   HEAP32[i2 >> 2] = i14;
   i2 = HEAP32[i1 >> 2] | 0;
   if (i2 | 0) {
    i2 = HEAP32[i2 + 4 >> 2] | 0;
    i3 = i6 + -1 | 0;
    if (!(i3 & i6)) i2 = i2 & i3; else i2 = (i2 >>> 0) % (i6 >>> 0) | 0;
    HEAP32[(HEAP32[i15 >> 2] | 0) + (i2 << 2) >> 2] = i1;
   }
  } else {
   HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i3 >> 2] = i1;
  }
  HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 1;
 }
 return i1 + 12 | 0;
}

function __ZN4wasm7VisitorINS_16PrintSExpressionEvE5visitEPNS_10ExpressionE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i4;
 if (!i2) ___assert_fail(41743, 49642, 68, 41748);
 do switch (HEAP32[i2 >> 2] | 0) {
 case 1:
  {
   __ZN4wasm16PrintSExpression10visitBlockEPNS_5BlockE(i3, i2);
   break;
  }
 case 2:
  {
   __ZN4wasm16PrintSExpression7visitIfEPNS_2IfE(i3, i2);
   break;
  }
 case 3:
  {
   __ZN4wasm16PrintSExpression9visitLoopEPNS_4LoopE(i3, i2);
   break;
  }
 case 4:
  {
   __ZN4wasm16PrintSExpression10visitBreakEPNS_5BreakE(i3, i2);
   break;
  }
 case 5:
  {
   __ZN4wasm16PrintSExpression11visitSwitchEPNS_6SwitchE(i3, i2);
   break;
  }
 case 6:
  {
   __ZN4wasm16PrintSExpression9visitCallEPNS_4CallE(i3, i2);
   break;
  }
 case 7:
  {
   __ZN4wasm16PrintSExpression15visitCallImportEPNS_10CallImportE(i3, i2);
   break;
  }
 case 8:
  {
   __ZN4wasm16PrintSExpression17visitCallIndirectEPNS_12CallIndirectE(i3, i2);
   break;
  }
 case 9:
  {
   __ZN4wasm16PrintSExpression13visitGetLocalEPNS_8GetLocalE(i3, i2);
   break;
  }
 case 10:
  {
   __ZN4wasm16PrintSExpression13visitSetLocalEPNS_8SetLocalE(i3, i2);
   break;
  }
 case 11:
  {
   __ZN4wasm16PrintSExpression9visitLoadEPNS_4LoadE(i3, i2);
   break;
  }
 case 12:
  {
   __ZN4wasm16PrintSExpression10visitStoreEPNS_5StoreE(i3, i2);
   break;
  }
 case 13:
  {
   i3 = HEAP32[i3 >> 2] | 0;
   i2 = i2 + 8 | 0;
   HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
   HEAP32[i1 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
   HEAP32[i1 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
   HEAP32[i1 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
   __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_7LiteralE(i3, i1) | 0;
   break;
  }
 case 14:
  {
   __ZN4wasm16PrintSExpression10visitUnaryEPNS_5UnaryE(i3, i2);
   break;
  }
 case 15:
  {
   __ZN4wasm16PrintSExpression11visitBinaryEPNS_6BinaryE(i3, i2);
   break;
  }
 case 16:
  {
   __ZN4wasm16PrintSExpression11visitSelectEPNS_6SelectE(i3, i2);
   break;
  }
 case 17:
  {
   __ZN4wasm16PrintSExpression11visitReturnEPNS_6ReturnE(i3, i2);
   break;
  }
 case 18:
  {
   __ZN4wasm16PrintSExpression9visitHostEPNS_4HostE(i3, i2);
   break;
  }
 case 19:
  {
   __ZN4wasm16PrintSExpression8visitNopEPNS_3NopE(i3, i2);
   break;
  }
 case 20:
  {
   __ZN4wasm16PrintSExpression16visitUnreachableEPNS_11UnreachableE(i3, i2);
   break;
  }
 default:
  {}
 } while (0);
 STACKTOP = i4;
 return;
}

function __ZNKSt3__28messagesIwE6do_getEiiiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE(i17, i1, i7, i9, i8, i2) {
 i17 = i17 | 0;
 i1 = i1 | 0;
 i7 = i7 | 0;
 i9 = i9 | 0;
 i8 = i8 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 176 | 0;
 i13 = i16 + 168 | 0;
 i12 = i16 + 40 | 0;
 i11 = i16 + 36 | 0;
 i15 = i16 + 32 | 0;
 i14 = i16;
 i6 = i16 + 24 | 0;
 i10 = i16 + 16 | 0;
 HEAP32[i14 >> 2] = 0;
 HEAP32[i14 + 4 >> 2] = 0;
 HEAP32[i14 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i14 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i6 + 4 >> 2] = 0;
 HEAP32[i6 >> 2] = 14772;
 i4 = HEAP8[i2 + 8 + 3 >> 0] | 0;
 i5 = i4 << 24 >> 24 < 0;
 i1 = i5 ? HEAP32[i2 >> 2] | 0 : i2;
 i4 = i1 + ((i5 ? HEAP32[i2 + 4 >> 2] | 0 : i4 & 255) << 2) | 0;
 i5 = i12 + 32 | 0;
 i2 = i1;
 i1 = 0;
 while (1) {
  if (!((i1 | 0) != 2 & i2 >>> 0 < i4 >>> 0)) break;
  HEAP32[i15 >> 2] = i2;
  i3 = FUNCTION_TABLE_iiiiiiiii[HEAP32[(HEAP32[i6 >> 2] | 0) + 12 >> 2] & 15](i6, i13, i2, i4, i15, i12, i5, i11) | 0;
  i1 = i12;
  while (1) {
   if (i1 >>> 0 >= (HEAP32[i11 >> 2] | 0) >>> 0) break;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i14, HEAP8[i1 >> 0] | 0);
   i1 = i1 + 1 | 0;
  }
  i2 = HEAP32[i15 >> 2] | 0;
  i1 = i3;
 }
 i2 = _catgets((i7 | 0) == -1 ? -1 : i7 << 1, i9, i8, (HEAP8[i14 + 11 >> 0] | 0) < 0 ? HEAP32[i14 >> 2] | 0 : i14) | 0;
 HEAP32[i17 >> 2] = 0;
 HEAP32[i17 + 4 >> 2] = 0;
 HEAP32[i17 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i17 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i10 + 4 >> 2] = 0;
 HEAP32[i10 >> 2] = 14820;
 i4 = i2 + (_strlen(i2) | 0) | 0;
 i5 = i4;
 i6 = i12 + 128 | 0;
 i1 = 0;
 while (1) {
  if (!((i1 | 0) != 2 & i2 >>> 0 < i4 >>> 0)) break;
  HEAP32[i15 >> 2] = i2;
  i3 = FUNCTION_TABLE_iiiiiiiii[HEAP32[(HEAP32[i10 >> 2] | 0) + 16 >> 2] & 15](i10, i13, i2, (i5 - i2 | 0) > 32 ? i2 + 32 | 0 : i4, i15, i12, i6, i11) | 0;
  i1 = i12;
  while (1) {
   if (i1 >>> 0 >= (HEAP32[i11 >> 2] | 0) >>> 0) break;
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw(i17, HEAP32[i1 >> 2] | 0);
   i1 = i1 + 4 | 0;
  }
  i2 = HEAP32[i15 >> 2] | 0;
  i1 = i3;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i14);
 STACKTOP = i16;
 return;
}

function __ZN4wasm13WasmValidator11visitModuleEPNS_6ModuleE(i19, i17) {
 i19 = i19 | 0;
 i17 = i17 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i18 = 0, i20 = 0, i21 = 0;
 i20 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i13 = i20 + 32 | 0;
 i18 = i20 + 8 | 0;
 i5 = i20 + 28 | 0;
 i12 = i20;
 i6 = i20 + 24 | 0;
 i14 = i20 + 20 | 0;
 i15 = i20 + 4 | 0;
 HEAP32[i18 + 4 >> 2] = 0;
 HEAP32[i18 + 8 >> 2] = 0;
 HEAP32[i18 >> 2] = i18 + 4;
 i7 = HEAP32[i17 + 28 >> 2] | 0;
 i8 = i17 + 36 | 0;
 i9 = i17 + 40 | 0;
 i11 = HEAP32[i17 + 24 >> 2] | 0;
 while (1) {
  if ((i11 | 0) == (i7 | 0)) break;
  i10 = HEAP32[(HEAP32[i11 >> 2] | 0) + 4 >> 2] | 0;
  i2 = HEAP32[i9 >> 2] | 0;
  i3 = i10;
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = 0;
  while (1) {
   if ((i4 | 0) == (i2 | 0)) break;
   i21 = (HEAP32[HEAP32[i4 >> 2] >> 2] | 0) == (i3 | 0);
   i1 = i1 | i21;
   if (i21) break; else i4 = i4 + 4 | 0;
  }
  HEAP32[i5 >> 2] = i10;
  HEAP32[i13 >> 2] = HEAP32[i5 >> 2];
  __ZN4wasm13WasmValidator12shouldBeTrueINS_4NameEEEbbT_PKc(i19, i1, i13, 20732) | 0;
  i10 = HEAP32[HEAP32[i11 >> 2] >> 2] | 0;
  HEAP32[i12 >> 2] = i10;
  i21 = (__ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(i18, i12) | 0) != 0;
  HEAP32[i6 >> 2] = i10;
  HEAP32[i13 >> 2] = HEAP32[i6 >> 2];
  __ZN4wasm13WasmValidator13shouldBeFalseINS_4NameEEEbbT_PKc(i19, i21, i13, 20761) | 0;
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i13, i18, i12, i12);
  i11 = i11 + 4 | 0;
 }
 i1 = i17 + 84 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if (i2 | 0 ? (HEAP32[i14 >> 2] = i2, HEAP32[i13 >> 2] = HEAP32[i14 >> 2], i16 = __ZN4wasm6Module13checkFunctionENS_4NameE(i17, i13) | 0, HEAP32[i15 >> 2] = HEAP32[i1 >> 2], HEAP32[i13 >> 2] = HEAP32[i15 >> 2], __ZN4wasm13WasmValidator12shouldBeTrueINS_4NameEEEbbT_PKc(i19, (i16 | 0) != 0, i13, 20791) | 0) : 0) {
  __ZN4wasm13WasmValidator12shouldBeTrueIPNS_6ModuleEEEbbT_PKc(i19, (HEAP32[i16 + 12 >> 2] | 0) == (HEAP32[i16 + 8 >> 2] | 0), i17, 20811) | 0;
  __ZN4wasm13WasmValidator12shouldBeTrueIPNS_6ModuleEEEbbT_PKc(i19, (HEAP32[i16 + 4 >> 2] | 0) == 0, i17, 20836) | 0;
 }
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEED2Ev(i18);
 STACKTOP = i20;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseAfterCurlyERPc(i12, i14) {
 i12 = i12 | 0;
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i15 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i4 = i16 + 36 | 0;
 i3 = i16 + 32 | 0;
 i2 = i16 + 28 | 0;
 i11 = i16;
 i5 = i16 + 24 | 0;
 i6 = i16 + 20 | 0;
 i9 = i16 + 16 | 0;
 __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE6resizeEj(i12, (((HEAP32[i12 + 4 >> 2] | 0) - (HEAP32[i12 >> 2] | 0) | 0) / 12 | 0) + 1 | 0);
 i13 = __ZN6cashew12ValueBuilder10makeObjectEv() | 0;
 i7 = i11 + 12 | 0;
 i8 = i11 + 8 | 0;
 L1 : while (1) {
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
  i1 = HEAP32[i14 >> 2] | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 0:
   {
    i15 = 3;
    break L1;
   }
  case 125:
   {
    i10 = i1;
    break L1;
   }
  default:
   {}
  }
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i11, i1);
  if ((HEAP32[i7 >> 2] & -2 | 0) != 2) {
   i15 = 5;
   break;
  }
  HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) + (HEAP32[i8 >> 2] | 0);
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
  i1 = HEAP32[i14 >> 2] | 0;
  if ((HEAP8[i1 >> 0] | 0) != 58) {
   i15 = 7;
   break;
  }
  HEAP32[i14 >> 2] = i1 + 1;
  i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i12, i14, 32241) | 0;
  HEAP32[i5 >> 2] = i13;
  HEAP32[i6 >> 2] = HEAP32[i11 >> 2];
  HEAP32[i9 >> 2] = i1;
  HEAP32[i2 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i9 >> 2];
  __ZN6cashew12ValueBuilder14appendToObjectENS_3RefENS_7IStringES1_(i2, i3, i4);
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
  i1 = HEAP32[i14 >> 2] | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 125:
   {
    i15 = 11;
    break L1;
   }
  case 44:
   break;
  default:
   {
    i15 = 10;
    break L1;
   }
  }
  HEAP32[i14 >> 2] = i1 + 1;
 }
 if ((i15 | 0) == 3) ___assert_fail(32129, 31173, 695, 32185); else if ((i15 | 0) == 5) ___assert_fail(32201, 31173, 698, 32185); else if ((i15 | 0) == 7) ___assert_fail(31673, 31173, 701, 32185); else if ((i15 | 0) == 10) _abort(); else if ((i15 | 0) == 11) i10 = i1;
 HEAP32[i14 >> 2] = i10 + 1;
 STACKTOP = i16;
 return i13 | 0;
}

function __ZZN4wasm14ModuleInstance15getFinalAddressINS_5StoreEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i1, i5, i6, i7, i8, i11) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 i11 = i11 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i9 = 0, i10 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 176 | 0;
 i9 = i13 + 160 | 0;
 i12 = i13 + 16 | 0;
 i10 = i13;
 i4 = HEAP32[i1 >> 2] | 0;
 if (i6 >>> 0 > i8 >>> 0 | (i6 | 0) == (i8 | 0) & i5 >>> 0 > i7 >>> 0) {
  i2 = i12 + 64 | 0;
  i1 = i12 + 8 | 0;
  HEAP32[i1 >> 2] = 4716;
  i3 = i12 + 12 | 0;
  HEAP32[i12 >> 2] = 4856;
  HEAP32[i2 >> 2] = 4876;
  HEAP32[i12 + 4 >> 2] = 0;
  __ZNSt3__28ios_base4initEPv(i12 + 64 | 0, i3);
  HEAP32[i12 + 136 >> 2] = 0;
  HEAP32[i12 + 140 >> 2] = -1;
  HEAP32[i12 >> 2] = 4696;
  HEAP32[i2 >> 2] = 4736;
  HEAP32[i1 >> 2] = 4716;
  __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i3);
  HEAP32[i3 >> 2] = 4392;
  i1 = i12 + 44 | 0;
  HEAP32[i1 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = 0;
  HEAP32[i1 + 8 >> 2] = 0;
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  HEAP32[i12 + 56 >> 2] = 0;
  HEAP32[i12 + 60 >> 2] = 24;
  HEAP32[i9 >> 2] = 0;
  HEAP32[i9 + 4 >> 2] = 0;
  HEAP32[i9 + 8 >> 2] = 0;
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i9 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE(i3, i9);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i9);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i12 + 8 | 0, i11) | 0, 19435) | 0, i5, i6) | 0, 28448) | 0, i7, i8) | 0;
  i11 = HEAP32[i4 + 24 >> 2] | 0;
  i9 = HEAP32[(HEAP32[i11 >> 2] | 0) + 20 >> 2] | 0;
  __ZNKSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strEv(i10, i3);
  FUNCTION_TABLE_vii[i9 & 1023](i11, (HEAP8[i10 + 11 >> 0] | 0) < 0 ? HEAP32[i10 >> 2] | 0 : i10);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i10);
  __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i12);
 }
 STACKTOP = i13;
 return;
}

function __ZZN4wasm14ModuleInstance15getFinalAddressINS_4LoadEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i1, i5, i6, i7, i8, i11) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 i11 = i11 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i9 = 0, i10 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 176 | 0;
 i9 = i13 + 160 | 0;
 i12 = i13 + 16 | 0;
 i10 = i13;
 i4 = HEAP32[i1 >> 2] | 0;
 if (i6 >>> 0 > i8 >>> 0 | (i6 | 0) == (i8 | 0) & i5 >>> 0 > i7 >>> 0) {
  i2 = i12 + 64 | 0;
  i1 = i12 + 8 | 0;
  HEAP32[i1 >> 2] = 4716;
  i3 = i12 + 12 | 0;
  HEAP32[i12 >> 2] = 4856;
  HEAP32[i2 >> 2] = 4876;
  HEAP32[i12 + 4 >> 2] = 0;
  __ZNSt3__28ios_base4initEPv(i12 + 64 | 0, i3);
  HEAP32[i12 + 136 >> 2] = 0;
  HEAP32[i12 + 140 >> 2] = -1;
  HEAP32[i12 >> 2] = 4696;
  HEAP32[i2 >> 2] = 4736;
  HEAP32[i1 >> 2] = 4716;
  __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i3);
  HEAP32[i3 >> 2] = 4392;
  i1 = i12 + 44 | 0;
  HEAP32[i1 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = 0;
  HEAP32[i1 + 8 >> 2] = 0;
  i2 = 0;
  while (1) {
   if ((i2 | 0) == 3) break;
   HEAP32[i1 + (i2 << 2) >> 2] = 0;
   i2 = i2 + 1 | 0;
  }
  HEAP32[i12 + 56 >> 2] = 0;
  HEAP32[i12 + 60 >> 2] = 24;
  HEAP32[i9 >> 2] = 0;
  HEAP32[i9 + 4 >> 2] = 0;
  HEAP32[i9 + 8 >> 2] = 0;
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break;
   HEAP32[i9 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE(i3, i9);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i9);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i12 + 8 | 0, i11) | 0, 19435) | 0, i5, i6) | 0, 28448) | 0, i7, i8) | 0;
  i11 = HEAP32[i4 + 24 >> 2] | 0;
  i9 = HEAP32[(HEAP32[i11 >> 2] | 0) + 20 >> 2] | 0;
  __ZNKSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strEv(i10, i3);
  FUNCTION_TABLE_vii[i9 & 1023](i11, (HEAP8[i10 + 11 >> 0] | 0) < 0 ? HEAP32[i10 >> 2] | 0 : i10);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i10);
  __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i12);
 }
 STACKTOP = i13;
 return;
}
function __ZNSt3__210__stdinbufIwE9__getcharEb(i11, i14) {
 i11 = i11 | 0;
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0, i13 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i13 = i16 + 16 | 0;
 i12 = i16 + 8 | 0;
 i8 = i16 + 4 | 0;
 i9 = i16;
 i3 = i11 + 52 | 0;
 if (HEAP8[i3 >> 0] | 0) {
  i2 = i11 + 48 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if (i14) {
   HEAP32[i2 >> 2] = -1;
   HEAP8[i3 >> 0] = 0;
  }
 } else {
  i1 = HEAP32[i11 + 44 >> 2] | 0;
  i1 = (i1 | 0) > 1 ? i1 : 1;
  i10 = i11 + 32 | 0;
  i3 = 0;
  while (1) {
   if ((i3 | 0) >= (i1 | 0)) {
    i15 = 8;
    break;
   }
   i2 = _getc(HEAP32[i10 >> 2] | 0) | 0;
   if ((i2 | 0) == -1) {
    i1 = -1;
    break;
   }
   HEAP8[i13 + i3 >> 0] = i2;
   i3 = i3 + 1 | 0;
  }
  if ((i15 | 0) == 8) {
   do if (!(HEAP8[i11 + 53 >> 0] | 0)) {
    i5 = i11 + 40 | 0;
    i6 = i11 + 36 | 0;
    i7 = i12 + 4 | 0;
    L11 : while (1) {
     i17 = HEAP32[i5 >> 2] | 0;
     i3 = i17;
     i2 = HEAP32[i3 >> 2] | 0;
     i3 = HEAP32[i3 + 4 >> 2] | 0;
     i18 = HEAP32[i6 >> 2] | 0;
     i4 = i13 + i1 | 0;
     switch (FUNCTION_TABLE_iiiiiiiii[HEAP32[(HEAP32[i18 >> 2] | 0) + 16 >> 2] & 15](i18, i17, i13, i4, i8, i12, i7, i9) | 0) {
     case 3:
      {
       i15 = 15;
       break L11;
      }
     case 2:
      {
       i15 = 17;
       break L11;
      }
     case 1:
      break;
     default:
      break L11;
     }
     i18 = HEAP32[i5 >> 2] | 0;
     HEAP32[i18 >> 2] = i2;
     HEAP32[i18 + 4 >> 2] = i3;
     if ((i1 | 0) == 8) {
      i15 = 17;
      break;
     }
     i2 = _getc(HEAP32[i10 >> 2] | 0) | 0;
     if ((i2 | 0) == -1) {
      i15 = 17;
      break;
     }
     HEAP8[i4 >> 0] = i2;
     i1 = i1 + 1 | 0;
    }
    if ((i15 | 0) == 15) HEAP32[i12 >> 2] = HEAP8[i13 >> 0]; else if ((i15 | 0) == 17) {
     i1 = -1;
     break;
    }
    i15 = 18;
   } else {
    HEAP32[i12 >> 2] = HEAP8[i13 >> 0];
    i15 = 18;
   } while (0);
   L21 : do if ((i15 | 0) == 18) {
    if (i14) {
     i1 = HEAP32[i12 >> 2] | 0;
     HEAP32[i11 + 48 >> 2] = i1;
     break;
    }
    while (1) {
     if ((i1 | 0) <= 0) break;
     i1 = i1 + -1 | 0;
     if ((_ungetc(HEAP8[i13 + i1 >> 0] | 0, HEAP32[i10 >> 2] | 0) | 0) == -1) {
      i1 = -1;
      break L21;
     }
    }
    i1 = HEAP32[i12 >> 2] | 0;
   } while (0);
  }
 }
 STACKTOP = i16;
 return i1 | 0;
}

function __ZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionE(i14, i12) {
 i14 = i14 | 0;
 i12 = i12 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i15 = 0, i16 = 0, i17 = 0, i18 = 0, i19 = 0;
 i18 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i13 = i18 + 44 | 0;
 i15 = i18;
 i4 = i14 + 44 | 0;
 i5 = i14 + 16 | 0;
 i6 = i12 + 36 | 0;
 i7 = i14 + 60 | 0;
 i8 = i14 + 64 | 0;
 i9 = i14 + 48 | 0;
 i10 = i14 + 52 | 0;
 i11 = i14 + 45 | 0;
 i16 = 0;
 while (1) {
  HEAP8[i4 >> 0] = 0;
  __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i5, i6);
  if ((HEAP32[i7 >> 2] | 0) == (HEAP32[i8 >> 2] | 0)) i3 = 0; else {
   i17 = 3;
   break;
  }
  while (1) {
   i1 = HEAP32[i10 >> 2] | 0;
   i19 = HEAP32[i9 >> 2] | 0;
   i2 = i19;
   if (i3 >>> 0 >= i1 - i19 >> 2 >>> 0) break;
   i1 = __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[HEAP32[i2 + (i3 << 2) >> 2] >> 2] | 0) | 0;
   i2 = HEAP32[i1 + 8 >> 2] | 0;
   if (i2) {
    if (HEAP8[i11 >> 0] | 0) {
     HEAP32[HEAP32[(HEAP32[i9 >> 2] | 0) + (i3 << 2) >> 2] >> 2] = i2;
     HEAP8[i4 >> 0] = 1;
    }
   } else {
    HEAP32[i1 >> 2] = 19;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP8[i4 >> 0] = 1;
   }
   i3 = i3 + 1 | 0;
  }
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i19 = i1 + -4 | 0;
   HEAP32[i10 >> 2] = i19;
   i1 = i19;
  }
  if (!(HEAP8[i4 >> 0] | 0)) break; else i16 = 1;
 }
 if ((i17 | 0) == 3) ___assert_fail(38306, 38266, 163, 46573);
 __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11SelectifierC2Ev(i13);
 HEAP32[i13 + 40 >> 2] = HEAP32[i14 + 40 >> 2];
 HEAP32[i13 + 36 >> 2] = i12;
 __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE4walkERPNS_10ExpressionE(i13 + 16 + -16 + 16 | 0, i6);
 if (i16) {
  __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11TypeUpdaterC2Ev(i15);
  HEAP32[i15 + 36 >> 2] = i12;
  __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE4walkERPNS_10ExpressionE(i15 + 16 + -16 + 16 | 0, i6);
  __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEED2Ev(i15);
 }
 __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEED2Ev(i13);
 STACKTOP = i18;
 return;
}

function __ZN4wasm15Asm2WasmBuilder13detectAsmTypeEN6cashew3RefEP7AsmData(i9, i5, i6) {
 i9 = i9 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i10 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i11 + 12 | 0;
 i1 = i11 + 8 | 0;
 i2 = i11 + 4 | 0;
 i3 = i11;
 do if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i5, 0) | 0, 59292) | 0) {
  i4 = __ZN6cashew3RefixEj(i5, 1) | 0;
  i4 = __ZN6cashew5Value10getIStringEv(HEAP32[i4 >> 2] | 0) | 0;
  HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
  if (__ZNKSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS6_PvEEEERKT_(i6, i8) | 0) {
   i10 = 11;
   break;
  }
  i1 = i9 + 48 | 0;
  if ((__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i1, i8) | 0) == (i9 + 52 | 0)) ___assert_fail(29725, 16311, 289, 30430); else {
   i7 = (__ZNSt3__23mapIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_(i1, i8) | 0) + 4 | 0;
   i7 = __ZN4wasm13wasmToAsmTypeENS_8WasmTypeE(HEAP32[i7 >> 2] | 0) | 0;
   break;
  }
 } else if ((__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i5, 0) | 0, 59340) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i5, 1) | 0, 0) | 0, 59292) | 0 : 0) ? (i4 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i5, 1) | 0, 1) | 0, i4 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i9 + 60 | 0, __ZN6cashew5Value10getIStringEv(HEAP32[i4 >> 2] | 0) | 0) | 0, (i4 | 0) != (i9 + 64 | 0)) : 0) i7 = HEAP32[i4 + 28 >> 2] | 0; else i10 = 11; while (0);
 if ((i10 | 0) == 11) {
  HEAP32[i2 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i9 + 80 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i8 >> 2] = HEAP32[i3 >> 2];
  i7 = __Z10detectTypeN6cashew3RefEP7AsmDatabNS_7IStringE(i1, i6, 0, i8) | 0;
 }
 STACKTOP = i11;
 return i7 | 0;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE(i2, i5, i6, i7, i1) {
 i2 = i2 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i8 = 0;
 i4 = i1 + 8 | 0;
 L1 : while (1) {
  i1 = HEAP32[i5 >> 2] | 0;
  do if (i1) {
   if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
    HEAP32[i5 >> 2] = 0;
    i1 = 0;
    break;
   } else {
    i1 = HEAP32[i5 >> 2] | 0;
    break;
   }
  } else i1 = 0; while (0);
  i1 = (i1 | 0) == 0;
  i2 = HEAP32[i6 >> 2] | 0;
  do if (i2) {
   if ((HEAP32[i2 + 12 >> 2] | 0) != (HEAP32[i2 + 16 >> 2] | 0)) if (i1) break; else break L1;
   if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) != -1) if (i1) break; else break L1; else {
    HEAP32[i6 >> 2] = 0;
    i8 = 12;
    break;
   }
  } else i8 = 12; while (0);
  if ((i8 | 0) == 12) {
   i8 = 0;
   if (i1) {
    i2 = 0;
    break;
   } else i2 = 0;
  }
  i1 = HEAP32[i5 >> 2] | 0;
  i3 = HEAP32[i1 + 12 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) i1 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0; else i1 = HEAPU8[i3 >> 0] | 0;
  if ((i1 & 255) << 24 >> 24 <= -1) break;
  if (!(HEAP16[(HEAP32[i4 >> 2] | 0) + (i1 << 24 >> 24 << 1) >> 1] & 8192)) break;
  i1 = HEAP32[i5 >> 2] | 0;
  i2 = i1 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i1 + 16 >> 2] | 0)) {
   FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 40 >> 2] & 255](i1) | 0;
   continue;
  } else {
   HEAP32[i2 >> 2] = i3 + 1;
   continue;
  }
 }
 i1 = HEAP32[i5 >> 2] | 0;
 do if (i1) {
  if ((HEAP32[i1 + 12 >> 2] | 0) == (HEAP32[i1 + 16 >> 2] | 0)) if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) {
   HEAP32[i5 >> 2] = 0;
   i1 = 0;
   break;
  } else {
   i1 = HEAP32[i5 >> 2] | 0;
   break;
  }
 } else i1 = 0; while (0);
 i1 = (i1 | 0) == 0;
 do if (i2) {
  if ((HEAP32[i2 + 12 >> 2] | 0) == (HEAP32[i2 + 16 >> 2] | 0) ? (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 36 >> 2] & 255](i2) | 0) == -1 : 0) {
   HEAP32[i6 >> 2] = 0;
   i8 = 32;
   break;
  }
  if (!i1) i8 = 33;
 } else i8 = 32; while (0);
 if ((i8 | 0) == 32 ? i1 : 0) i8 = 33;
 if ((i8 | 0) == 33) HEAP32[i7 >> 2] = HEAP32[i7 >> 2] | 2;
 return;
}

function __ZNSt3__28ios_base4InitC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i1 = HEAP32[2020] | 0;
 __ZNSt3__210__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t(61312, i1, 61368);
 HEAP32[15158] = 12168;
 HEAP32[15160] = 12188;
 HEAP32[15159] = 0;
 __ZNSt3__28ios_base4initEPv(60640, 61312);
 HEAP32[15178] = 0;
 HEAP32[15179] = -1;
 __ZNSt3__210__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t(61376, i1, 61432);
 HEAP32[15180] = 12208;
 HEAP32[15182] = 12228;
 HEAP32[15181] = 0;
 __ZNSt3__28ios_base4initEPv(60728, 61376);
 HEAP32[15200] = 0;
 HEAP32[15201] = -1;
 i1 = HEAP32[1990] | 0;
 __ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t(61440, i1, 61488);
 HEAP32[15202] = 12248;
 HEAP32[15203] = 12268;
 __ZNSt3__28ios_base4initEPv(60812, 61440);
 HEAP32[15221] = 0;
 HEAP32[15222] = -1;
 __ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t(61496, i1, 61544);
 HEAP32[15223] = 12288;
 HEAP32[15224] = 12308;
 __ZNSt3__28ios_base4initEPv(60896, 61496);
 HEAP32[15242] = 0;
 HEAP32[15243] = -1;
 i1 = HEAP32[1961] | 0;
 __ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t(61552, i1, 61600);
 HEAP32[15244] = 12248;
 HEAP32[15245] = 12268;
 __ZNSt3__28ios_base4initEPv(60980, 61552);
 HEAP32[15263] = 0;
 HEAP32[15264] = -1;
 i2 = HEAP32[60976 + (HEAP32[(HEAP32[15244] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0;
 HEAP32[15286] = 12248;
 HEAP32[15287] = 12268;
 __ZNSt3__28ios_base4initEPv(61148, i2);
 HEAP32[15305] = 0;
 HEAP32[15306] = -1;
 __ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t(61608, i1, 61656);
 HEAP32[15265] = 12288;
 HEAP32[15266] = 12308;
 __ZNSt3__28ios_base4initEPv(61064, 61608);
 HEAP32[15284] = 0;
 HEAP32[15285] = -1;
 i1 = HEAP32[61060 + (HEAP32[(HEAP32[15265] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0;
 HEAP32[15307] = 12288;
 HEAP32[15308] = 12308;
 __ZNSt3__28ios_base4initEPv(61232, i1);
 HEAP32[15326] = 0;
 HEAP32[15327] = -1;
 HEAP32[60632 + (HEAP32[(HEAP32[15158] | 0) + -12 >> 2] | 0) + 72 >> 2] = 60808;
 HEAP32[60720 + (HEAP32[(HEAP32[15180] | 0) + -12 >> 2] | 0) + 72 >> 2] = 60892;
 i1 = 60976 + (HEAP32[(HEAP32[15244] | 0) + -12 >> 2] | 0) + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i1 >> 2] | 8192;
 i1 = 61060 + (HEAP32[(HEAP32[15265] | 0) + -12 >> 2] | 0) + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i1 >> 2] | 8192;
 HEAP32[60976 + (HEAP32[(HEAP32[15244] | 0) + -12 >> 2] | 0) + 72 >> 2] = 60808;
 HEAP32[61060 + (HEAP32[(HEAP32[15265] | 0) + -12 >> 2] | 0) + 72 >> 2] = 60892;
 return;
}

function __ZNSt3__2L12ucs4_to_utf8EPKjS1_RS1_PhS3_RS3_mNS_12codecvt_modeE(i1, i8, i9, i4, i2, i10, i7, i3) {
 i1 = i1 | 0;
 i8 = i8 | 0;
 i9 = i9 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i10 = i10 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 var i5 = 0, i6 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP32[i10 >> 2] = i4;
 i6 = i2;
 if (i3 & 2) if ((i6 - i4 | 0) < 3) i1 = 1; else {
  HEAP32[i10 >> 2] = i4 + 1;
  HEAP8[i4 >> 0] = -17;
  i5 = HEAP32[i10 >> 2] | 0;
  HEAP32[i10 >> 2] = i5 + 1;
  HEAP8[i5 >> 0] = -69;
  i5 = HEAP32[i10 >> 2] | 0;
  HEAP32[i10 >> 2] = i5 + 1;
  HEAP8[i5 >> 0] = -65;
  i5 = 4;
 } else i5 = 4;
 L4 : do if ((i5 | 0) == 4) {
  i1 = HEAP32[i9 >> 2] | 0;
  while (1) {
   if (i1 >>> 0 >= i8 >>> 0) {
    i1 = 0;
    break L4;
   }
   i3 = HEAP32[i1 >> 2] | 0;
   if (i3 >>> 0 > i7 >>> 0 | (i3 & -2048 | 0) == 55296) {
    i1 = 2;
    break L4;
   }
   do if (i3 >>> 0 >= 128) {
    if (i3 >>> 0 < 2048) {
     i1 = HEAP32[i10 >> 2] | 0;
     if ((i6 - i1 | 0) < 2) {
      i1 = 1;
      break L4;
     }
     HEAP32[i10 >> 2] = i1 + 1;
     HEAP8[i1 >> 0] = i3 >>> 6 | 192;
     i5 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i5 + 1;
     HEAP8[i5 >> 0] = i3 & 63 | 128;
     break;
    }
    i1 = HEAP32[i10 >> 2] | 0;
    i2 = i6 - i1 | 0;
    if (i3 >>> 0 < 65536) {
     if ((i2 | 0) < 3) {
      i1 = 1;
      break L4;
     }
     HEAP32[i10 >> 2] = i1 + 1;
     HEAP8[i1 >> 0] = i3 >>> 12 | 224;
     i5 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i5 + 1;
     HEAP8[i5 >> 0] = i3 >>> 6 & 63 | 128;
     i5 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i5 + 1;
     HEAP8[i5 >> 0] = i3 & 63 | 128;
     break;
    } else {
     if ((i2 | 0) < 4) {
      i1 = 1;
      break L4;
     }
     HEAP32[i10 >> 2] = i1 + 1;
     HEAP8[i1 >> 0] = i3 >>> 18 | 240;
     i5 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i5 + 1;
     HEAP8[i5 >> 0] = i3 >>> 12 & 63 | 128;
     i5 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i5 + 1;
     HEAP8[i5 >> 0] = i3 >>> 6 & 63 | 128;
     i5 = HEAP32[i10 >> 2] | 0;
     HEAP32[i10 >> 2] = i5 + 1;
     HEAP8[i5 >> 0] = i3 & 63 | 128;
     break;
    }
   } else {
    i1 = HEAP32[i10 >> 2] | 0;
    if ((i6 - i1 | 0) < 1) {
     i1 = 1;
     break L4;
    }
    HEAP32[i10 >> 2] = i1 + 1;
    HEAP8[i1 >> 0] = i3;
   } while (0);
   i1 = (HEAP32[i9 >> 2] | 0) + 4 | 0;
   HEAP32[i9 >> 2] = i1;
  }
 } while (0);
 return i1 | 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11visitSelectEPNS_6SelectE(i1, i6, i3) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i5 = i7 + 48 | 0;
 i4 = i7 + 24 | 0;
 i2 = i7;
 __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i5, i6, HEAP32[i3 + 8 >> 2] | 0);
 if (!(HEAP32[i5 + 16 >> 2] | 0)) {
  __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i4, i6, HEAP32[i3 + 12 >> 2] | 0);
  if (!(HEAP32[i4 + 16 >> 2] | 0)) {
   __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i2, i6, HEAP32[i3 + 16 >> 2] | 0);
   if (!(HEAP32[i2 + 16 >> 2] | 0)) {
    i6 = (__ZNK4wasm7Literal6geti32Ev(i2) | 0) != 0;
    i6 = i6 ? i5 : i4;
    HEAP32[i1 >> 2] = HEAP32[i6 >> 2];
    HEAP32[i1 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
    HEAP32[i1 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
    HEAP32[i1 + 12 >> 2] = HEAP32[i6 + 12 >> 2];
    HEAP32[i1 + 16 >> 2] = HEAP32[i6 + 16 >> 2];
    HEAP32[i1 + 20 >> 2] = HEAP32[i6 + 20 >> 2];
   } else {
    HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
    HEAP32[i1 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
    HEAP32[i1 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
    HEAP32[i1 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
    HEAP32[i1 + 16 >> 2] = HEAP32[i2 + 16 >> 2];
    HEAP32[i1 + 20 >> 2] = HEAP32[i2 + 20 >> 2];
   }
  } else {
   HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
   HEAP32[i1 + 4 >> 2] = HEAP32[i4 + 4 >> 2];
   HEAP32[i1 + 8 >> 2] = HEAP32[i4 + 8 >> 2];
   HEAP32[i1 + 12 >> 2] = HEAP32[i4 + 12 >> 2];
   HEAP32[i1 + 16 >> 2] = HEAP32[i4 + 16 >> 2];
   HEAP32[i1 + 20 >> 2] = HEAP32[i4 + 20 >> 2];
  }
 } else {
  HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i5 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i5 + 8 >> 2];
  HEAP32[i1 + 12 >> 2] = HEAP32[i5 + 12 >> 2];
  HEAP32[i1 + 16 >> 2] = HEAP32[i5 + 16 >> 2];
  HEAP32[i1 + 20 >> 2] = HEAP32[i5 + 20 >> 2];
 }
 STACKTOP = i7;
 return;
}

function _pop_arg_529(i2, i3, i1) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0, d6 = 0.0;
 L1 : do if (i3 >>> 0 <= 20) do switch (i3 | 0) {
 case 9:
  {
   i4 = (HEAP32[i1 >> 2] | 0) + (4 - 1) & ~(4 - 1);
   i3 = HEAP32[i4 >> 2] | 0;
   HEAP32[i1 >> 2] = i4 + 4;
   HEAP32[i2 >> 2] = i3;
   break L1;
  }
 case 10:
  {
   i4 = (HEAP32[i1 >> 2] | 0) + (4 - 1) & ~(4 - 1);
   i3 = HEAP32[i4 >> 2] | 0;
   HEAP32[i1 >> 2] = i4 + 4;
   i4 = i2;
   HEAP32[i4 >> 2] = i3;
   HEAP32[i4 + 4 >> 2] = ((i3 | 0) < 0) << 31 >> 31;
   break L1;
  }
 case 11:
  {
   i4 = (HEAP32[i1 >> 2] | 0) + (4 - 1) & ~(4 - 1);
   i3 = HEAP32[i4 >> 2] | 0;
   HEAP32[i1 >> 2] = i4 + 4;
   i4 = i2;
   HEAP32[i4 >> 2] = i3;
   HEAP32[i4 + 4 >> 2] = 0;
   break L1;
  }
 case 12:
  {
   i4 = (HEAP32[i1 >> 2] | 0) + (8 - 1) & ~(8 - 1);
   i3 = i4;
   i5 = HEAP32[i3 >> 2] | 0;
   i3 = HEAP32[i3 + 4 >> 2] | 0;
   HEAP32[i1 >> 2] = i4 + 8;
   i4 = i2;
   HEAP32[i4 >> 2] = i5;
   HEAP32[i4 + 4 >> 2] = i3;
   break L1;
  }
 case 13:
  {
   i5 = (HEAP32[i1 >> 2] | 0) + (4 - 1) & ~(4 - 1);
   i4 = HEAP32[i5 >> 2] | 0;
   HEAP32[i1 >> 2] = i5 + 4;
   i4 = (i4 & 65535) << 16 >> 16;
   i5 = i2;
   HEAP32[i5 >> 2] = i4;
   HEAP32[i5 + 4 >> 2] = ((i4 | 0) < 0) << 31 >> 31;
   break L1;
  }
 case 14:
  {
   i5 = (HEAP32[i1 >> 2] | 0) + (4 - 1) & ~(4 - 1);
   i4 = HEAP32[i5 >> 2] | 0;
   HEAP32[i1 >> 2] = i5 + 4;
   i5 = i2;
   HEAP32[i5 >> 2] = i4 & 65535;
   HEAP32[i5 + 4 >> 2] = 0;
   break L1;
  }
 case 15:
  {
   i5 = (HEAP32[i1 >> 2] | 0) + (4 - 1) & ~(4 - 1);
   i4 = HEAP32[i5 >> 2] | 0;
   HEAP32[i1 >> 2] = i5 + 4;
   i4 = (i4 & 255) << 24 >> 24;
   i5 = i2;
   HEAP32[i5 >> 2] = i4;
   HEAP32[i5 + 4 >> 2] = ((i4 | 0) < 0) << 31 >> 31;
   break L1;
  }
 case 16:
  {
   i5 = (HEAP32[i1 >> 2] | 0) + (4 - 1) & ~(4 - 1);
   i4 = HEAP32[i5 >> 2] | 0;
   HEAP32[i1 >> 2] = i5 + 4;
   i5 = i2;
   HEAP32[i5 >> 2] = i4 & 255;
   HEAP32[i5 + 4 >> 2] = 0;
   break L1;
  }
 case 17:
  {
   i5 = (HEAP32[i1 >> 2] | 0) + (8 - 1) & ~(8 - 1);
   d6 = +HEAPF64[i5 >> 3];
   HEAP32[i1 >> 2] = i5 + 8;
   HEAPF64[i2 >> 3] = d6;
   break L1;
  }
 case 18:
  {
   i5 = (HEAP32[i1 >> 2] | 0) + (8 - 1) & ~(8 - 1);
   d6 = +HEAPF64[i5 >> 3];
   HEAP32[i1 >> 2] = i5 + 8;
   HEAPF64[i2 >> 3] = d6;
   break L1;
  }
 default:
  break L1;
 } while (0); while (0);
 return;
}

function __ZZN4wasm22SExpressionWasmBuilder6makeIfERNS_7ElementEENKUlPKcS2_E_clES4_S2_(i1, i2, i7) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i7 = i7 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i9 = i11 + 20 | 0;
 i3 = i11 + 16 | 0;
 i6 = i11 + 4 | 0;
 i10 = i11;
 i8 = HEAP32[i1 >> 2] | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i6 + 4 >> 2] = 0;
 HEAP32[i6 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i6, i2, _strlen(i2) | 0);
 i1 = __ZN4wasm22SExpressionWasmBuilder15getPrefixedNameENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i8, i6) | 0;
 HEAP32[i3 >> 2] = i1;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i6);
 i6 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i7, 0) | 0) | 0;
 if ((i6 | 0) != (HEAP32[14989] | 0) ? (i6 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i7, 0) | 0) | 0, (i6 | 0) != (HEAP32[14990] | 0)) : 0) {
  i5 = i1;
  i6 = 0;
 } else {
  i6 = __ZN4wasm7ElementixEj(i7, 1) | 0;
  if ((HEAP8[i6 >> 0] | 0) == 0 ? (i6 = (__ZN4wasm7ElementixEj(i7, 1) | 0) + 24 | 0, (HEAP8[i6 >> 0] | 0) != 0) : 0) {
   i5 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i7, 1) | 0) | 0;
   HEAP32[i3 >> 2] = i5;
   i6 = 1;
  } else {
   i5 = i1;
   i6 = 1;
  }
 }
 i4 = i8 + 68 | 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if ((i1 | 0) == (HEAP32[i8 + 72 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i8 + 64 | 0, i3); else {
  HEAP32[i1 >> 2] = i5;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 4;
 }
 i1 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i8, i7) | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i2 = i3 + -4 | 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  i7 = i3 + -4 | 0;
  HEAP32[i4 >> 2] = i7;
  i3 = i7;
 }
 if (!i6) {
  HEAP32[i10 >> 2] = i5;
  HEAP32[i9 >> 2] = HEAP32[i10 >> 2];
  if (__ZN4wasm11BreakSeeker3hasEPNS_10ExpressionENS_4NameE(i1, i9) | 0) {
   i10 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i8 + 4 >> 2] | 0) | 0;
   HEAP32[i10 + 8 >> 2] = i5;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i10 + 12 | 0, i1);
   __ZN4wasm5Block8finalizeEv(i10);
   i1 = i10;
  }
 } else HEAP32[((HEAP32[i1 >> 2] | 0) == 1 ? i1 : 0) + 8 >> 2] = i5;
 STACKTOP = i11;
 return i1 | 0;
}

function _scanexp(i8, i3) {
 i8 = i8 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i6 = i8 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i7 = i8 + 100 | 0;
 if (i1 >>> 0 < (HEAP32[i7 >> 2] | 0) >>> 0) {
  HEAP32[i6 >> 2] = i1 + 1;
  i1 = HEAPU8[i1 >> 0] | 0;
 } else i1 = ___shgetc(i8) | 0;
 switch (i1 | 0) {
 case 43:
 case 45:
  {
   i2 = (i1 | 0) == 45 & 1;
   i1 = HEAP32[i6 >> 2] | 0;
   if (i1 >>> 0 < (HEAP32[i7 >> 2] | 0) >>> 0) {
    HEAP32[i6 >> 2] = i1 + 1;
    i1 = HEAPU8[i1 >> 0] | 0;
   } else i1 = ___shgetc(i8) | 0;
   if ((i3 | 0) != 0 & (i1 + -48 | 0) >>> 0 > 9 ? (HEAP32[i7 >> 2] | 0) != 0 : 0) {
    HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + -1;
    i5 = i2;
   } else i5 = i2;
   break;
  }
 default:
  i5 = 0;
 }
 if ((i1 + -48 | 0) >>> 0 > 9) if (!(HEAP32[i7 >> 2] | 0)) {
  i2 = -2147483648;
  i1 = 0;
 } else {
  HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + -1;
  i2 = -2147483648;
  i1 = 0;
 } else {
  i2 = 0;
  do {
   i2 = i1 + -48 + (i2 * 10 | 0) | 0;
   i1 = HEAP32[i6 >> 2] | 0;
   if (i1 >>> 0 < (HEAP32[i7 >> 2] | 0) >>> 0) {
    HEAP32[i6 >> 2] = i1 + 1;
    i1 = HEAPU8[i1 >> 0] | 0;
   } else i1 = ___shgetc(i8) | 0;
  } while ((i1 + -48 | 0) >>> 0 < 10 & (i2 | 0) < 214748364);
  i3 = ((i2 | 0) < 0) << 31 >> 31;
  if ((i1 + -48 | 0) >>> 0 < 10) {
   do {
    i3 = ___muldi3(i2 | 0, i3 | 0, 10, 0) | 0;
    i2 = tempRet0;
    i1 = _i64Add(i1 | 0, ((i1 | 0) < 0) << 31 >> 31 | 0, -48, -1) | 0;
    i2 = _i64Add(i1 | 0, tempRet0 | 0, i3 | 0, i2 | 0) | 0;
    i3 = tempRet0;
    i1 = HEAP32[i6 >> 2] | 0;
    if (i1 >>> 0 < (HEAP32[i7 >> 2] | 0) >>> 0) {
     HEAP32[i6 >> 2] = i1 + 1;
     i1 = HEAPU8[i1 >> 0] | 0;
    } else i1 = ___shgetc(i8) | 0;
   } while ((i1 + -48 | 0) >>> 0 < 10 & ((i3 | 0) < 21474836 | (i3 | 0) == 21474836 & i2 >>> 0 < 2061584302));
   i4 = i2;
  } else i4 = i2;
  if ((i1 + -48 | 0) >>> 0 < 10) do {
   i1 = HEAP32[i6 >> 2] | 0;
   if (i1 >>> 0 < (HEAP32[i7 >> 2] | 0) >>> 0) {
    HEAP32[i6 >> 2] = i1 + 1;
    i1 = HEAPU8[i1 >> 0] | 0;
   } else i1 = ___shgetc(i8) | 0;
  } while ((i1 + -48 | 0) >>> 0 < 10);
  if (HEAP32[i7 >> 2] | 0) HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + -1;
  i8 = (i5 | 0) != 0;
  i1 = _i64Subtract(0, 0, i4 | 0, i3 | 0) | 0;
  i2 = i8 ? tempRet0 : i3;
  i1 = i8 ? i1 : i4;
 }
 tempRet0 = i2;
 return i1 | 0;
}

function __ZN4wasm20OptimizeInstructions10visitUnaryEPNS_5UnaryE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 L1 : do if (((HEAP32[i1 + 8 >> 2] | 0) == 20 ? (i2 = HEAP32[i1 + 12 >> 2] | 0, !((i2 | 0) == 0 | (HEAP32[i2 >> 2] | 0) != 15)) : 0) ? ((HEAP32[i2 + 4 >> 2] | 0) + -1 | 0) >>> 0 < 2 : 0) {
  i1 = i2 + 8 | 0;
  do switch (HEAP32[i1 >> 2] | 0) {
  case 15:
   {
    HEAP32[i1 >> 2] = 16;
    break;
   }
  case 16:
   {
    HEAP32[i1 >> 2] = 15;
    break;
   }
  case 17:
   {
    HEAP32[i1 >> 2] = 23;
    break;
   }
  case 18:
   {
    HEAP32[i1 >> 2] = 24;
    break;
   }
  case 19:
   {
    HEAP32[i1 >> 2] = 21;
    break;
   }
  case 20:
   {
    HEAP32[i1 >> 2] = 22;
    break;
   }
  case 21:
   {
    HEAP32[i1 >> 2] = 19;
    break;
   }
  case 22:
   {
    HEAP32[i1 >> 2] = 20;
    break;
   }
  case 23:
   {
    HEAP32[i1 >> 2] = 17;
    break;
   }
  case 24:
   {
    HEAP32[i1 >> 2] = 18;
    break;
   }
  case 40:
   {
    HEAP32[i1 >> 2] = 41;
    break;
   }
  case 41:
   {
    HEAP32[i1 >> 2] = 40;
    break;
   }
  case 42:
   {
    HEAP32[i1 >> 2] = 48;
    break;
   }
  case 43:
   {
    HEAP32[i1 >> 2] = 49;
    break;
   }
  case 44:
   {
    HEAP32[i1 >> 2] = 46;
    break;
   }
  case 45:
   {
    HEAP32[i1 >> 2] = 47;
    break;
   }
  case 46:
   {
    HEAP32[i1 >> 2] = 44;
    break;
   }
  case 47:
   {
    HEAP32[i1 >> 2] = 45;
    break;
   }
  case 48:
   {
    HEAP32[i1 >> 2] = 42;
    break;
   }
  case 49:
   {
    HEAP32[i1 >> 2] = 43;
    break;
   }
  case 57:
   {
    HEAP32[i1 >> 2] = 58;
    break;
   }
  case 58:
   {
    HEAP32[i1 >> 2] = 57;
    break;
   }
  case 59:
   {
    HEAP32[i1 >> 2] = 62;
    break;
   }
  case 60:
   {
    HEAP32[i1 >> 2] = 61;
    break;
   }
  case 61:
   {
    HEAP32[i1 >> 2] = 60;
    break;
   }
  case 62:
   {
    HEAP32[i1 >> 2] = 59;
    break;
   }
  case 70:
   {
    HEAP32[i1 >> 2] = 71;
    break;
   }
  case 71:
   {
    HEAP32[i1 >> 2] = 70;
    break;
   }
  case 72:
   {
    HEAP32[i1 >> 2] = 75;
    break;
   }
  case 73:
   {
    HEAP32[i1 >> 2] = 74;
    break;
   }
  case 74:
   {
    HEAP32[i1 >> 2] = 73;
    break;
   }
  case 75:
   {
    HEAP32[i1 >> 2] = 72;
    break;
   }
  default:
   break L1;
  } while (0);
  HEAP32[i3 + 20 >> 2] = i2;
 } while (0);
 return;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11visitSwitchEPNS_6SwitchE(i12, i4, i6) {
 i12 = i12 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i1 = i15 + 24 | 0;
 i2 = i15;
 HEAP32[i12 >> 2] = 0;
 i8 = i12 + 8 | 0;
 i11 = i8;
 HEAP32[i11 >> 2] = 0;
 HEAP32[i11 + 4 >> 2] = 0;
 i11 = i12 + 16 | 0;
 HEAP32[i11 >> 2] = 0;
 i3 = HEAP32[i6 + 32 >> 2] | 0;
 if (i3) {
  __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i1, i4, i3);
  HEAP32[i12 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i12 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i12 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
  HEAP32[i12 + 12 >> 2] = HEAP32[i1 + 12 >> 2];
  HEAP32[i12 + 16 >> 2] = HEAP32[i1 + 16 >> 2];
  if (!(HEAP32[i11 >> 2] | 0)) {
   i10 = i8;
   i7 = i12;
   i9 = HEAP32[i10 >> 2] | 0;
   i10 = HEAP32[i10 + 4 >> 2] | 0;
   i13 = HEAP32[i12 >> 2] | 0;
   i14 = HEAP32[i12 + 4 >> 2] | 0;
   i5 = 5;
  }
 } else {
  i7 = i12;
  i9 = 0;
  i10 = 0;
  i13 = 0;
  i14 = 0;
  i5 = 5;
 }
 if ((i5 | 0) == 5 ? (__ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i2, i4, HEAP32[i6 + 28 >> 2] | 0), HEAP32[i7 >> 2] = HEAP32[i2 >> 2], HEAP32[i7 + 4 >> 2] = HEAP32[i2 + 4 >> 2], HEAP32[i7 + 8 >> 2] = HEAP32[i2 + 8 >> 2], HEAP32[i7 + 12 >> 2] = HEAP32[i2 + 12 >> 2], HEAP32[i7 + 16 >> 2] = HEAP32[i2 + 16 >> 2], (HEAP32[i11 >> 2] | 0) == 0) : 0) {
  i2 = __ZN4wasm7Literal10getIntegerEv(i12) | 0;
  i5 = tempRet0;
  i1 = HEAP32[i6 + 24 >> 2] | 0;
  if ((i5 | 0) > -1 | (i5 | 0) == -1 & i2 >>> 0 > 4294967295 ? i2 >>> 0 < (HEAP32[i6 + 16 >> 2] | 0) >>> 0 : 0) {
   i1 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i6 + 8 | 0, i2) | 0;
   i1 = HEAP32[i1 >> 2] | 0;
  }
  HEAP32[i11 >> 2] = i1;
  HEAP32[i12 >> 2] = i13;
  HEAP32[i7 + 4 >> 2] = i14;
  i14 = i8;
  HEAP32[i14 >> 2] = i9;
  HEAP32[i14 + 4 >> 2] = i10;
 }
 STACKTOP = i15;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i1, i4, i6, i3) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i2 = 0, i5 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i7;
 i1 = HEAP8[i4 >> 0] | 0;
 L1 : do switch (i1 << 24 >> 24) {
 case 105:
  {
   switch (HEAP8[i4 + 1 >> 0] | 0) {
   case 51:
    break;
   case 54:
    {
     if ((HEAP8[i4 + 2 >> 0] | 0) != 52) {
      i2 = 17;
      break L1;
     }
     if (i3) {
      i1 = 2;
      i2 = 19;
      break L1;
     }
     i1 = (HEAP8[i4 + 3 >> 0] | 0) == 0;
     if (i1 | i6) {
      i1 = i1 ? 2 : 0;
      i2 = 19;
      break L1;
     } else {
      i2 = 18;
      break L1;
     }
    }
   default:
    {
     i2 = 17;
     break L1;
    }
   }
   if ((HEAP8[i4 + 2 >> 0] | 0) == 50) if (!i3 ? (HEAP8[i4 + 3 >> 0] | 0) != 0 : 0) if (i1 << 24 >> 24 == 102) i2 = 10; else i2 = 17; else {
    i1 = 1;
    i2 = 19;
   } else i2 = 17;
   break;
  }
 case 102:
  {
   i2 = 10;
   break;
  }
 default:
  i2 = 17;
 } while (0);
 L11 : do if ((i2 | 0) == 10) switch (HEAP8[i4 + 1 >> 0] | 0) {
 case 51:
  {
   if ((HEAP8[i4 + 2 >> 0] | 0) != 50) {
    i2 = 17;
    break L11;
   }
   if (i3) {
    i1 = 3;
    i2 = 19;
    break L11;
   }
   i1 = (HEAP8[i4 + 3 >> 0] | 0) == 0;
   if (i1 | i6) {
    i1 = i1 ? 3 : 0;
    i2 = 19;
    break L11;
   } else {
    i2 = 18;
    break L11;
   }
  }
 case 54:
  {
   if ((HEAP8[i4 + 2 >> 0] | 0) != 52) {
    i2 = 17;
    break L11;
   }
   if (i3) {
    i1 = 4;
    i2 = 19;
    break L11;
   }
   i1 = (HEAP8[i4 + 3 >> 0] | 0) == 0;
   if (i1 | i6) {
    i1 = i1 ? 4 : 0;
    i2 = 19;
    break L11;
   } else {
    i2 = 18;
    break L11;
   }
  }
 default:
  {
   i2 = 17;
   break L11;
  }
 } while (0);
 if ((i2 | 0) == 17) if (i6) {
  i1 = 0;
  i2 = 19;
 } else i2 = 18;
 if ((i2 | 0) == 18) {
  i7 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i5 >> 2] = 0;
  HEAP32[i5 + 4 >> 2] = 0;
  HEAP32[i5 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i5, 21700, 12);
  __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i7, i5);
  ___cxa_throw(i7 | 0, 64, 279);
 } else if ((i2 | 0) == 19) {
  STACKTOP = i7;
  return i1 | 0;
 }
 return 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17parseAfterKeywordERNS3_4FragERPcPKc(i5, i1, i4, i3) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i2 = 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i4);
 i1 = HEAP32[i1 >> 2] | 0;
 do if ((i1 | 0) != (HEAP32[14887] | 0)) {
  if ((i1 | 0) == (HEAP32[14824] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE8parseVarERPcPKcb(i5, i4, i3, 0) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14825] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE8parseVarERPcPKcb(i5, i4, i3, 1) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14828] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE11parseReturnERPcPKc(i5, i4, i3) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14829] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE7parseIfERPcPKc(i5, i4, i3) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14832] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE7parseDoERPcPKc(i5, i4, i3) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14831] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10parseWhileERPcPKc(i5, i4, i3) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14839] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10parseBreakERPcPKc(i5, i4, i3) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14840] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseContinueERPcPKc(i5, i4, i3) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14841] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE11parseSwitchERPcPKc(i5, i4, i3) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14899] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE8parseNewERPcPKc(i5, i4, i3) | 0;
   break;
  }
  if ((i1 | 0) == (HEAP32[14833] | 0)) {
   i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE8parseForERPcPKc(i5, i4, i3) | 0;
   break;
  } else {
   __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4dumpEPKcPc(i1, HEAP32[i4 >> 2] | 0);
   _abort();
  }
 } else i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseFunctionERPcPKc(i5, i4, i3) | 0; while (0);
 return i2 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_114parse_decltypeINS0_2DbEEEPKcS4_S4_RT_(i1, i4, i3) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i2 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i5 = i10 + 40 | 0;
 i6 = i10 + 24 | 0;
 i8 = i10 + 12 | 0;
 i9 = i10;
 L1 : do if ((i4 - i1 | 0) > 3 ? (HEAP8[i1 >> 0] | 0) == 68 : 0) {
  switch (HEAP8[i1 + 1 >> 0] | 0) {
  case 84:
  case 116:
   break;
  default:
   break L1;
  }
  i11 = i1 + 2 | 0;
  i7 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i11, i4, i3) | 0;
  if ((!((i7 | 0) == (i11 | 0) | (i7 | 0) == (i4 | 0)) ? (HEAP8[i7 >> 0] | 0) == 69 : 0) ? (i2 = HEAP32[i3 + 4 >> 2] | 0, (HEAP32[i3 >> 2] | 0) != (i2 | 0)) : 0) {
   i3 = i2 + -24 | 0;
   __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i9, i3);
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i9, 0, 57604) | 0;
   HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i8 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i8 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i8, 56966) | 0;
   HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i6 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
   HEAP32[i6 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
   i2 = 0;
   while (1) {
    if ((i2 | 0) == 3) break;
    HEAP32[i1 + (i2 << 2) >> 2] = 0;
    i2 = i2 + 1 | 0;
   }
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i5, i6);
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i3, i5);
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i5);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i6);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i8);
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i9);
   i1 = i7 + 1 | 0;
  }
 } while (0);
 STACKTOP = i10;
 return i1 | 0;
}

function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE8overflowEi(i17, i16) {
 i17 = i17 | 0;
 i16 = i16 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i18 = 0;
 i18 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i11 = i18;
 do if ((i16 | 0) != -1) {
  i12 = i17 + 12 | 0;
  i13 = i17 + 8 | 0;
  i14 = (HEAP32[i12 >> 2] | 0) - (HEAP32[i13 >> 2] | 0) | 0;
  i15 = i17 + 24 | 0;
  i7 = HEAP32[i15 >> 2] | 0;
  i9 = i17 + 28 | 0;
  i1 = HEAP32[i9 >> 2] | 0;
  if ((i7 | 0) == (i1 | 0)) {
   i6 = i17 + 48 | 0;
   if (!(HEAP32[i6 >> 2] & 16)) {
    i1 = -1;
    break;
   }
   i4 = i17 + 20 | 0;
   i5 = HEAP32[i4 >> 2] | 0;
   i10 = i17 + 44 | 0;
   i8 = (HEAP32[i10 >> 2] | 0) - i5 | 0;
   i3 = i17 + 32 | 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i3, 0);
   i1 = i3 + 11 | 0;
   if ((HEAP8[i1 >> 0] | 0) < 0) i2 = (HEAP32[i17 + 40 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i3, i2, 0);
   i1 = HEAP8[i1 >> 0] | 0;
   if (i1 << 24 >> 24 < 0) {
    i2 = HEAP32[i3 >> 2] | 0;
    i1 = HEAP32[i17 + 36 >> 2] | 0;
   } else {
    i2 = i3;
    i1 = i1 & 255;
   }
   i1 = i2 + i1 | 0;
   HEAP32[i4 >> 2] = i2;
   HEAP32[i9 >> 2] = i1;
   i7 = i2 + (i7 - i5) | 0;
   HEAP32[i15 >> 2] = i7;
   i2 = i2 + i8 | 0;
   HEAP32[i10 >> 2] = i2;
   i8 = i10;
   i3 = i10;
   i5 = i1;
  } else {
   i2 = i17 + 44 | 0;
   i8 = i2;
   i6 = i17 + 48 | 0;
   i3 = i2;
   i2 = HEAP32[i2 >> 2] | 0;
   i5 = i1;
  }
  i4 = i7 + 1 | 0;
  HEAP32[i11 >> 2] = i4;
  i2 = HEAP32[(i4 >>> 0 < i2 >>> 0 ? i3 : i11) >> 2] | 0;
  HEAP32[i8 >> 2] = i2;
  if (HEAP32[i6 >> 2] & 8 | 0) {
   i1 = i17 + 32 | 0;
   if ((HEAP8[i1 + 11 >> 0] | 0) < 0) i1 = HEAP32[i1 >> 2] | 0;
   HEAP32[i13 >> 2] = i1;
   HEAP32[i12 >> 2] = i1 + i14;
   HEAP32[i17 + 16 >> 2] = i2;
  }
  if ((i7 | 0) == (i5 | 0)) {
   i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i17 >> 2] | 0) + 52 >> 2] & 63](i17, i16 & 255) | 0;
   break;
  } else {
   HEAP32[i15 >> 2] = i4;
   HEAP8[i7 >> 0] = i16;
   i1 = i16 & 255;
   break;
  }
 } else i1 = 0; while (0);
 STACKTOP = i18;
 return i1 | 0;
}

function __ZNSt3__227__insertion_sort_incompleteIRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEbT0_S8_T_(i6, i8, i5) {
 i6 = i6 | 0;
 i8 = i8 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 switch (i8 - i6 >> 2 | 0) {
 case 1:
 case 0:
  {
   i1 = 1;
   break;
  }
 case 2:
  {
   i1 = i8 + -4 | 0;
   if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i5, HEAP32[i1 >> 2] | 0, HEAP32[i6 >> 2] | 0) | 0) {
    i8 = HEAP32[i6 >> 2] | 0;
    HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i1 >> 2] = i8;
    i1 = 1;
   } else i1 = 1;
   break;
  }
 case 3:
  {
   __ZNSt3__27__sort3IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_T_(i6, i6 + 4 | 0, i8 + -4 | 0, i5) | 0;
   i1 = 1;
   break;
  }
 case 4:
  {
   __ZNSt3__27__sort4IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_S8_T_(i6, i6 + 4 | 0, i6 + 8 | 0, i8 + -4 | 0, i5) | 0;
   i1 = 1;
   break;
  }
 case 5:
  {
   __ZNSt3__27__sort5IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_S8_S8_T_(i6, i6 + 4 | 0, i6 + 8 | 0, i6 + 12 | 0, i8 + -4 | 0, i5) | 0;
   i1 = 1;
   break;
  }
 default:
  {
   i2 = i6 + 8 | 0;
   __ZNSt3__27__sort3IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_T_(i6, i6 + 4 | 0, i2, i5) | 0;
   i1 = 0;
   i7 = i6 + 12 | 0;
   while (1) {
    if ((i7 | 0) == (i8 | 0)) {
     i2 = 1;
     i1 = 0;
     break;
    }
    if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i5, HEAP32[i7 >> 2] | 0, HEAP32[i2 >> 2] | 0) | 0) {
     i4 = HEAP32[i7 >> 2] | 0;
     i3 = i7;
     while (1) {
      HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
      if ((i2 | 0) == (i6 | 0)) {
       i2 = i6;
       break;
      }
      i3 = i2 + -4 | 0;
      if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i5, i4, HEAP32[i3 >> 2] | 0) | 0) {
       i9 = i2;
       i2 = i3;
       i3 = i9;
      } else break;
     }
     HEAP32[i2 >> 2] = i4;
     i1 = i1 + 1 | 0;
     if ((i1 | 0) == 8) {
      i2 = 0;
      i1 = (i7 + 4 | 0) == (i8 | 0);
      break;
     }
    }
    i2 = i7;
    i7 = i7 + 4 | 0;
   }
   i1 = i1 | i2;
  }
 }
 return i1 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb(i10, i11, i8, i9, i12, i14) {
 i10 = i10 | 0;
 i11 = i11 | 0;
 i8 = i8 | 0;
 i9 = i9 | 0;
 i12 = i12 | 0;
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i2 = i15 + 48 | 0;
 i1 = i15 + 24 | 0;
 i13 = i15 + 16 | 0;
 i3 = i15 + 20 | 0;
 i4 = i15 + 12 | 0;
 i5 = i15 + 8 | 0;
 i6 = i15 + 4 | 0;
 i7 = i15;
 if (!(HEAP32[i9 + 4 >> 2] & 1)) {
  HEAP32[i13 >> 2] = -1;
  i7 = HEAP32[(HEAP32[i10 >> 2] | 0) + 16 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i11 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  i1 = FUNCTION_TABLE_iiiiiii[i7 & 63](i10, i1, i2, i9, i12, i13) | 0;
  HEAP32[i11 >> 2] = i1;
  switch (HEAP32[i13 >> 2] | 0) {
  case 0:
   {
    HEAP8[i14 >> 0] = 0;
    break;
   }
  case 1:
   {
    HEAP8[i14 >> 0] = 1;
    break;
   }
  default:
   {
    HEAP8[i14 >> 0] = 1;
    HEAP32[i12 >> 2] = 4;
   }
  }
 } else {
  i10 = __ZNKSt3__28ios_base6getlocEv(i9) | 0;
  HEAP32[i5 >> 2] = i10;
  i13 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61712) | 0;
  __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
  i9 = __ZNKSt3__28ios_base6getlocEv(i9) | 0;
  HEAP32[i6 >> 2] = i9;
  i10 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61720) | 0;
  __ZNSt3__214__shared_count16__release_sharedEv(i9) | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i10 >> 2] | 0) + 24 >> 2] & 1023](i1, i10);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i10 >> 2] | 0) + 28 >> 2] & 1023](i1 + 12 | 0, i10);
  HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i7 >> 2];
  i13 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb(i11, i2, i1, i1 + 24 | 0, i13, i12, 1) | 0) == (i1 | 0) & 1;
  HEAP8[i14 >> 0] = i13;
  i14 = HEAP32[i11 >> 2] | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i1 + 12 | 0);
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i1);
  i1 = i14;
 }
 STACKTOP = i15;
 return i1 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb(i10, i11, i8, i9, i12, i14) {
 i10 = i10 | 0;
 i11 = i11 | 0;
 i8 = i8 | 0;
 i9 = i9 | 0;
 i12 = i12 | 0;
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i2 = i15 + 48 | 0;
 i1 = i15 + 24 | 0;
 i13 = i15 + 16 | 0;
 i3 = i15 + 20 | 0;
 i4 = i15 + 12 | 0;
 i5 = i15 + 8 | 0;
 i6 = i15 + 4 | 0;
 i7 = i15;
 if (!(HEAP32[i9 + 4 >> 2] & 1)) {
  HEAP32[i13 >> 2] = -1;
  i7 = HEAP32[(HEAP32[i10 >> 2] | 0) + 16 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i11 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  i1 = FUNCTION_TABLE_iiiiiii[i7 & 63](i10, i1, i2, i9, i12, i13) | 0;
  HEAP32[i11 >> 2] = i1;
  switch (HEAP32[i13 >> 2] | 0) {
  case 0:
   {
    HEAP8[i14 >> 0] = 0;
    break;
   }
  case 1:
   {
    HEAP8[i14 >> 0] = 1;
    break;
   }
  default:
   {
    HEAP8[i14 >> 0] = 1;
    HEAP32[i12 >> 2] = 4;
   }
  }
 } else {
  i10 = __ZNKSt3__28ios_base6getlocEv(i9) | 0;
  HEAP32[i5 >> 2] = i10;
  i13 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
  __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
  i9 = __ZNKSt3__28ios_base6getlocEv(i9) | 0;
  HEAP32[i6 >> 2] = i9;
  i10 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61692) | 0;
  __ZNSt3__214__shared_count16__release_sharedEv(i9) | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i10 >> 2] | 0) + 24 >> 2] & 1023](i1, i10);
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i10 >> 2] | 0) + 28 >> 2] & 1023](i1 + 12 | 0, i10);
  HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i7 >> 2];
  i13 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb(i11, i2, i1, i1 + 24 | 0, i13, i12, 1) | 0) == (i1 | 0) & 1;
  HEAP8[i14 >> 0] = i13;
  i14 = HEAP32[i11 >> 2] | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 12 | 0);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1);
  i1 = i14;
 }
 STACKTOP = i15;
 return i1 | 0;
}

function __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i4, i13) {
 i4 = i4 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i14 + 28 | 0;
 i3 = i14 + 12 | 0;
 i10 = i14 + 16 | 0;
 i11 = i14 + 8 | 0;
 i2 = i14 + 4 | 0;
 i12 = i14;
 __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_(i10, 48789, i4);
 __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i10 + 11 >> 0] | 0) < 0 ? HEAP32[i10 >> 2] | 0 : i10, 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i10);
 i3 = HEAP32[i3 >> 2] | 0;
 HEAP32[i11 >> 2] = i3;
 HEAP32[i1 >> 2] = HEAP32[i11 >> 2];
 if (!(__ZN4wasm6Module17checkFunctionTypeENS_4NameE(i13, i1) | 0)) {
  i1 = __Znwj(20) | 0;
  HEAP32[i1 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = 0;
  HEAP32[i1 + 8 >> 2] = 0;
  HEAP32[i1 + 12 >> 2] = 0;
  HEAP32[i1 + 16 >> 2] = 0;
  HEAP32[i1 >> 2] = i3;
  i11 = i4 + 11 | 0;
  if ((HEAP8[i11 >> 0] | 0) < 0) {
   i9 = i4;
   i10 = i4;
   i2 = HEAP32[i4 >> 2] | 0;
  } else {
   i9 = i4;
   i10 = i4;
   i2 = i4;
  }
  i5 = __ZN4wasm13sigToWasmTypeEc(HEAP8[i2 >> 0] | 0) | 0;
  HEAP32[i1 + 4 >> 2] = i5;
  i4 = i4 + 4 | 0;
  i5 = i1 + 8 | 0;
  i6 = i1 + 12 | 0;
  i7 = i1 + 16 | 0;
  i8 = 1;
  while (1) {
   i2 = HEAP8[i11 >> 0] | 0;
   i3 = i2 << 24 >> 24 < 0;
   if (i3) i2 = HEAP32[i4 >> 2] | 0; else i2 = i2 & 255;
   if (i8 >>> 0 >= i2 >>> 0) break;
   if (i3) i2 = HEAP32[i10 >> 2] | 0; else i2 = i9;
   i2 = __ZN4wasm13sigToWasmTypeEc(HEAP8[i2 + i8 >> 0] | 0) | 0;
   HEAP32[i12 >> 2] = i2;
   i3 = HEAP32[i6 >> 2] | 0;
   if (i3 >>> 0 < (HEAP32[i7 >> 2] | 0) >>> 0) {
    HEAP32[i3 >> 2] = i2;
    HEAP32[i6 >> 2] = i3 + 4;
   } else __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i5, i12);
   i8 = i8 + 1 | 0;
  }
  __ZN4wasm6Module15addFunctionTypeEPNS_12FunctionTypeE(i13, i1);
 } else {
  HEAP32[i2 >> 2] = i3;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  i1 = __ZN4wasm6Module15getFunctionTypeENS_4NameE(i13, i1) | 0;
 }
 STACKTOP = i14;
 return i1 | 0;
}

function __ZN4wasm17WasmBinaryBuilder16processFunctionsEv(i7) {
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i1 = HEAP32[i7 + 44 >> 2] | 0;
 i2 = HEAP32[i7 + 40 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __ZN4wasm6Module11addFunctionEPNS_8FunctionE(HEAP32[i7 >> 2] | 0, HEAP32[i2 >> 2] | 0);
  i2 = i2 + 4 | 0;
 }
 i1 = HEAP32[i7 + 20 >> 2] | 0;
 if ((i1 | 0) > -1) {
  i6 = HEAP32[i7 >> 2] | 0;
  HEAP32[i6 + 84 >> 2] = HEAP32[HEAP32[(HEAP32[i6 + 36 >> 2] | 0) + (i1 << 2) >> 2] >> 2];
 }
 i1 = i7 + 76 | 0;
 i2 = HEAP32[i7 + 72 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  i6 = HEAP32[i2 + 16 >> 2] | 0;
  HEAP32[i6 + 4 >> 2] = HEAP32[HEAP32[(HEAP32[(HEAP32[i7 >> 2] | 0) + 36 >> 2] | 0) + (HEAP32[i2 + 20 >> 2] << 2) >> 2] >> 2];
  __ZN4wasm6Module9addExportEPNS_6ExportE(HEAP32[i7 >> 2] | 0, i6);
  i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i2) | 0;
 }
 i1 = i7 + 56 | 0;
 i4 = HEAP32[i7 + 52 >> 2] | 0;
 while (1) {
  if ((i4 | 0) == (i1 | 0)) break;
  i2 = HEAP32[i4 + 16 >> 2] | 0;
  i3 = HEAP32[i4 + 24 >> 2] | 0;
  i5 = HEAP32[i4 + 20 >> 2] | 0;
  while (1) {
   if ((i5 | 0) == (i3 | 0)) break;
   HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] = HEAP32[HEAP32[(HEAP32[(HEAP32[i7 >> 2] | 0) + 36 >> 2] | 0) + (i2 << 2) >> 2] >> 2];
   i5 = i5 + 4 | 0;
  }
  i4 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i4) | 0;
 }
 i4 = HEAP32[i7 + 116 >> 2] | 0;
 i6 = HEAP32[i7 + 112 >> 2] | 0;
 while (1) {
  if ((i6 | 0) == (i4 | 0)) {
   i1 = 17;
   break;
  }
  i1 = HEAP32[i6 >> 2] | 0;
  i5 = HEAP32[i7 >> 2] | 0;
  i2 = HEAP32[i5 + 36 >> 2] | 0;
  if (i1 >>> 0 >= (HEAP32[i5 + 40 >> 2] | 0) - i2 >> 2 >>> 0) {
   i1 = 19;
   break;
  }
  i1 = HEAP32[i2 + (i1 << 2) >> 2] | 0;
  i2 = i5 + 52 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i5 + 56 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i5 + 48 | 0, i1); else {
   HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
  }
  i6 = i6 + 4 | 0;
 }
 if ((i1 | 0) == 17) return; else if ((i1 | 0) == 19) ___assert_fail(25368, 22948, 1600, 25398);
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseCallES1_RPc(i10, i3, i9) {
 i10 = i10 | 0;
 i3 = i3 | 0;
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i14 + 16 | 0;
 i4 = i14 + 12 | 0;
 i1 = i14 + 8 | 0;
 i6 = i14 + 4 | 0;
 i7 = i14;
 i12 = i10 + 4 | 0;
 __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE6resizeEj(i10, (((HEAP32[i12 >> 2] | 0) - (HEAP32[i10 >> 2] | 0) | 0) / 12 | 0) + 1 | 0);
 i2 = HEAP32[i9 >> 2] | 0;
 if ((HEAP8[i2 >> 0] | 0) != 40) ___assert_fail(31317, 31173, 614, 31804);
 HEAP32[i9 >> 2] = i2 + 1;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i1 >> 2];
 i3 = __ZN6cashew12ValueBuilder8makeCallENS_3RefE(i5) | 0;
 L4 : while (1) {
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i9);
  i1 = HEAP32[i9 >> 2] | 0;
  if ((HEAP8[i1 >> 0] | 0) == 41) {
   i8 = i1;
   break;
  }
  HEAP32[i6 >> 2] = i3;
  i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i10, i9, 31814) | 0;
  HEAP32[i7 >> 2] = i1;
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
  __ZN6cashew12ValueBuilder12appendToCallENS_3RefES1_(i4, i5);
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i9);
  i1 = HEAP32[i9 >> 2] | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 41:
   {
    i8 = i1;
    break L4;
   }
  case 44:
   break;
  default:
   {
    i11 = 7;
    break L4;
   }
  }
  HEAP32[i9 >> 2] = i1 + 1;
 }
 if ((i11 | 0) == 7) _abort();
 HEAP32[i9 >> 2] = i8 + 1;
 i1 = HEAP32[i12 >> 2] | 0;
 i2 = i1 + -12 | 0;
 if ((HEAP32[i1 + -8 >> 2] | 0) == (HEAP32[i2 >> 2] | 0)) i13 = i1; else ___assert_fail(31817, 31173, 630, 31804);
 while (1) {
  if ((i13 | 0) == (i2 | 0)) break;
  i11 = i13 + -12 | 0;
  HEAP32[i12 >> 2] = i11;
  __ZNSt3__213__vector_baseIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEED2Ev(i11);
  i13 = HEAP32[i12 >> 2] | 0;
 }
 STACKTOP = i14;
 return i3 | 0;
}

function __ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_(i7, i13, i11, i12, i14, i3, i2, i4, i5, i8) {
 i7 = i7 | 0;
 i13 = i13 | 0;
 i11 = i11 | 0;
 i12 = i12 | 0;
 i14 = i14 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i8 = i8 | 0;
 var i1 = 0, i6 = 0, i9 = 0, i10 = 0;
 i9 = HEAP32[i12 >> 2] | 0;
 i10 = (i9 | 0) == (i11 | 0);
 do if (i10) {
  i1 = (HEAP8[i8 + 24 >> 0] | 0) == i7 << 24 >> 24;
  if (!i1 ? (HEAP8[i8 + 25 >> 0] | 0) != i7 << 24 >> 24 : 0) {
   i6 = 5;
   break;
  }
  HEAP32[i12 >> 2] = i11 + 1;
  HEAP8[i11 >> 0] = i1 ? 43 : 45;
  HEAP32[i14 >> 2] = 0;
  i1 = 0;
 } else i6 = 5; while (0);
 L6 : do if ((i6 | 0) == 5) {
  i6 = HEAP8[i2 + 11 >> 0] | 0;
  if (i7 << 24 >> 24 == i3 << 24 >> 24 ? ((i6 << 24 >> 24 < 0 ? HEAP32[i2 + 4 >> 2] | 0 : i6 & 255) | 0) != 0 : 0) {
   i1 = HEAP32[i5 >> 2] | 0;
   if ((i1 - i4 | 0) >= 160) {
    i1 = 0;
    break;
   }
   i13 = HEAP32[i14 >> 2] | 0;
   HEAP32[i5 >> 2] = i1 + 4;
   HEAP32[i1 >> 2] = i13;
   HEAP32[i14 >> 2] = 0;
   i1 = 0;
   break;
  }
  i2 = i8 + 26 | 0;
  i1 = i8;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) {
    i1 = i2;
    break;
   }
   if ((HEAP8[i1 >> 0] | 0) == i7 << 24 >> 24) break;
   i1 = i1 + 1 | 0;
  }
  i1 = i1 - i8 | 0;
  if ((i1 | 0) > 23) i1 = -1; else {
   switch (i13 | 0) {
   case 10:
   case 8:
    {
     if ((i1 | 0) >= (i13 | 0)) {
      i1 = -1;
      break L6;
     }
     break;
    }
   case 16:
    {
     if ((i1 | 0) >= 22) {
      if (i10) {
       i1 = -1;
       break L6;
      }
      if ((i9 - i11 | 0) >= 3) {
       i1 = -1;
       break L6;
      }
      if ((HEAP8[i9 + -1 >> 0] | 0) != 48) {
       i1 = -1;
       break L6;
      }
      HEAP32[i14 >> 2] = 0;
      i1 = HEAP8[53246 + i1 >> 0] | 0;
      HEAP32[i12 >> 2] = i9 + 1;
      HEAP8[i9 >> 0] = i1;
      i1 = 0;
      break L6;
     }
     break;
    }
   default:
    {}
   }
   i1 = HEAP8[53246 + i1 >> 0] | 0;
   HEAP32[i12 >> 2] = i9 + 1;
   HEAP8[i9 >> 0] = i1;
   HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) + 1;
   i1 = 0;
  }
 } while (0);
 return i1 | 0;
}

function __ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw(i7, i13, i11, i12, i14, i3, i2, i4, i5, i8) {
 i7 = i7 | 0;
 i13 = i13 | 0;
 i11 = i11 | 0;
 i12 = i12 | 0;
 i14 = i14 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i8 = i8 | 0;
 var i1 = 0, i6 = 0, i9 = 0, i10 = 0;
 i9 = HEAP32[i12 >> 2] | 0;
 i10 = (i9 | 0) == (i11 | 0);
 do if (i10) {
  i1 = (HEAP32[i8 + 96 >> 2] | 0) == (i7 | 0);
  if (!i1 ? (HEAP32[i8 + 100 >> 2] | 0) != (i7 | 0) : 0) {
   i6 = 5;
   break;
  }
  HEAP32[i12 >> 2] = i11 + 1;
  HEAP8[i11 >> 0] = i1 ? 43 : 45;
  HEAP32[i14 >> 2] = 0;
  i1 = 0;
 } else i6 = 5; while (0);
 L6 : do if ((i6 | 0) == 5) {
  i6 = HEAP8[i2 + 11 >> 0] | 0;
  if ((i7 | 0) == (i3 | 0) ? ((i6 << 24 >> 24 < 0 ? HEAP32[i2 + 4 >> 2] | 0 : i6 & 255) | 0) != 0 : 0) {
   i1 = HEAP32[i5 >> 2] | 0;
   if ((i1 - i4 | 0) >= 160) {
    i1 = 0;
    break;
   }
   i13 = HEAP32[i14 >> 2] | 0;
   HEAP32[i5 >> 2] = i1 + 4;
   HEAP32[i1 >> 2] = i13;
   HEAP32[i14 >> 2] = 0;
   i1 = 0;
   break;
  }
  i2 = i8 + 104 | 0;
  i1 = i8;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) {
    i1 = i2;
    break;
   }
   if ((HEAP32[i1 >> 2] | 0) == (i7 | 0)) break;
   i1 = i1 + 4 | 0;
  }
  i1 = i1 - i8 | 0;
  i2 = i1 >> 2;
  if ((i1 | 0) > 92) i1 = -1; else {
   switch (i13 | 0) {
   case 10:
   case 8:
    {
     if ((i2 | 0) >= (i13 | 0)) {
      i1 = -1;
      break L6;
     }
     break;
    }
   case 16:
    {
     if ((i1 | 0) >= 88) {
      if (i10) {
       i1 = -1;
       break L6;
      }
      if ((i9 - i11 | 0) >= 3) {
       i1 = -1;
       break L6;
      }
      if ((HEAP8[i9 + -1 >> 0] | 0) != 48) {
       i1 = -1;
       break L6;
      }
      HEAP32[i14 >> 2] = 0;
      i1 = HEAP8[53246 + i2 >> 0] | 0;
      HEAP32[i12 >> 2] = i9 + 1;
      HEAP8[i9 >> 0] = i1;
      i1 = 0;
      break L6;
     }
     break;
    }
   default:
    {}
   }
   i1 = HEAP8[53246 + i2 >> 0] | 0;
   HEAP32[i12 >> 2] = i9 + 1;
   HEAP8[i9 >> 0] = i1;
   HEAP32[i14 >> 2] = (HEAP32[i14 >> 2] | 0) + 1;
   i1 = 0;
  }
 } while (0);
 return i1 | 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11truncUFloatEPNS_5UnaryES5_(i3, i5, i4, i6) {
 i3 = i3 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 var d1 = 0.0, i2 = 0, d7 = 0.0;
 d1 = +__ZN4wasm7Literal8getFloatEv(i6);
 d7 = +Math_abs(+d1);
 HEAPF64[tempDoublePtr >> 3] = d7;
 i2 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 if (i2 >>> 0 > 2146435072 | (i2 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0) {
  i2 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i2, 28704);
 }
 i2 = (HEAP32[i6 >> 2] | 0) == 3;
 if ((HEAP32[i4 + 4 >> 2] | 0) == 1) {
  if (i2) {
   if (!(__ZN4wasm18isInRangeI32TruncUEi(__ZNK4wasm7Literal14reinterpreti32Ev(i6) | 0) | 0)) {
    i6 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 20 >> 2] & 1023](i6, 28723);
   }
  } else {
   i6 = __ZNK4wasm7Literal14reinterpreti64Ev(i6) | 0;
   if (!(__ZN4wasm18isInRangeI32TruncUEx(i6, tempRet0) | 0)) {
    i6 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 20 >> 2] & 1023](i6, 28723);
   }
  }
  HEAP32[i3 >> 2] = 1;
  HEAP32[i3 + 8 >> 2] = ~~d1 >>> 0;
 } else {
  if (i2) {
   if (!(__ZN4wasm18isInRangeI64TruncUEi(__ZNK4wasm7Literal14reinterpreti32Ev(i6) | 0) | 0)) {
    i6 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 20 >> 2] & 1023](i6, 28748);
   }
  } else {
   i6 = __ZNK4wasm7Literal14reinterpreti64Ev(i6) | 0;
   if (!(__ZN4wasm18isInRangeI64TruncUEx(i6, tempRet0) | 0)) {
    i6 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 20 >> 2] & 1023](i6, 28748);
   }
  }
  i5 = +Math_abs(d1) >= 1.0 ? (d1 > 0.0 ? ~~+Math_min(+Math_floor(d1 / 4294967296.0), 4294967295.0) >>> 0 : ~~+Math_ceil((d1 - +(~~d1 >>> 0)) / 4294967296.0) >>> 0) : 0;
  HEAP32[i3 >> 2] = 2;
  i6 = i3 + 8 | 0;
  HEAP32[i6 >> 2] = ~~d1 >>> 0;
  HEAP32[i6 + 4 >> 2] = i5;
 }
 return;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11truncSFloatEPNS_5UnaryES5_(i3, i5, i4, i6) {
 i3 = i3 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 var d1 = 0.0, i2 = 0, d7 = 0.0;
 d1 = +__ZN4wasm7Literal8getFloatEv(i6);
 d7 = +Math_abs(+d1);
 HEAPF64[tempDoublePtr >> 3] = d7;
 i2 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 if (i2 >>> 0 > 2146435072 | (i2 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0) {
  i2 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i2, 28561);
 }
 i2 = (HEAP32[i6 >> 2] | 0) == 3;
 if ((HEAP32[i4 + 4 >> 2] | 0) == 1) {
  if (i2) {
   if (!(__ZN4wasm18isInRangeI32TruncSEi(__ZNK4wasm7Literal14reinterpreti32Ev(i6) | 0) | 0)) {
    i6 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 20 >> 2] & 1023](i6, 28580);
   }
  } else {
   i6 = __ZNK4wasm7Literal14reinterpreti64Ev(i6) | 0;
   if (!(__ZN4wasm18isInRangeI32TruncSEx(i6, tempRet0) | 0)) {
    i6 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 20 >> 2] & 1023](i6, 28580);
   }
  }
  HEAP32[i3 >> 2] = 1;
  HEAP32[i3 + 8 >> 2] = ~~d1;
 } else {
  if (i2) {
   if (!(__ZN4wasm18isInRangeI64TruncSEi(__ZNK4wasm7Literal14reinterpreti32Ev(i6) | 0) | 0)) {
    i6 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 20 >> 2] & 1023](i6, 28605);
   }
  } else {
   i6 = __ZNK4wasm7Literal14reinterpreti64Ev(i6) | 0;
   if (!(__ZN4wasm18isInRangeI64TruncSEx(i6, tempRet0) | 0)) {
    i6 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
    FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 20 >> 2] & 1023](i6, 28605);
   }
  }
  i5 = +Math_abs(d1) >= 1.0 ? (d1 > 0.0 ? ~~+Math_min(+Math_floor(d1 / 4294967296.0), 4294967295.0) >>> 0 : ~~+Math_ceil((d1 - +(~~d1 >>> 0)) / 4294967296.0) >>> 0) : 0;
  HEAP32[i3 >> 2] = 2;
  i6 = i3 + 8 | 0;
  HEAP32[i6 >> 2] = ~~d1 >>> 0;
  HEAP32[i6 + 4 >> 2] = i5;
 }
 return;
}

function __ZN4wasm15Asm2WasmBuilder22getBuiltinFunctionTypeENS_4NameES1_P11ArenaVectorIPNS_10ExpressionEE(i8, i6, i5, i7) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i2 = i9 + 24 | 0;
 i3 = i9 + 12 | 0;
 i4 = i9;
 L1 : do if ((HEAP32[i6 >> 2] | 0) == (HEAP32[14963] | 0) ? (HEAP32[i5 >> 2] | 0) == (HEAP32[14964] | 0) : 0) {
  if (i7 | 0 ? (HEAP32[i7 + 8 >> 2] | 0) == 1 : 0) {
   i7 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 0) | 0;
   switch (HEAP32[(HEAP32[i7 >> 2] | 0) + 4 >> 2] | 0) {
   case 1:
    {
     HEAP32[i2 >> 2] = 0;
     HEAP32[i2 + 4 >> 2] = 0;
     HEAP32[i2 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i2, 19121, 2);
     i1 = __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i2, HEAP32[i8 >> 2] | 0) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i2);
     break L1;
    }
   case 3:
    {
     HEAP32[i3 >> 2] = 0;
     HEAP32[i3 + 4 >> 2] = 0;
     HEAP32[i3 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i3, 19124, 2);
     i1 = __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i3, HEAP32[i8 >> 2] | 0) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i3);
     break L1;
    }
   case 4:
    {
     HEAP32[i4 >> 2] = 0;
     HEAP32[i4 + 4 >> 2] = 0;
     HEAP32[i4 + 8 >> 2] = 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i4, 19127, 2);
     i1 = __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i4, HEAP32[i8 >> 2] | 0) | 0;
     __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
     break L1;
    }
   default:
    {
     i1 = 0;
     break L1;
    }
   }
  }
  ___assert_fail(19064, 16311, 420, 19098);
 } else i1 = 0; while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZN4wasm16PrintSExpression17visitFunctionTypeEPNS_12FunctionTypeEb(i6, i4, i5) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7 + 4 | 0;
 i2 = i7;
 if (i5) {
  i3 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i6 >> 2] | 0, 49146, 0) | 0, 32) | 0;
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i3, i1) | 0, 34579) | 0;
 }
 i2 = i4 + 8 | 0;
 i1 = i4 + 12 | 0;
 if ((HEAP32[i1 >> 2] | 0) != (HEAP32[i2 >> 2] | 0)) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i6 >> 2] | 0, HEAP32[i6 + 12 >> 2] | 0) | 0;
  __Z17printMinorOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i6 >> 2] | 0, 49092) | 0;
  i3 = HEAP32[i1 >> 2] | 0;
  i2 = HEAP32[i2 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i6 >> 2] | 0;
   if ((i2 | 0) == (i3 | 0)) break;
   i1 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i1, 32) | 0;
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i1, __ZN4wasm13printWasmTypeENS_8WasmTypeE(HEAP32[i2 >> 2] | 0) | 0) | 0;
   i2 = i2 + 4 | 0;
  }
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i1, 41) | 0;
 }
 i1 = i4 + 4 | 0;
 if (HEAP32[i1 >> 2] | 0) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i6 >> 2] | 0, HEAP32[i6 + 12 >> 2] | 0) | 0;
  i4 = __Z17printMinorOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i6 >> 2] | 0, 34592) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i4, __ZN4wasm13printWasmTypeENS_8WasmTypeE(HEAP32[i1 >> 2] | 0) | 0) | 0, 41) | 0;
 }
 if (i5) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i6 >> 2] | 0, 34600) | 0;
 STACKTOP = i7;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder9parseTypeERNS_7ElementE(i13, i2) {
 i13 = i13 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i11 = i14;
 i12 = __ZN4wasm11make_uniqueINS_12FunctionTypeEJEEENSt3__210unique_ptrIT_NS2_14default_deleteIS4_EEEEDpOT0_() | 0;
 i10 = __ZN4wasm7ElementixEj(i2, 1) | 0;
 if (!(HEAP8[i10 >> 0] | 0)) {
  i1 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i2, 1) | 0) | 0;
  HEAP32[i12 >> 2] = i1;
  i1 = 2;
 } else i1 = 1;
 i8 = __ZN4wasm7ElementixEj(i2, i1) | 0;
 if (!(HEAP8[i8 >> 0] | 0)) ___assert_fail(21676, 21446, 1299, 21690);
 i1 = i12 + 4 | 0;
 i2 = i12 + 8 | 0;
 i3 = i12 + 12 | 0;
 i4 = i12 + 16 | 0;
 i9 = 1;
 while (1) {
  i10 = (__ZN4wasm7Element4listEv(i8) | 0) + 8 | 0;
  if (i9 >>> 0 >= (HEAP32[i10 >> 2] | 0) >>> 0) break;
  i5 = __ZN4wasm7ElementixEj(i8, i9) | 0;
  i10 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i5, 0) | 0) | 0;
  L10 : do if ((i10 | 0) != (HEAP32[14975] | 0)) {
   i10 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i5, 0) | 0) | 0;
   if ((i10 | 0) == (HEAP32[14976] | 0)) {
    i10 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i13, __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i5, 1) | 0) | 0, 0, 0) | 0;
    HEAP32[i1 >> 2] = i10;
   }
  } else {
   i10 = 1;
   while (1) {
    i7 = (__ZN4wasm7Element4listEv(i5) | 0) + 8 | 0;
    if (i10 >>> 0 >= (HEAP32[i7 >> 2] | 0) >>> 0) break L10;
    i6 = __ZN4wasm22SExpressionWasmBuilder16stringToWasmTypeEPKcbb(i13, __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i5, i10) | 0) | 0, 0, 0) | 0;
    HEAP32[i11 >> 2] = i6;
    i7 = HEAP32[i3 >> 2] | 0;
    if (i7 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
     HEAP32[i7 >> 2] = i6;
     HEAP32[i3 >> 2] = i7 + 4;
    } else __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i2, i11);
    i10 = i10 + 1 | 0;
   }
  } while (0);
  i9 = i9 + 1 | 0;
 }
 __ZN4wasm6Module15addFunctionTypeEPNS_12FunctionTypeE(HEAP32[i13 >> 2] | 0, i12);
 STACKTOP = i14;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE8parseForERPcPKc(i15, i14, i13) {
 i15 = i15 | 0;
 i14 = i14 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i16 + 28 | 0;
 i7 = i16 + 24 | 0;
 i6 = i16 + 20 | 0;
 i5 = i16 + 16 | 0;
 i9 = i16 + 12 | 0;
 i10 = i16 + 8 | 0;
 i11 = i16 + 4 | 0;
 i12 = i16;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
 i1 = HEAP32[i14 >> 2] | 0;
 if ((HEAP8[i1 >> 0] | 0) != 40) ___assert_fail(31317, 31173, 501, 31783);
 HEAP32[i14 >> 2] = i1 + 1;
 i4 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i15, i14, 31140) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
 i1 = HEAP32[i14 >> 2] | 0;
 if ((HEAP8[i1 >> 0] | 0) != 59) ___assert_fail(31792, 31173, 505, 31783);
 HEAP32[i14 >> 2] = i1 + 1;
 i3 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i15, i14, 31140) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
 i1 = HEAP32[i14 >> 2] | 0;
 if ((HEAP8[i1 >> 0] | 0) != 59) ___assert_fail(31792, 31173, 509, 31783);
 HEAP32[i14 >> 2] = i1 + 1;
 i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i15, i14, 56966) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i14);
 i2 = HEAP32[i14 >> 2] | 0;
 if ((HEAP8[i2 >> 0] | 0) == 41) {
  HEAP32[i14 >> 2] = i2 + 1;
  i15 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseMaybeBracketedERPcPKc(i15, i14, i13) | 0;
  HEAP32[i9 >> 2] = i4;
  HEAP32[i10 >> 2] = i3;
  HEAP32[i11 >> 2] = i1;
  HEAP32[i12 >> 2] = i15;
  HEAP32[i5 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i6 >> 2] = HEAP32[i10 >> 2];
  HEAP32[i7 >> 2] = HEAP32[i11 >> 2];
  HEAP32[i8 >> 2] = HEAP32[i12 >> 2];
  i15 = __ZN6cashew12ValueBuilder7makeForENS_3RefES1_S1_S1_(i5, i6, i7, i8) | 0;
  STACKTOP = i16;
  return i15 | 0;
 } else ___assert_fail(31539, 31173, 513, 31783);
 return 0;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE8__rehashEj(i11, i10) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = i11 + 4 | 0;
 L1 : do if (i10) {
  if (i10 >>> 0 > 1073741823) {
   i11 = ___cxa_allocate_exception(4) | 0;
   __ZNSt9bad_allocC2Ev(i11);
   ___cxa_throw(i11 | 0, 4128, 273);
  }
  i9 = __Znwj(i10 << 2) | 0;
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = i9;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = i10;
  i1 = 0;
  while (1) {
   if ((i1 | 0) == (i10 | 0)) break;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  i3 = i11 + 8 | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  if (i1 | 0) {
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   i8 = i10 + -1 | 0;
   i9 = (i8 & i10 | 0) == 0;
   if (i9) i2 = i2 & i8; else i2 = (i2 >>> 0) % (i10 >>> 0) | 0;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i2 << 2) >> 2] = i3;
   while (1) {
    i7 = i1;
    L24 : while (1) while (1) {
     i1 = HEAP32[i7 >> 2] | 0;
     if (!i1) break L1;
     i3 = HEAP32[i1 + 4 >> 2] | 0;
     if (i9) i6 = i3 & i8; else i6 = (i3 >>> 0) % (i10 >>> 0) | 0;
     if ((i6 | 0) == (i2 | 0)) {
      i7 = i1;
      continue L24;
     }
     i4 = (HEAP32[i11 >> 2] | 0) + (i6 << 2) | 0;
     if (!(HEAP32[i4 >> 2] | 0)) {
      i2 = i6;
      i3 = i7;
      break L24;
     }
     i5 = i1 + 8 | 0;
     i3 = i1;
     while (1) {
      i4 = HEAP32[i3 >> 2] | 0;
      if (!i4) break;
      if ((HEAP32[i5 >> 2] | 0) == (HEAP32[i4 + 8 >> 2] | 0)) i3 = i4; else break;
     }
     HEAP32[i7 >> 2] = i4;
     HEAP32[i3 >> 2] = HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2];
     HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2] = i1;
    }
    HEAP32[i4 >> 2] = i3;
   }
  }
 } else {
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = 0;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = 0;
 } while (0);
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE8parseVarERPcPKcb(i13, i15, i1, i2) {
 i13 = i13 | 0;
 i15 = i15 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0, i16 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i6 = i14 + 36 | 0;
 i5 = i14 + 32 | 0;
 i4 = i14 + 28 | 0;
 i11 = i14;
 i7 = i14 + 24 | 0;
 i8 = i14 + 20 | 0;
 i9 = i14 + 16 | 0;
 i10 = __ZN6cashew12ValueBuilder7makeVarEb(i2) | 0;
 i2 = i11 + 12 | 0;
 i3 = i11 + 8 | 0;
 L1 : while (1) {
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i15);
  i1 = HEAP32[i15 >> 2] | 0;
  if ((HEAP8[i1 >> 0] | 0) == 59) {
   i12 = i1;
   break;
  }
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i11, i1);
  if ((HEAP32[i2 >> 2] | 0) != 2) {
   i16 = 4;
   break;
  }
  HEAP32[i15 >> 2] = (HEAP32[i15 >> 2] | 0) + (HEAP32[i3 >> 2] | 0);
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i15);
  i1 = HEAP32[i15 >> 2] | 0;
  if ((HEAP8[i1 >> 0] | 0) == 61) {
   HEAP32[i15 >> 2] = i1 + 1;
   __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i15);
   i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i13, i15, 31464) | 0;
  } else i1 = 0;
  HEAP32[i7 >> 2] = i10;
  HEAP32[i8 >> 2] = HEAP32[i11 >> 2];
  HEAP32[i9 >> 2] = i1;
  HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i5 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i6 >> 2] = HEAP32[i9 >> 2];
  __ZN6cashew12ValueBuilder11appendToVarENS_3RefENS_7IStringES1_(i4, i5, i6);
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i15);
  i1 = HEAP32[i15 >> 2] | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 59:
   {
    i16 = 10;
    break L1;
   }
  case 44:
   break;
  default:
   {
    i16 = 9;
    break L1;
   }
  }
  HEAP32[i15 >> 2] = i1 + 1;
 }
 if ((i16 | 0) == 4) ___assert_fail(31436, 31173, 437, 31455); else if ((i16 | 0) == 9) _abort(); else if ((i16 | 0) == 10) i12 = i1;
 HEAP32[i15 >> 2] = i12 + 1;
 STACKTOP = i14;
 return i10 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEEclEOS5_Oj(i9, i1, i2) {
 i9 = i9 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i10 = 0, i11 = 0, i12 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i11 + 24 | 0;
 i5 = i11 + 20 | 0;
 i6 = i11 + 8 | 0;
 i7 = i11 + 4 | 0;
 i8 = i11;
 i2 = HEAP32[i2 >> 2] | 0;
 HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
 i1 = HEAP32[i9 + 4 >> 2] | 0;
 i2 = __ZN4wasm15Asm2WasmBuilder12bytesToShiftEj(i1, i2) | 0;
 if (((__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i8, 0) | 0, 59308) | 0 ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i8, 1) | 0, 59492) | 0 : 0) ? __ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i8, 3) | 0, 0) | 0, 59348) | 0 : 0) ? (i12 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i8, 3) | 0, 1) | 0, (__ZN6cashew5Value10getIntegerEv(HEAP32[i12 >> 2] | 0) | 0) == (i2 | 0)) : 0) {
  i3 = HEAP32[i9 + 8 >> 2] | 0;
  i12 = __ZN6cashew3RefixEj(i8, 2) | 0;
  HEAP32[i5 >> 2] = HEAP32[i12 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
  i3 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i3, i4) | 0;
 } else i10 = 6;
 do if ((i10 | 0) == 6) if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i8, 0) | 0, 59348) | 0) {
  i12 = __ZN6cashew3RefixEj(i8, 1) | 0;
  i12 = (__ZN6cashew5Value10getIntegerEv(HEAP32[i12 >> 2] | 0) | 0) << i2;
  i3 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i1 + 8 >> 2] | 0) | 0;
  HEAP32[i3 + 8 >> 2] = 1;
  HEAP32[i3 + 16 >> 2] = i12;
  HEAP32[i3 + 4 >> 2] = 1;
  break;
 } else {
  HEAP32[i6 >> 2] = 0;
  HEAP32[i6 + 4 >> 2] = 0;
  HEAP32[i6 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i6, 30864, 20);
  HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
  __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew3RefE(i6, i4);
 } while (0);
 STACKTOP = i11;
 return i3 | 0;
}

function _wcsrtombs(i3, i6, i1, i2) {
 i3 = i3 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i8;
 L1 : do if (!i3) {
  i3 = HEAP32[i6 >> 2] | 0;
  i2 = HEAP32[i3 >> 2] | 0;
  if (!i2) i1 = 0; else {
   i1 = 0;
   do {
    if (i2 >>> 0 > 127) {
     i2 = _wcrtomb(i7, i2, 0) | 0;
     if ((i2 | 0) == -1) {
      i1 = -1;
      break L1;
     }
    } else i2 = 1;
    i1 = i2 + i1 | 0;
    i3 = i3 + 4 | 0;
    i2 = HEAP32[i3 >> 2] | 0;
   } while ((i2 | 0) != 0);
  }
 } else {
  L9 : do if (i1 >>> 0 > 3) {
   i2 = i1;
   i4 = HEAP32[i6 >> 2] | 0;
   while (1) {
    i5 = HEAP32[i4 >> 2] | 0;
    if ((i5 + -1 | 0) >>> 0 > 126) {
     if (!i5) break;
     i5 = _wcrtomb(i3, i5, 0) | 0;
     if ((i5 | 0) == -1) {
      i1 = -1;
      break L1;
     }
     i3 = i3 + i5 | 0;
     i2 = i2 - i5 | 0;
    } else {
     HEAP8[i3 >> 0] = i5;
     i3 = i3 + 1 | 0;
     i2 = i2 + -1 | 0;
     i4 = HEAP32[i6 >> 2] | 0;
    }
    i4 = i4 + 4 | 0;
    HEAP32[i6 >> 2] = i4;
    if (i2 >>> 0 <= 3) break L9;
   }
   HEAP8[i3 >> 0] = 0;
   HEAP32[i6 >> 2] = 0;
   i1 = i1 - i2 | 0;
   break L1;
  } else i2 = i1; while (0);
  if (i2) {
   i4 = HEAP32[i6 >> 2] | 0;
   while (1) {
    i5 = HEAP32[i4 >> 2] | 0;
    if ((i5 + -1 | 0) >>> 0 > 126) {
     if (!i5) {
      i4 = 19;
      break;
     }
     i5 = _wcrtomb(i7, i5, 0) | 0;
     if ((i5 | 0) == -1) {
      i1 = -1;
      break L1;
     }
     if (i2 >>> 0 < i5 >>> 0) {
      i4 = 22;
      break;
     }
     _wcrtomb(i3, HEAP32[i4 >> 2] | 0, 0) | 0;
     i3 = i3 + i5 | 0;
     i2 = i2 - i5 | 0;
    } else {
     HEAP8[i3 >> 0] = i5;
     i3 = i3 + 1 | 0;
     i2 = i2 + -1 | 0;
     i4 = HEAP32[i6 >> 2] | 0;
    }
    i4 = i4 + 4 | 0;
    HEAP32[i6 >> 2] = i4;
    if (!i2) break L1;
   }
   if ((i4 | 0) == 19) {
    HEAP8[i3 >> 0] = 0;
    HEAP32[i6 >> 2] = 0;
    i1 = i1 - i2 | 0;
    break;
   } else if ((i4 | 0) == 22) {
    i1 = i1 - i2 | 0;
    break;
   }
  }
 } while (0);
 STACKTOP = i8;
 return i1 | 0;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEE8__rehashEj(i11, i10) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = i11 + 4 | 0;
 L1 : do if (i10) {
  if (i10 >>> 0 > 1073741823) {
   i11 = ___cxa_allocate_exception(4) | 0;
   __ZNSt9bad_allocC2Ev(i11);
   ___cxa_throw(i11 | 0, 4128, 273);
  }
  i9 = __Znwj(i10 << 2) | 0;
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = i9;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = i10;
  i1 = 0;
  while (1) {
   if ((i1 | 0) == (i10 | 0)) break;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  i3 = i11 + 8 | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  if (i1 | 0) {
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   i8 = i10 + -1 | 0;
   i9 = (i8 & i10 | 0) == 0;
   if (i9) i2 = i2 & i8; else i2 = (i2 >>> 0) % (i10 >>> 0) | 0;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i2 << 2) >> 2] = i3;
   while (1) {
    i7 = i1;
    L24 : while (1) while (1) {
     i1 = HEAP32[i7 >> 2] | 0;
     if (!i1) break L1;
     i3 = HEAP32[i1 + 4 >> 2] | 0;
     if (i9) i6 = i3 & i8; else i6 = (i3 >>> 0) % (i10 >>> 0) | 0;
     if ((i6 | 0) == (i2 | 0)) {
      i7 = i1;
      continue L24;
     }
     i4 = (HEAP32[i11 >> 2] | 0) + (i6 << 2) | 0;
     if (!(HEAP32[i4 >> 2] | 0)) {
      i2 = i6;
      i3 = i7;
      break L24;
     }
     i5 = i1 + 8 | 0;
     i3 = i1;
     while (1) {
      i4 = HEAP32[i3 >> 2] | 0;
      if (!i4) break;
      if ((HEAP32[i5 >> 2] | 0) == (HEAP32[i4 + 8 >> 2] | 0)) i3 = i4; else break;
     }
     HEAP32[i7 >> 2] = i4;
     HEAP32[i3 >> 2] = HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2];
     HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2] = i1;
    }
    HEAP32[i4 >> 2] = i3;
   }
  }
 } else {
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = 0;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = 0;
 } while (0);
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairaSEOS1_(i6, i4) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0;
 i1 = i6 + 11 | 0;
 do if ((HEAP8[i1 >> 0] | 0) < 0) {
  HEAP8[HEAP32[i6 >> 2] >> 0] = 0;
  i3 = i6 + 4 | 0;
  HEAP32[i3 >> 2] = 0;
  i2 = HEAP8[i1 >> 0] | 0;
  if (i2 << 24 >> 24 < 0) {
   if ((HEAP32[i6 + 8 >> 2] & 2147483647 | 0) == 11) break;
   i5 = HEAP32[i6 >> 2] | 0;
   HEAP8[i6 >> 0] = HEAP8[i5 >> 0] | 0;
   _free(i5);
   HEAP8[i1 >> 0] = 0;
   break;
  } else {
   i1 = i2 & 255;
   if ((i2 & 255) < 11) break;
   i2 = i1 + 16 & 496;
   i5 = _malloc(i2) | 0;
   _memcpy(i5 | 0, i6 | 0, i1 + 1 | 0) | 0;
   HEAP32[i6 + 8 >> 2] = i2 | -2147483648;
   HEAP32[i3 >> 2] = i1;
   HEAP32[i6 >> 2] = i5;
   break;
  }
 } else {
  HEAP8[i6 >> 0] = 0;
  HEAP8[i1 >> 0] = 0;
 } while (0);
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i6 + 4 >> 2] = HEAP32[i4 + 4 >> 2];
 HEAP32[i6 + 8 >> 2] = HEAP32[i4 + 8 >> 2];
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i4 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i5 = i6 + 12 | 0;
 i4 = i4 + 12 | 0;
 i1 = i5 + 11 | 0;
 do if ((HEAP8[i1 >> 0] | 0) < 0) {
  HEAP8[HEAP32[i5 >> 2] >> 0] = 0;
  i3 = i6 + 16 | 0;
  HEAP32[i3 >> 2] = 0;
  i2 = HEAP8[i1 >> 0] | 0;
  if (i2 << 24 >> 24 < 0) {
   if ((HEAP32[i6 + 20 >> 2] & 2147483647 | 0) == 11) break;
   i6 = HEAP32[i5 >> 2] | 0;
   HEAP8[i5 >> 0] = HEAP8[i6 >> 0] | 0;
   _free(i6);
   HEAP8[i1 >> 0] = 0;
   break;
  } else {
   i1 = i2 & 255;
   if ((i2 & 255) < 11) break;
   i7 = i1 + 16 & 496;
   i2 = _malloc(i7) | 0;
   _memcpy(i2 | 0, i5 | 0, i1 + 1 | 0) | 0;
   HEAP32[i6 + 20 >> 2] = i7 | -2147483648;
   HEAP32[i3 >> 2] = i1;
   HEAP32[i5 >> 2] = i2;
   break;
  }
 } else {
  HEAP8[i5 >> 0] = 0;
  HEAP8[i1 >> 0] = 0;
 } while (0);
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i5 + 4 >> 2] = HEAP32[i4 + 4 >> 2];
 HEAP32[i5 + 8 >> 2] = HEAP32[i4 + 8 >> 2];
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i4 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZN4wasm17WasmBinaryBuilder15maybeVisitConstERPNS_10ExpressionEh(i5, i4, i1) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i6 = 0, i7 = 0, d8 = 0.0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i7;
 switch (i1 & 255 | 0) {
 case 16:
  {
   i2 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   i1 = __ZN4wasm17WasmBinaryBuilder9getS32LEBEv(i5) | 0;
   HEAP32[i2 + 8 >> 2] = 1;
   HEAP32[i2 + 16 >> 2] = i1;
   i1 = 1;
   i6 = 6;
   break;
  }
 case 17:
  {
   i2 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   i6 = __ZN4wasm17WasmBinaryBuilder9getS64LEBEv(i5) | 0;
   HEAP32[i2 + 8 >> 2] = 2;
   i1 = i2 + 16 | 0;
   HEAP32[i1 >> 2] = i6;
   HEAP32[i1 + 4 >> 2] = tempRet0;
   i1 = 2;
   i6 = 6;
   break;
  }
 case 19:
  {
   i2 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   d8 = +__ZN4wasm17WasmBinaryBuilder10getFloat32Ev(i5);
   HEAP32[i2 + 8 >> 2] = 3;
   HEAPF32[i2 + 16 >> 2] = d8;
   i1 = 3;
   i6 = 6;
   break;
  }
 case 18:
  {
   i2 = __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
   d8 = +__ZN4wasm17WasmBinaryBuilder10getFloat64Ev(i5);
   HEAP32[i2 + 8 >> 2] = 4;
   HEAPF64[i2 + 16 >> 3] = d8;
   i1 = 4;
   i6 = 6;
   break;
  }
 default:
  i1 = 0;
 }
 if ((i6 | 0) == 6) {
  HEAP32[i2 + 4 >> 2] = i1;
  HEAP32[i4 >> 2] = i2;
  if (!(HEAP8[i5 + 12 >> 0] | 0)) i1 = 1; else {
   i1 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24677) | 0;
   i6 = __ZNKSt3__28ios_base6getlocEv(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i3 >> 2] = i6;
   i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i3, 61680) | 0;
   i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
   __ZNSt3__26localeD2Ev(i3);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i1, i6) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i1) | 0;
   i1 = 1;
  }
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE8__rehashEj(i11, i10) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = i11 + 4 | 0;
 L1 : do if (i10) {
  if (i10 >>> 0 > 1073741823) {
   i11 = ___cxa_allocate_exception(4) | 0;
   __ZNSt9bad_allocC2Ev(i11);
   ___cxa_throw(i11 | 0, 4128, 273);
  }
  i9 = __Znwj(i10 << 2) | 0;
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = i9;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = i10;
  i1 = 0;
  while (1) {
   if ((i1 | 0) == (i10 | 0)) break;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  i3 = i11 + 8 | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  if (i1 | 0) {
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   i8 = i10 + -1 | 0;
   i9 = (i8 & i10 | 0) == 0;
   if (i9) i2 = i2 & i8; else i2 = (i2 >>> 0) % (i10 >>> 0) | 0;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i2 << 2) >> 2] = i3;
   while (1) {
    i7 = i1;
    L24 : while (1) while (1) {
     i1 = HEAP32[i7 >> 2] | 0;
     if (!i1) break L1;
     i3 = HEAP32[i1 + 4 >> 2] | 0;
     if (i9) i6 = i3 & i8; else i6 = (i3 >>> 0) % (i10 >>> 0) | 0;
     if ((i6 | 0) == (i2 | 0)) {
      i7 = i1;
      continue L24;
     }
     i4 = (HEAP32[i11 >> 2] | 0) + (i6 << 2) | 0;
     if (!(HEAP32[i4 >> 2] | 0)) {
      i2 = i6;
      i3 = i7;
      break L24;
     }
     i5 = i1 + 8 | 0;
     i3 = i1;
     while (1) {
      i4 = HEAP32[i3 >> 2] | 0;
      if (!i4) break;
      if ((HEAP32[i5 >> 2] | 0) == (HEAP32[i4 + 8 >> 2] | 0)) i3 = i4; else break;
     }
     HEAP32[i7 >> 2] = i4;
     HEAP32[i3 >> 2] = HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2];
     HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2] = i1;
    }
    HEAP32[i4 >> 2] = i3;
   }
  }
 } else {
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = 0;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = 0;
 } while (0);
 return;
}

function __ZN4wasm14CoalesceLocals14doWalkFunctionEPNS_8FunctionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i4 = i3 + 40 | 0;
 i7 = i3 + 20 | 0;
 i5 = i3;
 i6 = __ZN4wasm8Function12getNumLocalsEv(i1) | 0;
 HEAP32[i2 + 112 >> 2] = i6;
 i6 = i2 + 16 | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE14doWalkFunctionEPNS_8FunctionE(i6, i1);
 i1 = i2 + 128 | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE14findLiveBlocksEv(i7, i6);
 HEAP8[i4 >> 0] = HEAP8[i3 + 52 >> 0] | 0;
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE13__move_assignERSG_NS_17integral_constantIbLb1EEE(i1, i7, i4);
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEED2Ev(i7);
 __ZNSt3__213unordered_setIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEEC2ERKSG_(i5, i1);
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE16unlinkDeadBlocksENSt3__213unordered_setIPNS5_10BasicBlockENS6_4hashIS9_EENS6_8equal_toIS9_EENS6_9allocatorIS9_EEEE(i6, i5);
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEED2Ev(i5);
 __ZN4wasm14CoalesceLocals12flowLivenessEv(i2);
 __ZN4wasm14CoalesceLocals22calculateInterferencesEv(i2);
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 1023](i2, i4);
 __ZN4wasm14CoalesceLocals12applyIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEEPNS_10ExpressionE(i2, i4, 0);
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function ___stdio_write(i14, i2, i1) {
 i14 = i14 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i15 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i11 = i15 + 16 | 0;
 i10 = i15;
 i3 = i15 + 32 | 0;
 i12 = i14 + 28 | 0;
 i4 = HEAP32[i12 >> 2] | 0;
 HEAP32[i3 >> 2] = i4;
 i13 = i14 + 20 | 0;
 i4 = (HEAP32[i13 >> 2] | 0) - i4 | 0;
 HEAP32[i3 + 4 >> 2] = i4;
 HEAP32[i3 + 8 >> 2] = i2;
 HEAP32[i3 + 12 >> 2] = i1;
 i8 = i14 + 60 | 0;
 i9 = i14 + 44 | 0;
 i2 = 2;
 i4 = i4 + i1 | 0;
 while (1) {
  if (!(HEAP32[15018] | 0)) {
   HEAP32[i11 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i11 + 4 >> 2] = i3;
   HEAP32[i11 + 8 >> 2] = i2;
   i6 = ___syscall_ret(___syscall146(146, i11 | 0) | 0) | 0;
  } else {
   _pthread_cleanup_push(287, i14 | 0);
   HEAP32[i10 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i10 + 4 >> 2] = i3;
   HEAP32[i10 + 8 >> 2] = i2;
   i6 = ___syscall_ret(___syscall146(146, i10 | 0) | 0) | 0;
   _pthread_cleanup_pop(0);
  }
  if ((i4 | 0) == (i6 | 0)) {
   i4 = 6;
   break;
  }
  if ((i6 | 0) < 0) {
   i4 = 8;
   break;
  }
  i4 = i4 - i6 | 0;
  i5 = HEAP32[i3 + 4 >> 2] | 0;
  if (i6 >>> 0 <= i5 >>> 0) if ((i2 | 0) == 2) {
   HEAP32[i12 >> 2] = (HEAP32[i12 >> 2] | 0) + i6;
   i7 = i5;
   i2 = 2;
  } else i7 = i5; else {
   i7 = HEAP32[i9 >> 2] | 0;
   HEAP32[i12 >> 2] = i7;
   HEAP32[i13 >> 2] = i7;
   i7 = HEAP32[i3 + 12 >> 2] | 0;
   i6 = i6 - i5 | 0;
   i3 = i3 + 8 | 0;
   i2 = i2 + -1 | 0;
  }
  HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + i6;
  HEAP32[i3 + 4 >> 2] = i7 - i6;
 }
 if ((i4 | 0) == 6) {
  i11 = HEAP32[i9 >> 2] | 0;
  HEAP32[i14 + 16 >> 2] = i11 + (HEAP32[i14 + 48 >> 2] | 0);
  i14 = i11;
  HEAP32[i12 >> 2] = i14;
  HEAP32[i13 >> 2] = i14;
 } else if ((i4 | 0) == 8) {
  HEAP32[i14 + 16 >> 2] = 0;
  HEAP32[i12 >> 2] = 0;
  HEAP32[i13 >> 2] = 0;
  HEAP32[i14 >> 2] = HEAP32[i14 >> 2] | 32;
  if ((i2 | 0) == 2) i1 = 0; else i1 = i1 - (HEAP32[i3 + 4 >> 2] | 0) | 0;
 }
 STACKTOP = i15;
 return i1 | 0;
}

function __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i8, i11, i7, i12, i5, i6) {
 i8 = i8 | 0;
 i11 = i11 | 0;
 i7 = i7 | 0;
 i12 = i12 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i9 = 0, i10 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 144 | 0;
 i1 = i13 + 72 | 0;
 i2 = i13;
 do if (HEAP32[i7 >> 2] | 0) {
  if ((i5 | 0 ? (i3 = HEAP32[i5 >> 2] | 0, i3 | 0) : 0) ? (__ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i1, i3), i5 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i1) | 0, __ZN4wasm14EffectAnalyzerD2Ev(i1), i5) : 0) {
   i1 = i12;
   break;
  }
  if ((i6 | 0 ? (i4 = HEAP32[i6 >> 2] | 0, i4 | 0) : 0) ? (__ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i2, i4), i6 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i2) | 0, __ZN4wasm14EffectAnalyzerD2Ev(i2), i6) : 0) {
   i1 = i12;
   break;
  }
  i1 = HEAP32[i7 >> 2] | 0;
  if ((!((i1 | 0) == 0 | (HEAP32[i1 >> 2] | 0) != 1) ? (HEAP32[i1 + 8 >> 2] | 0) == 0 : 0) ? (i9 = i1 + 12 | 0, i10 = i9 + 8 | 0, (HEAP32[i10 >> 2] | 0) >>> 0 > 1) : 0) {
   i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i9) | 0;
   HEAP32[i7 >> 2] = HEAP32[i6 >> 2];
   if (!i12) {
    i12 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i9) | 0;
    HEAP32[i12 >> 2] = i11;
    __ZN4wasm5Block8finalizeEv(i1);
    HEAP32[i8 + 20 >> 2] = i1;
    break;
   }
   i1 = i12 + 12 | 0;
   i8 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i1) | 0;
   if ((HEAP32[i8 >> 2] | 0) != (i11 | 0)) ___assert_fail(34227, 34254, 113, 34281);
   __ZN11ArenaVectorIPN4wasm10ExpressionEE8pop_backEv(i1) | 0;
   i2 = 0;
   while (1) {
    if (i2 >>> 0 >= ((HEAP32[i10 >> 2] | 0) + -1 | 0) >>> 0) break;
    i8 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i9, i2) | 0;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i1, HEAP32[i8 >> 2] | 0);
    i2 = i2 + 1 | 0;
   }
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i1, i11);
   i1 = i12;
  } else i1 = i12;
 } else i1 = i12; while (0);
 STACKTOP = i13;
 return i1 | 0;
}

function __ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlNS_4NameES3_E_clES3_S3_(i9, i5, i7) {
 i9 = i9 | 0;
 i5 = i5 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i8 = 0, i10 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i11 + 4 | 0;
 i10 = i11;
 i4 = HEAP32[i5 >> 2] | 0;
 i3 = (i4 | 0) != 0;
 i6 = HEAP32[i7 >> 2] | 0;
 i1 = i3 ^ (i6 | 0) != 0;
 do if (!(i1 | i3 ^ 1)) {
  i3 = HEAP32[i9 >> 2] | 0;
  i1 = i3 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  if ((i2 | 0) == (HEAP32[i3 + 8 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i3, i5); else {
   HEAP32[i2 >> 2] = i4;
   HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
  }
  i1 = __ZNSt3__23mapIN4wasm4NameENS_6vectorIS2_NS_9allocatorIS2_EEEENS_4lessIS2_EENS4_INS_4pairIKS2_S6_EEEEEixERSA_(HEAP32[i9 + 4 >> 2] | 0, i5) | 0;
  i2 = i1 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i1 + 8 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i1, i7); else {
   HEAP32[i3 >> 2] = i6;
   HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
  }
  i1 = HEAP32[i9 + 8 >> 2] | 0;
  i5 = i9 + 12 | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  HEAP32[i8 >> 2] = i2;
  i3 = i1 + 4 | 0;
  i4 = HEAP32[i3 >> 2] | 0;
  if (i4 >>> 0 < (HEAP32[i1 + 8 >> 2] | 0) >>> 0) {
   HEAP32[i4 >> 2] = i2;
   HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 4;
  } else __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i1, i8);
  i4 = HEAP32[i9 + 16 >> 2] | 0;
  i1 = HEAP32[i5 >> 2] | 0;
  HEAP32[i10 >> 2] = i1;
  i2 = i4 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i4 + 8 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
   i1 = 1;
   break;
  } else {
   __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i4, i10);
   i1 = 1;
   break;
  }
 } else i1 = i1 ^ 1; while (0);
 STACKTOP = i11;
 return i1 | 0;
}

function __ZN4wasm7Literal11printDoubleERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEd(i4, d3) {
 i4 = i4 | 0;
 d3 = +d3;
 var i1 = 0, i2 = 0, i5 = 0, d6 = 0.0;
 HEAPF64[tempDoublePtr >> 3] = d3;
 i1 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 i2 = (i1 | 0) < 0;
 do if (d3 == 0.0 & i2) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i4, 29440) | 0; else {
  d6 = +Math_abs(+d3);
  HEAPF64[tempDoublePtr >> 3] = d6;
  i5 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
  if (i5 >>> 0 > 2146435072 | (i5 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0) {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i4, i2 ? 58036 : 67717) | 0, 52371) | 0;
   i1 = __ZN4wasm7Literal10NaNPayloadEd(d3) | 0;
   i2 = tempRet0;
   if ((i1 | 0) == 0 & (i2 | 0) == 0) break;
   i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i4, 29425) | 0;
   i4 = i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
   HEAP32[i4 >> 2] = HEAP32[i4 >> 2] & -75 | 8;
   i5 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy(i5, i1, i2) | 0;
   i5 = i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
   HEAP32[i5 >> 2] = HEAP32[i5 >> 2] & -75 | 2;
   break;
  }
  i5 = i1 & 2146435072;
  if (!(i5 >>> 0 < 2146435072 | (i5 | 0) == 2146435072 & 0 < 0)) {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i4, i2 ? 49204 : 49946) | 0;
   break;
  }
  i1 = __ZN6cashew9JSPrinter11numToStringEdb(d3, 1) | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 46:
   {
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i4, 48) | 0;
    break;
   }
  case 45:
   {
    i2 = i1 + 1 | 0;
    if ((HEAP8[i2 >> 0] | 0) == 46) {
     __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i4, 29440) | 0;
     i1 = i2;
    }
    break;
   }
  default:
   {}
  }
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i4, i1) | 0;
 } while (0);
 return;
}

function __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i9, i8, i7, i6) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i1 = i10 + 88 | 0;
 i2 = i10 + 76 | 0;
 i3 = i10 + 24 | 0;
 i4 = i10 + 64 | 0;
 i5 = i10;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, i8, _strlen(i8) | 0);
 if ((__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE4findIS7_EENS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEERKT_(i9, i1) | 0) == (i9 + 4 | 0)) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1);
  HEAP32[i2 >> 2] = 0;
  HEAP32[i2 + 4 >> 2] = 0;
  HEAP32[i2 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i2, i8, _strlen(i8) | 0);
  i9 = __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixEOS6_(i9, i2) | 0;
  HEAP32[i4 >> 2] = 0;
  HEAP32[i4 + 4 >> 2] = 0;
  HEAP32[i4 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i4, i7, _strlen(i7) | 0);
  __ZNSt3__28functionIFPN4wasm4PassEvEEC2ERKS5_(i5, i6);
  __ZN4wasm12PassRegistry8PassInfoC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEENS2_8functionIFPNS_4PassEvEEE(i3, i4, i5);
  __ZN4wasm12PassRegistry8PassInfoaSEOS1_(i9, i3) | 0;
  __ZN4wasm12PassRegistry8PassInfoD2Ev(i3);
  __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i5);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i2);
  STACKTOP = i10;
  return;
 } else ___assert_fail(32310, 32350, 34, 32370);
}

function __ZN4wasm17WasmBinaryBuilder9visitLoopEPNS_4LoopE(i5, i7) {
 i5 = i5 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8;
 if (HEAP8[i5 + 12 >> 0] | 0) {
  i6 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24142) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i6 + (HEAP32[(HEAP32[i6 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i6, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i6) | 0;
 }
 i3 = __ZN4wasm17WasmBinaryBuilder12getNextLabelEv(i5) | 0;
 HEAP32[i7 + 8 >> 2] = i3;
 i3 = __ZN4wasm17WasmBinaryBuilder12getNextLabelEv(i5) | 0;
 HEAP32[i7 + 12 >> 2] = i3;
 i3 = i5 + 84 | 0;
 i1 = i7 + 8 | 0;
 i6 = i5 + 88 | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i4 = i5 + 92 | 0;
 if ((i2 | 0) == (HEAP32[i4 >> 2] | 0)) {
  __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i3, i1);
  i2 = HEAP32[i6 >> 2] | 0;
 } else {
  HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
  i2 = (HEAP32[i6 >> 2] | 0) + 4 | 0;
  HEAP32[i6 >> 2] = i2;
 }
 i1 = i7 + 12 | 0;
 if ((i2 | 0) == (HEAP32[i4 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i3, i1); else {
  HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + 4;
 }
 i2 = __ZN4wasm17WasmBinaryBuilder13getMaybeBlockEv(i5) | 0;
 HEAP32[i7 + 16 >> 2] = i2;
 i2 = HEAP32[i6 >> 2] | 0;
 i1 = i2 + -4 | 0;
 i3 = i2;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i6 >> 2] = i5;
  i3 = i5;
 }
 i2 = i2 + -8 | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i5 = i1 + -4 | 0;
  HEAP32[i6 >> 2] = i5;
  i1 = i5;
 }
 __ZN4wasm4Loop8finalizeEv(i7);
 STACKTOP = i8;
 return;
}

function __ZN4wasm17WasmBinaryBuilder9visitCallEPNS_4CallE(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i11 + 4 | 0;
 i9 = i11;
 HEAP32[i9 >> 2] = i6;
 i10 = i6;
 if (HEAP8[i8 + 12 >> 0] | 0) {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24299) | 0;
  i5 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i5;
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i5) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
 }
 i2 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i8) | 0;
 i3 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i8) | 0;
 HEAP32[i1 >> 2] = i3;
 i3 = HEAP32[(HEAP32[i8 + 24 >> 2] | 0) + (i3 << 2) >> 2] | 0;
 if (((HEAP32[i3 + 12 >> 2] | 0) - (HEAP32[i3 + 8 >> 2] | 0) >> 2 | 0) != (i2 | 0)) ___assert_fail(24313, 22948, 1809, 24326);
 i4 = i6 + 8 | 0;
 __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i4, i2);
 i5 = i2 + -1 | 0;
 i7 = 0;
 while (1) {
  if ((i7 | 0) == (i2 | 0)) break;
  i13 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i8) | 0;
  i12 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i4, i5 - i7 | 0) | 0;
  HEAP32[i12 >> 2] = i13;
  i7 = i7 + 1 | 0;
 }
 HEAP32[i6 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 i1 = __ZNSt3__23mapIjNS_6vectorIPN4wasm4CallENS_9allocatorIS4_EEEENS_4lessIjEENS5_INS_4pairIKjS7_EEEEEixERSB_(i8 + 52 | 0, i1) | 0;
 i2 = i1 + 4 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if ((i3 | 0) == (HEAP32[i1 + 8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm4CallENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i1, i9); else {
  HEAP32[i3 >> 2] = i10;
  HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
 }
 STACKTOP = i11;
 return;
}

function __ZN4wasm16PrintSExpression10visitStoreEPNS_5StoreE(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i5 >> 2] | 0, 40) | 0;
 i3 = __Z12prepareColorRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE(HEAP32[i5 >> 2] | 0) | 0;
 i6 = i4 + 4 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i3, __ZN4wasm13printWasmTypeENS_8WasmTypeE(HEAP32[i6 >> 2] | 0) | 0) | 0, 34799) | 0;
 i3 = i4 + 8 | 0;
 i1 = HEAP8[i3 >> 0] | 0;
 if (!((i1 & 255) >= 4 ? !((i1 & 255) < 8 & (HEAP32[i6 >> 2] | 0) == 2) : 0)) i2 = 3;
 L3 : do if ((i2 | 0) == 3) switch (i1 << 24 >> 24) {
 case 1:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i5 >> 2] | 0, 56) | 0;
   break L3;
  }
 case 2:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i5 >> 2] | 0, 34770) | 0;
   break L3;
  }
 case 4:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i5 >> 2] | 0, 34773) | 0;
   break L3;
  }
 default:
  _abort();
 } while (0);
 i1 = i4 + 12 | 0;
 if (HEAP32[i1 >> 2] | 0) {
  i6 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i5 >> 2] | 0, 34782) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i6, HEAP32[i1 >> 2] | 0) | 0;
 }
 i1 = i4 + 16 | 0;
 if ((HEAP32[i1 >> 2] | 0) != (HEAPU8[i3 >> 0] | 0 | 0)) {
  i6 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i5 >> 2] | 0, 34791) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i6, HEAP32[i1 >> 2] | 0) | 0;
 }
 __ZN4wasm16PrintSExpression9incIndentEv(i5);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i5, HEAP32[i4 + 20 >> 2] | 0);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i5, HEAP32[i4 + 24 >> 2] | 0);
 __ZN4wasm16PrintSExpression9decIndentEv(i5);
 return;
}

function __ZNKSt3__220__time_get_c_storageIwE7__weeksEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if ((HEAP8[58640] | 0) == 0 ? ___cxa_guard_acquire(58640) | 0 : 0) {
  if ((HEAP8[58648] | 0) == 0 ? ___cxa_guard_acquire(58648) | 0 : 0) {
   i1 = 62564;
   do {
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i1 = i1 + 12 | 0;
   } while ((i1 | 0) != 62732);
   ___cxa_atexit(296, 0, ___dso_handle | 0) | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62564, 13228) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62576, 13256) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62588, 13284) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62600, 13316) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62612, 13356) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62624, 13392) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62636, 13420) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62648, 13456) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62660, 13472) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62672, 13488) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62684, 13504) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62696, 13520) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62708, 13536) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(62720, 13552) | 0;
  HEAP32[15683] = 62564;
 }
 return HEAP32[15683] | 0;
}

function __ZNKSt3__220__time_get_c_storageIcE7__weeksEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if ((HEAP8[58560] | 0) == 0 ? ___cxa_guard_acquire(58560) | 0 : 0) {
  if ((HEAP8[58568] | 0) == 0 ? ___cxa_guard_acquire(58568) | 0 : 0) {
   i1 = 61752;
   do {
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i1 = i1 + 12 | 0;
   } while ((i1 | 0) != 61920);
   ___cxa_atexit(292, 0, ___dso_handle | 0) | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61752, 53763) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61764, 53770) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61776, 53777) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61788, 53785) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61800, 53795) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61812, 53804) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61824, 53811) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61836, 53820) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61848, 53824) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61860, 53828) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61872, 53832) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61884, 53836) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61896, 53840) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(61908, 53844) | 0;
  HEAP32[15480] = 61752;
 }
 return HEAP32[15480] | 0;
}

function __ZN4wasm16PrintSExpression9visitLoadEPNS_4LoadE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i4 >> 2] | 0, 40) | 0;
 i2 = __Z12prepareColorRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE(HEAP32[i4 >> 2] | 0) | 0;
 i5 = i3 + 4 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i2, __ZN4wasm13printWasmTypeENS_8WasmTypeE(HEAP32[i5 >> 2] | 0) | 0) | 0, 34764) | 0;
 i2 = i3 + 8 | 0;
 i1 = HEAP8[i2 >> 0] | 0;
 if (!((i1 & 255) >= 4 ? !((i1 & 255) < 8 & (HEAP32[i5 >> 2] | 0) == 2) : 0)) {
  switch (i1 << 24 >> 24) {
  case 1:
   {
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i4 >> 2] | 0, 56) | 0;
    break;
   }
  case 2:
   {
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i4 >> 2] | 0, 34770) | 0;
    break;
   }
  case 4:
   {
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i4 >> 2] | 0, 34773) | 0;
    break;
   }
  default:
   _abort();
  }
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i4 >> 2] | 0, HEAP8[i3 + 9 >> 0] | 0 ? 34776 : 34779) | 0;
 }
 i1 = i3 + 12 | 0;
 if (HEAP32[i1 >> 2] | 0) {
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i4 >> 2] | 0, 34782) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i5, HEAP32[i1 >> 2] | 0) | 0;
 }
 i1 = i3 + 16 | 0;
 if ((HEAP32[i1 >> 2] | 0) != (HEAPU8[i2 >> 0] | 0)) {
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i4 >> 2] | 0, 34791) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i5, HEAP32[i1 >> 2] | 0) | 0;
 }
 __ZN4wasm16PrintSExpression9incIndentEv(i4);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i4, HEAP32[i3 + 20 >> 2] | 0);
 __ZN4wasm16PrintSExpression9decIndentEv(i4);
 return;
}

function __ZNSt3__212__hash_tableIPKcN6cashew7IString11CStringHashENS4_12CStringEqualENS_9allocatorIS2_EEE8__rehashEj(i11, i10) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = i11 + 4 | 0;
 L1 : do if (i10) {
  if (i10 >>> 0 > 1073741823) {
   i11 = ___cxa_allocate_exception(4) | 0;
   __ZNSt9bad_allocC2Ev(i11);
   ___cxa_throw(i11 | 0, 4128, 273);
  }
  i9 = __Znwj(i10 << 2) | 0;
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = i9;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = i10;
  i1 = 0;
  while (1) {
   if ((i1 | 0) == (i10 | 0)) break;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  i3 = i11 + 8 | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  if (i1 | 0) {
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   i8 = i10 + -1 | 0;
   i9 = (i8 & i10 | 0) == 0;
   if (i9) i2 = i2 & i8; else i2 = (i2 >>> 0) % (i10 >>> 0) | 0;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i2 << 2) >> 2] = i3;
   while (1) {
    i7 = i1;
    L24 : while (1) while (1) {
     i1 = HEAP32[i7 >> 2] | 0;
     if (!i1) break L1;
     i3 = HEAP32[i1 + 4 >> 2] | 0;
     if (i9) i6 = i3 & i8; else i6 = (i3 >>> 0) % (i10 >>> 0) | 0;
     if ((i6 | 0) == (i2 | 0)) {
      i7 = i1;
      continue L24;
     }
     i4 = (HEAP32[i11 >> 2] | 0) + (i6 << 2) | 0;
     if (!(HEAP32[i4 >> 2] | 0)) {
      i2 = i6;
      i3 = i7;
      break L24;
     }
     i5 = i1 + 8 | 0;
     i3 = i1;
     while (1) {
      i4 = HEAP32[i3 >> 2] | 0;
      if (!i4) break;
      if (!(_strcmp(HEAP32[i5 >> 2] | 0, HEAP32[i4 + 8 >> 2] | 0) | 0)) i3 = i4; else break;
     }
     HEAP32[i7 >> 2] = i4;
     HEAP32[i3 >> 2] = HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2];
     HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2] = i1;
    }
    HEAP32[i4 >> 2] = i3;
   }
  }
 } else {
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = 0;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = 0;
 } while (0);
 return;
}

function __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE8__rehashEj(i11, i10) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = i11 + 4 | 0;
 L1 : do if (i10) {
  if (i10 >>> 0 > 1073741823) {
   i11 = ___cxa_allocate_exception(4) | 0;
   __ZNSt9bad_allocC2Ev(i11);
   ___cxa_throw(i11 | 0, 4128, 273);
  }
  i9 = __Znwj(i10 << 2) | 0;
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = i9;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = i10;
  i1 = 0;
  while (1) {
   if ((i1 | 0) == (i10 | 0)) break;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
  i3 = i11 + 8 | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  if (i1 | 0) {
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   i8 = i10 + -1 | 0;
   i9 = (i8 & i10 | 0) == 0;
   if (i9) i2 = i2 & i8; else i2 = (i2 >>> 0) % (i10 >>> 0) | 0;
   HEAP32[(HEAP32[i11 >> 2] | 0) + (i2 << 2) >> 2] = i3;
   while (1) {
    i7 = i1;
    L24 : while (1) while (1) {
     i1 = HEAP32[i7 >> 2] | 0;
     if (!i1) break L1;
     i3 = HEAP32[i1 + 4 >> 2] | 0;
     if (i9) i6 = i3 & i8; else i6 = (i3 >>> 0) % (i10 >>> 0) | 0;
     if ((i6 | 0) == (i2 | 0)) {
      i7 = i1;
      continue L24;
     }
     i4 = (HEAP32[i11 >> 2] | 0) + (i6 << 2) | 0;
     if (!(HEAP32[i4 >> 2] | 0)) {
      i2 = i6;
      i3 = i7;
      break L24;
     }
     i5 = i1 + 8 | 0;
     i3 = i1;
     while (1) {
      i4 = HEAP32[i3 >> 2] | 0;
      if (!i4) break;
      if ((HEAP32[i5 >> 2] | 0) == (HEAP32[i4 + 8 >> 2] | 0)) i3 = i4; else break;
     }
     HEAP32[i7 >> 2] = i4;
     HEAP32[i3 >> 2] = HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2];
     HEAP32[HEAP32[(HEAP32[i11 >> 2] | 0) + (i6 << 2) >> 2] >> 2] = i1;
    }
    HEAP32[i4 >> 2] = i3;
   }
  }
 } else {
  i1 = HEAP32[i11 >> 2] | 0;
  HEAP32[i11 >> 2] = 0;
  if (i1 | 0) __ZdlPv(i1);
  HEAP32[i2 >> 2] = 0;
 } while (0);
 return;
}

function __ZN4wasm17SExpressionParser14skipWhitespaceEv(i6) {
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0;
 i4 = i6 + 4 | 0;
 i5 = i6 + 8 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 L1 : while (1) {
  i3 = (_isspace(HEAP8[i1 >> 0] | 0) | 0) == 0;
  i1 = HEAP32[i6 >> 2] | 0;
  i2 = HEAP8[i1 >> 0] | 0;
  if (!i3) {
   if (i2 << 24 >> 24 == 10) {
    HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
    i1 = i1 + 1 | 0;
    HEAP32[i5 >> 2] = i1;
   } else i1 = i1 + 1 | 0;
   HEAP32[i6 >> 2] = i1;
   continue;
  }
  switch (i2 << 24 >> 24) {
  case 59:
   {
    if ((HEAP8[i1 + 1 >> 0] | 0) == 59) i2 = 59; else break L1;
    L12 : while (1) {
     switch (i2 << 24 >> 24) {
     case 10:
     case 0:
      break L12;
     default:
      {}
     }
     i2 = i1 + 1 | 0;
     HEAP32[i6 >> 2] = i2;
     i1 = i2;
     i2 = HEAP8[i2 >> 0] | 0;
    }
    HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
    HEAP32[i5 >> 2] = i1;
    continue L1;
   }
  case 40:
   break;
  default:
   break L1;
  }
  if ((HEAP8[i1 + 1 >> 0] | 0) != 59) break;
  i1 = i1 + 2 | 0;
  HEAP32[i6 >> 2] = i1;
  i3 = 1;
  while (1) {
   L20 : while (1) {
    switch (HEAP8[i1 >> 0] | 0) {
    case 0:
     break L1;
    case 40:
     {
      if ((HEAP8[i1 + 1 >> 0] | 0) == 59) {
       i7 = 17;
       break L20;
      } else i7 = 18;
      break;
     }
    case 59:
     {
      i2 = i1 + 1 | 0;
      if ((HEAP8[i2 >> 0] | 0) == 41) {
       i7 = 20;
       break L20;
      } else i1 = i2;
      break;
     }
    default:
     i7 = 18;
    }
    if ((i7 | 0) == 18) {
     i7 = 0;
     i1 = i1 + 1 | 0;
    }
    HEAP32[i6 >> 2] = i1;
   }
   if ((i7 | 0) == 17) {
    i7 = 0;
    i1 = i1 + 2 | 0;
    HEAP32[i6 >> 2] = i1;
    i3 = i3 + 1 | 0;
    continue;
   } else if ((i7 | 0) == 20) {
    i7 = 0;
    i1 = i1 + 2 | 0;
    HEAP32[i6 >> 2] = i1;
    i2 = i3 + -1 | 0;
    if (!i2) continue L1; else {
     i3 = i2;
     continue;
    }
   }
  }
 }
 return;
}

function ___cxx_global_array_dtor_112(i1) {
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63304);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63292);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63280);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63268);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63256);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63244);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63232);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63220);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63208);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63196);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63184);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63172);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63160);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63148);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63136);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63124);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63112);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63100);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63088);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63076);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63064);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63052);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63040);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63028);
 return;
}

function ___cxx_global_array_dtor_109(i1) {
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62492);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62480);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62468);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62456);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62444);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62432);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62420);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62408);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62396);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62384);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62372);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62360);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62348);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62336);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62324);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62312);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62300);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62288);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62276);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62264);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62252);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62240);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62228);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62216);
 return;
}

function ___cxx_global_array_dtor_61(i1) {
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62200);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62188);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62176);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62164);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62152);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62140);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62128);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62116);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62104);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62092);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62080);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62068);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62056);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62044);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62032);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62020);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(62008);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61996);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61984);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61972);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61960);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61948);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61936);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61924);
 return;
}

function ___cxx_global_array_dtor_85(i1) {
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63012);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(63e3);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62988);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62976);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62964);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62952);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62940);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62928);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62916);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62904);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62892);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62880);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62868);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62856);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62844);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62832);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62820);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62808);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62796);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62784);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62772);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62760);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62748);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62736);
 return;
}

function __ZN4wasm17WasmBinaryBuilder9getS64LEBEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i1 = i6 + 32 | 0;
 i4 = i6;
 i2 = i6 + 8 | 0;
 i3 = i5 + 12 | 0;
 if (HEAP8[i3 >> 0] | 0) {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23002) | 0;
  i8 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i8;
  i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i8 >> 2] | 0) + 28 >> 2] & 63](i8, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i8) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
 }
 HEAP32[i2 >> 2] = 4588;
 HEAP32[i2 + 4 >> 2] = i5;
 HEAP32[i2 + 16 >> 2] = i2;
 __ZN4wasm3LEBIxaE4readENSt3__28functionIFavEEE(i4, i2);
 __ZNSt3__28functionIFavEED2Ev(i2);
 if (!(HEAP8[i3 >> 0] | 0)) {
  i2 = i4;
  i1 = HEAP32[i2 + 4 >> 2] | 0;
  i2 = HEAP32[i2 >> 2] | 0;
 } else {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24928) | 0;
  i8 = i4;
  i2 = HEAP32[i8 >> 2] | 0;
  i8 = HEAP32[i8 + 4 >> 2] | 0;
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx(i7, i2, i8) | 0, 23017) | 0;
  i5 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i5;
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i5) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
  i1 = i8;
 }
 tempRet0 = i1;
 STACKTOP = i6;
 return i2 | 0;
}

function __ZNK4wasm7Literal3divERKS0_(i6, i1, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 var d2 = 0.0, d3 = 0.0, d4 = 0.0;
 L1 : do if ((HEAP32[i1 >> 2] | 0) == 3) {
  d4 = +__ZNK4wasm7Literal6getf32Ev(i1);
  d2 = +__ZNK4wasm7Literal6getf32Ev(i5);
  i5 = ((HEAPF32[tempDoublePtr >> 2] = d4, HEAP32[tempDoublePtr >> 2] | 0) | 0) < 0;
  d3 = i5 ^ ((HEAPF32[tempDoublePtr >> 2] = d2, HEAP32[tempDoublePtr >> 2] | 0) | 0) < 0 ? -0.0 : 0.0;
  if ((___fpclassifyf(d2) | 0) != 2) {
   HEAP32[i6 >> 2] = 3;
   HEAPF32[i6 + 8 >> 2] = d4 / d2;
   break;
  }
  switch (___fpclassifyf(d4) | 0) {
  case 0:
   {
    d4 = +__ZN4wasm7Literal11setQuietNaNEf(d4);
    HEAP32[i6 >> 2] = 3;
    HEAPF32[i6 + 8 >> 2] = d4;
    break L1;
   }
  case 2:
   {
    d4 = +_copysignf(nan, d3);
    HEAP32[i6 >> 2] = 3;
    HEAPF32[i6 + 8 >> 2] = d4;
    break L1;
   }
  case 1:
  case 3:
  case 4:
   {
    d4 = +_copysignf(inf, d3);
    HEAP32[i6 >> 2] = 3;
    HEAPF32[i6 + 8 >> 2] = d4;
    break L1;
   }
  default:
   {}
  }
 } else {
  d4 = +__ZNK4wasm7Literal6getf64Ev(i1);
  d2 = +__ZNK4wasm7Literal6getf64Ev(i5);
  HEAPF64[tempDoublePtr >> 3] = d4;
  i5 = (HEAP32[tempDoublePtr + 4 >> 2] | 0) < 0;
  HEAPF64[tempDoublePtr >> 3] = d2;
  d3 = i5 ^ (HEAP32[tempDoublePtr + 4 >> 2] | 0) < 0 ? -0.0 : 0.0;
  if ((___fpclassify(d2) | 0) != 2) {
   HEAP32[i6 >> 2] = 4;
   HEAPF64[i6 + 8 >> 3] = d4 / d2;
   break;
  }
  switch (___fpclassify(d4) | 0) {
  case 0:
   {
    d4 = +__ZN4wasm7Literal11setQuietNaNEd(d4);
    HEAP32[i6 >> 2] = 4;
    HEAPF64[i6 + 8 >> 3] = d4;
    break L1;
   }
  case 2:
   {
    d4 = +_copysign(nan, d3);
    HEAP32[i6 >> 2] = 4;
    HEAPF64[i6 + 8 >> 3] = d4;
    break L1;
   }
  case 1:
  case 3:
  case 4:
   {
    d4 = +_copysign(inf, d3);
    HEAP32[i6 >> 2] = 4;
    HEAPF64[i6 + 8 >> 3] = d4;
    break L1;
   }
  default:
   {}
  }
 } while (0);
 return;
}

function __ZZ11instantiateEN19JSExternalInterface10callImportEPN4wasm6ImportERNSt3__26vectorINS0_7LiteralENS3_9allocatorIS5_EEEE(i6, i2, i7, i4) {
 i6 = i6 | 0;
 i2 = i2 | 0;
 i7 = i7 | 0;
 i4 = i4 | 0;
 var d1 = 0.0, i3 = 0, i5 = 0;
 if (HEAP8[63612] | 0) {
  i3 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60808, 25706) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i3, HEAP32[i7 >> 2] | 0) | 0, 10) | 0;
 }
 _emscripten_asm_const_v(16);
 i3 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = HEAP32[i4 >> 2] | 0;
 L4 : while (1) {
  if ((i2 | 0) == (i3 | 0)) break;
  switch (HEAP32[i2 >> 2] | 0) {
  case 1:
   {
    _emscripten_asm_const_ii(18, __ZNK4wasm7Literal6geti32Ev(i2) | 0) | 0;
    break;
   }
  case 3:
   {
    _emscripten_asm_const_id(18, +(+__ZNK4wasm7Literal6getf32Ev(i2))) | 0;
    break;
   }
  case 4:
   {
    _emscripten_asm_const_id(18, +(+__ZNK4wasm7Literal6getf64Ev(i2))) | 0;
    break;
   }
  default:
   {
    i5 = 10;
    break L4;
   }
  }
  i2 = i2 + 16 | 0;
 }
 if ((i5 | 0) == 10) _abort();
 d1 = +_emscripten_asm_const_dii(17, HEAP32[i7 + 4 >> 2] | 0, HEAP32[i7 + 8 >> 2] | 0);
 if (HEAP8[63612] | 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60808, 26031) | 0, d1) | 0, 10) | 0;
 switch (HEAP32[(HEAP32[i7 + 12 >> 2] | 0) + 4 >> 2] | 0) {
 case 0:
  {
   HEAP32[i6 >> 2] = 1;
   HEAP32[i6 + 8 >> 2] = 0;
   break;
  }
 case 1:
  {
   HEAP32[i6 >> 2] = 1;
   HEAP32[i6 + 8 >> 2] = ~~d1;
   break;
  }
 case 3:
  {
   HEAP32[i6 >> 2] = 3;
   HEAPF32[i6 + 8 >> 2] = d1;
   break;
  }
 case 4:
  {
   HEAP32[i6 >> 2] = 4;
   HEAPF64[i6 + 8 >> 3] = d1;
   break;
  }
 default:
  _abort();
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS4_PNS_11__tree_nodeIS4_SE_EEiEESH_RKT_(i5, i1, i8, i4) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i8 = i8 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i6 = 0, i7 = 0;
 i3 = i5 + 4 | 0;
 i6 = HEAP32[i1 >> 2] | 0;
 i1 = i6;
 do if ((i6 | 0) != (i3 | 0) ? (i2 = i6 + 16 | 0, !(__ZNK6cashew7IStringltERKS0_(i4, i2) | 0)) : 0) {
  if (__ZNK6cashew7IStringltERKS0_(i2, i4) | 0) i2 = 1; else {
   HEAP32[i8 >> 2] = i1;
   i1 = i8;
   break;
  }
  while (1) {
   if ((i2 | 0) <= 0) break;
   i2 = i2 + -1 | 0;
   i1 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i1) | 0;
  }
  i2 = i1;
  if ((i2 | 0) != (i3 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i4, i2 + 16 | 0) | 0) : 0) {
   i1 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESH_RKT_(i5, i8, i4) | 0;
   break;
  }
  i2 = i6 + 4 | 0;
  if (!(HEAP32[i2 >> 2] | 0)) {
   HEAP32[i8 >> 2] = i6;
   i1 = i2;
   break;
  } else {
   HEAP32[i8 >> 2] = i1;
   break;
  }
 } else i7 = 3; while (0);
 do if ((i7 | 0) == 3) {
  if ((i6 | 0) != (HEAP32[i5 >> 2] | 0)) {
   i1 = __ZNSt3__211__tree_prevIPNS_16__tree_node_baseIPvEEEET_S5_(i6) | 0;
   if (!(__ZNK6cashew7IStringltERKS0_(i1 + 16 | 0, i4) | 0)) {
    i1 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESH_RKT_(i5, i8, i4) | 0;
    break;
   }
  }
  if (!(HEAP32[i6 >> 2] | 0)) {
   HEAP32[i8 >> 2] = i6;
   i1 = i6;
   break;
  } else {
   HEAP32[i8 >> 2] = i1;
   i1 = i1 + 4 | 0;
   break;
  }
 } while (0);
 return i1 | 0;
}

function __ZN4wasm16PrintSExpression9visitLoopEPNS_4LoopE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i8 + 8 | 0;
 i1 = i8 + 4 | 0;
 i4 = i8;
 __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i6 >> 2] | 0, 34638, 0) | 0;
 i2 = i5 + 8 | 0;
 do if (!(HEAP32[i2 >> 2] | 0)) {
  i1 = i5 + 12 | 0;
  if (HEAP32[i1 >> 2] | 0) i7 = 6;
 } else {
  i9 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i6 >> 2] | 0, 32) | 0;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
  __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i9, i3) | 0;
  if (!(HEAP32[i5 + 12 >> 2] | 0)) ___assert_fail(34643, 34657, 140, 34678); else {
   i1 = i5 + 12 | 0;
   i7 = 6;
   break;
  }
 } while (0);
 if ((i7 | 0) == 6) {
  i9 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i6 >> 2] | 0, 32) | 0;
  HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i9, i3) | 0;
 }
 __ZN4wasm16PrintSExpression9incIndentEv(i6);
 i1 = HEAP32[i5 + 16 >> 2] | 0;
 i2 = (HEAP32[i1 >> 2] | 0) == 1 ? i1 : 0;
 L10 : do if ((HEAP8[i6 + 20 >> 0] | 0) == 0 & (i2 | 0) != 0 ? (HEAP32[i2 + 8 >> 2] | 0) == 0 : 0) {
  i3 = i2 + 12 | 0;
  i1 = HEAP32[i2 + 20 >> 2] | 0;
  i2 = 0;
  while (1) {
   if ((i2 | 0) == (i1 | 0)) break L10;
   i9 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, i2) | 0;
   __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i6, HEAP32[i9 >> 2] | 0);
   i2 = i2 + 1 | 0;
  }
 } else i7 = 12; while (0);
 if ((i7 | 0) == 12) __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i6, i1);
 __ZN4wasm16PrintSExpression9decIndentEv(i6);
 STACKTOP = i8;
 return;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner10visitBreakEPNS_5BreakE(i11, i10, i9) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i12;
 i7 = i9 + 8 | 0;
 i1 = HEAP32[i9 + 12 >> 2] | 0;
 if (i1) {
  __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i2, i10, i1);
  i6 = HEAP32[i2 >> 2] | 0;
  i5 = HEAP32[i2 + 4 >> 2] | 0;
  i4 = i2 + 8 | 0;
  i3 = HEAP32[i4 >> 2] | 0;
  i4 = HEAP32[i4 + 4 >> 2] | 0;
  i1 = HEAP32[i2 + 16 >> 2] | 0;
  if (!i1) i8 = 4; else {
   HEAP32[i11 >> 2] = i6;
   HEAP32[i11 + 4 >> 2] = i5;
   i10 = i11 + 8 | 0;
   HEAP32[i10 >> 2] = i3;
   HEAP32[i10 + 4 >> 2] = i4;
   HEAP32[i11 + 16 >> 2] = i1;
  }
 } else {
  i3 = 0;
  i4 = 0;
  i6 = 0;
  i5 = 0;
  i8 = 4;
 }
 do if ((i8 | 0) == 4) {
  i2 = HEAP32[i7 >> 2] | 0;
  i1 = HEAP32[i9 + 16 >> 2] | 0;
  if (i1 | 0) {
   __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i11, i10, i1);
   i1 = i11 + 16 | 0;
   if (HEAP32[i1 >> 2] | 0) break;
   i10 = __ZN4wasm7Literal10getIntegerEv(i11) | 0;
   if ((i10 | 0) == 0 & (tempRet0 | 0) == 0) {
    HEAP32[i11 >> 2] = 0;
    i11 = i11 + 8 | 0;
    HEAP32[i11 >> 2] = 0;
    HEAP32[i11 + 4 >> 2] = 0;
    HEAP32[i1 >> 2] = 0;
    break;
   }
  }
  HEAP32[i11 >> 2] = i6;
  HEAP32[i11 + 4 >> 2] = i5;
  i10 = i11 + 8 | 0;
  HEAP32[i10 >> 2] = i3;
  HEAP32[i10 + 4 >> 2] = i4;
  HEAP32[i11 + 16 >> 2] = i2;
 } while (0);
 STACKTOP = i12;
 return;
}

function __ZNSt3__26vectorINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEE8__appendEj(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i2 = HEAP32[i8 + 8 >> 2] | 0;
 i4 = i8 + 4 | 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (((i2 - i1 | 0) / 20 | 0) >>> 0 < i6 >>> 0) {
  i5 = HEAP32[i8 >> 2] | 0;
  i3 = ((i1 - i5 | 0) / 20 | 0) + i6 | 0;
  if (i3 >>> 0 > 214748364) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
  i1 = (i2 - i5 | 0) / 20 | 0;
  if (i1 >>> 0 < 107374182) {
   i1 = i1 << 1;
   i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
  } else i1 = 214748364;
  __ZNSt3__214__split_bufferINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEERNS8_ISD_EEEC2EjjSF_(i7, i1, ((HEAP32[i4 >> 2] | 0) - i5 | 0) / 20 | 0, i8 + 8 | 0);
  i3 = i7 + 8 | 0;
  i2 = HEAP32[i3 >> 2] | 0;
  i1 = i6;
  i4 = i2;
  while (1) {
   HEAP32[i4 >> 2] = 0;
   HEAP32[i4 + 4 >> 2] = 0;
   HEAP32[i4 + 8 >> 2] = 0;
   HEAP32[i4 + 12 >> 2] = 0;
   HEAPF32[i4 + 16 >> 2] = 1.0;
   i1 = i1 + -1 | 0;
   if (!i1) break; else i4 = i4 + 20 | 0;
  }
  HEAP32[i3 >> 2] = i2 + (i6 * 20 | 0);
  __ZNSt3__26vectorINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEE26__swap_out_circular_bufferERNS_14__split_bufferISD_RSE_EE(i8, i7);
  __ZNSt3__214__split_bufferINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEERNS8_ISD_EEED2Ev(i7);
 } else __ZNSt3__26vectorINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEE18__construct_at_endEj(i8, i6);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSR_IJEEEEEENS_4pairINS_15__tree_iteratorISG_PNS_11__tree_nodeISG_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESS_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSR_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISG_PvEENS_22__tree_node_destructorINSD_ISZ_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSQ_SQ_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZN4wasm17WasmBinaryBuilder7getInt8Ev(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i8 + 12 | 0;
 i4 = i8;
 i7 = i5 + 16 | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i6 = i5 + 8 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 if (i2 >>> 0 >= ((HEAP32[i1 + 4 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) | 0) >>> 0) {
  i8 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i4 >> 2] = 0;
  HEAP32[i4 + 4 >> 2] = 0;
  HEAP32[i4 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i4, 23033, 23);
  __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i8, i4);
  ___cxa_throw(i8 | 0, 64, 279);
 }
 if (HEAP8[i5 + 12 >> 0] | 0) {
  i2 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23057) | 0;
  i2 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(i2, HEAPU8[(HEAP32[HEAP32[i6 >> 2] >> 2] | 0) + (HEAP32[i7 >> 2] | 0) >> 0] | 0) | 0, 23067) | 0;
  i2 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i2, HEAP32[i7 >> 2] | 0) | 0, 56966) | 0;
  i1 = __ZNKSt3__28ios_base6getlocEv(i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i3 >> 2] = i1;
  i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i3, 61680) | 0;
  i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 10) | 0;
  __ZNSt3__26localeD2Ev(i3);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i2, i1) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i2) | 0;
  i2 = HEAP32[i7 >> 2] | 0;
  i1 = HEAP32[i6 >> 2] | 0;
 }
 HEAP32[i7 >> 2] = i2 + 1;
 STACKTOP = i8;
 return HEAP8[(HEAP32[i1 >> 2] | 0) + i2 >> 0] | 0;
}

function _mbsnrtowcs(i2, i12, i3, i1, i9) {
 i2 = i2 | 0;
 i12 = i12 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i9 = i9 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 1040 | 0;
 i8 = i13 + 8 | 0;
 i11 = i13;
 i7 = HEAP32[i12 >> 2] | 0;
 HEAP32[i11 >> 2] = i7;
 i10 = (i2 | 0) != 0;
 i1 = i10 ? i1 : 256;
 i2 = i10 ? i2 : i8;
 i4 = i7;
 L1 : do if ((i1 | 0) != 0 & (i7 | 0) != 0) {
  i6 = i1;
  i7 = i4;
  i1 = 0;
  while (1) {
   i4 = i3 >>> 2;
   i5 = i4 >>> 0 >= i6 >>> 0;
   if (!(i3 >>> 0 > 131 | i5)) {
    i4 = i7;
    break L1;
   }
   i4 = i5 ? i6 : i4;
   i3 = i3 - i4 | 0;
   i4 = _mbsrtowcs(i2, i11, i4, i9) | 0;
   if ((i4 | 0) == -1) {
    i1 = i3;
    break;
   }
   i14 = (i2 | 0) == (i8 | 0);
   i7 = i14 ? 0 : i4;
   i5 = i6 - i7 | 0;
   i2 = i14 ? i2 : i2 + (i4 << 2) | 0;
   i1 = i4 + i1 | 0;
   i4 = HEAP32[i11 >> 2] | 0;
   if ((i6 | 0) != (i7 | 0) & (i4 | 0) != 0) {
    i6 = i5;
    i7 = i4;
   } else {
    i6 = i5;
    break L1;
   }
  }
  i3 = i1;
  i6 = 0;
  i4 = HEAP32[i11 >> 2] | 0;
  i1 = -1;
 } else {
  i6 = i1;
  i1 = 0;
 } while (0);
 L8 : do if ((i4 | 0) != 0 ? (i6 | 0) != 0 & (i3 | 0) != 0 : 0) {
  i5 = i4;
  i4 = i2;
  while (1) {
   i2 = _mbrtowc(i4, i5, i3, i9) | 0;
   if ((i2 + 2 | 0) >>> 0 < 3) break;
   i5 = (HEAP32[i11 >> 2] | 0) + i2 | 0;
   HEAP32[i11 >> 2] = i5;
   i6 = i6 + -1 | 0;
   i1 = i1 + 1 | 0;
   if (!((i6 | 0) != 0 & (i3 | 0) != (i2 | 0))) break L8; else {
    i3 = i3 - i2 | 0;
    i4 = i4 + 4 | 0;
   }
  }
  switch (i2 | 0) {
  case -1:
   {
    i1 = -1;
    break L8;
   }
  case 0:
   {
    HEAP32[i11 >> 2] = 0;
    break L8;
   }
  default:
   {
    HEAP32[i9 >> 2] = 0;
    break L8;
   }
  }
 } while (0);
 if (i10) HEAP32[i12 >> 2] = HEAP32[i11 >> 2];
 STACKTOP = i13;
 return i1 | 0;
}

function __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(i10, i7) {
 i10 = i10 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i9 = i11 + 24 | 0;
 i5 = i11;
 i8 = i10 + 4 | 0;
 i6 = (HEAP32[i8 >> 2] | 0) - (HEAP32[i10 >> 2] | 0) >> 2;
 i2 = HEAP32[i7 + 4 >> 2] | 0;
 i3 = HEAP32[i7 >> 2] | 0;
 i1 = i3;
 L1 : do if (i6) {
  if (((i2 - i3 | 0) / 24 | 0 | 0) != (i6 | 0)) ___assert_fail(48756, 48612, 144, 48751);
  i3 = i10 + 12 | 0;
  if (HEAP8[i3 >> 0] | 0) ___assert_fail(48780, 48612, 145, 48751);
  HEAP8[i3 >> 0] = 1;
  i1 = i10 + 16 | 0;
  HEAP32[i9 >> 2] = i1;
  i4 = i9 + 4 | 0;
  HEAP8[i4 >> 0] = 1;
  __ZNSt3__25mutex4lockEv(i1);
  __ZN4wasm10ThreadPool20resetThreadsAreReadyEv(i10);
  i1 = 0;
  while (1) {
   if (i1 >>> 0 >= i6 >>> 0) break;
   i2 = HEAP32[(HEAP32[i10 >> 2] | 0) + (i1 << 2) >> 2] | 0;
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2ERKS4_(i5, (HEAP32[i7 >> 2] | 0) + (i1 * 24 | 0) | 0);
   __ZN4wasm6Thread4workENSt3__28functionIFNS_15ThreadWorkStateEvEEE(i2, i5);
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i5);
   i1 = i1 + 1 | 0;
  }
  i1 = i10 + 44 | 0;
  i2 = i10 + 92 | 0;
  while (1) {
   if ((HEAP32[i2 >> 2] | 0) == ((HEAP32[i8 >> 2] | 0) - (HEAP32[i10 >> 2] | 0) >> 2 | 0)) break;
   __ZNSt3__218condition_variable4waitERNS_11unique_lockINS_5mutexEEE(i1, i9);
  }
  HEAP8[i3 >> 0] = 0;
  if (HEAP8[i4 >> 0] | 0) __ZNSt3__25mutex6unlockEv(HEAP32[i9 >> 2] | 0);
 } else {
  if ((i2 | 0) == (i3 | 0)) ___assert_fail(48730, 48612, 137, 48751);
  while (1) {
   if (__ZNKSt3__28functionIFN4wasm15ThreadWorkStateEvEEclEv(i1) | 0) break L1;
   i1 = HEAP32[i7 >> 2] | 0;
  }
 } while (0);
 STACKTOP = i11;
 return;
}

function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb(i5, i9, i4, i3, i6) {
 i5 = i5 | 0;
 i9 = i9 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i7 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i10 + 8 | 0;
 i1 = i10 + 4 | 0;
 i2 = i10;
 if (!(HEAP32[i4 + 4 >> 2] & 1)) {
  i7 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
  HEAP32[i1 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
  i1 = FUNCTION_TABLE_iiiiii[i7 & 31](i5, i8, i4, i3, i6 & 1) | 0;
 } else {
  i7 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
  HEAP32[i2 >> 2] = i7;
  i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61720) | 0;
  __ZNSt3__214__shared_count16__release_sharedEv(i7) | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  if (i6) FUNCTION_TABLE_vii[HEAP32[i2 + 24 >> 2] & 1023](i8, i1); else FUNCTION_TABLE_vii[HEAP32[i2 + 28 >> 2] & 1023](i8, i1);
  i5 = i8 + 8 + 3 | 0;
  i4 = HEAP8[i5 >> 0] | 0;
  i7 = HEAP32[i8 >> 2] | 0;
  i6 = i8 + 4 | 0;
  i1 = i4;
  i2 = i7;
  i7 = i4 << 24 >> 24 < 0 ? i7 : i8;
  while (1) {
   i4 = i1 << 24 >> 24 < 0;
   if ((i7 | 0) == ((i4 ? i2 : i8) + ((i4 ? HEAP32[i6 >> 2] | 0 : i1 & 255) << 2) | 0)) break;
   i1 = HEAP32[i7 >> 2] | 0;
   i2 = HEAP32[i9 >> 2] | 0;
   if (i2 | 0) {
    i3 = i2 + 24 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if ((i4 | 0) == (HEAP32[i2 + 28 >> 2] | 0)) i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i2 >> 2] | 0) + 52 >> 2] & 63](i2, i1) | 0; else {
     HEAP32[i3 >> 2] = i4 + 4;
     HEAP32[i4 >> 2] = i1;
    }
    if ((i1 | 0) == -1) HEAP32[i9 >> 2] = 0;
   }
   i1 = HEAP8[i5 >> 0] | 0;
   i2 = HEAP32[i8 >> 2] | 0;
   i7 = i7 + 4 | 0;
  }
  i1 = HEAP32[i9 >> 2] | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i8);
 }
 STACKTOP = i10;
 return i1 | 0;
}

function __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEE4swapERS7_(i8, i7) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i9;
 i5 = i8 + 16 | 0;
 i1 = HEAP32[i5 >> 2] | 0;
 i6 = i1;
 if ((i1 | 0) == (i8 | 0) ? (i2 = i7 + 16 | 0, (HEAP32[i2 >> 2] | 0) == (i7 | 0)) : 0) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i1 >> 2] | 0) + 12 >> 2] & 1023](i1, i3);
  i6 = HEAP32[i5 >> 2] | 0;
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[i6 >> 2] | 0) + 16 >> 2] & 511](i6);
  HEAP32[i5 >> 2] = 0;
  i6 = HEAP32[i2 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 12 >> 2] & 1023](i6, i8);
  i6 = HEAP32[i2 >> 2] | 0;
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[i6 >> 2] | 0) + 16 >> 2] & 511](i6);
  HEAP32[i2 >> 2] = 0;
  HEAP32[i5 >> 2] = i8;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i3 >> 2] | 0) + 12 >> 2] & 1023](i3, i7);
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 511](i3);
  HEAP32[i2 >> 2] = i7;
 } else i4 = 4;
 do if ((i4 | 0) == 4) {
  if ((i1 | 0) == (i8 | 0)) {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i1 >> 2] | 0) + 12 >> 2] & 1023](i1, i7);
   i8 = HEAP32[i5 >> 2] | 0;
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[i8 >> 2] | 0) + 16 >> 2] & 511](i8);
   i8 = i7 + 16 | 0;
   HEAP32[i5 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i8 >> 2] = i7;
   break;
  }
  i1 = i7 + 16 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  if ((i2 | 0) == (i7 | 0)) {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 1023](i2, i8);
   i7 = HEAP32[i1 >> 2] | 0;
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[i7 >> 2] | 0) + 16 >> 2] & 511](i7);
   HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
   HEAP32[i5 >> 2] = i8;
   break;
  } else {
   HEAP32[i5 >> 2] = i2;
   HEAP32[i1 >> 2] = i6;
   break;
  }
 } while (0);
 STACKTOP = i9;
 return;
}

function __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i6 + 28 | 0;
 i4 = i6 + 24 | 0;
 i2 = i6;
 i3 = i5 + 12 | 0;
 if (HEAP8[i3 >> 0] | 0) {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23002) | 0;
  i8 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i8;
  i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i8 >> 2] | 0) + 28 >> 2] & 63](i8, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i8) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
 }
 HEAP32[i2 >> 2] = 4500;
 HEAP32[i2 + 4 >> 2] = i5;
 HEAP32[i2 + 16 >> 2] = i2;
 __ZN4wasm3LEBIjhE4readENSt3__28functionIFhvEEE(i4, i2);
 __ZNSt3__28functionIFhvEED2Ev(i2);
 if (!(HEAP8[i3 >> 0] | 0)) i1 = HEAP32[i4 >> 2] | 0; else {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23073) | 0;
  i8 = HEAP32[i4 >> 2] | 0;
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i7, i8) | 0, 23017) | 0;
  i5 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i5;
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i5) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
  i1 = i8;
 }
 STACKTOP = i6;
 return i1 | 0;
}
function __ZN4wasm17WasmBinaryBuilder9getS32LEBEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i6 + 28 | 0;
 i4 = i6 + 24 | 0;
 i2 = i6;
 i3 = i5 + 12 | 0;
 if (HEAP8[i3 >> 0] | 0) {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23002) | 0;
  i8 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i8;
  i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i8 >> 2] | 0) + 28 >> 2] & 63](i8, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i8) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
 }
 HEAP32[i2 >> 2] = 4544;
 HEAP32[i2 + 4 >> 2] = i5;
 HEAP32[i2 + 16 >> 2] = i2;
 __ZN4wasm3LEBIiaE4readENSt3__28functionIFavEEE(i4, i2);
 __ZNSt3__28functionIFavEED2Ev(i2);
 if (!(HEAP8[i3 >> 0] | 0)) i1 = HEAP32[i4 >> 2] | 0; else {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23073) | 0;
  i8 = HEAP32[i4 >> 2] | 0;
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(i7, i8) | 0, 23017) | 0;
  i5 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i5;
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i5) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
  i1 = i8;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEE4swapERS4_(i8, i7) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i9;
 i5 = i8 + 16 | 0;
 i1 = HEAP32[i5 >> 2] | 0;
 i6 = i1;
 if ((i1 | 0) == (i8 | 0) ? (i2 = i7 + 16 | 0, (HEAP32[i2 >> 2] | 0) == (i7 | 0)) : 0) {
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i1 >> 2] | 0) + 12 >> 2] & 1023](i1, i3);
  i6 = HEAP32[i5 >> 2] | 0;
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[i6 >> 2] | 0) + 16 >> 2] & 511](i6);
  HEAP32[i5 >> 2] = 0;
  i6 = HEAP32[i2 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i6 >> 2] | 0) + 12 >> 2] & 1023](i6, i8);
  i6 = HEAP32[i2 >> 2] | 0;
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[i6 >> 2] | 0) + 16 >> 2] & 511](i6);
  HEAP32[i2 >> 2] = 0;
  HEAP32[i5 >> 2] = i8;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i3 >> 2] | 0) + 12 >> 2] & 1023](i3, i7);
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 511](i3);
  HEAP32[i2 >> 2] = i7;
 } else i4 = 4;
 do if ((i4 | 0) == 4) {
  if ((i1 | 0) == (i8 | 0)) {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i1 >> 2] | 0) + 12 >> 2] & 1023](i1, i7);
   i8 = HEAP32[i5 >> 2] | 0;
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[i8 >> 2] | 0) + 16 >> 2] & 511](i8);
   i8 = i7 + 16 | 0;
   HEAP32[i5 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i8 >> 2] = i7;
   break;
  }
  i1 = i7 + 16 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  if ((i2 | 0) == (i7 | 0)) {
   FUNCTION_TABLE_vii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 1023](i2, i8);
   i7 = HEAP32[i1 >> 2] | 0;
   FUNCTION_TABLE_vi[HEAP32[(HEAP32[i7 >> 2] | 0) + 16 >> 2] & 511](i7);
   HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
   HEAP32[i5 >> 2] = i8;
   break;
  } else {
   HEAP32[i5 >> 2] = i2;
   HEAP32[i1 >> 2] = i6;
   break;
  }
 } while (0);
 STACKTOP = i9;
 return;
}

function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb(i5, i9, i4, i3, i6) {
 i5 = i5 | 0;
 i9 = i9 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i7 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i10 + 8 | 0;
 i1 = i10 + 4 | 0;
 i2 = i10;
 if (!(HEAP32[i4 + 4 >> 2] & 1)) {
  i7 = HEAP32[(HEAP32[i5 >> 2] | 0) + 24 >> 2] | 0;
  HEAP32[i1 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
  i1 = FUNCTION_TABLE_iiiiii[i7 & 31](i5, i8, i4, i3, i6 & 1) | 0;
 } else {
  i7 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
  HEAP32[i2 >> 2] = i7;
  i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61692) | 0;
  __ZNSt3__214__shared_count16__release_sharedEv(i7) | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  if (i6) FUNCTION_TABLE_vii[HEAP32[i2 + 24 >> 2] & 1023](i8, i1); else FUNCTION_TABLE_vii[HEAP32[i2 + 28 >> 2] & 1023](i8, i1);
  i5 = i8 + 11 | 0;
  i7 = HEAP8[i5 >> 0] | 0;
  i6 = i8 + 4 | 0;
  i1 = i7;
  i7 = i7 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i8;
  while (1) {
   i4 = i1 << 24 >> 24 < 0;
   if ((i7 | 0) == ((i4 ? HEAP32[i8 >> 2] | 0 : i8) + (i4 ? HEAP32[i6 >> 2] | 0 : i1 & 255) | 0)) break;
   i1 = HEAP8[i7 >> 0] | 0;
   i2 = HEAP32[i9 >> 2] | 0;
   do if (i2 | 0) {
    i3 = i2 + 24 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if ((i4 | 0) != (HEAP32[i2 + 28 >> 2] | 0)) {
     HEAP32[i3 >> 2] = i4 + 1;
     HEAP8[i4 >> 0] = i1;
     break;
    }
    if ((FUNCTION_TABLE_iii[HEAP32[(HEAP32[i2 >> 2] | 0) + 52 >> 2] & 63](i2, i1 & 255) | 0) == -1) HEAP32[i9 >> 2] = 0;
   } while (0);
   i1 = HEAP8[i5 >> 0] | 0;
   i7 = i7 + 1 | 0;
  }
  i1 = HEAP32[i9 >> 2] | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i8);
 }
 STACKTOP = i10;
 return i1 | 0;
}

function __ZN4wasm14EffectAnalyzer11invalidatesERS0_(i7, i4) {
 i7 = i7 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i9;
 i1 = HEAP16[i7 + 28 >> 1] | 0;
 L1 : do if ((i1 & 255) << 24 >> 24 == 0 ? (i2 = HEAP16[i4 + 28 >> 1] | 0, (i2 & 255) << 24 >> 24 == 0) : 0) {
  if (!((HEAP8[i7 + 57 >> 0] | 0) == 0 & (i1 & 65535) < 256) ? __ZN4wasm14EffectAnalyzer14accessesMemoryEv(i4) | 0 : 0) {
   i1 = 1;
   break;
  }
  if (__ZN4wasm14EffectAnalyzer14accessesMemoryEv(i7) | 0 ? !((HEAP8[i4 + 57 >> 0] | 0) == 0 & (i2 & 65535) < 256) : 0) {
   i1 = 1;
   break;
  }
  if (((HEAP32[i7 + 40 >> 2] | 0) + (HEAP32[i7 + 52 >> 2] | 0) | 0) >>> 0 >= 2) ___assert_fail(41754, 41800, 108, 41816);
  i3 = i7 + 48 | 0;
  i5 = i4 + 44 | 0;
  i1 = i4 + 32 | 0;
  i2 = HEAP32[i7 + 44 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   HEAP32[i8 >> 2] = HEAP32[i2 + 16 >> 2];
   if (__ZNKSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__count_uniqueIjEEjRKT_(i5, i8) | 0) {
    i6 = 14;
    break;
   }
   if (__ZNKSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__count_uniqueIjEEjRKT_(i1, i8) | 0) {
    i6 = 14;
    break;
   }
   i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i2) | 0;
  }
  if ((i6 | 0) == 14) {
   i1 = 1;
   break;
  }
  i2 = i7 + 36 | 0;
  i1 = HEAP32[i7 + 32 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) {
    i1 = 0;
    break L1;
   }
   HEAP32[i8 >> 2] = HEAP32[i1 + 16 >> 2];
   if (__ZNKSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__count_uniqueIjEEjRKT_(i5, i8) | 0) {
    i1 = 1;
    break L1;
   }
   i1 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i1) | 0;
  }
 } else i1 = 1; while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZN4wasm14CoalesceLocals22calculateInterferencesEv(i12) {
 i12 = i12 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i13;
 i11 = i13 + 4 | 0;
 i6 = HEAP32[i12 + 52 >> 2] | 0;
 i7 = i12 + 128 | 0;
 i8 = i11 + 4 | 0;
 i9 = HEAP32[i12 + 48 >> 2] | 0;
 while (1) {
  if ((i9 | 0) == (i6 | 0)) break;
  HEAP32[i4 >> 2] = HEAP32[i9 >> 2];
  if (__ZNKSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE4findIS9_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEERKT_(i7, i4) | 0) {
   __ZNSt3__26vectorIjNS_9allocatorIjEEEC2ERKS3_(i11, (HEAP32[i9 >> 2] | 0) + 12 | 0);
   __ZN4wasm14CoalesceLocals22calculateInterferencesERNS_8LocalSetE(i12, i11);
   i1 = HEAP32[i9 >> 2] | 0;
   i5 = i1 + 24 | 0;
   i1 = (HEAP32[i1 + 28 >> 2] | 0) - (HEAP32[i5 >> 2] | 0) >> 4;
   L6 : while (1) {
    i10 = i1 + -1 | 0;
    if ((i1 | 0) <= 0) break;
    i1 = HEAP32[i5 >> 2] | 0;
    i3 = HEAP32[i1 + (i10 << 4) + 4 >> 2] | 0;
    if (HEAP32[i1 + (i10 << 4) >> 2] | 0) {
     if (!(__ZN4wasm8LocalSet5eraseEj(i11, i3) | 0)) {
      i1 = i10;
      continue;
     }
     HEAP8[i1 + (i10 << 4) + 12 >> 0] = 1;
     i1 = i10;
     continue;
    }
    __ZN4wasm8LocalSet6insertEj(i11, i3);
    i1 = HEAP32[i8 >> 2] | 0;
    i2 = HEAP32[i11 >> 2] | 0;
    while (1) {
     if ((i2 | 0) == (i1 | 0)) {
      i1 = i10;
      continue L6;
     }
     __ZN4wasm14CoalesceLocals9interfereEjj(i12, HEAP32[i2 >> 2] | 0, i3);
     i2 = i2 + 4 | 0;
    }
   }
   __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i11);
  }
  i9 = i9 + 4 | 0;
 }
 STACKTOP = i13;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10parseBlockERPcPKcNS_7IStringES8_(i16, i15, i14, i12, i13) {
 i16 = i16 | 0;
 i15 = i15 | 0;
 i14 = i14 | 0;
 i12 = i12 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i17 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i17;
 i5 = i17 + 24 | 0;
 i7 = i17 + 20 | 0;
 i8 = i17 + 16 | 0;
 i9 = __ZN6cashew12ValueBuilder9makeBlockEv() | 0;
 i10 = i6 + 12 | 0;
 i11 = i6 + 12 | 0;
 L1 : while (1) {
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i15);
  i4 = HEAP32[i15 >> 2] | 0;
  i2 = HEAP8[i4 >> 0] | 0;
  switch (i2 << 24 >> 24) {
  case 0:
   break L1;
  case 59:
   {
    HEAP32[i15 >> 2] = i4 + 1;
    continue L1;
   }
  default:
   i1 = i14;
  }
  while (1) {
   i3 = HEAP8[i1 >> 0] | 0;
   if (!(i3 << 24 >> 24)) break;
   if (i3 << 24 >> 24 == i2 << 24 >> 24) break L1; else i1 = i1 + 1 | 0;
  }
  i1 = HEAP32[i12 >> 2] | 0;
  if ((i1 | 0 ? HEAP8[i1 >> 0] | 0 : 0) ? (__ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i6, i4), (HEAP32[i11 >> 2] | 0) == 0 ? (HEAP32[i6 >> 2] | 0) == (i1 | 0) : 0) : 0) break;
  i1 = HEAP32[i13 >> 2] | 0;
  if ((i1 | 0 ? HEAP8[i1 >> 0] | 0 : 0) ? (__ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i6, HEAP32[i15 >> 2] | 0), (HEAP32[i10 >> 2] | 0) == 0 ? (HEAP32[i6 >> 2] | 0) == (i1 | 0) : 0) : 0) break;
  i4 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE23parseElementOrStatementERPcPKc(i16, i15, i14) | 0;
  HEAP32[i7 >> 2] = i9;
  HEAP32[i8 >> 2] = i4;
  HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i6 >> 2] = HEAP32[i8 >> 2];
  __ZN6cashew12ValueBuilder13appendToBlockENS_3RefES1_(i5, i6);
 }
 STACKTOP = i17;
 return i9 | 0;
}

function __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE8__appendEj(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i2 = HEAP32[i8 + 8 >> 2] | 0;
 i4 = i8 + 4 | 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (((i2 - i1 | 0) / 12 | 0) >>> 0 < i6 >>> 0) {
  i5 = HEAP32[i8 >> 2] | 0;
  i3 = ((i1 - i5 | 0) / 12 | 0) + i6 | 0;
  if (i3 >>> 0 > 357913941) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
  i1 = (i2 - i5 | 0) / 12 | 0;
  if (i1 >>> 0 < 178956970) {
   i1 = i1 << 1;
   i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
  } else i1 = 357913941;
  __ZNSt3__214__split_bufferINS_6vectorIN6cashew6ParserINS2_3RefENS2_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS7_EEEERNS8_ISA_EEEC2EjjSC_(i7, i1, ((HEAP32[i4 >> 2] | 0) - i5 | 0) / 12 | 0, i8 + 8 | 0);
  i3 = i7 + 8 | 0;
  i2 = HEAP32[i3 >> 2] | 0;
  i1 = i6;
  i4 = i2;
  while (1) {
   HEAP32[i4 >> 2] = 0;
   HEAP32[i4 + 4 >> 2] = 0;
   HEAP32[i4 + 8 >> 2] = 0;
   i1 = i1 + -1 | 0;
   if (!i1) break; else i4 = i4 + 12 | 0;
  }
  HEAP32[i3 >> 2] = i2 + (i6 * 12 | 0);
  __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSA_EE(i8, i7);
  __ZNSt3__214__split_bufferINS_6vectorIN6cashew6ParserINS2_3RefENS2_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS7_EEEERNS8_ISA_EEED2Ev(i7);
 } else __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE18__construct_at_endEj(i8, i6);
 STACKTOP = i9;
 return;
}

function __ZNK4wasm8LocalSet5mergeERKS0_(i15, i12, i14) {
 i15 = i15 | 0;
 i12 = i12 | 0;
 i14 = i14 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0;
 HEAP32[i15 >> 2] = 0;
 HEAP32[i15 + 4 >> 2] = 0;
 HEAP32[i15 + 8 >> 2] = 0;
 i11 = i12 + 4 | 0;
 i13 = i14 + 4 | 0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i15, ((HEAP32[i13 >> 2] | 0) - (HEAP32[i14 >> 2] | 0) >> 2) + ((HEAP32[i11 >> 2] | 0) - (HEAP32[i12 >> 2] | 0) >> 2) | 0);
 i10 = HEAP32[i12 >> 2] | 0;
 i8 = (HEAP32[i11 >> 2] | 0) - i10 >> 2;
 i7 = HEAP32[i14 >> 2] | 0;
 i9 = (HEAP32[i13 >> 2] | 0) - i7 >> 2;
 i3 = 0;
 i2 = 0;
 i1 = 0;
 while (1) {
  if (!(i3 >>> 0 < i8 >>> 0 & i2 >>> 0 < i9 >>> 0)) break;
  i4 = HEAP32[i10 + (i3 << 2) >> 2] | 0;
  i5 = HEAP32[i7 + (i2 << 2) >> 2] | 0;
  do if (i4 >>> 0 >= i5 >>> 0) {
   i6 = (HEAP32[i15 >> 2] | 0) + (i1 << 2) | 0;
   if (i4 >>> 0 > i5 >>> 0) {
    HEAP32[i6 >> 2] = i5;
    i2 = i2 + 1 | 0;
    break;
   } else {
    HEAP32[i6 >> 2] = i4;
    i3 = i3 + 1 | 0;
    i2 = i2 + 1 | 0;
    break;
   }
  } else {
   HEAP32[(HEAP32[i15 >> 2] | 0) + (i1 << 2) >> 2] = i4;
   i3 = i3 + 1 | 0;
  } while (0);
  i1 = i1 + 1 | 0;
 }
 i5 = HEAP32[i12 >> 2] | 0;
 i4 = (HEAP32[i11 >> 2] | 0) - i5 >> 2;
 while (1) {
  if (i3 >>> 0 >= i4 >>> 0) break;
  HEAP32[(HEAP32[i15 >> 2] | 0) + (i1 << 2) >> 2] = HEAP32[i5 + (i3 << 2) >> 2];
  i3 = i3 + 1 | 0;
  i1 = i1 + 1 | 0;
 }
 i3 = HEAP32[i14 >> 2] | 0;
 i4 = (HEAP32[i13 >> 2] | 0) - i3 >> 2;
 while (1) {
  if (i2 >>> 0 >= i4 >>> 0) break;
  HEAP32[(HEAP32[i15 >> 2] | 0) + (i1 << 2) >> 2] = HEAP32[i3 + (i2 << 2) >> 2];
  i2 = i2 + 1 | 0;
  i1 = i1 + 1 | 0;
 }
 __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i15, i1);
 return;
}

function __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6removeENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEE(i12, i13, i1) {
 i12 = i12 | 0;
 i13 = i13 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i11 = HEAP32[i1 >> 2] | 0;
 i8 = HEAP32[i13 + 4 >> 2] | 0;
 i1 = HEAP32[i11 + 4 >> 2] | 0;
 i9 = i8 + -1 | 0;
 i10 = (i9 & i8 | 0) == 0;
 if (i10) i7 = i9 & i1; else i7 = (i1 >>> 0) % (i8 >>> 0) | 0;
 i3 = (HEAP32[i13 >> 2] | 0) + (i7 << 2) | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 while (1) {
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == (i11 | 0)) {
   i6 = i2;
   break;
  } else i2 = i1;
 }
 i5 = i13 + 8 | 0;
 if ((i6 | 0) != (i5 | 0)) {
  i1 = HEAP32[i6 + 4 >> 2] | 0;
  if (i10) i1 = i1 & i9; else i1 = (i1 >>> 0) % (i8 >>> 0) | 0;
  if ((i1 | 0) == (i7 | 0)) i3 = i11; else i4 = 12;
 } else i4 = 12;
 do if ((i4 | 0) == 12) {
  i1 = HEAP32[i11 >> 2] | 0;
  if (i1 | 0) {
   i1 = HEAP32[i1 + 4 >> 2] | 0;
   if (i10) i1 = i1 & i9; else i1 = (i1 >>> 0) % (i8 >>> 0) | 0;
   if ((i1 | 0) == (i7 | 0)) {
    i3 = i11;
    break;
   }
  }
  HEAP32[i3 >> 2] = 0;
  i3 = i11;
 } while (0);
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = i2;
 if (i2) {
  i2 = HEAP32[i2 + 4 >> 2] | 0;
  if (i10) i2 = i2 & i9; else i2 = (i2 >>> 0) % (i8 >>> 0) | 0;
  if ((i2 | 0) != (i7 | 0)) {
   HEAP32[(HEAP32[i13 >> 2] | 0) + (i2 << 2) >> 2] = i6;
   i1 = HEAP32[i11 >> 2] | 0;
  }
 }
 HEAP32[i6 >> 2] = i1;
 HEAP32[i3 >> 2] = 0;
 i13 = i13 + 12 | 0;
 HEAP32[i13 >> 2] = (HEAP32[i13 >> 2] | 0) + -1;
 HEAP32[i12 >> 2] = i11;
 HEAP32[i12 + 4 >> 2] = i5;
 HEAP8[i12 + 8 >> 0] = 1;
 return;
}

function __ZN10MixedArena10allocSpaceEj(i1, i6) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i11;
 i5 = _pthread_self() | 0;
 if ((i5 | 0) == (HEAP32[i1 + 20 >> 2] | 0)) {
  i9 = i6 + 7 & -8;
  i2 = i1 + 12 | 0;
  i4 = HEAP32[i2 >> 2] | 0;
  i5 = 0;
  while (1) {
   if (i4 >>> 0 > i9 >>> 0) break;
   i5 = i4 << 1;
   HEAP32[i2 >> 2] = i5;
   i4 = i5;
   i5 = 1;
  }
  i6 = i1 + 4 | 0;
  i7 = HEAP32[i6 >> 2] | 0;
  i2 = i7;
  if ((i7 | 0) != (HEAP32[i1 >> 2] | 0) ? (i3 = i1 + 16 | 0, i10 = HEAP32[i3 >> 2] | 0, !(i5 | (i10 + i9 | 0) >>> 0 >= i4 >>> 0)) : 0) i1 = i10; else {
   i3 = __Znaj(i4) | 0;
   HEAP32[i8 >> 2] = i3;
   if (i2 >>> 0 < (HEAP32[i1 + 8 >> 2] | 0) >>> 0) {
    HEAP32[i7 >> 2] = i3;
    i2 = (HEAP32[i6 >> 2] | 0) + 4 | 0;
    HEAP32[i6 >> 2] = i2;
   } else {
    __ZNSt3__26vectorIPcNS_9allocatorIS1_EEE21__push_back_slow_pathIS1_EEvOT_(i1, i8);
    i2 = HEAP32[i6 >> 2] | 0;
   }
   i3 = i1 + 16 | 0;
   HEAP32[i3 >> 2] = 0;
   i1 = 0;
  }
  i10 = (HEAP32[i2 + -4 >> 2] | 0) + i1 | 0;
  HEAP32[i3 >> 2] = i1 + i9;
  i1 = i10;
 } else {
  i2 = 0;
  L16 : while (1) {
   while (1) {
    if ((i5 | 0) == (HEAP32[i1 + 20 >> 2] | 0)) {
     i7 = 9;
     break L16;
    }
    i3 = i1 + 24 | 0;
    i4 = HEAP32[i3 >> 2] | 0;
    if (!i4) break; else i1 = i4;
   }
   if (!i2) {
    i2 = __Znwj(28) | 0;
    __ZN10MixedArenaC2Ev(i2);
   }
   i4 = HEAP32[i3 >> 2] | 0;
   if (!i4) HEAP32[i3 >> 2] = i2;
   if (!i4) break;
   i1 = i4;
  }
  if ((i7 | 0) == 9) if (i2) {
   __ZN10MixedArenaD2Ev(i2);
   __ZdlPv(i2);
  }
  i1 = __ZN10MixedArena10allocSpaceEj(i1, i6) | 0;
 }
 STACKTOP = i11;
 return i1 | 0;
}

function __ZN4wasm18ExpressionAnalyzer12isResultUsedENSt3__26vectorIPNS_10ExpressionENS1_9allocatorIS4_EEEEPNS_8FunctionE(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0, i10 = 0;
 i7 = ((HEAP32[i8 + 4 >> 2] | 0) - (HEAP32[i8 >> 2] | 0) >> 2) + -2 | 0;
 L1 : while (1) {
  if ((i7 | 0) <= -1) {
   i9 = 14;
   break;
  }
  i5 = HEAP32[i8 >> 2] | 0;
  i1 = HEAP32[i5 + (i7 << 2) >> 2] | 0;
  i5 = HEAP32[i5 + (i7 + 1 << 2) >> 2] | 0;
  switch (HEAP32[i1 >> 2] | 0) {
  case 1:
   {
    i2 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i1) | 0;
    i1 = i2 + 12 | 0;
    i2 = i2 + 20 | 0;
    i3 = 0;
    while (1) {
     if (i3 >>> 0 >= ((HEAP32[i2 >> 2] | 0) + -1 | 0) >>> 0) break;
     i10 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i3) | 0;
     if ((HEAP32[i10 >> 2] | 0) == (i5 | 0)) {
      i4 = 0;
      break L1;
     } else i3 = i3 + 1 | 0;
    }
    i10 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i1) | 0;
    if ((HEAP32[i10 >> 2] | 0) != (i5 | 0)) {
     i9 = 8;
     break L1;
    }
    break;
   }
  case 2:
   {
    i1 = __ZN4wasm10Expression4castINS_2IfEEEPT_v(i1) | 0;
    if ((i5 | 0) == (HEAP32[i1 + 8 >> 2] | 0)) {
     i4 = 1;
     break L1;
    }
    i2 = HEAP32[i1 + 16 >> 2] | 0;
    if (!i2) {
     i4 = 0;
     break L1;
    }
    if (!((i5 | 0) == (i2 | 0) ? 1 : (i5 | 0) == (HEAP32[i1 + 12 >> 2] | 0))) {
     i9 = 12;
     break L1;
    }
    break;
   }
  default:
   {
    i4 = 1;
    break L1;
   }
  }
  i7 = i7 + -1 | 0;
 }
 if ((i9 | 0) == 8) ___assert_fail(41828, 41800, 230, 41856); else if ((i9 | 0) == 12) ___assert_fail(41869, 41800, 236, 41856); else if ((i9 | 0) == 14) i4 = (HEAP32[i6 + 4 >> 2] | 0) != 0;
 return i4 | 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner7visitIfEPNS_2IfE(i3, i4, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i5;
 __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i2, i4, HEAP32[i1 + 8 >> 2] | 0);
 do if (!(HEAP32[i2 + 16 >> 2] | 0)) if (!(__ZNK4wasm7Literal6geti32Ev(i2) | 0)) {
  i1 = HEAP32[i1 + 16 >> 2] | 0;
  if (!i1) {
   HEAP32[i3 >> 2] = 0;
   i4 = i3 + 8 | 0;
   HEAP32[i4 >> 2] = 0;
   HEAP32[i4 + 4 >> 2] = 0;
   HEAP32[i3 + 16 >> 2] = 0;
   break;
  } else {
   __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i3, i4, i1);
   break;
  }
 } else {
  __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i3, i4, HEAP32[i1 + 12 >> 2] | 0);
  if (HEAP32[i3 + 16 >> 2] | 0) break;
  if (HEAP32[i1 + 16 >> 2] | 0) break;
  HEAP32[i3 >> 2] = 0;
  i4 = i3 + 8 | 0;
  HEAP32[i4 >> 2] = 0;
  HEAP32[i4 + 4 >> 2] = 0;
  break;
 } else {
  HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i3 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
  HEAP32[i3 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
  HEAP32[i3 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
  HEAP32[i3 + 16 >> 2] = HEAP32[i2 + 16 >> 2];
  HEAP32[i3 + 20 >> 2] = HEAP32[i2 + 20 >> 2];
 } while (0);
 STACKTOP = i5;
 return;
}

function _load_binary2wasm(i4, i5) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 144 | 0;
 i2 = i6 + 128 | 0;
 i3 = i6;
 __ZL12prepare2wasmv();
 if (HEAP8[63612] | 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17729) | 0;
 i1 = __Znwj(180) | 0;
 __ZN4wasm6ModuleC2Ev(i1);
 HEAP32[14814] = i1;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 __ZNSt3__26vectorIcNS_9allocatorIcEEE6resizeEj(i2, i5);
 i1 = 0;
 while (1) {
  if ((i1 | 0) >= (i5 | 0)) break;
  HEAP8[(HEAP32[i2 >> 2] | 0) + i1 >> 0] = HEAP8[i4 + i1 >> 0] | 0;
  i1 = i1 + 1 | 0;
 }
 i4 = HEAP32[14814] | 0;
 i5 = (HEAP32[14809] | 0) != 0;
 HEAP32[i3 >> 2] = i4;
 HEAP32[i3 + 4 >> 2] = i4 + 88;
 HEAP32[i3 + 8 >> 2] = i2;
 HEAP8[i3 + 12 >> 0] = i5 & 1;
 HEAP32[i3 + 16 >> 2] = 0;
 HEAP32[i3 + 20 >> 2] = -1;
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = 0;
 HEAP32[i3 + 32 >> 2] = 0;
 HEAP32[i3 + 40 >> 2] = 0;
 HEAP32[i3 + 44 >> 2] = 0;
 HEAP32[i3 + 48 >> 2] = 0;
 HEAP32[i3 + 56 >> 2] = 0;
 HEAP32[i3 + 60 >> 2] = 0;
 HEAP32[i3 + 52 >> 2] = i3 + 56;
 HEAP32[i3 + 64 >> 2] = 0;
 HEAP32[i3 + 76 >> 2] = 0;
 HEAP32[i3 + 80 >> 2] = 0;
 HEAP32[i3 + 72 >> 2] = i3 + 76;
 i5 = i3 + 84 | 0;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP32[i5 + 8 >> 2] = 0;
 HEAP32[i5 + 12 >> 2] = 0;
 HEAP32[i5 + 16 >> 2] = 0;
 HEAP32[i5 + 20 >> 2] = 0;
 HEAP32[i3 + 108 >> 2] = 15;
 HEAP32[i3 + 112 >> 2] = 0;
 HEAP32[i3 + 116 >> 2] = 0;
 HEAP32[i3 + 120 >> 2] = 0;
 __ZN4wasm17WasmBinaryBuilder4readEv(i3);
 __Z14finalizeModulev();
 __ZN4wasm17WasmBinaryBuilderD2Ev(i3);
 __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i2);
 STACKTOP = i6;
 return;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_(i3, i11, i2) {
 i3 = i3 | 0;
 i11 = i11 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i10 = i2;
 i6 = i11;
 i4 = i10 - i6 | 0;
 i5 = i4 >> 2;
 i1 = i3 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 i7 = i9;
 L1 : do if (i5 >>> 0 > (HEAP32[i1 >> 2] | 0) - i9 >> 2 >>> 0) {
  __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE10deallocateEv(i3);
  if (i5 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i3);
  i1 = (HEAP32[i1 >> 2] | 0) - (HEAP32[i3 >> 2] | 0) | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i5 >>> 0 ? i5 : i1;
  } else i1 = 1073741823;
  __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE8allocateEj(i3, i1);
  i1 = i3 + 4 | 0;
  if ((i4 | 0) > 0) {
   _memcpy(HEAP32[i1 >> 2] | 0, i11 | 0, i4 | 0) | 0;
   HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + (i5 << 2);
  }
 } else {
  i8 = i3 + 4 | 0;
  i4 = (HEAP32[i8 >> 2] | 0) - i9 >> 2;
  i5 = i5 >>> 0 > i4 >>> 0;
  i4 = i5 ? i11 + (i4 << 2) | 0 : i2;
  i3 = i4;
  i1 = i3 - i6 | 0;
  i2 = i1 >> 2;
  if (i2 | 0) _memmove(i9 | 0, i11 | 0, i1 | 0) | 0;
  i2 = i7 + (i2 << 2) | 0;
  if (i5) {
   i1 = i10 - i3 | 0;
   if ((i1 | 0) <= 0) break;
   _memcpy(HEAP32[i8 >> 2] | 0, i4 | 0, i1 | 0) | 0;
   HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + (i1 >> 2 << 2);
   break;
  }
  i1 = HEAP32[i8 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break L1;
   i11 = i1 + -4 | 0;
   HEAP32[i8 >> 2] = i11;
   i1 = i11;
  }
 } while (0);
 return;
}

function __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_(i3, i11, i2) {
 i3 = i3 | 0;
 i11 = i11 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i10 = i2;
 i6 = i11;
 i4 = i10 - i6 | 0;
 i5 = i4 >> 3;
 i1 = i3 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 i7 = i9;
 L1 : do if (i5 >>> 0 > (HEAP32[i1 >> 2] | 0) - i9 >> 3 >>> 0) {
  __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE10deallocateEv(i3);
  if (i5 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i3);
  i1 = (HEAP32[i1 >> 2] | 0) - (HEAP32[i3 >> 2] | 0) | 0;
  if (i1 >> 3 >>> 0 < 268435455) {
   i1 = i1 >> 2;
   i1 = i1 >>> 0 < i5 >>> 0 ? i5 : i1;
  } else i1 = 536870911;
  __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE8allocateEj(i3, i1);
  i1 = i3 + 4 | 0;
  if ((i4 | 0) > 0) {
   _memcpy(HEAP32[i1 >> 2] | 0, i11 | 0, i4 | 0) | 0;
   HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + (i5 << 3);
  }
 } else {
  i8 = i3 + 4 | 0;
  i4 = (HEAP32[i8 >> 2] | 0) - i9 >> 3;
  i5 = i5 >>> 0 > i4 >>> 0;
  i4 = i5 ? i11 + (i4 << 3) | 0 : i2;
  i3 = i4;
  i1 = i3 - i6 | 0;
  i2 = i1 >> 3;
  if (i2 | 0) _memmove(i9 | 0, i11 | 0, i1 | 0) | 0;
  i2 = i7 + (i2 << 3) | 0;
  if (i5) {
   i1 = i10 - i3 | 0;
   if ((i1 | 0) <= 0) break;
   _memcpy(HEAP32[i8 >> 2] | 0, i4 | 0, i1 | 0) | 0;
   HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + (i1 >> 3 << 3);
   break;
  }
  i1 = HEAP32[i8 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break L1;
   i11 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i11;
   i1 = i11;
  }
 } while (0);
 return;
}

function __ZN4wasm17WasmBinaryBuilder10getFloat64Ev(i3) {
 i3 = i3 | 0;
 var d1 = 0.0, i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i6 + 16 | 0;
 i2 = i6;
 i5 = i3 + 12 | 0;
 if (HEAP8[i5 >> 0] | 0) {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23002) | 0;
  i8 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i4 >> 2] = i8;
  i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i4, 61680) | 0;
  i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i8 >> 2] | 0) + 28 >> 2] & 63](i8, 10) | 0;
  __ZNSt3__26localeD2Ev(i4);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i8) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
 }
 i7 = __ZN4wasm17WasmBinaryBuilder8getInt64Ev(i3) | 0;
 HEAP32[i2 >> 2] = 2;
 i8 = i2 + 8 | 0;
 HEAP32[i8 >> 2] = i7;
 HEAP32[i8 + 4 >> 2] = tempRet0;
 d1 = +__ZNK4wasm7Literal14reinterpretf64Ev(i2);
 if (HEAP8[i5 >> 0] | 0) {
  i8 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25110) | 0, d1) | 0, 23017) | 0;
  i7 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i4 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i4, 61680) | 0;
  i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
  __ZNSt3__26localeD2Ev(i4);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i7) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
 }
 STACKTOP = i6;
 return +d1;
}

function __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_(i3, i11, i2) {
 i3 = i3 | 0;
 i11 = i11 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i10 = i2;
 i6 = i11;
 i4 = i10 - i6 | 0;
 i5 = i4 >> 2;
 i1 = i3 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 i7 = i9;
 L1 : do if (i5 >>> 0 > (HEAP32[i1 >> 2] | 0) - i9 >> 2 >>> 0) {
  __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE10deallocateEv(i3);
  if (i5 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i3);
  i1 = (HEAP32[i1 >> 2] | 0) - (HEAP32[i3 >> 2] | 0) | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i5 >>> 0 ? i5 : i1;
  } else i1 = 1073741823;
  __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE8allocateEj(i3, i1);
  i1 = i3 + 4 | 0;
  if ((i4 | 0) > 0) {
   _memcpy(HEAP32[i1 >> 2] | 0, i11 | 0, i4 | 0) | 0;
   HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + (i5 << 2);
  }
 } else {
  i8 = i3 + 4 | 0;
  i4 = (HEAP32[i8 >> 2] | 0) - i9 >> 2;
  i5 = i5 >>> 0 > i4 >>> 0;
  i4 = i5 ? i11 + (i4 << 2) | 0 : i2;
  i3 = i4;
  i1 = i3 - i6 | 0;
  i2 = i1 >> 2;
  if (i2 | 0) _memmove(i9 | 0, i11 | 0, i1 | 0) | 0;
  i2 = i7 + (i2 << 2) | 0;
  if (i5) {
   i1 = i10 - i3 | 0;
   if ((i1 | 0) <= 0) break;
   _memcpy(HEAP32[i8 >> 2] | 0, i4 | 0, i1 | 0) | 0;
   HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + (i1 >> 2 << 2);
   break;
  }
  i1 = HEAP32[i8 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break L1;
   i11 = i1 + -4 | 0;
   HEAP32[i8 >> 2] = i11;
   i1 = i11;
  }
 } while (0);
 return;
}

function __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(i7, i1) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 HEAP8[i1 + 12 >> 0] = (i1 | 0) == (i7 | 0) & 1;
 i4 = i1;
 while (1) {
  if ((i4 | 0) == (i7 | 0)) break;
  i2 = HEAP32[i4 + 8 >> 2] | 0;
  i6 = i2 + 12 | 0;
  if (HEAP8[i6 >> 0] | 0) break;
  i3 = i2 + 8 | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  i5 = HEAP32[i1 >> 2] | 0;
  if ((i5 | 0) == (i2 | 0)) {
   i5 = HEAP32[i1 + 4 >> 2] | 0;
   if (!i5) {
    i8 = 8;
    break;
   }
   i5 = i5 + 12 | 0;
   if (HEAP8[i5 >> 0] | 0) {
    i8 = 8;
    break;
   }
   HEAP8[i6 >> 0] = 1;
   HEAP8[i1 + 12 >> 0] = (i1 | 0) == (i7 | 0) & 1;
   HEAP8[i5 >> 0] = 1;
   i4 = i1;
   continue;
  } else {
   if (!i5) {
    i8 = 14;
    break;
   }
   i5 = i5 + 12 | 0;
   if (HEAP8[i5 >> 0] | 0) {
    i8 = 14;
    break;
   }
   HEAP8[i6 >> 0] = 1;
   HEAP8[i1 + 12 >> 0] = (i1 | 0) == (i7 | 0) & 1;
   HEAP8[i5 >> 0] = 1;
   i4 = i1;
   continue;
  }
 }
 if ((i8 | 0) == 8) {
  if ((HEAP32[i2 >> 2] | 0) != (i4 | 0)) {
   __ZNSt3__218__tree_left_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i2);
   i1 = HEAP32[i3 >> 2] | 0;
   i2 = i1;
   i1 = HEAP32[i1 + 8 >> 2] | 0;
  }
  HEAP8[i2 + 12 >> 0] = 1;
  HEAP8[i1 + 12 >> 0] = 0;
  __ZNSt3__219__tree_right_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i1);
 } else if ((i8 | 0) == 14) {
  if ((HEAP32[i2 >> 2] | 0) == (i4 | 0)) {
   __ZNSt3__219__tree_right_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i2);
   i1 = HEAP32[i3 >> 2] | 0;
   i2 = i1;
   i1 = HEAP32[i1 + 8 >> 2] | 0;
  }
  HEAP8[i2 + 12 >> 0] = 1;
  HEAP8[i1 + 12 >> 0] = 0;
  __ZNSt3__218__tree_left_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i1);
 }
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE10doEndBlockEPS1_PPNS_10ExpressionE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i3 >> 2] | 0) | 0) + 8 | 0;
 if (((HEAP32[i7 >> 2] | 0 ? (i8 = i4 + 16 | 0, i9 = i4 + 64 | 0, i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE4findIS3_EENS_15__tree_iteratorISG_PNS_11__tree_nodeISG_PvEEiEERKT_(i9, i7) | 0, (i2 | 0) != (i4 + 68 | 0)) : 0) ? (i5 = i2 + 20 | 0, i1 = i2 + 24 | 0, (HEAP32[i1 >> 2] | 0) != (HEAP32[i5 >> 2] | 0)) : 0) ? (i6 = i4 + 60 | 0, i2 = HEAP32[i6 >> 2] | 0, __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i4, i3), __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i8, i2, HEAP32[i6 >> 2] | 0), HEAP32[i7 >> 2] | 0) : 0) {
  i2 = HEAP32[i1 >> 2] | 0;
  i1 = HEAP32[i5 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i8, HEAP32[i1 >> 2] | 0, HEAP32[i6 >> 2] | 0);
   i1 = i1 + 4 | 0;
  }
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE14__erase_uniqueIS3_EEjRKT_(i9, i7) | 0;
 }
 return;
}

function __ZN4wasm11MergeBlocks10visitBlockEPNS_5BlockE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i11 = i12;
 i10 = i1 + 12 | 0;
 i9 = i1 + 20 | 0;
 i5 = i2 + 40 | 0;
 i6 = i11 + 4 | 0;
 i7 = i11 + 8 | 0;
 i8 = i11 + 12 | 0;
 i1 = 0;
 while (1) {
  if (i1 >>> 0 >= (HEAP32[i9 >> 2] | 0) >>> 0) break;
  i2 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i10, i1) | 0;
  i2 = HEAP32[i2 >> 2] | 0;
  if (!((i2 | 0) == 0 | (HEAP32[i2 >> 2] | 0) != 1) ? (HEAP32[i2 + 8 >> 2] | 0) == 0 : 0) {
   HEAP32[i11 >> 2] = (HEAP32[i5 >> 2] | 0) + 88;
   HEAP32[i6 >> 2] = 0;
   HEAP32[i7 >> 2] = 0;
   HEAP32[i8 >> 2] = 0;
   i3 = 0;
   while (1) {
    if ((i3 | 0) == (i1 | 0)) break;
    i4 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i10, i3) | 0;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i11, HEAP32[i4 >> 2] | 0);
    i3 = i3 + 1 | 0;
   }
   i2 = i2 + 12 | 0;
   i3 = HEAP32[i2 + 8 >> 2] | 0;
   i4 = 0;
   while (1) {
    if ((i4 | 0) == (i3 | 0)) break;
    i13 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i2, i4) | 0;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i11, HEAP32[i13 >> 2] | 0);
    i4 = i4 + 1 | 0;
   }
   while (1) {
    i1 = i1 + 1 | 0;
    if (i1 >>> 0 >= (HEAP32[i9 >> 2] | 0) >>> 0) break;
    i13 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i10, i1) | 0;
    __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i11, HEAP32[i13 >> 2] | 0);
   }
   __ZN11ArenaVectorIPN4wasm10ExpressionEE3setIS3_EEvRT_(i10, i11);
   i1 = 0;
   continue;
  }
  i1 = i1 + 1 | 0;
 }
 STACKTOP = i12;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE25__emplace_unique_key_argsIS7_JRKNS_21piecewise_construct_tENS_5tupleIJRKS7_EEENSM_IJEEEEEENS_4pairINS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEESN_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS7_EEENSM_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISB_PvEENS_22__tree_node_destructorINS5_ISU_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSL_SL_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE25__emplace_unique_key_argsIS7_JRKNS_21piecewise_construct_tENS_5tupleIJOS7_EEENSM_IJEEEEEENS_4pairINS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEESN_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJOS7_EEENSM_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISB_PvEENS_22__tree_node_destructorINS5_IST_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSL_SL_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZN4wasm17WasmBinaryBuilder10getFloat32Ev(i3) {
 i3 = i3 | 0;
 var d1 = 0.0, i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i6 + 16 | 0;
 i2 = i6;
 i5 = i3 + 12 | 0;
 if (HEAP8[i5 >> 0] | 0) {
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23002) | 0;
  i8 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i4 >> 2] = i8;
  i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i4, 61680) | 0;
  i8 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i8 >> 2] | 0) + 28 >> 2] & 63](i8, 10) | 0;
  __ZNSt3__26localeD2Ev(i4);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i8) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
 }
 i8 = __ZN4wasm17WasmBinaryBuilder8getInt32Ev(i3) | 0;
 HEAP32[i2 >> 2] = 1;
 HEAP32[i2 + 8 >> 2] = i8;
 d1 = +__ZNK4wasm7Literal14reinterpretf32Ev(i2);
 if (HEAP8[i5 >> 0] | 0) {
  i8 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25082) | 0, d1) | 0, 23017) | 0;
  i7 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i4 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i4, 61680) | 0;
  i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
  __ZNSt3__26localeD2Ev(i4);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i7) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
 }
 STACKTOP = i6;
 return +d1;
}

function __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i11, i8, i10, i2, i3, i7) {
 i11 = i11 | 0;
 i8 = i8 | 0;
 i10 = i10 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i7 = i7 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i12 = 0, i13 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i9 = i12;
 i1 = HEAP32[i11 >> 2] | 0;
 L1 : do if (!i1) i1 = 0; else {
  i13 = i8;
  i5 = i2 - i13 >> 2;
  i6 = i3 + 12 | 0;
  i3 = HEAP32[i6 >> 2] | 0;
  i5 = (i3 | 0) > (i5 | 0) ? i3 - i5 | 0 : 0;
  i3 = i10;
  i13 = i3 - i13 | 0;
  i4 = i13 >> 2;
  if ((i13 | 0) > 0 ? (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 48 >> 2] & 31](i1, i8, i4) | 0) != (i4 | 0) : 0) {
   HEAP32[i11 >> 2] = 0;
   i1 = 0;
   break;
  }
  do if ((i5 | 0) > 0) {
   HEAP32[i9 >> 2] = 0;
   HEAP32[i9 + 4 >> 2] = 0;
   HEAP32[i9 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEjw(i9, i5, i7);
   if ((FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 48 >> 2] & 31](i1, (HEAP8[i9 + 8 + 3 >> 0] | 0) < 0 ? HEAP32[i9 >> 2] | 0 : i9, i5) | 0) == (i5 | 0)) {
    __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i9);
    break;
   } else {
    HEAP32[i11 >> 2] = 0;
    __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i9);
    i1 = 0;
    break L1;
   }
  } while (0);
  i13 = i2 - i3 | 0;
  i2 = i13 >> 2;
  if ((i13 | 0) > 0 ? (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 48 >> 2] & 31](i1, i10, i2) | 0) != (i2 | 0) : 0) {
   HEAP32[i11 >> 2] = 0;
   i1 = 0;
   break;
  }
  HEAP32[i6 >> 2] = 0;
 } while (0);
 STACKTOP = i12;
 return i1 | 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner15visitCallImportEPNS_10CallImportE(i4, i8, i6) {
 i4 = i4 | 0;
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0, i9 = 0, i10 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i1 = i9 + 56 | 0;
 i5 = i9 + 44 | 0;
 i7 = i9 + 16 | 0;
 i2 = i9;
 i3 = i9 + 40 | 0;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP32[i5 + 8 >> 2] = 0;
 __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner17generateArgumentsERK11ArenaVectorIPNS_10ExpressionEES9_(i7, i8, i6 + 8 | 0, i5);
 if (!(HEAP32[i7 + 16 >> 2] | 0)) {
  i8 = HEAP32[i8 >> 2] | 0;
  i7 = HEAP32[i8 + 24 >> 2] | 0;
  i10 = HEAP32[(HEAP32[i7 >> 2] | 0) + 4 >> 2] | 0;
  i8 = HEAP32[i8 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i6 + 24 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  i8 = __ZN4wasm6Module9getImportENS_4NameE(i8, i1) | 0;
  FUNCTION_TABLE_viiii[i10 & 15](i2, i7, i8, i5);
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
  HEAP32[i4 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
  HEAP32[i4 + 16 >> 2] = 0;
 } else {
  HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i7 + 8 >> 2];
  HEAP32[i4 + 12 >> 2] = HEAP32[i7 + 12 >> 2];
  HEAP32[i4 + 16 >> 2] = HEAP32[i7 + 16 >> 2];
  HEAP32[i4 + 20 >> 2] = HEAP32[i7 + 20 >> 2];
 }
 __ZNSt3__213__vector_baseIN4wasm7LiteralENS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_(i3, i11, i2) {
 i3 = i3 | 0;
 i11 = i11 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i10 = i2;
 i6 = i11;
 i4 = i10 - i6 | 0;
 i5 = i4 >> 2;
 i1 = i3 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 i7 = i9;
 L1 : do if (i5 >>> 0 > (HEAP32[i1 >> 2] | 0) - i9 >> 2 >>> 0) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE10deallocateEv(i3);
  if (i5 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i3);
  i1 = (HEAP32[i1 >> 2] | 0) - (HEAP32[i3 >> 2] | 0) | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i5 >>> 0 ? i5 : i1;
  } else i1 = 1073741823;
  __ZNSt3__26vectorIjNS_9allocatorIjEEE8allocateEj(i3, i1);
  i1 = i3 + 4 | 0;
  if ((i4 | 0) > 0) {
   _memcpy(HEAP32[i1 >> 2] | 0, i11 | 0, i4 | 0) | 0;
   HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + (i5 << 2);
  }
 } else {
  i8 = i3 + 4 | 0;
  i4 = (HEAP32[i8 >> 2] | 0) - i9 >> 2;
  i5 = i5 >>> 0 > i4 >>> 0;
  i4 = i5 ? i11 + (i4 << 2) | 0 : i2;
  i3 = i4;
  i1 = i3 - i6 | 0;
  i2 = i1 >> 2;
  if (i2 | 0) _memmove(i9 | 0, i11 | 0, i1 | 0) | 0;
  i2 = i7 + (i2 << 2) | 0;
  if (i5) {
   i1 = i10 - i3 | 0;
   if ((i1 | 0) <= 0) break;
   _memcpy(HEAP32[i8 >> 2] | 0, i4 | 0, i1 | 0) | 0;
   HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + (i1 >> 2 << 2);
   break;
  }
  i1 = HEAP32[i8 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break L1;
   i11 = i1 + -4 | 0;
   HEAP32[i8 >> 2] = i11;
   i1 = i11;
  }
 } while (0);
 return;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner9visitLoadEPNS_4LoadE(i4, i7, i5) {
 i4 = i4 | 0;
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0, i8 = 0, i9 = 0, i10 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i1 = i8 + 40 | 0;
 i6 = i8;
 i2 = i8 + 24 | 0;
 i3 = i8 + 56 | 0;
 __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i6, i7, HEAP32[i5 + 20 >> 2] | 0);
 if (!(HEAP32[i6 + 16 >> 2] | 0)) {
  i10 = HEAP32[i7 >> 2] | 0;
  i7 = HEAP32[i10 + 24 >> 2] | 0;
  i9 = HEAP32[(HEAP32[i7 >> 2] | 0) + 8 >> 2] | 0;
  HEAP32[i1 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i1 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
  HEAP32[i1 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
  HEAP32[i1 + 12 >> 2] = HEAP32[i6 + 12 >> 2];
  i6 = __ZN4wasm14ModuleInstance15getFinalAddressINS_4LoadEEENS_7AddressEPT_NS_7LiteralE(i10, i5, i1) | 0;
  HEAP32[i3 >> 2] = i6;
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  FUNCTION_TABLE_viiii[i9 & 15](i2, i7, i5, i1);
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
  HEAP32[i4 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
  HEAP32[i4 + 16 >> 2] = 0;
 } else {
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
  HEAP32[i4 + 12 >> 2] = HEAP32[i6 + 12 >> 2];
  HEAP32[i4 + 16 >> 2] = HEAP32[i6 + 16 >> 2];
  HEAP32[i4 + 20 >> 2] = HEAP32[i6 + 20 >> 2];
 }
 STACKTOP = i8;
 return;
}

function __ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i1, i4, i5) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i3 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i9 + 4 | 0;
 i7 = i9;
 HEAP32[i6 >> 2] = i4;
 HEAP32[i7 >> 2] = i5;
 i8 = HEAP32[i1 >> 2] | 0;
 i1 = HEAP32[i1 + 4 >> 2] | 0;
 i1 = (HEAP32[i1 + 12 >> 2] | 0) - (HEAP32[i1 + 8 >> 2] | 0) >> 2;
 i2 = i1 >>> 0 > i5 >>> 0;
 do if (i1 >>> 0 <= i4 >>> 0 | i2) {
  i3 = i1 >>> 0 > i4 >>> 0;
  if (i1 >>> 0 <= i5 >>> 0 | i3) {
   if (i2 & i3) {
    i1 = i4 >>> 0 < i5 >>> 0;
    break;
   }
   i1 = i8 + 44 | 0;
   i2 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i1, i6) | 0;
   i2 = HEAP32[i2 >> 2] | 0;
   i5 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i1, i7) | 0;
   i5 = (i2 | 0) == (HEAP32[i5 >> 2] | 0);
   i2 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i1, i6) | 0;
   i2 = HEAP32[i2 >> 2] | 0;
   if (!i5) {
    i1 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i1, i7) | 0;
    i1 = i2 >>> 0 > (HEAP32[i1 >> 2] | 0) >>> 0;
    break;
   }
   if (!i2) {
    i1 = (HEAP32[i6 >> 2] | 0) >>> 0 < (HEAP32[i7 >> 2] | 0) >>> 0;
    break;
   } else {
    i1 = i8 + 56 | 0;
    i8 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i1, i6) | 0;
    i8 = HEAP32[i8 >> 2] | 0;
    i1 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i1, i7) | 0;
    i1 = i8 >>> 0 < (HEAP32[i1 >> 2] | 0) >>> 0;
    break;
   }
  } else i1 = 0;
 } else i1 = 1; while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib(i3, i8, i7, i2, i4) {
 i3 = i3 | 0;
 i8 = i8 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i5 = 0, i6 = 0;
 do if ((i3 | 0) == (HEAP32[i8 + 8 >> 2] | 0)) {
  if ((HEAP32[i8 + 4 >> 2] | 0) == (i7 | 0) ? (i1 = i8 + 28 | 0, (HEAP32[i1 >> 2] | 0) != 1) : 0) HEAP32[i1 >> 2] = i2;
 } else {
  if ((i3 | 0) != (HEAP32[i8 >> 2] | 0)) {
   i6 = HEAP32[i3 + 8 >> 2] | 0;
   FUNCTION_TABLE_viiiii[HEAP32[(HEAP32[i6 >> 2] | 0) + 24 >> 2] & 3](i6, i8, i7, i2, i4);
   break;
  }
  if ((HEAP32[i8 + 16 >> 2] | 0) != (i7 | 0) ? (i6 = i8 + 20 | 0, (HEAP32[i6 >> 2] | 0) != (i7 | 0)) : 0) {
   HEAP32[i8 + 32 >> 2] = i2;
   i5 = i8 + 44 | 0;
   if ((HEAP32[i5 >> 2] | 0) == 4) break;
   i1 = i8 + 52 | 0;
   HEAP8[i1 >> 0] = 0;
   i2 = i8 + 53 | 0;
   HEAP8[i2 >> 0] = 0;
   i3 = HEAP32[i3 + 8 >> 2] | 0;
   FUNCTION_TABLE_viiiiii[HEAP32[(HEAP32[i3 >> 2] | 0) + 20 >> 2] & 15](i3, i8, i7, i7, 1, i4);
   if (HEAP8[i2 >> 0] | 0) if (!(HEAP8[i1 >> 0] | 0)) {
    i1 = 1;
    i2 = 13;
   } else i2 = 17; else {
    i1 = 0;
    i2 = 13;
   }
   do if ((i2 | 0) == 13) {
    HEAP32[i6 >> 2] = i7;
    i7 = i8 + 40 | 0;
    HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 1;
    if ((HEAP32[i8 + 36 >> 2] | 0) == 1 ? (HEAP32[i8 + 24 >> 2] | 0) == 2 : 0) {
     HEAP8[i8 + 54 >> 0] = 1;
     if (i1) {
      i2 = 17;
      break;
     } else {
      i1 = 4;
      break;
     }
    }
    if (i1) i2 = 17; else i1 = 4;
   } while (0);
   if ((i2 | 0) == 17) i1 = 3;
   HEAP32[i5 >> 2] = i1;
   break;
  }
  if ((i2 | 0) == 1) HEAP32[i8 + 32 >> 2] = 1;
 } while (0);
 return;
}

function __ZN4wasm22SExpressionWasmBuilder14stringToBinaryEPKcjRNSt3__26vectorIcNS3_9allocatorIcEEEE(i2, i1, i3, i5) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i4 = 0;
 i4 = i5 + 4 | 0;
 i2 = (HEAP32[i4 >> 2] | 0) - (HEAP32[i5 >> 2] | 0) | 0;
 __ZNSt3__26vectorIcNS_9allocatorIcEEE6resizeEj(i5, i2 + i3 | 0);
 i3 = (HEAP32[i5 >> 2] | 0) + i2 | 0;
 L1 : while (1) {
  i2 = HEAP8[i1 >> 0] | 0;
  L3 : do switch (i2 << 24 >> 24) {
  case 0:
   {
    i1 = i3;
    break L1;
   }
  case 92:
   {
    i2 = HEAP8[i1 + 1 >> 0] | 0;
    switch (i2 << 24 >> 24) {
    case 34:
     {
      HEAP8[i3 >> 0] = 34;
      i1 = i1 + 2 | 0;
      break L3;
     }
    case 39:
     {
      HEAP8[i3 >> 0] = 39;
      i1 = i1 + 2 | 0;
      break L3;
     }
    case 92:
     {
      HEAP8[i3 >> 0] = 92;
      i1 = i1 + 2 | 0;
      break L3;
     }
    case 110:
     {
      HEAP8[i3 >> 0] = 10;
      i1 = i1 + 2 | 0;
      break L3;
     }
    case 116:
     {
      HEAP8[i3 >> 0] = 9;
      i1 = i1 + 2 | 0;
      break L3;
     }
    default:
     {
      i2 = ((__ZN4wasm5unhexEc(i2) | 0) << 4) + (__ZN4wasm5unhexEc(HEAP8[i1 + 2 >> 0] | 0) | 0) & 255;
      HEAP8[i3 >> 0] = i2;
      i1 = i1 + 3 | 0;
      break L3;
     }
    }
   }
  default:
   {
    HEAP8[i3 >> 0] = i2;
    i1 = i1 + 1 | 0;
   }
  } while (0);
  i3 = i3 + 1 | 0;
 }
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i3;
 if (i1 >>> 0 < i3 >>> 0) ___assert_fail(21601, 21446, 1198, 21622);
 i1 = i1 - i2 | 0;
 if (i1 >>> 0 > ((HEAP32[i4 >> 2] | 0) - i2 | 0) >>> 0) ___assert_fail(21637, 21446, 1200, 21622); else {
  __ZNSt3__26vectorIcNS_9allocatorIcEEE6resizeEj(i5, i1);
  return;
 }
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseIndexingES1_RPc(i7, i6, i8) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i9 = 0, i10 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i11 + 12 | 0;
 i1 = i11 + 8 | 0;
 i3 = i11 + 4 | 0;
 i4 = i11;
 i9 = i7 + 4 | 0;
 __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE6resizeEj(i7, (((HEAP32[i9 >> 2] | 0) - (HEAP32[i7 >> 2] | 0) | 0) / 12 | 0) + 1 | 0);
 i5 = HEAP32[i8 >> 2] | 0;
 if ((HEAP8[i5 >> 0] | 0) != 91) ___assert_fail(31886, 31173, 637, 31898);
 HEAP32[i8 >> 2] = i5 + 1;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 i7 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i7, i8, 56962) | 0;
 HEAP32[i4 >> 2] = i7;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
 i3 = __ZN6cashew12ValueBuilder12makeIndexingENS_3RefES1_(i1, i2) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i8);
 i1 = HEAP32[i8 >> 2] | 0;
 if ((HEAP8[i1 >> 0] | 0) != 93) ___assert_fail(31912, 31173, 641, 31898);
 HEAP32[i8 >> 2] = i1 + 1;
 i1 = HEAP32[i9 >> 2] | 0;
 i2 = i1 + -12 | 0;
 if ((HEAP32[i1 + -8 >> 2] | 0) == (HEAP32[i2 >> 2] | 0)) i10 = i1; else ___assert_fail(31817, 31173, 643, 31898);
 while (1) {
  if ((i10 | 0) == (i2 | 0)) break;
  i8 = i10 + -12 | 0;
  HEAP32[i9 >> 2] = i8;
  __ZNSt3__213__vector_baseIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEED2Ev(i8);
  i10 = HEAP32[i9 >> 2] | 0;
 }
 STACKTOP = i11;
 return i3 | 0;
}

function _wcsnrtombs(i3, i11, i4, i2, i1) {
 i3 = i3 | 0;
 i11 = i11 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0, i13 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 272 | 0;
 i7 = i10 + 8 | 0;
 i9 = i10;
 i6 = HEAP32[i11 >> 2] | 0;
 HEAP32[i9 >> 2] = i6;
 i8 = (i3 | 0) != 0;
 i1 = i8 ? i2 : 256;
 i2 = i8 ? i3 : i7;
 i3 = i6;
 L1 : do if ((i1 | 0) != 0 & (i6 | 0) != 0) {
  i6 = i1;
  i5 = i3;
  i1 = 0;
  while (1) {
   i3 = i4 >>> 0 >= i6 >>> 0;
   if (!(i3 | i4 >>> 0 > 32)) {
    i3 = i5;
    break L1;
   }
   i3 = i3 ? i6 : i4;
   i4 = i4 - i3 | 0;
   i3 = _wcsrtombs(i2, i9, i3, 0) | 0;
   if ((i3 | 0) == -1) {
    i1 = i4;
    break;
   }
   i13 = (i2 | 0) == (i7 | 0);
   i12 = i13 ? 0 : i3;
   i5 = i6 - i12 | 0;
   i2 = i13 ? i2 : i2 + i3 | 0;
   i1 = i3 + i1 | 0;
   i3 = HEAP32[i9 >> 2] | 0;
   if ((i6 | 0) != (i12 | 0) & (i3 | 0) != 0) {
    i6 = i5;
    i5 = i3;
   } else {
    i6 = i5;
    break L1;
   }
  }
  i4 = i1;
  i6 = 0;
  i3 = HEAP32[i9 >> 2] | 0;
  i1 = -1;
 } else {
  i6 = i1;
  i1 = 0;
 } while (0);
 L8 : do if ((i3 | 0) != 0 ? (i6 | 0) != 0 & (i4 | 0) != 0 : 0) {
  i5 = i3;
  i3 = i2;
  while (1) {
   i2 = _wcrtomb(i3, HEAP32[i5 >> 2] | 0, 0) | 0;
   if ((i2 + 1 | 0) >>> 0 < 2) break;
   i5 = (HEAP32[i9 >> 2] | 0) + 4 | 0;
   HEAP32[i9 >> 2] = i5;
   i4 = i4 + -1 | 0;
   i1 = i1 + 1 | 0;
   if (!((i6 | 0) != (i2 | 0) & (i4 | 0) != 0)) break L8; else {
    i6 = i6 - i2 | 0;
    i3 = i3 + i2 | 0;
   }
  }
  if (!i2) HEAP32[i9 >> 2] = 0; else i1 = -1;
 } while (0);
 if (i8) HEAP32[i11 >> 2] = HEAP32[i9 >> 2];
 STACKTOP = i10;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE12__find_equalIS7_EERPNS_16__tree_node_baseIPvEESN_RKT_(i1, i8, i3) {
 i1 = i1 | 0;
 i8 = i8 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i7 = HEAP8[i3 + 11 >> 0] | 0;
  i6 = i7 << 24 >> 24 < 0;
  i7 = i6 ? HEAP32[i3 + 4 >> 2] | 0 : i7 & 255;
  i6 = i6 ? HEAP32[i3 >> 2] | 0 : i3;
  while (1) {
   i3 = i2 + 16 | 0;
   i1 = HEAP8[i3 + 11 >> 0] | 0;
   i4 = i1 << 24 >> 24 < 0;
   i1 = i4 ? HEAP32[i2 + 20 >> 2] | 0 : i1 & 255;
   i3 = i4 ? HEAP32[i3 >> 2] | 0 : i3;
   i4 = i1 >>> 0 < i7 >>> 0;
   i9 = __ZNSt3__211char_traitsIcE7compareEPKcS3_j(i6, i3, i4 ? i1 : i7) | 0;
   i5 = i7 >>> 0 < i1 >>> 0;
   if ((((i9 | 0) == 0 ? (i5 ? -2147483648 : 0) : i9) | 0) < 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    i9 = __ZNSt3__211char_traitsIcE7compareEPKcS3_j(i3, i6, i5 ? i7 : i1) | 0;
    if ((((i9 | 0) == 0 ? (i4 ? -2147483648 : 0) : i9) | 0) >= 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i8 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i8 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i8 >> 2] = i1;
   i1 = i8;
   break;
  }
 } else HEAP32[i8 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder18parseModuleElementERNS_7ElementE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5;
 i2 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i3, 0) | 0) | 0;
 do if ((i2 | 0) != (HEAP32[14973] | 0)) {
  if ((i2 | 0) == (HEAP32[14974] | 0)) {
   __ZN4wasm22SExpressionWasmBuilder13parseFunctionERNS_7ElementE(i4, i3);
   break;
  }
  if ((i2 | 0) == (HEAP32[14977] | 0)) {
   __ZN4wasm22SExpressionWasmBuilder11parseMemoryERNS_7ElementE(i4, i3);
   break;
  }
  if ((i2 | 0) == (HEAP32[14979] | 0)) {
   __ZN4wasm22SExpressionWasmBuilder11parseExportERNS_7ElementE(i4, i3);
   break;
  }
  if ((i2 | 0) != (HEAP32[14980] | 0)) {
   if ((i2 | 0) == (HEAP32[14981] | 0)) {
    __ZN4wasm22SExpressionWasmBuilder10parseTableERNS_7ElementE(i4, i3);
    break;
   }
   if ((i2 | 0) != (HEAP32[14983] | 0)) {
    __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 21858) | 0, i2) | 0, 10) | 0;
    i5 = ___cxa_allocate_exception(20) | 0;
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 21878, 22);
    __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i5, i1);
    ___cxa_throw(i5 | 0, 64, 279);
   }
  }
 } else __ZN4wasm22SExpressionWasmBuilder10parseStartERNS_7ElementE(i4, i3); while (0);
 STACKTOP = i5;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSL_IJEEEEEENS_4pairINS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESM_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSL_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISA_PvEENS_22__tree_node_destructorINS7_IST_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSK_SK_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZN4wasm19DeadCodeElimination11visitSelectEPNS_6SelectE(i5, i3) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i6 = 0, i7 = 0;
 i4 = i3 + 8 | 0;
 i6 = HEAP32[i4 >> 2] | 0;
 i1 = i6;
 if ((i6 | 0) != 0 ? (HEAP32[i6 >> 2] | 0) == 20 : 0) HEAP32[i5 + 20 >> 2] = i1; else i2 = 4;
 do if ((i2 | 0) == 4) {
  i2 = i3 + 12 | 0;
  i6 = HEAP32[i2 >> 2] | 0;
  if (i6 | 0 ? (HEAP32[i6 >> 2] | 0) == 20 : 0) {
   i6 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v((HEAP32[i5 + 40 >> 2] | 0) + 88 | 0) | 0;
   i1 = i6 + 12 | 0;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i1, 2);
   i4 = HEAP32[i4 >> 2] | 0;
   i3 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, 0) | 0;
   HEAP32[i3 >> 2] = i4;
   i3 = HEAP32[i2 >> 2] | 0;
   i4 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, 1) | 0;
   HEAP32[i4 >> 2] = i3;
   __ZN4wasm5Block8finalizeEv(i6);
   HEAP32[i5 + 20 >> 2] = i6;
   break;
  }
  i1 = i3 + 16 | 0;
  i6 = HEAP32[i1 >> 2] | 0;
  if (i6 | 0 ? (HEAP32[i6 >> 2] | 0) == 20 : 0) {
   i6 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v((HEAP32[i5 + 40 >> 2] | 0) + 88 | 0) | 0;
   i7 = i6 + 12 | 0;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i7, 3);
   i3 = HEAP32[i4 >> 2] | 0;
   i4 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 0) | 0;
   HEAP32[i4 >> 2] = i3;
   i4 = HEAP32[i2 >> 2] | 0;
   i3 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 1) | 0;
   HEAP32[i3 >> 2] = i4;
   i3 = HEAP32[i1 >> 2] | 0;
   i4 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 2) | 0;
   HEAP32[i4 >> 2] = i3;
   __ZN4wasm5Block8finalizeEv(i6);
   HEAP32[i5 + 20 >> 2] = i6;
  }
 } while (0);
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 5768;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 5168;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i11, i8, i10, i2, i3, i7) {
 i11 = i11 | 0;
 i8 = i8 | 0;
 i10 = i10 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i7 = i7 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i12 = 0, i13 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i9 = i12;
 i1 = HEAP32[i11 >> 2] | 0;
 L1 : do if (!i1) i1 = 0; else {
  i13 = i8;
  i5 = i2 - i13 | 0;
  i6 = i3 + 12 | 0;
  i4 = HEAP32[i6 >> 2] | 0;
  i5 = (i4 | 0) > (i5 | 0) ? i4 - i5 | 0 : 0;
  i4 = i10;
  i3 = i4 - i13 | 0;
  if ((i3 | 0) > 0 ? (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 48 >> 2] & 31](i1, i8, i3) | 0) != (i3 | 0) : 0) {
   HEAP32[i11 >> 2] = 0;
   i1 = 0;
   break;
  }
  do if ((i5 | 0) > 0) {
   HEAP32[i9 >> 2] = 0;
   HEAP32[i9 + 4 >> 2] = 0;
   HEAP32[i9 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEjc(i9, i5, i7);
   if ((FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 48 >> 2] & 31](i1, (HEAP8[i9 + 11 >> 0] | 0) < 0 ? HEAP32[i9 >> 2] | 0 : i9, i5) | 0) == (i5 | 0)) {
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i9);
    break;
   } else {
    HEAP32[i11 >> 2] = 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i9);
    i1 = 0;
    break L1;
   }
  } while (0);
  i2 = i2 - i4 | 0;
  if ((i2 | 0) > 0 ? (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 48 >> 2] & 31](i1, i10, i2) | 0) != (i2 | 0) : 0) {
   HEAP32[i11 >> 2] = 0;
   i1 = 0;
   break;
  }
  HEAP32[i6 >> 2] = 0;
 } while (0);
 STACKTOP = i12;
 return i1 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE7parseIfERPcPKc(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0, i17 = 0;
 i17 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i11 = i17;
 i10 = i17 + 32 | 0;
 i9 = i17 + 28 | 0;
 i12 = i17 + 24 | 0;
 i13 = i17 + 20 | 0;
 i14 = i17 + 16 | 0;
 i15 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseParennedERPc(i7, i6) | 0;
 i16 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseMaybeBracketedERPcPKc(i7, i6, i5) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i6);
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP8[i2 >> 0] | 0;
 i1 = i5;
 while (1) {
  i4 = HEAP8[i1 >> 0] | 0;
  if (!(i4 << 24 >> 24)) {
   i8 = 4;
   break;
  }
  if (i4 << 24 >> 24 == i3 << 24 >> 24) {
   i1 = 0;
   break;
  } else i1 = i1 + 1 | 0;
 }
 if ((i8 | 0) == 4) {
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i11, i2);
  if ((HEAP32[i11 + 12 >> 2] | 0) == 0 ? (HEAP32[i11 >> 2] | 0) == (HEAP32[14830] | 0) : 0) {
   HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + (HEAP32[i11 + 8 >> 2] | 0);
   i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseMaybeBracketedERPcPKc(i7, i6, i5) | 0;
  } else i1 = 0;
 }
 HEAP32[i12 >> 2] = i15;
 HEAP32[i13 >> 2] = i16;
 HEAP32[i14 >> 2] = i1;
 HEAP32[i9 >> 2] = HEAP32[i12 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i13 >> 2];
 HEAP32[i11 >> 2] = HEAP32[i14 >> 2];
 i16 = __ZN6cashew12ValueBuilder6makeIfENS_3RefES1_S1_(i9, i10, i11) | 0;
 STACKTOP = i17;
 return i16 | 0;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 6312;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 7476;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 5948;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm17WasmBinaryBuilder8getInt16Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i4;
 i3 = i1 + 12 | 0;
 if (HEAP8[i3 >> 0] | 0) {
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23002) | 0;
  i6 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i2 >> 2] = i6;
  i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
  i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
  __ZNSt3__26localeD2Ev(i2);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i6) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
 }
 i6 = (__ZN4wasm17WasmBinaryBuilder7getInt8Ev(i1) | 0) & 255;
 i1 = ((__ZN4wasm17WasmBinaryBuilder7getInt8Ev(i1) | 0) & 255) << 8 | i6;
 if (HEAP8[i3 >> 0] | 0) {
  i6 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23022) | 0, i1) | 0, 23017) | 0;
  i5 = __ZNKSt3__28ios_base6getlocEv(i6 + (HEAP32[(HEAP32[i6 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i2 >> 2] = i5;
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
  i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
  __ZNSt3__26localeD2Ev(i2);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i6, i5) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i6) | 0;
 }
 STACKTOP = i4;
 return i1 & 65535 | 0;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 6672;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 6492;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm6WalkerINS_14FunctionHasherENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 7408;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 7600;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm17WasmBinaryBuilder8getInt32Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i4;
 i3 = i1 + 12 | 0;
 if (HEAP8[i3 >> 0] | 0) {
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23002) | 0;
  i6 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i2 >> 2] = i6;
  i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
  i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
  __ZNSt3__26localeD2Ev(i2);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i6) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
 }
 i6 = (__ZN4wasm17WasmBinaryBuilder8getInt16Ev(i1) | 0) & 65535;
 i1 = ((__ZN4wasm17WasmBinaryBuilder8getInt16Ev(i1) | 0) & 65535) << 16 | i6;
 if (HEAP8[i3 >> 0] | 0) {
  i6 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23006) | 0, i1) | 0, 23017) | 0;
  i5 = __ZNKSt3__28ios_base6getlocEv(i6 + (HEAP32[(HEAP32[i6 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i2 >> 2] = i5;
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
  i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
  __ZNSt3__26localeD2Ev(i2);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i6, i5) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i6) | 0;
 }
 STACKTOP = i4;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 7036;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 5348;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm(i5, i3, i2, i1, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 128 | 0;
 i8 = i6;
 i12 = i6 + 116 | 0;
 i14 = i6 + 104 | 0;
 i7 = i6 + 20 | 0;
 i10 = i6 + 16 | 0;
 i5 = i6 + 8 | 0;
 i11 = i6 + 12 | 0;
 i9 = i6 + 4 | 0;
 HEAP8[i12 >> 0] = HEAP8[53489] | 0;
 HEAP8[i12 + 1 >> 0] = HEAP8[53490] | 0;
 HEAP8[i12 + 2 >> 0] = HEAP8[53491] | 0;
 HEAP8[i12 + 3 >> 0] = HEAP8[53492] | 0;
 HEAP8[i12 + 4 >> 0] = HEAP8[53493] | 0;
 HEAP8[i12 + 5 >> 0] = HEAP8[53494] | 0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj(i12 + 1 | 0, 56981, 0, HEAP32[i2 + 4 >> 2] | 0);
 i13 = __ZNSt3__26__clocEv() | 0;
 HEAP32[i8 >> 2] = i4;
 i12 = i14 + (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i14, 12, i13, i12, i8) | 0) | 0;
 i13 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i14, i12, i2) | 0;
 i4 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i11 >> 2] = i4;
 __ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE(i14, i13, i12, i7, i10, i5, i11);
 __ZNSt3__214__shared_count16__release_sharedEv(i4) | 0;
 HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
 i4 = HEAP32[i10 >> 2] | 0;
 i5 = HEAP32[i5 >> 2] | 0;
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 i5 = __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i8, i7, i4, i5, i2, i1) | 0;
 STACKTOP = i6;
 return i5 | 0;
}

function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl(i5, i3, i2, i1, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 144 | 0;
 i8 = i6;
 i12 = i6 + 126 | 0;
 i14 = i6 + 112 | 0;
 i7 = i6 + 20 | 0;
 i10 = i6 + 16 | 0;
 i5 = i6 + 8 | 0;
 i11 = i6 + 12 | 0;
 i9 = i6 + 4 | 0;
 HEAP8[i12 >> 0] = HEAP8[53489] | 0;
 HEAP8[i12 + 1 >> 0] = HEAP8[53490] | 0;
 HEAP8[i12 + 2 >> 0] = HEAP8[53491] | 0;
 HEAP8[i12 + 3 >> 0] = HEAP8[53492] | 0;
 HEAP8[i12 + 4 >> 0] = HEAP8[53493] | 0;
 HEAP8[i12 + 5 >> 0] = HEAP8[53494] | 0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj(i12 + 1 | 0, 56981, 1, HEAP32[i2 + 4 >> 2] | 0);
 i13 = __ZNSt3__26__clocEv() | 0;
 HEAP32[i8 >> 2] = i4;
 i12 = i14 + (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i14, 13, i13, i12, i8) | 0) | 0;
 i13 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i14, i12, i2) | 0;
 i4 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i11 >> 2] = i4;
 __ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE(i14, i13, i12, i7, i10, i5, i11);
 __ZNSt3__214__shared_count16__release_sharedEv(i4) | 0;
 HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
 i4 = HEAP32[i10 >> 2] | 0;
 i5 = HEAP32[i5 >> 2] | 0;
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 i5 = __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i8, i7, i4, i5, i2, i1) | 0;
 STACKTOP = i6;
 return i5 | 0;
}

function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm(i5, i3, i2, i1, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i8 = i6;
 i12 = i6 + 56 | 0;
 i14 = i6 + 44 | 0;
 i7 = i6 + 20 | 0;
 i10 = i6 + 16 | 0;
 i5 = i6 + 8 | 0;
 i11 = i6 + 12 | 0;
 i9 = i6 + 4 | 0;
 HEAP8[i12 >> 0] = HEAP8[53489] | 0;
 HEAP8[i12 + 1 >> 0] = HEAP8[53490] | 0;
 HEAP8[i12 + 2 >> 0] = HEAP8[53491] | 0;
 HEAP8[i12 + 3 >> 0] = HEAP8[53492] | 0;
 HEAP8[i12 + 4 >> 0] = HEAP8[53493] | 0;
 HEAP8[i12 + 5 >> 0] = HEAP8[53494] | 0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj(i12 + 1 | 0, 56981, 0, HEAP32[i2 + 4 >> 2] | 0);
 i13 = __ZNSt3__26__clocEv() | 0;
 HEAP32[i8 >> 2] = i4;
 i12 = i14 + (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i14, 12, i13, i12, i8) | 0) | 0;
 i13 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i14, i12, i2) | 0;
 i4 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i11 >> 2] = i4;
 __ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE(i14, i13, i12, i7, i10, i5, i11);
 __ZNSt3__214__shared_count16__release_sharedEv(i4) | 0;
 HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
 i4 = HEAP32[i10 >> 2] | 0;
 i5 = HEAP32[i5 >> 2] | 0;
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 i5 = __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i8, i7, i4, i5, i2, i1) | 0;
 STACKTOP = i6;
 return i5 | 0;
}

function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl(i5, i3, i2, i1, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i8 = i6;
 i12 = i6 + 56 | 0;
 i14 = i6 + 43 | 0;
 i7 = i6 + 20 | 0;
 i10 = i6 + 16 | 0;
 i5 = i6 + 8 | 0;
 i11 = i6 + 12 | 0;
 i9 = i6 + 4 | 0;
 HEAP8[i12 >> 0] = HEAP8[53489] | 0;
 HEAP8[i12 + 1 >> 0] = HEAP8[53490] | 0;
 HEAP8[i12 + 2 >> 0] = HEAP8[53491] | 0;
 HEAP8[i12 + 3 >> 0] = HEAP8[53492] | 0;
 HEAP8[i12 + 4 >> 0] = HEAP8[53493] | 0;
 HEAP8[i12 + 5 >> 0] = HEAP8[53494] | 0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj(i12 + 1 | 0, 56981, 1, HEAP32[i2 + 4 >> 2] | 0);
 i13 = __ZNSt3__26__clocEv() | 0;
 HEAP32[i8 >> 2] = i4;
 i12 = i14 + (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i14, 13, i13, i12, i8) | 0) | 0;
 i13 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i14, i12, i2) | 0;
 i4 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i11 >> 2] = i4;
 __ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE(i14, i13, i12, i7, i10, i5, i11);
 __ZNSt3__214__shared_count16__release_sharedEv(i4) | 0;
 HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
 i4 = HEAP32[i10 >> 2] | 0;
 i5 = HEAP32[i5 >> 2] | 0;
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 i5 = __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i8, i7, i4, i5, i2, i1) | 0;
 STACKTOP = i6;
 return i5 | 0;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i9 = i13 + 28 | 0;
 i11 = i13 + 32 | 0;
 i12 = i13 + 24 | 0;
 i10 = i13;
 HEAP32[i9 >> 2] = i1;
 i6 = __ZN4wasm10ThreadPool4sizeEv(__ZN4wasm10ThreadPool3getEv() | 0) | 0;
 HEAP32[i11 >> 2] = 0;
 i7 = i11 + 4 | 0;
 HEAP32[i7 >> 2] = 0;
 HEAP32[i11 + 8 >> 2] = 0;
 HEAP32[i12 >> 2] = 0;
 i1 = HEAP32[i9 >> 2] | 0;
 i1 = (HEAP32[i1 + 40 >> 2] | 0) - (HEAP32[i1 + 36 >> 2] | 0) >> 2;
 i3 = i10 + 16 | 0;
 i4 = i11 + 8 | 0;
 i8 = 0;
 while (1) {
  if (i8 >>> 0 >= i6 >>> 0) break;
  i5 = __Znwj(20) | 0;
  HEAP32[i5 >> 2] = 7240;
  HEAP32[i5 + 4 >> 2] = i12;
  HEAP32[i5 + 8 >> 2] = i1;
  HEAP32[i5 + 12 >> 2] = i9;
  HEAP32[i5 + 16 >> 2] = i2;
  HEAP32[i3 >> 2] = i5;
  i5 = HEAP32[i7 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i4 >> 2] | 0) >>> 0) {
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i5, i10);
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 24;
  } else __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i11, i10);
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i10);
  i8 = i8 + 1 | 0;
 }
 __ZN4wasm10ThreadPool4workERNSt3__26vectorINS1_8functionIFNS_15ThreadWorkStateEvEEENS1_9allocatorIS6_EEEE(__ZN4wasm10ThreadPool3getEv() | 0, i11);
 __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i11);
 STACKTOP = i13;
 return;
}

function __ZN4wasm17WasmBinaryBuilder8getInt64Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5;
 i3 = i1 + 12 | 0;
 if (HEAP8[i3 >> 0] | 0) {
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23002) | 0;
  i6 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i2 >> 2] = i6;
  i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
  i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
  __ZNSt3__26localeD2Ev(i2);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i6) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
 }
 i4 = __ZN4wasm17WasmBinaryBuilder8getInt32Ev(i1) | 0;
 i1 = __ZN4wasm17WasmBinaryBuilder8getInt32Ev(i1) | 0;
 if (HEAP8[i3 >> 0] | 0) {
  i6 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25123) | 0, i4, i1) | 0, 23017) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i6 + (HEAP32[(HEAP32[i6 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i2 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i2);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i6, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i6) | 0;
 }
 tempRet0 = i1;
 STACKTOP = i5;
 return i4 | 0;
}

function __ZN4wasm17WasmBinaryBuilder17visitCallIndirectEPNS_12CallIndirectE(i7, i8) {
 i7 = i7 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i10 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i9;
 if (HEAP8[i7 + 12 >> 0] | 0) {
  i6 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24420) | 0;
  i5 = __ZNKSt3__28ios_base6getlocEv(i6 + (HEAP32[(HEAP32[i6 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i5;
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i6, i5) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i6) | 0;
 }
 i2 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i7) | 0;
 i5 = HEAP32[i7 >> 2] | 0;
 i5 = __ZN4wasm6Module15getFunctionTypeEj(i5, __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i7) | 0) | 0;
 i6 = i8 + 24 | 0;
 HEAP32[i6 >> 2] = i5;
 if (((HEAP32[i5 + 12 >> 2] | 0) - (HEAP32[i5 + 8 >> 2] | 0) >> 2 | 0) != (i2 | 0)) ___assert_fail(24313, 22948, 1837, 24442);
 i3 = i8 + 8 | 0;
 __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i3, i2);
 i4 = i2 + -1 | 0;
 i5 = 0;
 while (1) {
  i1 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i7) | 0;
  if ((i5 | 0) == (i2 | 0)) break;
  i10 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, i4 - i5 | 0) | 0;
  HEAP32[i10 >> 2] = i1;
  i5 = i5 + 1 | 0;
 }
 HEAP32[i8 + 28 >> 2] = i1;
 HEAP32[i8 + 4 >> 2] = HEAP32[(HEAP32[i6 >> 2] | 0) + 4 >> 2];
 STACKTOP = i9;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS7_EEEEEENS_19__map_value_compareIS3_SB_NS_4lessIS3_EELb1EEENS8_ISB_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSM_IJEEEEEENS_4pairINS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS7_EEEEEENS_19__map_value_compareIS3_SB_NS_4lessIS3_EELb1EEENS8_ISB_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESN_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS7_EEEEEENS_19__map_value_compareIS3_SB_NS_4lessIS3_EELb1EEENS8_ISB_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSM_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISB_PvEENS_22__tree_node_destructorINS8_ISU_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS7_EEEEEENS_19__map_value_compareIS3_SB_NS_4lessIS3_EELb1EEENS8_ISB_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSL_SL_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseAfterBraceERPc(i6, i8) {
 i6 = i6 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i9 + 12 | 0;
 i2 = i9 + 8 | 0;
 i4 = i9 + 4 | 0;
 i5 = i9;
 __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE6resizeEj(i6, (((HEAP32[i6 + 4 >> 2] | 0) - (HEAP32[i6 >> 2] | 0) | 0) / 12 | 0) + 1 | 0);
 i7 = __ZN6cashew12ValueBuilder9makeArrayEv() | 0;
 L1 : while (1) {
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i8);
  i1 = HEAP32[i8 >> 2] | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 0:
   {
    i2 = 3;
    break L1;
   }
  case 93:
   {
    i2 = 7;
    break L1;
   }
  default:
   {}
  }
  i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i6, i8, 32150) | 0;
  HEAP32[i4 >> 2] = i7;
  HEAP32[i5 >> 2] = i1;
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
  __ZN6cashew12ValueBuilder13appendToArrayENS_3RefES1_(i2, i3);
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i8);
  i1 = HEAP32[i8 >> 2] | 0;
  switch (HEAP8[i1 >> 0] | 0) {
  case 93:
   {
    i2 = 7;
    break L1;
   }
  case 44:
   break;
  default:
   {
    i2 = 6;
    break L1;
   }
  }
  HEAP32[i8 >> 2] = i1 + 1;
 }
 if ((i2 | 0) == 3) ___assert_fail(32129, 31173, 674, 32134); else if ((i2 | 0) == 6) _abort(); else if ((i2 | 0) == 7) {
  HEAP32[i8 >> 2] = i1 + 1;
  STACKTOP = i9;
  return i7 | 0;
 }
 return 0;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj(i9, i1) {
 i9 = i9 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 if (i1 >>> 0 > 1073741807) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i9);
 i7 = i9 + 8 | 0;
 i6 = i7 + 3 | 0;
 i3 = HEAP8[i6 >> 0] | 0;
 i4 = i3 << 24 >> 24 < 0;
 if (i4) {
  i8 = HEAP32[i9 + 4 >> 2] | 0;
  i2 = (HEAP32[i7 >> 2] & 2147483647) + -1 | 0;
 } else {
  i8 = i3 & 255;
  i2 = 1;
 }
 i1 = i8 >>> 0 > i1 >>> 0 ? i8 : i1;
 if (i1 >>> 0 < 2) i5 = 1; else i5 = (i1 + 4 & -4) + -1 | 0;
 do if ((i5 | 0) != (i2 | 0)) {
  do if ((i5 | 0) == 1) {
   i2 = HEAP32[i9 >> 2] | 0;
   if (i4) {
    i1 = i9;
    i3 = 0;
    i4 = 17;
   } else {
    __ZNSt3__211char_traitsIwE4copyEPwPKwj(i9, i2, (i3 & 255) + 1 | 0) | 0;
    __ZdlPv(i2);
    i4 = 19;
   }
  } else {
   i1 = i5 + 1 | 0;
   if (i1 >>> 0 > 1073741823) ___assert_fail(55771, 55808, 1734, 55911);
   i1 = __Znwj(i1 << 2) | 0;
   if (i4) {
    i3 = 1;
    i2 = HEAP32[i9 >> 2] | 0;
    i4 = 17;
    break;
   } else {
    __ZNSt3__211char_traitsIwE4copyEPwPKwj(i1, i9, (i3 & 255) + 1 | 0) | 0;
    i4 = 18;
    break;
   }
  } while (0);
  if ((i4 | 0) == 17) {
   __ZNSt3__211char_traitsIwE4copyEPwPKwj(i1, i2, (HEAP32[i9 + 4 >> 2] | 0) + 1 | 0) | 0;
   __ZdlPv(i2);
   if (i3) i4 = 18; else i4 = 19;
  }
  if ((i4 | 0) == 18) {
   HEAP32[i7 >> 2] = i5 + 1 | -2147483648;
   HEAP32[i9 + 4 >> 2] = i8;
   HEAP32[i9 >> 2] = i1;
   break;
  } else if ((i4 | 0) == 19) {
   HEAP8[i6 >> 0] = i8;
   break;
  }
 } while (0);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS7_PvEENS_22__tree_node_destructorINSC_ISR_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZN4wasm16PrintSExpression10visitBreakEPNS_5BreakE(i8, i5) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i9 + 8 | 0;
 i2 = i9 + 4 | 0;
 i3 = i9;
 i7 = i5 + 16 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 do if (!(HEAP32[i7 >> 2] | 0)) {
  i4 = __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(i4, 34695, 0) | 0;
  HEAP32[i3 >> 2] = HEAP32[i5 + 8 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i4, i1) | 0;
  i1 = i5 + 12 | 0;
  i5 = HEAP32[i1 >> 2] | 0;
  if (i5 | 0 ? (HEAP32[i5 >> 2] | 0) != 19 : 0) {
   __ZN4wasm16PrintSExpression9incIndentEv(i8);
   i6 = 7;
   break;
  }
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i8 >> 2] | 0, 56966) | 0;
 } else {
  i6 = __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(i4, 34688, 0) | 0;
  HEAP32[i2 >> 2] = HEAP32[i5 + 8 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i6, i1) | 0;
  __ZN4wasm16PrintSExpression9incIndentEv(i8);
  i1 = i5 + 12 | 0;
  i6 = 7;
 } while (0);
 if ((i6 | 0) == 7) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (i1 | 0 ? (HEAP32[i1 >> 2] | 0) != 19 : 0) __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i8, i1);
  i1 = HEAP32[i7 >> 2] | 0;
  if (i1 | 0) __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i8, i1);
  __ZN4wasm16PrintSExpression9decIndentEv(i8);
 }
 STACKTOP = i9;
 return;
}
function __ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib(i1, i13, i12, i11, i14, i15) {
 i1 = i1 | 0;
 i13 = i13 | 0;
 i12 = i12 | 0;
 i11 = i11 | 0;
 i14 = i14 | 0;
 i15 = i15 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 if ((i1 | 0) == (HEAP32[i13 + 8 >> 2] | 0)) __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0, i13, i12, i11, i14); else {
  i7 = i13 + 52 | 0;
  i10 = HEAP16[i7 >> 1] | 0;
  i8 = i10 & 255;
  i9 = i13 + 53 | 0;
  i10 = (i10 & 65535) >>> 8 & 255;
  i6 = HEAP32[i1 + 12 >> 2] | 0;
  i3 = i1 + 16 + (i6 << 3) | 0;
  HEAP8[i7 >> 0] = 0;
  HEAP8[i9 >> 0] = 0;
  __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib(i1 + 16 | 0, i13, i12, i11, i14, i15);
  L4 : do if ((i6 | 0) > 1) {
   i4 = i13 + 24 | 0;
   i5 = i1 + 8 | 0;
   i6 = i13 + 54 | 0;
   i2 = i1 + 24 | 0;
   do {
    if (HEAP8[i6 >> 0] | 0) break L4;
    i1 = HEAP16[i7 >> 1] | 0;
    if (!((i1 & 255) << 24 >> 24)) {
     if ((i1 & 65535) >= 256 ? (HEAP32[i5 >> 2] & 1 | 0) == 0 : 0) break L4;
    } else {
     if ((HEAP32[i4 >> 2] | 0) == 1) break L4;
     if (!(HEAP32[i5 >> 2] & 2)) break L4;
    }
    HEAP8[i7 >> 0] = 0;
    HEAP8[i9 >> 0] = 0;
    __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib(i2, i13, i12, i11, i14, i15);
    i2 = i2 + 8 | 0;
   } while (i2 >>> 0 < i3 >>> 0);
  } while (0);
  HEAP8[i7 >> 0] = i8;
  HEAP8[i9 >> 0] = i10;
 }
 return;
}

function ___dynamic_cast(i2, i3, i12, i1) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 i12 = i12 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i13 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i13 = i14;
 i11 = HEAP32[i2 >> 2] | 0;
 i10 = i2 + (HEAP32[i11 + -8 >> 2] | 0) | 0;
 i11 = HEAP32[i11 + -4 >> 2] | 0;
 HEAP32[i13 >> 2] = i12;
 HEAP32[i13 + 4 >> 2] = i2;
 HEAP32[i13 + 8 >> 2] = i3;
 HEAP32[i13 + 12 >> 2] = i1;
 i7 = i13 + 16 | 0;
 i1 = i13 + 20 | 0;
 i2 = i13 + 24 | 0;
 i3 = i13 + 28 | 0;
 i4 = i13 + 32 | 0;
 i5 = i13 + 40 | 0;
 i6 = (i11 | 0) == (i12 | 0);
 i8 = i7;
 i9 = i8 + 36 | 0;
 do {
  HEAP32[i8 >> 2] = 0;
  i8 = i8 + 4 | 0;
 } while ((i8 | 0) < (i9 | 0));
 HEAP16[i7 + 36 >> 1] = 0;
 HEAP8[i7 + 38 >> 0] = 0;
 L1 : do if (i6) {
  HEAP32[i13 + 48 >> 2] = 1;
  FUNCTION_TABLE_viiiiii[HEAP32[(HEAP32[i12 >> 2] | 0) + 20 >> 2] & 15](i12, i13, i10, i10, 1, 0);
  i1 = (HEAP32[i2 >> 2] | 0) == 1 ? i10 : 0;
 } else {
  FUNCTION_TABLE_viiiii[HEAP32[(HEAP32[i11 >> 2] | 0) + 24 >> 2] & 3](i11, i13, i10, 1, 0);
  switch (HEAP32[i13 + 36 >> 2] | 0) {
  case 0:
   {
    i1 = (HEAP32[i5 >> 2] | 0) == 1 & (HEAP32[i3 >> 2] | 0) == 1 & (HEAP32[i4 >> 2] | 0) == 1 ? HEAP32[i1 >> 2] | 0 : 0;
    break L1;
   }
  case 1:
   break;
  default:
   {
    i1 = 0;
    break L1;
   }
  }
  if ((HEAP32[i2 >> 2] | 0) != 1 ? !((HEAP32[i5 >> 2] | 0) == 0 & (HEAP32[i3 >> 2] | 0) == 1 & (HEAP32[i4 >> 2] | 0) == 1) : 0) {
   i1 = 0;
   break;
  }
  i1 = HEAP32[i7 >> 2] | 0;
 } while (0);
 STACKTOP = i14;
 return i1 | 0;
}

function _vfprintf(i15, i11, i1) {
 i15 = i15 | 0;
 i11 = i11 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0, i13 = 0, i14 = 0, i16 = 0;
 i16 = STACKTOP;
 STACKTOP = STACKTOP + 224 | 0;
 i10 = i16 + 120 | 0;
 i14 = i16 + 80 | 0;
 i13 = i16;
 i12 = i16 + 136 | 0;
 i2 = i14;
 i3 = i2 + 40 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 HEAP32[i10 >> 2] = HEAP32[i1 >> 2];
 if ((_printf_core(0, i11, i10, i13, i14) | 0) < 0) i1 = -1; else {
  if ((HEAP32[i15 + 76 >> 2] | 0) > -1) i8 = ___lockfile(i15) | 0; else i8 = 0;
  i1 = HEAP32[i15 >> 2] | 0;
  i9 = i1 & 32;
  if ((HEAP8[i15 + 74 >> 0] | 0) < 1) HEAP32[i15 >> 2] = i1 & -33;
  i1 = i15 + 48 | 0;
  if (!(HEAP32[i1 >> 2] | 0)) {
   i3 = i15 + 44 | 0;
   i4 = HEAP32[i3 >> 2] | 0;
   HEAP32[i3 >> 2] = i12;
   i5 = i15 + 28 | 0;
   HEAP32[i5 >> 2] = i12;
   i6 = i15 + 20 | 0;
   HEAP32[i6 >> 2] = i12;
   HEAP32[i1 >> 2] = 80;
   i7 = i15 + 16 | 0;
   HEAP32[i7 >> 2] = i12 + 80;
   i2 = _printf_core(i15, i11, i10, i13, i14) | 0;
   if (i4) {
    FUNCTION_TABLE_iiii[HEAP32[i15 + 36 >> 2] & 31](i15, 0, 0) | 0;
    i2 = (HEAP32[i6 >> 2] | 0) == 0 ? -1 : i2;
    HEAP32[i3 >> 2] = i4;
    HEAP32[i1 >> 2] = 0;
    HEAP32[i7 >> 2] = 0;
    HEAP32[i5 >> 2] = 0;
    HEAP32[i6 >> 2] = 0;
   }
  } else i2 = _printf_core(i15, i11, i10, i13, i14) | 0;
  i1 = HEAP32[i15 >> 2] | 0;
  HEAP32[i15 >> 2] = i1 | i9;
  if (i8 | 0) ___unlockfile(i15);
  i1 = (i1 & 32 | 0) == 0 ? i2 : -1;
 }
 STACKTOP = i16;
 return i1 | 0;
}

function __ZN4wasm17WasmBinaryBuilder11visitSwitchEPNS_6SwitchE(i7, i8) {
 i7 = i7 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i9 + 4 | 0;
 i6 = i9;
 if (HEAP8[i7 + 12 >> 0] | 0) {
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24271) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i5 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i5);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
 }
 i1 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i7) | 0;
 if ((i1 | 1 | 0) != 1) ___assert_fail(24171, 22948, 1794, 24287);
 i4 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i7) | 0;
 HEAP32[i8 + 28 >> 2] = i4;
 if ((i1 | 0) == 1) {
  i4 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i7) | 0;
  HEAP32[i8 + 32 >> 2] = i4;
 }
 i2 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i7) | 0;
 i3 = i8 + 8 | 0;
 i4 = 0;
 while (1) {
  i1 = __ZN4wasm17WasmBinaryBuilder12getBreakNameEi(i7, __ZN4wasm17WasmBinaryBuilder8getInt32Ev(i7) | 0) | 0;
  if ((i4 | 0) == (i2 | 0)) break;
  HEAP32[i6 >> 2] = i1;
  HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
  __ZN11ArenaVectorIN4wasm4NameEE9push_backES1_(i3, i5);
  i4 = i4 + 1 | 0;
 }
 HEAP32[i8 + 24 >> 2] = i1;
 STACKTOP = i9;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder11parseExportERNS_7ElementE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5;
 i6 = (__ZN4wasm7ElementixEj(i2, 2) | 0) + 24 | 0;
 do if ((HEAP8[i6 >> 0] | 0) == 0 ? (i6 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i2, 2) | 0) | 0, ((HEAP8[i6 >> 0] | 0) + -48 | 0) >>> 0 >= 10) : 0) {
  i6 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i2, 2) | 0) | 0;
  if ((i6 | 0) != (HEAP32[14977] | 0)) ___assert_fail(22835, 21446, 1235, 22857);
  if (!(HEAP8[i3 + 76 >> 0] | 0)) {
   i6 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i1 >> 2] = 0;
   HEAP32[i1 + 4 >> 2] = 0;
   HEAP32[i1 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 22869, 29);
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i6, i1);
   ___cxa_throw(i6 | 0, 64, 279);
  } else {
   i6 = (HEAP32[i3 >> 2] | 0) + 80 | 0;
   i3 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i2, 1) | 0) | 0;
   HEAP32[i6 >> 2] = i3;
   break;
  }
 } else i4 = 8; while (0);
 if ((i4 | 0) == 8) {
  i6 = __ZN4wasm11make_uniqueINS_6ExportEJEEENSt3__210unique_ptrIT_NS2_14default_deleteIS4_EEEEDpOT0_() | 0;
  i4 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i2, 1) | 0) | 0;
  HEAP32[i6 >> 2] = i4;
  i4 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i2, 2) | 0) | 0;
  HEAP32[i6 + 4 >> 2] = i4;
  __ZN4wasm6Module9addExportEPNS_6ExportE(HEAP32[i3 >> 2] | 0, i6);
 }
 STACKTOP = i5;
 return;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner9visitCallEPNS_4CallE(i4, i8, i6) {
 i4 = i4 | 0;
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i1 = i9 + 56 | 0;
 i5 = i9 + 44 | 0;
 i7 = i9 + 16 | 0;
 i2 = i9;
 i3 = i9 + 40 | 0;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP32[i5 + 8 >> 2] = 0;
 __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner17generateArgumentsERK11ArenaVectorIPNS_10ExpressionEES9_(i7, i8, i6 + 8 | 0, i5);
 if (!(HEAP32[i7 + 16 >> 2] | 0)) {
  i8 = HEAP32[i8 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i6 + 24 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  __ZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEE(i2, i8, i1, i5);
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
  HEAP32[i4 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
  HEAP32[i4 + 16 >> 2] = 0;
 } else {
  HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i7 + 8 >> 2];
  HEAP32[i4 + 12 >> 2] = HEAP32[i7 + 12 >> 2];
  HEAP32[i4 + 16 >> 2] = HEAP32[i7 + 16 >> 2];
  HEAP32[i4 + 20 >> 2] = HEAP32[i7 + 20 >> 2];
 }
 __ZNSt3__213__vector_baseIN4wasm7LiteralENS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i9;
 return;
}

function __ZNSt3__211__stdoutbufIwE8overflowEj(i3, i13) {
 i3 = i3 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i11 = i14 + 16 | 0;
 i1 = i14 + 8 | 0;
 i10 = i14 + 4 | 0;
 i9 = i14;
 i12 = (i13 | 0) == -1;
 do if (!i12) {
  HEAP32[i1 >> 2] = i13;
  if (HEAP8[i3 + 44 >> 0] | 0) if ((_fwrite(i1, 4, 1, HEAP32[i3 + 32 >> 2] | 0) | 0) == 1) {
   i2 = 14;
   break;
  } else {
   i1 = -1;
   break;
  }
  HEAP32[i10 >> 2] = i11;
  i7 = i1 + 4 | 0;
  i8 = i3 + 36 | 0;
  i4 = i3 + 40 | 0;
  i5 = i11 + 8 | 0;
  i6 = i11;
  i3 = i3 + 32 | 0;
  while (1) {
   i2 = HEAP32[i8 >> 2] | 0;
   i2 = FUNCTION_TABLE_iiiiiiiii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 15](i2, HEAP32[i4 >> 2] | 0, i1, i7, i9, i11, i5, i10) | 0;
   if ((HEAP32[i9 >> 2] | 0) == (i1 | 0)) {
    i2 = 13;
    break;
   }
   if ((i2 | 0) == 3) {
    i2 = 7;
    break;
   }
   if ((i2 | 1 | 0) != 1) {
    i2 = 13;
    break;
   }
   i1 = (HEAP32[i10 >> 2] | 0) - i6 | 0;
   if ((_fwrite(i11, 1, i1, HEAP32[i3 >> 2] | 0) | 0) != (i1 | 0)) {
    i2 = 13;
    break;
   }
   if ((i2 | 0) == 1) i1 = HEAP32[i9 >> 2] | 0; else {
    i2 = 12;
    break;
   }
  }
  if ((i2 | 0) == 7) if ((_fwrite(i1, 1, 1, HEAP32[i3 >> 2] | 0) | 0) == 1) i2 = 12; else i2 = 13;
  if ((i2 | 0) == 12) {
   i2 = 14;
   break;
  } else if ((i2 | 0) == 13) {
   i1 = -1;
   break;
  }
 } else i2 = 14; while (0);
 if ((i2 | 0) == 14) i1 = i12 ? 0 : i13;
 STACKTOP = i14;
 return i1 | 0;
}

function __ZNSt3__211__stdoutbufIcE8overflowEi(i3, i13) {
 i3 = i3 | 0;
 i13 = i13 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i11 = i14 + 16 | 0;
 i1 = i14 + 8 | 0;
 i10 = i14 + 4 | 0;
 i9 = i14;
 i12 = (i13 | 0) == -1;
 do if (!i12) {
  HEAP8[i1 >> 0] = i13;
  if (HEAP8[i3 + 44 >> 0] | 0) if ((_fwrite(i1, 1, 1, HEAP32[i3 + 32 >> 2] | 0) | 0) == 1) {
   i2 = 14;
   break;
  } else {
   i1 = -1;
   break;
  }
  HEAP32[i10 >> 2] = i11;
  i8 = i1 + 1 | 0;
  i4 = i3 + 36 | 0;
  i5 = i3 + 40 | 0;
  i6 = i11 + 8 | 0;
  i7 = i11;
  i3 = i3 + 32 | 0;
  while (1) {
   i2 = HEAP32[i4 >> 2] | 0;
   i2 = FUNCTION_TABLE_iiiiiiiii[HEAP32[(HEAP32[i2 >> 2] | 0) + 12 >> 2] & 15](i2, HEAP32[i5 >> 2] | 0, i1, i8, i9, i11, i6, i10) | 0;
   if ((HEAP32[i9 >> 2] | 0) == (i1 | 0)) {
    i2 = 13;
    break;
   }
   if ((i2 | 0) == 3) {
    i2 = 7;
    break;
   }
   if ((i2 | 1 | 0) != 1) {
    i2 = 13;
    break;
   }
   i1 = (HEAP32[i10 >> 2] | 0) - i7 | 0;
   if ((_fwrite(i11, 1, i1, HEAP32[i3 >> 2] | 0) | 0) != (i1 | 0)) {
    i2 = 13;
    break;
   }
   if ((i2 | 0) == 1) i1 = HEAP32[i9 >> 2] | 0; else {
    i2 = 12;
    break;
   }
  }
  if ((i2 | 0) == 7) if ((_fwrite(i1, 1, 1, HEAP32[i3 >> 2] | 0) | 0) == 1) i2 = 12; else i2 = 13;
  if ((i2 | 0) == 12) {
   i2 = 14;
   break;
  } else if ((i2 | 0) == 13) {
   i1 = -1;
   break;
  }
 } else i2 = 14; while (0);
 if ((i2 | 0) == 14) i1 = i12 ? 0 : i13;
 STACKTOP = i14;
 return i1 | 0;
}

function __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlNS_4NameEE_clES3_(i7, i5) {
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i9 + 4 | 0;
 i8 = i9;
 i4 = HEAP32[i5 >> 2] | 0;
 i1 = i4;
 do if (i4 | 0) {
  i2 = HEAP32[i7 >> 2] | 0;
  i3 = i2 + 4 | 0;
  i4 = HEAP32[i3 >> 2] | 0;
  if ((i4 | 0) == (HEAP32[i2 + 8 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i2, i5); else {
   HEAP32[i4 >> 2] = i1;
   HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 4;
  }
  i1 = __ZNSt3__23mapIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEENS_4lessIS2_EENS4_INS_4pairIKS2_S6_EEEEEixERSA_(HEAP32[i7 + 4 >> 2] | 0, i5) | 0;
  i3 = HEAP32[i7 + 8 >> 2] | 0;
  i2 = HEAP32[i3 >> 2] | 0;
  HEAP32[i3 >> 2] = i2 + 1;
  HEAP32[i6 >> 2] = i2;
  i3 = i1 + 4 | 0;
  i4 = HEAP32[i3 >> 2] | 0;
  if (i4 >>> 0 < (HEAP32[i1 + 8 >> 2] | 0) >>> 0) {
   HEAP32[i4 >> 2] = i2;
   HEAP32[i3 >> 2] = i4 + 4;
  } else __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIjEEvOT_(i1, i6);
  i4 = HEAP32[i7 + 12 >> 2] | 0;
  i1 = HEAP32[i7 + 16 >> 2] | 0;
  HEAP32[i8 >> 2] = i1;
  i2 = i4 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i4 + 8 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
   break;
  } else {
   __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i4, i8);
   break;
  }
 } while (0);
 STACKTOP = i9;
 return 1;
}

function _mbrtowc(i4, i3, i7, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i7 = i7 | 0;
 i1 = i1 | 0;
 var i2 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0, i10 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i9;
 i6 = (i1 | 0) == 0 ? 60128 : i1;
 i1 = HEAP32[i6 >> 2] | 0;
 L1 : do if (!i3) if (!i1) i1 = 0; else i8 = 15; else {
  i5 = (i4 | 0) == 0 ? i2 : i4;
  if (!i7) i1 = -2; else {
   if (!i1) {
    i1 = HEAP8[i3 >> 0] | 0;
    i2 = i1 & 255;
    if (i1 << 24 >> 24 > -1) {
     HEAP32[i5 >> 2] = i2;
     i1 = i1 << 24 >> 24 != 0 & 1;
     break;
    }
    i1 = i2 + -194 | 0;
    if (i1 >>> 0 > 50) {
     i8 = 15;
     break;
    }
    i1 = HEAP32[8196 + (i1 << 2) >> 2] | 0;
    i2 = i7 + -1 | 0;
    if (i2) {
     i3 = i3 + 1 | 0;
     i8 = 9;
    }
   } else {
    i2 = i7;
    i8 = 9;
   }
   L11 : do if ((i8 | 0) == 9) {
    i4 = HEAP8[i3 >> 0] | 0;
    i10 = (i4 & 255) >>> 3;
    if ((i10 + -16 | i10 + (i1 >> 26)) >>> 0 > 7) {
     i8 = 15;
     break L1;
    }
    while (1) {
     i3 = i3 + 1 | 0;
     i1 = (i4 & 255) + -128 | i1 << 6;
     i2 = i2 + -1 | 0;
     if ((i1 | 0) >= 0) break;
     if (!i2) break L11;
     i4 = HEAP8[i3 >> 0] | 0;
     if ((i4 & -64) << 24 >> 24 != -128) {
      i8 = 15;
      break L1;
     }
    }
    HEAP32[i6 >> 2] = 0;
    HEAP32[i5 >> 2] = i1;
    i1 = i7 - i2 | 0;
    break L1;
   } while (0);
   HEAP32[i6 >> 2] = i1;
   i1 = -2;
  }
 } while (0);
 if ((i8 | 0) == 15) {
  HEAP32[i6 >> 2] = 0;
  i1 = ___errno_location() | 0;
  HEAP32[i1 >> 2] = 84;
  i1 = -1;
 }
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEEclEOS5_Oj(i6, i1, i2) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i5 = i10 + 8 | 0;
 i8 = i10 + 4 | 0;
 i9 = i10;
 i3 = HEAP32[i1 >> 2] | 0;
 i2 = HEAP32[i2 >> 2] | 0;
 HEAP32[i9 >> 2] = i3;
 i1 = HEAP32[i6 + 4 >> 2] | 0;
 i4 = __ZN6cashew5Value4sizeEv(i3) | 0;
 do if ((i4 | 0) == (i2 | 0)) i1 = __ZN10MixedArena5allocIN4wasm3NopEEEPT_v(HEAP32[i1 + 4 >> 2] | 0) | 0; else {
  if ((i4 - i2 | 0) == 1) {
   i1 = HEAP32[i6 + 8 >> 2] | 0;
   i9 = __ZN6cashew3RefixEj(i9, i2) | 0;
   HEAP32[i5 >> 2] = HEAP32[i9 >> 2];
   HEAP32[i7 >> 2] = HEAP32[i5 >> 2];
   i1 = __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i7) | 0;
   break;
  }
  i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i1 + 4 >> 2] | 0) | 0;
  i5 = i1 + 12 | 0;
  i4 = i6 + 8 | 0;
  while (1) {
   if (i2 >>> 0 >= (__ZN6cashew5Value4sizeEv(i3) | 0) >>> 0) break;
   i3 = HEAP32[i4 >> 2] | 0;
   i6 = __ZN6cashew3RefixEj(i9, i2) | 0;
   HEAP32[i8 >> 2] = HEAP32[i6 >> 2];
   HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i5, __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i3, i7) | 0);
   i3 = HEAP32[i9 >> 2] | 0;
   i2 = i2 + 1 | 0;
  }
  __ZN4wasm5Block8finalizeEv(i1);
 } while (0);
 STACKTOP = i10;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_12CallIndirectENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == 5 | (i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_10CallImportENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == 5 | (i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv(i5, i3, i2, i1, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 192 | 0;
 i10 = i6;
 i5 = i6 + 180 | 0;
 i7 = i6 + 160 | 0;
 i8 = i6 + 8 | 0;
 i12 = i6 + 156 | 0;
 i11 = i6 + 4 | 0;
 HEAP8[i5 >> 0] = HEAP8[53497] | 0;
 HEAP8[i5 + 1 >> 0] = HEAP8[53498] | 0;
 HEAP8[i5 + 2 >> 0] = HEAP8[53499] | 0;
 HEAP8[i5 + 3 >> 0] = HEAP8[53500] | 0;
 HEAP8[i5 + 4 >> 0] = HEAP8[53501] | 0;
 HEAP8[i5 + 5 >> 0] = HEAP8[53502] | 0;
 i9 = __ZNSt3__26__clocEv() | 0;
 HEAP32[i10 >> 2] = i4;
 i5 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i7, 20, i9, i5, i10) | 0;
 i9 = i7 + i5 | 0;
 i4 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i7, i9, i2) | 0;
 i13 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i12 >> 2] = i13;
 i12 = __ZNKSt3__26locale9use_facetERNS0_2idE(i12, 61712) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i13) | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i12 >> 2] | 0) + 48 >> 2] & 7](i12, i7, i9, i8) | 0;
 i5 = i8 + (i5 << 2) | 0;
 HEAP32[i11 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i11 >> 2];
 i5 = __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i10, i8, (i4 | 0) == (i9 | 0) ? i5 : i8 + (i4 - i7 << 2) | 0, i5, i2, i1) | 0;
 STACKTOP = i6;
 return i5 | 0;
}

function __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_8SetLocalENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == 5 | (i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE24__emplace_back_slow_pathIJiRA1_KciEEEvDpOT_(i13, i9, i10, i11) {
 i13 = i13 | 0;
 i9 = i9 | 0;
 i10 = i10 | 0;
 i11 = i11 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i12 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i4 = i14 + 32 | 0;
 i3 = i14 + 28 | 0;
 i5 = i14 + 24 | 0;
 i6 = i14 + 20 | 0;
 i12 = i14;
 i7 = i13 + 4 | 0;
 i8 = HEAP32[i13 >> 2] | 0;
 i2 = ((HEAP32[i7 >> 2] | 0) - i8 >> 4) + 1 | 0;
 if (i2 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i13);
 i1 = (HEAP32[i13 + 8 >> 2] | 0) - i8 | 0;
 if (i1 >> 4 >>> 0 < 134217727) {
  i1 = i1 >> 3;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 268435455;
 __ZNSt3__214__split_bufferIN4wasm6Memory7SegmentERNS_9allocatorIS3_EEEC2EjjS6_(i12, i1, (HEAP32[i7 >> 2] | 0) - i8 >> 4, i13 + 8 | 0);
 i8 = i12 + 8 | 0;
 i7 = HEAP32[i8 >> 2] | 0;
 i9 = HEAP32[i9 >> 2] | 0;
 __ZN4wasm7AddressC2Ey(i5, i9, ((i9 | 0) < 0) << 31 >> 31);
 i11 = HEAP32[i11 >> 2] | 0;
 __ZN4wasm7AddressC2Ey(i6, i11, ((i11 | 0) < 0) << 31 >> 31);
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
 __ZN4wasm6Memory7SegmentC2ENS_7AddressEPKcS2_(i7, i3, i10, i4);
 HEAP32[i8 >> 2] = i7 + 16;
 __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i13, i12);
 __ZNSt3__214__split_bufferIN4wasm6Memory7SegmentERNS_9allocatorIS3_EEED2Ev(i12);
 STACKTOP = i14;
 return;
}

function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE(i8, i1) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i6 = i8 + 32 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_(i6, i1) | 0;
 i5 = i8 + 44 | 0;
 HEAP32[i5 >> 2] = 0;
 i7 = i8 + 48 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 if (i4 & 8 | 0) {
  i1 = HEAP8[i6 + 11 >> 0] | 0;
  if (i1 << 24 >> 24 < 0) {
   i1 = HEAP32[i6 >> 2] | 0;
   i2 = i1;
   i3 = i1;
   i1 = i1 + (HEAP32[i8 + 36 >> 2] | 0) | 0;
  } else {
   i2 = i6;
   i3 = i6;
   i1 = i6 + (i1 & 255) | 0;
  }
  HEAP32[i5 >> 2] = i1;
  HEAP32[i8 + 8 >> 2] = i2;
  HEAP32[i8 + 12 >> 2] = i3;
  HEAP32[i8 + 16 >> 2] = i1;
 }
 if (i4 & 16 | 0) {
  i2 = i6 + 11 | 0;
  i1 = HEAP8[i2 >> 0] | 0;
  if (i1 << 24 >> 24 < 0) {
   i4 = HEAP32[i8 + 36 >> 2] | 0;
   HEAP32[i5 >> 2] = (HEAP32[i6 >> 2] | 0) + i4;
   i1 = (HEAP32[i8 + 40 >> 2] & 2147483647) + -1 | 0;
   i5 = i4;
  } else {
   i4 = i1 & 255;
   HEAP32[i5 >> 2] = i6 + i4;
   i1 = 10;
   i5 = i4;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i6, i1, 0);
  i1 = HEAP8[i2 >> 0] | 0;
  if (i1 << 24 >> 24 < 0) {
   i2 = HEAP32[i6 >> 2] | 0;
   i4 = i2;
   i3 = HEAP32[i8 + 36 >> 2] | 0;
  } else {
   i4 = i6;
   i3 = i1 & 255;
   i2 = i6;
  }
  i1 = i8 + 24 | 0;
  HEAP32[i1 >> 2] = i2;
  HEAP32[i8 + 20 >> 2] = i2;
  HEAP32[i8 + 28 >> 2] = i4 + i3;
  if (HEAP32[i7 >> 2] & 3 | 0) HEAP32[i1 >> 2] = i2 + i5;
 }
 return;
}

function __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_5StoreENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == 5 | (i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_4LoadENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == 5 | (i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_4HostENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == 5 | (i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_4CallENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == 5 | (i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEENS_9allocatorISC_EEE21__push_back_slow_pathISC_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEERNS_9allocatorISC_EEEC2EjjSF_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i3 >> 2] = i2;
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEENS_9allocatorISC_EEE26__swap_out_circular_bufferERNS_14__split_bufferISC_RSE_EE(i7, i5);
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEERNS_9allocatorISC_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i5, i2) {
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i6 + 24 | 0;
 i7 = i6 + 12 | 0;
 i1 = i6;
 i3 = __ZN4wasm12PassRegistry3getEv() | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i7, i2);
 i3 = __ZN4wasm12PassRegistry10createPassENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i3, i7) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i7);
 HEAP32[i4 >> 2] = i3;
 if (!i3) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 21062) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 21040) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i1, i2);
  __ZNSt3__2lsIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_13basic_ostreamIT_T0_EES9_RKNS_12basic_stringIS6_S7_T1_EE(60976, i1) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 34477) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1);
  __ZN4wasm5FatalD2Ev(i6 + 28 | 0);
 }
 i1 = i5 + 12 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[i5 + 16 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm4PassENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i5 + 8 | 0, i4); else {
  HEAP32[i2 >> 2] = i3;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
 }
 STACKTOP = i6;
 return;
}

function __ZN4wasm17WasmBinaryBuilder14maybeVisitHostERPNS_10ExpressionEh(i4, i3, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i5 = 0, i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i6;
 switch (i1 & 255 | 0) {
 case 59:
  {
   i1 = __ZN10MixedArena5allocIN4wasm4HostEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 1;
   HEAP32[i1 + 4 >> 2] = 1;
   i5 = 4;
   break;
  }
 case 57:
  {
   i1 = __ZN10MixedArena5allocIN4wasm4HostEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
   HEAP32[i1 + 8 >> 2] = 2;
   i5 = i1 + 16 | 0;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i5, 1);
   i7 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i4) | 0;
   i5 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i5, 0) | 0;
   HEAP32[i5 >> 2] = i7;
   i5 = 4;
   break;
  }
 default:
  i1 = 0;
 }
 if ((i5 | 0) == 4) {
  if (HEAP8[i4 + 12 >> 0] | 0) {
   i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25178) | 0;
   i5 = __ZNKSt3__28ios_base6getlocEv(i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i2 >> 2] = i5;
   i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
   i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
   __ZNSt3__26localeD2Ev(i2);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i5) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i7) | 0;
  }
  __ZN4wasm4Host8finalizeEv(i1);
  HEAP32[i3 >> 2] = i1;
  i1 = 1;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy(i11, i6, i7) {
 i11 = i11 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i12 + 16 | 0;
 i9 = i12 + 12 | 0;
 i10 = i12;
 i1 = i12 + 8 | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i10, i11);
 if (HEAP8[i10 >> 0] | 0) {
  i8 = __ZNKSt3__28ios_base6getlocEv(i11 + (HEAP32[(HEAP32[i11 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i8;
  i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61736) | 0;
  __ZNSt3__26localeD2Ev(i1);
  i3 = i11 + (HEAP32[(HEAP32[i11 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i4 = HEAP32[i3 + 24 >> 2] | 0;
  i2 = i3 + 76 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   i1 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
   HEAP32[i5 >> 2] = i1;
   i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
   i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 32) | 0;
   __ZNSt3__26localeD2Ev(i5);
   i1 = i1 << 24 >> 24;
   HEAP32[i2 >> 2] = i1;
  }
  i2 = HEAP32[(HEAP32[i8 >> 2] | 0) + 28 >> 2] | 0;
  HEAP32[i9 >> 2] = i4;
  HEAP32[i5 >> 2] = HEAP32[i9 >> 2];
  if (!(FUNCTION_TABLE_iiiiiii[i2 & 63](i8, i5, i3, i1 & 255, i6, i7) | 0)) {
   i9 = i11 + (HEAP32[(HEAP32[i11 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
   HEAP32[i9 >> 2] = HEAP32[i9 >> 2] | 5;
  }
 }
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i10);
 STACKTOP = i12;
 return i11 | 0;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx(i11, i6, i7) {
 i11 = i11 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i12 + 16 | 0;
 i9 = i12 + 12 | 0;
 i10 = i12;
 i1 = i12 + 8 | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i10, i11);
 if (HEAP8[i10 >> 0] | 0) {
  i8 = __ZNKSt3__28ios_base6getlocEv(i11 + (HEAP32[(HEAP32[i11 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i8;
  i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61736) | 0;
  __ZNSt3__26localeD2Ev(i1);
  i3 = i11 + (HEAP32[(HEAP32[i11 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i4 = HEAP32[i3 + 24 >> 2] | 0;
  i2 = i3 + 76 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   i1 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
   HEAP32[i5 >> 2] = i1;
   i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
   i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 32) | 0;
   __ZNSt3__26localeD2Ev(i5);
   i1 = i1 << 24 >> 24;
   HEAP32[i2 >> 2] = i1;
  }
  i2 = HEAP32[(HEAP32[i8 >> 2] | 0) + 20 >> 2] | 0;
  HEAP32[i9 >> 2] = i4;
  HEAP32[i5 >> 2] = HEAP32[i9 >> 2];
  if (!(FUNCTION_TABLE_iiiiiii[i2 & 63](i8, i5, i3, i1 & 255, i6, i7) | 0)) {
   i9 = i11 + (HEAP32[(HEAP32[i11 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
   HEAP32[i9 >> 2] = HEAP32[i9 >> 2] | 5;
  }
 }
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i10);
 STACKTOP = i12;
 return i11 | 0;
}

function __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE24__emplace_back_slow_pathIJRPFvPS6_PPNS1_10ExpressionEERSI_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEEC2EjjSD_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE26__swap_out_circular_bufferERNS_14__split_bufferISA_RSC_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE24__emplace_back_slow_pathIJRPFvPS6_PPNS1_10ExpressionEERSI_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEEC2EjjSD_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE26__swap_out_circular_bufferERNS_14__split_bufferISA_RSC_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE24__emplace_back_slow_pathIJiPcjEEEvDpOT_(i13, i9, i10, i11) {
 i13 = i13 | 0;
 i9 = i9 | 0;
 i10 = i10 | 0;
 i11 = i11 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i12 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i4 = i14 + 32 | 0;
 i3 = i14 + 28 | 0;
 i5 = i14 + 24 | 0;
 i6 = i14 + 20 | 0;
 i12 = i14;
 i7 = i13 + 4 | 0;
 i8 = HEAP32[i13 >> 2] | 0;
 i2 = ((HEAP32[i7 >> 2] | 0) - i8 >> 4) + 1 | 0;
 if (i2 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i13);
 i1 = (HEAP32[i13 + 8 >> 2] | 0) - i8 | 0;
 if (i1 >> 4 >>> 0 < 134217727) {
  i1 = i1 >> 3;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 268435455;
 __ZNSt3__214__split_bufferIN4wasm6Memory7SegmentERNS_9allocatorIS3_EEEC2EjjS6_(i12, i1, (HEAP32[i7 >> 2] | 0) - i8 >> 4, i13 + 8 | 0);
 i8 = i12 + 8 | 0;
 i7 = HEAP32[i8 >> 2] | 0;
 i9 = HEAP32[i9 >> 2] | 0;
 __ZN4wasm7AddressC2Ey(i5, i9, ((i9 | 0) < 0) << 31 >> 31);
 i10 = HEAP32[i10 >> 2] | 0;
 __ZN4wasm7AddressC2Ey(i6, HEAP32[i11 >> 2] | 0, 0);
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
 __ZN4wasm6Memory7SegmentC2ENS_7AddressEPKcS2_(i7, i3, i10, i4);
 HEAP32[i8 >> 2] = i7 + 16;
 __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i13, i12);
 __ZNSt3__214__split_bufferIN4wasm6Memory7SegmentERNS_9allocatorIS3_EEED2Ev(i12);
 STACKTOP = i14;
 return;
}

function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv(i5, i3, i2, i1, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i10 = i6;
 i5 = i6 + 72 | 0;
 i7 = i6 + 52 | 0;
 i8 = i6 + 12 | 0;
 i12 = i6 + 8 | 0;
 i11 = i6 + 4 | 0;
 HEAP8[i5 >> 0] = HEAP8[53497] | 0;
 HEAP8[i5 + 1 >> 0] = HEAP8[53498] | 0;
 HEAP8[i5 + 2 >> 0] = HEAP8[53499] | 0;
 HEAP8[i5 + 3 >> 0] = HEAP8[53500] | 0;
 HEAP8[i5 + 4 >> 0] = HEAP8[53501] | 0;
 HEAP8[i5 + 5 >> 0] = HEAP8[53502] | 0;
 i9 = __ZNSt3__26__clocEv() | 0;
 HEAP32[i10 >> 2] = i4;
 i5 = __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i7, 20, i9, i5, i10) | 0;
 i9 = i7 + i5 | 0;
 i4 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i7, i9, i2) | 0;
 i13 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i12 >> 2] = i13;
 i12 = __ZNKSt3__26locale9use_facetERNS0_2idE(i12, 61680) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i13) | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i12 >> 2] | 0) + 32 >> 2] & 7](i12, i7, i9, i8) | 0;
 i5 = i8 + i5 | 0;
 HEAP32[i11 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i11 >> 2];
 i5 = __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i10, i8, (i4 | 0) == (i9 | 0) ? i5 : i8 + (i4 - i7) | 0, i5, i2, i1) | 0;
 STACKTOP = i6;
 return i5 | 0;
}

function __ZN4wasm10ThreadPool10initializeEj(i11, i6) {
 i11 = i11 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i10 = i12 + 8 | 0;
 i3 = i12;
 if ((i6 | 0) != 1) {
  i8 = i11 + 16 | 0;
  HEAP32[i10 >> 2] = i8;
  i7 = i10 + 4 | 0;
  HEAP8[i7 >> 0] = 1;
  __ZNSt3__25mutex4lockEv(i8);
  i8 = i11 + 4 | 0;
  i9 = i11 + 92 | 0;
  HEAP32[i9 >> 2] = (HEAP32[i8 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2;
  __ZN4wasm10ThreadPool20resetThreadsAreReadyEv(i11);
  i4 = i11 + 8 | 0;
  i5 = 0;
  while (1) {
   if (i5 >>> 0 >= i6 >>> 0) break;
   i1 = __Znwj(112) | 0;
   __ZN4wasm6ThreadC2Ev(i1);
   HEAP32[i3 >> 2] = i1;
   i2 = HEAP32[i8 >> 2] | 0;
   if (i2 >>> 0 >= (HEAP32[i4 >> 2] | 0) >>> 0) {
    __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE24__emplace_back_slow_pathIJS6_EEEvDpOT_(i11, i3);
    i1 = HEAP32[i3 >> 2] | 0;
    HEAP32[i3 >> 2] = 0;
    if (i1 | 0) {
     __ZN4wasm6ThreadD2Ev(i1);
     __ZdlPv(i1);
    }
   } else {
    HEAP32[i2 >> 2] = i1;
    HEAP32[i8 >> 2] = i2 + 4;
    HEAP32[i3 >> 2] = 0;
   }
   i5 = i5 + 1 | 0;
  }
  i1 = i11 + 44 | 0;
  while (1) {
   if ((HEAP32[i9 >> 2] | 0) == ((HEAP32[i8 >> 2] | 0) - (HEAP32[i11 >> 2] | 0) >> 2 | 0)) break;
   __ZNSt3__218condition_variable4waitERNS_11unique_lockINS_5mutexEEE(i1, i10);
  }
  if (HEAP8[i7 >> 0] | 0) __ZNSt3__25mutex6unlockEv(HEAP32[i10 >> 2] | 0);
 }
 STACKTOP = i12;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS8_PvEENS_22__tree_node_destructorINS5_ISR_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZNSt3__29remove_ifINS_11__wrap_iterIPPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEEEZNS8_16unlinkDeadBlocksENS_13unordered_setISA_NS_4hashISA_EENS_8equal_toISA_EENS_9allocatorISA_EEEEEUlSA_E0_EET_SM_SM_T0_(i6, i1, i7) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i1 >> 2] | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i5 | 0)) {
   i2 = 3;
   break;
  }
  if (__ZZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE16unlinkDeadBlocksENSt3__213unordered_setIPNS5_10BasicBlockENS6_4hashIS9_EENS6_8equal_toIS9_EENS6_9allocatorIS9_EEEEENKUlS9_E0_clES9_(i7, HEAP32[i1 >> 2] | 0) | 0) {
   i3 = i1;
   i2 = 6;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 L5 : do if ((i2 | 0) == 3) {
  HEAP32[i6 >> 2] = i5;
  i1 = i5;
 } else if ((i2 | 0) == 6) {
  HEAP32[i6 >> 2] = i3;
  if ((i3 | 0) == (i5 | 0)) i1 = i5; else {
   i1 = i3;
   i4 = i3;
   i2 = i3;
   while (1) {
    while (1) {
     i2 = i2 + 4 | 0;
     if ((i2 | 0) == (i5 | 0)) break L5;
     i3 = HEAP32[i2 >> 2] | 0;
     if (!(__ZZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE16unlinkDeadBlocksENSt3__213unordered_setIPNS5_10BasicBlockENS6_4hashIS9_EENS6_8equal_toIS9_EENS6_9allocatorIS9_EEEEENKUlS9_E0_clES9_(i7, i3) | 0)) {
      i1 = i3;
      break;
     }
    }
    HEAP32[i4 >> 2] = i1;
    i3 = i4 + 4 | 0;
    HEAP32[i6 >> 2] = i3;
    i1 = i3;
    i4 = i3;
   }
  }
 } while (0);
 return i1 | 0;
}

function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy(i6, i5, i4, i3, i1, i2) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 240 | 0;
 i9 = i7 + 8 | 0;
 i13 = i7;
 i14 = i7 + 204 | 0;
 i8 = i7 + 32 | 0;
 i11 = i7 + 28 | 0;
 i6 = i7 + 20 | 0;
 i12 = i7 + 24 | 0;
 i10 = i7 + 16 | 0;
 i15 = i13;
 HEAP32[i15 >> 2] = 37;
 HEAP32[i15 + 4 >> 2] = 0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj(i13 + 1 | 0, 56986, 0, HEAP32[i4 + 4 >> 2] | 0);
 i15 = __ZNSt3__26__clocEv() | 0;
 i16 = i9;
 HEAP32[i16 >> 2] = i1;
 HEAP32[i16 + 4 >> 2] = i2;
 i1 = i14 + (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i14, 23, i15, i13, i9) | 0) | 0;
 i13 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i14, i1, i4) | 0;
 i2 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i12 >> 2] = i2;
 __ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE(i14, i13, i1, i8, i11, i6, i12);
 __ZNSt3__214__shared_count16__release_sharedEv(i2) | 0;
 HEAP32[i10 >> 2] = HEAP32[i5 >> 2];
 i5 = HEAP32[i11 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i9 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i9, i8, i5, i6, i4, i3) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx(i6, i5, i4, i3, i1, i2) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 240 | 0;
 i9 = i7 + 8 | 0;
 i13 = i7;
 i14 = i7 + 204 | 0;
 i8 = i7 + 32 | 0;
 i11 = i7 + 28 | 0;
 i6 = i7 + 20 | 0;
 i12 = i7 + 24 | 0;
 i10 = i7 + 16 | 0;
 i15 = i13;
 HEAP32[i15 >> 2] = 37;
 HEAP32[i15 + 4 >> 2] = 0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj(i13 + 1 | 0, 56986, 1, HEAP32[i4 + 4 >> 2] | 0);
 i15 = __ZNSt3__26__clocEv() | 0;
 i16 = i9;
 HEAP32[i16 >> 2] = i1;
 HEAP32[i16 + 4 >> 2] = i2;
 i1 = i14 + (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i14, 23, i15, i13, i9) | 0) | 0;
 i13 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i14, i1, i4) | 0;
 i2 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i12 >> 2] = i2;
 __ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE(i14, i13, i1, i8, i11, i6, i12);
 __ZNSt3__214__shared_count16__release_sharedEv(i2) | 0;
 HEAP32[i10 >> 2] = HEAP32[i5 >> 2];
 i5 = HEAP32[i11 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i9 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i9, i8, i5, i6, i4, i3) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy(i6, i5, i4, i3, i1, i2) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i9 = i7 + 8 | 0;
 i13 = i7;
 i14 = i7 + 75 | 0;
 i8 = i7 + 32 | 0;
 i11 = i7 + 28 | 0;
 i6 = i7 + 20 | 0;
 i12 = i7 + 24 | 0;
 i10 = i7 + 16 | 0;
 i15 = i13;
 HEAP32[i15 >> 2] = 37;
 HEAP32[i15 + 4 >> 2] = 0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj(i13 + 1 | 0, 56986, 0, HEAP32[i4 + 4 >> 2] | 0);
 i15 = __ZNSt3__26__clocEv() | 0;
 i16 = i9;
 HEAP32[i16 >> 2] = i1;
 HEAP32[i16 + 4 >> 2] = i2;
 i1 = i14 + (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i14, 23, i15, i13, i9) | 0) | 0;
 i13 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i14, i1, i4) | 0;
 i2 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i12 >> 2] = i2;
 __ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE(i14, i13, i1, i8, i11, i6, i12);
 __ZNSt3__214__shared_count16__release_sharedEv(i2) | 0;
 HEAP32[i10 >> 2] = HEAP32[i5 >> 2];
 i5 = HEAP32[i11 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i9 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i9, i8, i5, i6, i4, i3) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx(i6, i5, i4, i3, i1, i2) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i9 = i7 + 8 | 0;
 i13 = i7;
 i14 = i7 + 75 | 0;
 i8 = i7 + 32 | 0;
 i11 = i7 + 28 | 0;
 i6 = i7 + 20 | 0;
 i12 = i7 + 24 | 0;
 i10 = i7 + 16 | 0;
 i15 = i13;
 HEAP32[i15 >> 2] = 37;
 HEAP32[i15 + 4 >> 2] = 0;
 __ZNSt3__214__num_put_base12__format_intEPcPKcbj(i13 + 1 | 0, 56986, 1, HEAP32[i4 + 4 >> 2] | 0);
 i15 = __ZNSt3__26__clocEv() | 0;
 i16 = i9;
 HEAP32[i16 >> 2] = i1;
 HEAP32[i16 + 4 >> 2] = i2;
 i1 = i14 + (__ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i14, 23, i15, i13, i9) | 0) | 0;
 i13 = __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i14, i1, i4) | 0;
 i2 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i12 >> 2] = i2;
 __ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE(i14, i13, i1, i8, i11, i6, i12);
 __ZNSt3__214__shared_count16__release_sharedEv(i2) | 0;
 HEAP32[i10 >> 2] = HEAP32[i5 >> 2];
 i5 = HEAP32[i11 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i9 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i9, i8, i5, i6, i4, i3) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNSt3__29remove_ifINS_11__wrap_iterIPPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEEEZNS8_16unlinkDeadBlocksENS_13unordered_setISA_NS_4hashISA_EENS_8equal_toISA_EENS_9allocatorISA_EEEEEUlSA_E_EET_SM_SM_T0_(i6, i1, i7) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i5 = HEAP32[i1 >> 2] | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i5 | 0)) {
   i2 = 3;
   break;
  }
  if (__ZZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE16unlinkDeadBlocksENSt3__213unordered_setIPNS5_10BasicBlockENS6_4hashIS9_EENS6_8equal_toIS9_EENS6_9allocatorIS9_EEEEENKUlS9_E_clES9_(i7, HEAP32[i1 >> 2] | 0) | 0) {
   i3 = i1;
   i2 = 6;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 L5 : do if ((i2 | 0) == 3) {
  HEAP32[i6 >> 2] = i5;
  i1 = i5;
 } else if ((i2 | 0) == 6) {
  HEAP32[i6 >> 2] = i3;
  if ((i3 | 0) == (i5 | 0)) i1 = i5; else {
   i1 = i3;
   i4 = i3;
   i2 = i3;
   while (1) {
    while (1) {
     i2 = i2 + 4 | 0;
     if ((i2 | 0) == (i5 | 0)) break L5;
     i3 = HEAP32[i2 >> 2] | 0;
     if (!(__ZZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE16unlinkDeadBlocksENSt3__213unordered_setIPNS5_10BasicBlockENS6_4hashIS9_EENS6_8equal_toIS9_EENS6_9allocatorIS9_EEEEENKUlS9_E_clES9_(i7, i3) | 0)) {
      i1 = i3;
      break;
     }
    }
    HEAP32[i4 >> 2] = i1;
    i3 = i4 + 4 | 0;
    HEAP32[i6 >> 2] = i3;
    i1 = i3;
    i4 = i3;
   }
  }
 } while (0);
 return i1 | 0;
}

function __ZZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEEEN9Generator10makeRandomEv(i10) {
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i11 + 12 | 0;
 i3 = i11 + 8 | 0;
 i5 = i11 + 4 | 0;
 i6 = i11;
 i7 = __Znwj(24) | 0;
 HEAP32[i7 >> 2] = 0;
 i8 = i7 + 4 | 0;
 HEAP32[i8 >> 2] = 0;
 HEAP32[i7 + 8 >> 2] = 0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i7, HEAP32[(HEAP32[i10 >> 2] | 0) + 112 >> 2] | 0);
 i9 = HEAP32[i10 >> 2] | 0;
 i1 = i9 + 112 | 0;
 i2 = 0;
 while (1) {
  if (i2 >>> 0 >= (HEAP32[i1 >> 2] | 0) >>> 0) break;
  HEAP32[(HEAP32[i7 >> 2] | 0) + (i2 << 2) >> 2] = i2;
  i2 = i2 + 1 | 0;
 }
 i1 = i10 + 2504 | 0;
 if (!(HEAP8[i1 >> 0] | 0)) {
  i9 = HEAP32[i9 + 36 >> 2] | 0;
  HEAP32[i5 >> 2] = (HEAP32[i7 >> 2] | 0) + ((HEAP32[i9 + 12 >> 2] | 0) - (HEAP32[i9 + 8 >> 2] | 0) >> 2 << 2);
  HEAP32[i6 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  __ZNSt3__27shuffleINS_11__wrap_iterIPjEERNS_23mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEEEEvT_S7_OT0_(i3, i4, i10 + 4 | 0);
 } else HEAP8[i1 >> 0] = 0;
 __ZZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEEEN9Generator16calculateFitnessEPZNS0_11pickIndicesES6_E5Order(i10, i7);
 STACKTOP = i11;
 return i7 | 0;
}

function __ZN4wasm3LEBIxaE4readENSt3__28functionIFavEEE(i10, i7) {
 i10 = i10 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0;
 i8 = i10;
 HEAP32[i8 >> 2] = 0;
 HEAP32[i8 + 4 >> 2] = 0;
 i8 = 0;
 i4 = 0;
 while (1) {
  i6 = (__ZNKSt3__28functionIFavEEclEv(i7) | 0) << 24 >> 24;
  i2 = i6 & 127;
  if ((i8 | 0) == 0 & (i4 | 0) == 0) i1 = -1; else {
   i1 = _i64Subtract(64, 0, i8 | 0, i4 | 0) | 0;
   i1 = _bitshift64Shl(1, 0, i1 | 0) | 0;
   i1 = _i64Add(i1 | 0, tempRet0 | 0, -1, -1) | 0;
  }
  i1 = i1 & i2;
  i5 = (i6 & 128 | 0) == 0;
  if (!(i5 | (i1 | 0) == (i2 | 0) & 0 == 0)) {
   i2 = 5;
   break;
  }
  i3 = _bitshift64Shl(i1 | 0, 0, i8 | 0) | 0;
  i1 = i10;
  i3 = HEAP32[i1 >> 2] | i3;
  i1 = HEAP32[i1 + 4 >> 2] | tempRet0;
  i2 = i10;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 4 >> 2] = i1;
  if (i5) {
   i5 = i8;
   i2 = 9;
   break;
  }
  i8 = _i64Add(i8 | 0, i4 | 0, 7, 0) | 0;
  if (i8 >>> 0 >= 64) {
   i2 = 8;
   break;
  } else i4 = tempRet0;
 }
 if ((i2 | 0) == 5) ___assert_fail(23085, 22948, 99, 22966); else if ((i2 | 0) == 8) ___assert_fail(23162, 22948, 104, 22966); else if ((i2 | 0) == 9) {
  if ((i6 & 64 | 0 ? (i9 = _i64Add(i5 | 0, i4 | 0, 7, 0) | 0, i9 >>> 0 < 64) : 0) ? (i8 = 64 - i9 | 0, i9 = _bitshift64Shl(i3 | 0, i1 | 0, i8 | 0) | 0, i8 = _bitshift64Ashr(i9 | 0, tempRet0 | 0, i8 | 0) | 0, i9 = tempRet0, i10, HEAP32[i10 >> 2] = i8, HEAP32[i10 + 4 >> 2] = i9, (i9 | 0) >= 0) : 0) ___assert_fail(24692, 22948, 114, 22966);
  return;
 }
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE25__emplace_unique_key_argsIjJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSK_IJEEEEEENS_4pairINS_15__tree_iteratorIS9_PNS_11__tree_nodeIS9_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESL_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSK_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS9_PvEENS_22__tree_node_destructorINS6_ISS_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSJ_SJ_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZN4wasm13WasmValidator13shouldBeEqualIPNS_10ExpressionENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner17generateArgumentsERK11ArenaVectorIPNS_10ExpressionEES9_(i7, i10, i9, i8) {
 i7 = i7 | 0;
 i10 = i10 | 0;
 i9 = i9 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i11 = 0;
 i2 = i9 + 8 | 0;
 __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE7reserveEj(i8, HEAP32[i2 >> 2] | 0);
 i2 = HEAP32[i2 >> 2] | 0;
 i3 = i7 + 16 | 0;
 i4 = i8 + 4 | 0;
 i5 = i8 + 8 | 0;
 i6 = 0;
 while (1) {
  if ((i6 | 0) == (i2 | 0)) {
   i11 = 8;
   break;
  }
  i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i9, i6) | 0;
  __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i7, i10, HEAP32[i1 >> 2] | 0);
  if (HEAP32[i3 >> 2] | 0) break;
  i1 = HEAP32[i4 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i5 >> 2] | 0)) __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i8, i7); else {
   HEAP32[i1 >> 2] = HEAP32[i7 >> 2];
   HEAP32[i1 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
   HEAP32[i1 + 8 >> 2] = HEAP32[i7 + 8 >> 2];
   HEAP32[i1 + 12 >> 2] = HEAP32[i7 + 12 >> 2];
   HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 16;
  }
  i6 = i6 + 1 | 0;
 }
 if ((i11 | 0) == 8) {
  HEAP32[i7 >> 2] = 0;
  i11 = i7 + 8 | 0;
  HEAP32[i11 >> 2] = 0;
  HEAP32[i11 + 4 >> 2] = 0;
  HEAP32[i3 >> 2] = 0;
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS8_PvEENS_22__tree_node_destructorINS5_ISR_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZN4wasm14SimplifyLocals4scanEPS0_PPNS_10ExpressionE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 i1 = i4 + 16 | 0;
 __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 315, i3);
 i2 = HEAP32[i3 >> 2] | 0;
 if ((HEAP32[i2 >> 2] | 0) == 2 ? (i5 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 16 | 0, (HEAP32[i5 >> 2] | 0) != 0) : 0) {
  __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 316, i3);
  __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 314, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 16 | 0);
  __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 317, i3);
  __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 314, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 12 | 0);
  __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 318, i3);
  __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 314, (__ZN4wasm10Expression4castINS_2IfEEEPT_v(i2) | 0) + 8 | 0);
 } else __ZN4wasm21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i4, i3);
 __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i1, 319, i3);
 return;
}

function __ZN4wasm13WasmValidator15shouldBeUnequalIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == (i4 | 0)) {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 20394) | 0, i3) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 } else i1 = 1;
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator13shouldBeEqualIPNS_6BinaryENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE24__emplace_back_slow_pathIJRPFvPS6_PPNS1_10ExpressionEERSI_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEEC2EjjSD_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE26__swap_out_circular_bufferERNS_14__split_bufferISA_RSC_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__214__copy_alignedINS_6vectorIbNS_9allocatorIbEEEELb1EEENS_14__bit_iteratorIT_Lb0EXLi0EEEENS5_IS6_XT0_EXLi0EEEES8_S7_(i9, i3, i1, i8) {
 i9 = i9 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i8 = i8 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i10 = 0;
 i4 = HEAP32[i3 >> 2] | 0;
 i2 = HEAP32[i3 + 4 >> 2] | 0;
 i5 = ((HEAP32[i1 >> 2] | 0) - i4 << 3) + (HEAP32[i1 + 4 >> 2] | 0) - i2 | 0;
 i1 = i4;
 if ((i5 | 0) > 0) {
  if (!i2) {
   i7 = i3;
   i6 = i8;
   i3 = HEAP32[i8 >> 2] | 0;
   i2 = i4;
   i1 = i5;
  } else {
   i10 = 32 - i2 | 0;
   i4 = (i5 | 0) < (i10 | 0) ? i5 : i10;
   i2 = -1 >>> (i10 - i4 | 0) & -1 << i2;
   i10 = HEAP32[i8 >> 2] | 0;
   HEAP32[i10 >> 2] = HEAP32[i10 >> 2] & ~i2 | HEAP32[i1 >> 2] & i2;
   i2 = i8 + 4 | 0;
   i7 = (HEAP32[i2 >> 2] | 0) + i4 | 0;
   i10 = i10 + (i7 >>> 5 << 2) | 0;
   HEAP32[i8 >> 2] = i10;
   HEAP32[i2 >> 2] = i7 & 31;
   i2 = i1 + 4 | 0;
   HEAP32[i3 >> 2] = i2;
   i7 = i3;
   i6 = i8;
   i3 = i10;
   i1 = i5 - i4 | 0;
  }
  i4 = i1 >>> 5;
  _memmove(i3 | 0, i2 | 0, i4 << 2 | 0) | 0;
  i2 = i1 - (i4 << 5) | 0;
  i3 = (HEAP32[i6 >> 2] | 0) + (i4 << 2) | 0;
  HEAP32[i6 >> 2] = i3;
  i1 = i3;
  if ((i2 | 0) > 0) {
   i6 = (HEAP32[i7 >> 2] | 0) + (i4 << 2) | 0;
   HEAP32[i7 >> 2] = i6;
   i10 = -1 >>> (32 - i2 | 0);
   HEAP32[i3 >> 2] = HEAP32[i3 >> 2] & ~i10 | HEAP32[i6 >> 2] & i10;
   HEAP32[i8 + 4 >> 2] = i2;
  }
 } else i1 = HEAP32[i8 >> 2] | 0;
 HEAP32[i9 >> 2] = i1;
 HEAP32[i9 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
 return;
}

function __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5UnaryENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5BlockENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i10, i8) {
 i10 = i10 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i11 + 16 | 0;
 i6 = i11 + 12 | 0;
 i9 = i11;
 i1 = i11 + 8 | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i9, i10);
 if (HEAP8[i9 >> 0] | 0) {
  i7 = __ZNKSt3__28ios_base6getlocEv(i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61736) | 0;
  __ZNSt3__26localeD2Ev(i1);
  i3 = i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i4 = HEAP32[i3 + 24 >> 2] | 0;
  i2 = i3 + 76 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   i1 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
   HEAP32[i5 >> 2] = i1;
   i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
   i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 32) | 0;
   __ZNSt3__26localeD2Ev(i5);
   i1 = i1 << 24 >> 24;
   HEAP32[i2 >> 2] = i1;
  }
  i2 = HEAP32[(HEAP32[i7 >> 2] | 0) + 24 >> 2] | 0;
  HEAP32[i6 >> 2] = i4;
  HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
  if (!(FUNCTION_TABLE_iiiiii[i2 & 31](i7, i5, i3, i1 & 255, i8) | 0)) {
   i8 = i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
   HEAP32[i8 >> 2] = HEAP32[i8 >> 2] | 5;
  }
 }
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i9);
 STACKTOP = i11;
 return i10 | 0;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(i10, i8) {
 i10 = i10 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i11 + 16 | 0;
 i6 = i11 + 12 | 0;
 i9 = i11;
 i1 = i11 + 8 | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i9, i10);
 if (HEAP8[i9 >> 0] | 0) {
  i7 = __ZNKSt3__28ios_base6getlocEv(i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61736) | 0;
  __ZNSt3__26localeD2Ev(i1);
  i3 = i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i4 = HEAP32[i3 + 24 >> 2] | 0;
  i2 = i3 + 76 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   i1 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
   HEAP32[i5 >> 2] = i1;
   i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
   i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 32) | 0;
   __ZNSt3__26localeD2Ev(i5);
   i1 = i1 << 24 >> 24;
   HEAP32[i2 >> 2] = i1;
  }
  i2 = HEAP32[(HEAP32[i7 >> 2] | 0) + 16 >> 2] | 0;
  HEAP32[i6 >> 2] = i4;
  HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
  if (!(FUNCTION_TABLE_iiiiii[i2 & 31](i7, i5, i3, i1 & 255, i8) | 0)) {
   i8 = i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
   HEAP32[i8 >> 2] = HEAP32[i8 >> 2] | 5;
  }
 }
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i9);
 STACKTOP = i11;
 return i10 | 0;
}

function __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE24__emplace_back_slow_pathIJRjPKcS8_EEEvDpOT_(i13, i9, i10, i11) {
 i13 = i13 | 0;
 i9 = i9 | 0;
 i10 = i10 | 0;
 i11 = i11 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i12 = 0, i14 = 0;
 i14 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i4 = i14 + 32 | 0;
 i3 = i14 + 28 | 0;
 i5 = i14 + 24 | 0;
 i6 = i14 + 20 | 0;
 i12 = i14;
 i7 = i13 + 4 | 0;
 i8 = HEAP32[i13 >> 2] | 0;
 i2 = ((HEAP32[i7 >> 2] | 0) - i8 >> 4) + 1 | 0;
 if (i2 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i13);
 i1 = (HEAP32[i13 + 8 >> 2] | 0) - i8 | 0;
 if (i1 >> 4 >>> 0 < 134217727) {
  i1 = i1 >> 3;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 268435455;
 __ZNSt3__214__split_bufferIN4wasm6Memory7SegmentERNS_9allocatorIS3_EEEC2EjjS6_(i12, i1, (HEAP32[i7 >> 2] | 0) - i8 >> 4, i13 + 8 | 0);
 i8 = i12 + 8 | 0;
 i7 = HEAP32[i8 >> 2] | 0;
 __ZN4wasm7AddressC2Ey(i5, HEAP32[i9 >> 2] | 0, 0);
 i10 = HEAP32[i10 >> 2] | 0;
 __ZN4wasm7AddressC2Ey(i6, HEAP32[i11 >> 2] | 0, 0);
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
 __ZN4wasm6Memory7SegmentC2ENS_7AddressEPKcS2_(i7, i3, i10, i4);
 HEAP32[i8 >> 2] = i7 + 16;
 __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i13, i12);
 __ZNSt3__214__split_bufferIN4wasm6Memory7SegmentERNS_9allocatorIS3_EEED2Ev(i12);
 STACKTOP = i14;
 return;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf(i10, d8) {
 i10 = i10 | 0;
 d8 = +d8;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i11 + 16 | 0;
 i6 = i11 + 12 | 0;
 i9 = i11;
 i1 = i11 + 8 | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i9, i10);
 if (HEAP8[i9 >> 0] | 0) {
  i7 = __ZNKSt3__28ios_base6getlocEv(i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61736) | 0;
  __ZNSt3__26localeD2Ev(i1);
  i3 = i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i4 = HEAP32[i3 + 24 >> 2] | 0;
  i2 = i3 + 76 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   i1 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
   HEAP32[i5 >> 2] = i1;
   i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
   i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 32) | 0;
   __ZNSt3__26localeD2Ev(i5);
   i1 = i1 << 24 >> 24;
   HEAP32[i2 >> 2] = i1;
  }
  i2 = HEAP32[(HEAP32[i7 >> 2] | 0) + 32 >> 2] | 0;
  HEAP32[i6 >> 2] = i4;
  HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
  if (!(FUNCTION_TABLE_iiiiid[i2 & 7](i7, i5, i3, i1 & 255, d8) | 0)) {
   i7 = i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
   HEAP32[i7 >> 2] = HEAP32[i7 >> 2] | 5;
  }
 }
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i9);
 STACKTOP = i11;
 return i10 | 0;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd(i10, d8) {
 i10 = i10 | 0;
 d8 = +d8;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i11 + 16 | 0;
 i6 = i11 + 12 | 0;
 i9 = i11;
 i1 = i11 + 8 | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i9, i10);
 if (HEAP8[i9 >> 0] | 0) {
  i7 = __ZNKSt3__28ios_base6getlocEv(i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61736) | 0;
  __ZNSt3__26localeD2Ev(i1);
  i3 = i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i4 = HEAP32[i3 + 24 >> 2] | 0;
  i2 = i3 + 76 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   i1 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
   HEAP32[i5 >> 2] = i1;
   i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61680) | 0;
   i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 32) | 0;
   __ZNSt3__26localeD2Ev(i5);
   i1 = i1 << 24 >> 24;
   HEAP32[i2 >> 2] = i1;
  }
  i2 = HEAP32[(HEAP32[i7 >> 2] | 0) + 32 >> 2] | 0;
  HEAP32[i6 >> 2] = i4;
  HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
  if (!(FUNCTION_TABLE_iiiiid[i2 & 7](i7, i5, i3, i1 & 255, d8) | 0)) {
   i7 = i10 + (HEAP32[(HEAP32[i10 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
   HEAP32[i7 >> 2] = HEAP32[i7 >> 2] | 5;
  }
 }
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i9);
 STACKTOP = i11;
 return i10 | 0;
}

function __ZNSt3__26vectorIbNS_9allocatorIbEEE18__construct_at_endINS_14__bit_iteratorIS3_Lb0ELj0EEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_(i6, i1, i2) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0, i14 = 0, i15 = 0, i16 = 0;
 i15 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i7 = i15 + 48 | 0;
 i8 = i15 + 40 | 0;
 i9 = i15 + 32 | 0;
 i10 = i15 + 24 | 0;
 i11 = i15 + 16 | 0;
 i12 = i15 + 8 | 0;
 i13 = i15;
 i3 = i6 + 4 | 0;
 i16 = HEAP32[i3 >> 2] | 0;
 i14 = HEAP32[i1 >> 2] | 0;
 i4 = HEAP32[i1 + 4 >> 2] | 0;
 i5 = HEAP32[i2 >> 2] | 0;
 i2 = HEAP32[i2 + 4 >> 2] | 0;
 HEAP32[i3 >> 2] = i16 - i4 + i2 + (i5 - i14 << 3);
 i3 = i16 & 31;
 i1 = (HEAP32[i6 >> 2] | 0) + (i16 >>> 5 << 2) | 0;
 if ((i4 | 0) == (i3 | 0)) {
  HEAP32[i7 >> 2] = i14;
  HEAP32[i7 + 4 >> 2] = i4;
  HEAP32[i8 >> 2] = i5;
  HEAP32[i8 + 4 >> 2] = i2;
  HEAP32[i9 >> 2] = i1;
  HEAP32[i9 + 4 >> 2] = i4;
  __ZNSt3__214__copy_alignedINS_6vectorIbNS_9allocatorIbEEEELb0EEENS_14__bit_iteratorIT_Lb0EXLi0EEEENS5_IS6_XT0_EXLi0EEEES8_S7_(i13, i7, i8, i9);
 } else {
  HEAP32[i10 >> 2] = i14;
  HEAP32[i10 + 4 >> 2] = i4;
  HEAP32[i11 >> 2] = i5;
  HEAP32[i11 + 4 >> 2] = i2;
  HEAP32[i12 >> 2] = i1;
  HEAP32[i12 + 4 >> 2] = i3;
  __ZNSt3__216__copy_unalignedINS_6vectorIbNS_9allocatorIbEEEELb0EEENS_14__bit_iteratorIT_Lb0EXLi0EEEENS5_IS6_XT0_EXLi0EEEES8_S7_(i13, i10, i11, i12);
 }
 STACKTOP = i15;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE25__emplace_unique_key_argsIjJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSK_IJEEEEEENS_4pairINS_15__tree_iteratorIS9_PNS_11__tree_nodeIS9_PvEEiEEbEERKT_DpOT0_(i9, i8, i1, i3, i4, i5) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i2 = 0, i6 = 0, i7 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i10 + 12 | 0;
 i6 = i10;
 i2 = __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESL_RKT_(i8, i7, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSK_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS9_PvEENS_22__tree_node_destructorINS6_ISS_EEEEEEDpOT_(i6, i8, i3, i4, i5);
  i1 = HEAP32[i6 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSJ_SJ_(i8, HEAP32[i7 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i9 >> 2] = i1;
 HEAP8[i9 + 4 >> 0] = i2;
 STACKTOP = i10;
 return;
}

function __ZN4wasm13WasmValidator13shouldBeEqualIPNS_4HostEjEEbT0_S4_T_PKc(i6, i3, i4, i2, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 if ((i3 | 0) == (i4 | 0)) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 67717) | 0, i3) | 0, 19430) | 0, i4) | 0, 19435) | 0, i5) | 0, 19438) | 0, 0) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNSt3__29remove_ifINS_11__wrap_iterIPNS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS4_EEEEEEZNS3_28DuplicateFunctionElimination3runEPNS3_10PassRunnerEPNS3_6ModuleEEUlRKS7_E_EET_SI_SI_T0_(i5, i6, i7) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0;
 i4 = HEAP32[i6 >> 2] | 0;
 i1 = HEAP32[i5 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i4 | 0)) {
   i2 = 3;
   break;
  }
  if (__ZZN4wasm28DuplicateFunctionElimination3runEPNS_10PassRunnerEPNS_6ModuleEENKUlRKNSt3__210unique_ptrINS_8FunctionENS5_14default_deleteIS7_EEEEE_clESC_(i7, i1) | 0) {
   i3 = i1;
   i2 = 6;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 L5 : do if ((i2 | 0) == 3) {
  HEAP32[i5 >> 2] = i4;
  i1 = i4;
 } else if ((i2 | 0) == 6) {
  HEAP32[i5 >> 2] = i3;
  if ((i3 | 0) == (i4 | 0)) i1 = i4; else {
   i1 = i3;
   i2 = i3;
   while (1) {
    while (1) {
     i2 = i2 + 4 | 0;
     if ((i2 | 0) == (i4 | 0)) break L5;
     if (!(__ZZN4wasm28DuplicateFunctionElimination3runEPNS_10PassRunnerEPNS_6ModuleEENKUlRKNSt3__210unique_ptrINS_8FunctionENS5_14default_deleteIS7_EEEEE_clESC_(i7, i2) | 0)) {
      i3 = i2;
      break;
     }
    }
    i4 = HEAP32[i3 >> 2] | 0;
    HEAP32[i3 >> 2] = 0;
    i2 = HEAP32[i1 >> 2] | 0;
    HEAP32[i1 >> 2] = i4;
    if (i2 | 0) {
     __ZN4wasm8FunctionD2Ev(i2);
     __ZdlPv(i2);
    }
    i1 = (HEAP32[i5 >> 2] | 0) + 4 | 0;
    HEAP32[i5 >> 2] = i1;
    i4 = HEAP32[i6 >> 2] | 0;
    i2 = i3;
   }
  }
 } while (0);
 return i1 | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i11, i1) {
 i11 = i11 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 if (i1 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i11);
 i9 = i11 + 11 | 0;
 i5 = HEAP8[i9 >> 0] | 0;
 i3 = i5 << 24 >> 24 < 0;
 if (i3) {
  i10 = HEAP32[i11 + 4 >> 2] | 0;
  i2 = (HEAP32[i11 + 8 >> 2] & 2147483647) + -1 | 0;
 } else {
  i10 = i5 & 255;
  i2 = 10;
 }
 i1 = i10 >>> 0 > i1 >>> 0 ? i10 : i1;
 if (i1 >>> 0 < 11) i8 = 10; else i8 = (i1 + 16 & -16) + -1 | 0;
 do if ((i8 | 0) != (i2 | 0)) {
  do if ((i8 | 0) == 10) {
   i2 = HEAP32[i11 >> 2] | 0;
   if (i3) {
    i1 = i11;
    i3 = 0;
    i7 = 14;
   } else {
    i1 = i11;
    i3 = 0;
    i4 = 1;
    i7 = 15;
   }
  } else {
   i1 = __Znwj(i8 + 1 | 0) | 0;
   if (i3) {
    i3 = 1;
    i2 = HEAP32[i11 >> 2] | 0;
    i7 = 14;
    break;
   } else {
    i3 = 1;
    i2 = i11;
    i4 = 0;
    i7 = 15;
    break;
   }
  } while (0);
  if ((i7 | 0) == 14) {
   i6 = HEAP32[i11 + 4 >> 2] | 0;
   i5 = i2;
   i4 = 1;
  } else if ((i7 | 0) == 15) {
   i6 = i5 & 255;
   i5 = i2;
  }
  i2 = i6 + 1 | 0;
  if (i2 | 0) _memcpy(i1 | 0, i5 | 0, i2 | 0) | 0;
  if (i4) __ZdlPv(i5);
  if (i3) {
   HEAP32[i11 + 8 >> 2] = i8 + 1 | -2147483648;
   HEAP32[i11 + 4 >> 2] = i10;
   HEAP32[i11 >> 2] = i1;
   break;
  } else {
   HEAP8[i9 >> 0] = i10;
   break;
  }
 } while (0);
 return;
}

function __ZNSt3__27__sort5IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_SL_SL_T_(i7, i8, i6, i5, i4, i1) {
 i7 = i7 | 0;
 i8 = i8 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __ZNSt3__27__sort4IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_SL_T_(i7, i8, i6, i5, i1) | 0;
 i2 = HEAP32[i4 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 if (+HEAPF64[i2 + 16 >> 3] > +HEAPF64[i3 + 16 >> 3]) {
  HEAP32[i5 >> 2] = i2;
  HEAP32[i4 >> 2] = i3;
  i2 = i1 + 1 | 0;
  i3 = HEAP32[i5 >> 2] | 0;
  i4 = HEAP32[i6 >> 2] | 0;
  if (+HEAPF64[i3 + 16 >> 3] > +HEAPF64[i4 + 16 >> 3]) {
   HEAP32[i6 >> 2] = i3;
   HEAP32[i5 >> 2] = i4;
   i2 = i1 + 2 | 0;
   i3 = HEAP32[i6 >> 2] | 0;
   i4 = HEAP32[i8 >> 2] | 0;
   if (+HEAPF64[i3 + 16 >> 3] > +HEAPF64[i4 + 16 >> 3]) {
    HEAP32[i8 >> 2] = i3;
    HEAP32[i6 >> 2] = i4;
    i2 = HEAP32[i8 >> 2] | 0;
    i3 = HEAP32[i7 >> 2] | 0;
    if (+HEAPF64[i2 + 16 >> 3] > +HEAPF64[i3 + 16 >> 3]) {
     HEAP32[i7 >> 2] = i2;
     HEAP32[i8 >> 2] = i3;
     i1 = i1 + 4 | 0;
    } else i1 = i1 + 3 | 0;
   } else i1 = i2;
  } else i1 = i2;
 }
 return i1 | 0;
}

function __ZN4wasm16PrintSExpression9visitHostEPNS_4HostE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i2 = i5;
 switch (HEAP32[i3 + 8 >> 2] | 0) {
 case 0:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i4 >> 2] | 0, 36089, 0) | 0, 41) | 0;
   break;
  }
 case 1:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i4 >> 2] | 0, 36098, 0) | 0, 41) | 0;
   break;
  }
 case 2:
  {
   __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i4 >> 2] | 0, 36113, 0) | 0;
   __ZN4wasm16PrintSExpression9incIndentEv(i4);
   i3 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3 + 16 | 0, 0) | 0;
   __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i4, HEAP32[i3 >> 2] | 0);
   __ZN4wasm16PrintSExpression9decIndentEv(i4);
   break;
  }
 case 3:
  {
   i4 = __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i4 >> 2] | 0, 36125, 0) | 0;
   HEAP32[i2 >> 2] = HEAP32[i3 + 12 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i4, i1) | 0, 41) | 0;
   break;
  }
 default:
  _abort();
 }
 STACKTOP = i5;
 return;
}

function __ZNSt3__26vectorINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE21__push_back_slow_pathISC_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = (((HEAP32[i3 >> 2] | 0) - i4 | 0) / 12 | 0) + 1 | 0;
 if (i2 >>> 0 > 357913941) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = ((HEAP32[i7 + 8 >> 2] | 0) - i4 | 0) / 12 | 0;
 if (i1 >>> 0 < 178956970) {
  i1 = i1 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 357913941;
 __ZNSt3__214__split_bufferINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEERNS7_ISC_EEEC2EjjSE_(i5, i1, ((HEAP32[i3 >> 2] | 0) - i4 | 0) / 12 | 0, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEEC2EOSC_(i3, i6);
 HEAP32[i4 >> 2] = i3 + 12;
 __ZNSt3__26vectorINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE26__swap_out_circular_bufferERNS_14__split_bufferISC_RSD_EE(i7, i5);
 __ZNSt3__214__split_bufferINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEERNS7_ISC_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__29to_stringEj(i7, i5) {
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i9;
 i8 = i9 + 4 | 0;
 HEAP32[i8 >> 2] = 0;
 HEAP32[i8 + 4 >> 2] = 0;
 HEAP32[i8 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i8 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i4 = i8 + 11 | 0;
 if ((HEAP8[i4 >> 0] | 0) < 0) i1 = (HEAP32[i8 + 8 >> 2] & 2147483647) + -1 | 0; else i1 = 10;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i8, i1, 0);
 i3 = HEAP8[i4 >> 0] | 0;
 i2 = i3;
 i3 = i3 << 24 >> 24 < 0 ? HEAP32[i8 + 4 >> 2] | 0 : i3 & 255;
 while (1) {
  i1 = i2 << 24 >> 24 < 0 ? HEAP32[i8 >> 2] | 0 : i8;
  HEAP32[i6 >> 2] = i5;
  i1 = _snprintf(i1, i3 + 1 | 0, 55960, i6) | 0;
  if ((i1 | 0) > -1) {
   if (i1 >>> 0 <= i3 >>> 0) break;
  } else i1 = i3 << 1 | 1;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i8, i1, 0);
  i2 = HEAP8[i4 >> 0] | 0;
  i3 = i1;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i8, i1, 0);
 HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
 HEAP32[i7 + 4 >> 2] = HEAP32[i8 + 4 >> 2];
 HEAP32[i7 + 8 >> 2] = HEAP32[i8 + 8 >> 2];
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i8 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i8);
 STACKTOP = i9;
 return;
}

function __ZN4wasm16PrintSExpression11visitSwitchEPNS_6SwitchE(i8, i7) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i10 = 0, i11 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i9 + 8 | 0;
 i2 = i9 + 4 | 0;
 i3 = i9;
 __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i8 >> 2] | 0, 34699, 0) | 0;
 i4 = i7 + 8 | 0;
 i5 = HEAP32[i7 + 16 >> 2] | 0;
 i6 = 0;
 while (1) {
  if ((i6 | 0) == (i5 | 0)) break;
  i11 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i4, i6) | 0;
  i10 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i8 >> 2] | 0, 58055) | 0;
  HEAP32[i2 >> 2] = HEAP32[i11 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i10, i1) | 0;
  i6 = i6 + 1 | 0;
 }
 i11 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i8 >> 2] | 0, 58055) | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 + 24 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i11, i1) | 0;
 __ZN4wasm16PrintSExpression9incIndentEv(i8);
 i1 = HEAP32[i7 + 32 >> 2] | 0;
 if (i1 | 0 ? (HEAP32[i1 >> 2] | 0) != 19 : 0) __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i8, i1);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i8, HEAP32[i7 + 28 >> 2] | 0);
 __ZN4wasm16PrintSExpression9decIndentEv(i8);
 STACKTOP = i9;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_118parse_template_argINS0_2DbEEEPKcS4_S4_RT_(i1, i4, i3) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i2 = 0, i5 = 0;
 L1 : do if ((i1 | 0) != (i4 | 0)) switch (HEAP8[i1 >> 0] | 0) {
 case 88:
  {
   i5 = i1 + 1 | 0;
   i2 = __ZN10__cxxabiv112_GLOBAL__N_116parse_expressionINS0_2DbEEEPKcS4_S4_RT_(i5, i4, i3) | 0;
   if ((i2 | 0) == (i5 | 0) | (i2 | 0) == (i4 | 0)) break L1;
   i1 = (HEAP8[i2 >> 0] | 0) == 69 ? i2 + 1 | 0 : i1;
   break L1;
  }
 case 74:
  {
   i2 = i1 + 1 | 0;
   if ((i2 | 0) == (i4 | 0)) break L1;
   while (1) {
    if ((HEAP8[i2 >> 0] | 0) == 69) {
     i1 = i2;
     break;
    }
    i5 = i2;
    i2 = __ZN10__cxxabiv112_GLOBAL__N_118parse_template_argINS0_2DbEEEPKcS4_S4_RT_(i2, i4, i3) | 0;
    if ((i2 | 0) == (i5 | 0)) break L1;
   }
   i1 = i1 + 1 | 0;
   break L1;
  }
 case 76:
  {
   i5 = i1 + 1 | 0;
   if ((i5 | 0) != (i4 | 0) ? (HEAP8[i5 >> 0] | 0) == 90 : 0) {
    i5 = i1 + 2 | 0;
    i2 = __ZN10__cxxabiv112_GLOBAL__N_114parse_encodingINS0_2DbEEEPKcS4_S4_RT_(i5, i4, i3) | 0;
    if ((i2 | 0) == (i5 | 0) | (i2 | 0) == (i4 | 0)) break L1;
    i1 = (HEAP8[i2 >> 0] | 0) == 69 ? i2 + 1 | 0 : i1;
    break L1;
   }
   i1 = __ZN10__cxxabiv112_GLOBAL__N_118parse_expr_primaryINS0_2DbEEEPKcS4_S4_RT_(i1, i4, i3) | 0;
   break L1;
  }
 default:
  {
   i1 = __ZN10__cxxabiv112_GLOBAL__N_110parse_typeINS0_2DbEEEPKcS4_S4_RT_(i1, i4, i3) | 0;
   break L1;
  }
 } while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorINS0_IPPN4wasm10ExpressionENS_9allocatorIS4_EEEENS5_IS7_EEE21__push_back_slow_pathIS7_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = (((HEAP32[i3 >> 2] | 0) - i4 | 0) / 12 | 0) + 1 | 0;
 if (i2 >>> 0 > 357913941) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = ((HEAP32[i7 + 8 >> 2] | 0) - i4 | 0) / 12 | 0;
 if (i1 >>> 0 < 178956970) {
  i1 = i1 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 357913941;
 __ZNSt3__214__split_bufferINS_6vectorIPPN4wasm10ExpressionENS_9allocatorIS5_EEEERNS6_IS8_EEEC2EjjSA_(i5, i1, ((HEAP32[i3 >> 2] | 0) - i4 | 0) / 12 | 0, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = 0;
 i1 = i3 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 i2 = i6 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
 i1 = i6 + 8 | 0;
 HEAP32[i3 + 8 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i1 >> 2] = 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i4 >> 2] = i3 + 12;
 __ZNSt3__26vectorINS0_IPPN4wasm10ExpressionENS_9allocatorIS4_EEEENS5_IS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS8_EE(i7, i5);
 __ZNSt3__214__split_bufferINS_6vectorIPPN4wasm10ExpressionENS_9allocatorIS5_EEEERNS6_IS8_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__214__copy_alignedINS_6vectorIbNS_9allocatorIbEEEELb0EEENS_14__bit_iteratorIT_Lb0EXLi0EEEENS5_IS6_XT0_EXLi0EEEES8_S7_(i8, i4, i1, i7) {
 i8 = i8 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0, i9 = 0;
 i2 = HEAP32[i4 >> 2] | 0;
 i3 = HEAP32[i4 + 4 >> 2] | 0;
 i5 = ((HEAP32[i1 >> 2] | 0) - i2 << 3) + (HEAP32[i1 + 4 >> 2] | 0) - i3 | 0;
 i1 = i2;
 if ((i5 | 0) > 0) {
  if (!i3) {
   i6 = i7;
   i1 = i5;
  } else {
   i2 = 32 - i3 | 0;
   i9 = (i5 | 0) < (i2 | 0) ? i5 : i2;
   i2 = -1 >>> (i2 - i9 | 0) & -1 << i3;
   i3 = HEAP32[i7 >> 2] | 0;
   HEAP32[i3 >> 2] = HEAP32[i3 >> 2] & ~i2 | HEAP32[i1 >> 2] & i2;
   i2 = i7 + 4 | 0;
   i6 = (HEAP32[i2 >> 2] | 0) + i9 | 0;
   HEAP32[i7 >> 2] = i3 + (i6 >>> 5 << 2);
   HEAP32[i2 >> 2] = i6 & 31;
   i2 = (HEAP32[i4 >> 2] | 0) + 4 | 0;
   HEAP32[i4 >> 2] = i2;
   i6 = i7;
   i1 = i5 - i9 | 0;
  }
  i3 = i1 >>> 5;
  _memmove(HEAP32[i7 >> 2] | 0, i2 | 0, i3 << 2 | 0) | 0;
  i2 = i1 - (i3 << 5) | 0;
  i1 = (HEAP32[i6 >> 2] | 0) + (i3 << 2) | 0;
  HEAP32[i6 >> 2] = i1;
  if ((i2 | 0) > 0) {
   i5 = (HEAP32[i4 >> 2] | 0) + (i3 << 2) | 0;
   HEAP32[i4 >> 2] = i5;
   i9 = -1 >>> (32 - i2 | 0);
   i1 = HEAP32[i6 >> 2] | 0;
   HEAP32[i1 >> 2] = HEAP32[i1 >> 2] & ~i9 | HEAP32[i5 >> 2] & i9;
   HEAP32[i7 + 4 >> 2] = i2;
  }
 } else i1 = HEAP32[i7 >> 2] | 0;
 HEAP32[i8 >> 2] = i1;
 HEAP32[i8 + 4 >> 2] = HEAP32[i7 + 4 >> 2];
 return;
}

function __ZN4wasm14FunctionHasher14doWalkFunctionEPNS_8FunctionE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i7;
 HEAP32[i3 >> 2] = i5;
 i4 = i6 + 32 | 0;
 if (HEAP32[i4 >> 2] | 0) ___assert_fail(45343, 45355, 43, 46573);
 i1 = i5 + 12 | 0;
 __ZN4wasm14FunctionHasher4hashEj(i6, (HEAP32[i1 >> 2] | 0) - (HEAP32[i5 + 8 >> 2] | 0) >> 2);
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = HEAP32[i5 + 8 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __ZN4wasm14FunctionHasher4hashEj(i6, HEAP32[i2 >> 2] | 0);
  i2 = i2 + 4 | 0;
 }
 i1 = i5 + 24 | 0;
 __ZN4wasm14FunctionHasher4hashEj(i6, (HEAP32[i1 >> 2] | 0) - (HEAP32[i5 + 20 >> 2] | 0) >> 2);
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = HEAP32[i5 + 20 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __ZN4wasm14FunctionHasher4hashEj(i6, HEAP32[i2 >> 2] | 0);
  i2 = i2 + 4 | 0;
 }
 __ZN4wasm14FunctionHasher4hashEj(i6, HEAP32[i5 + 4 >> 2] | 0);
 i1 = HEAP32[i5 + 32 >> 2] | 0;
 i2 = (i1 | 0) == 0;
 __ZN4wasm14FunctionHasher6hash64Ey(i6, i2 ? 0 : i1, i2 ? 0 : 0);
 __ZN4wasm14FunctionHasher4hashEj(i6, __ZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionE(HEAP32[i5 + 36 >> 2] | 0) | 0);
 i5 = HEAP32[i4 >> 2] | 0;
 i6 = __ZNSt3__23mapIPN4wasm8FunctionEjNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_jEEEEE2atERS8_(HEAP32[i6 + 28 >> 2] | 0, i3) | 0;
 HEAP32[i6 >> 2] = i5;
 STACKTOP = i7;
 return;
}

function __ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j(i8, i10, i1) {
 i8 = i8 | 0;
 i10 = i10 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i11 + 12 | 0;
 i9 = i11;
 i5 = i11 + 8 | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i9, i8);
 if (HEAP8[i9 >> 0] | 0) {
  i7 = i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0;
  HEAP32[i5 >> 2] = HEAP32[i7 + 24 >> 2];
  i6 = HEAP32[i7 + 4 >> 2] | 0;
  i3 = i10 + i1 | 0;
  i2 = i7 + 76 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == -1) {
   i1 = __ZNKSt3__28ios_base6getlocEv(i7) | 0;
   HEAP32[i4 >> 2] = i1;
   i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i4, 61680) | 0;
   i1 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 63](i1, 32) | 0;
   __ZNSt3__26localeD2Ev(i4);
   i1 = i1 << 24 >> 24;
   HEAP32[i2 >> 2] = i1;
  }
  HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
  if (!(__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_(i4, i10, (i6 & 176 | 0) == 32 ? i3 : i10, i3, i7, i1 & 255) | 0)) {
   i10 = i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0;
   __ZNSt3__28ios_base5clearEj(i10, HEAP32[i10 + 16 >> 2] | 5);
  }
 }
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i9);
 STACKTOP = i11;
 return i8 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_115parse_simple_idINS0_2DbEEEPKcS4_S4_RT_(i4, i2, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i8;
 if ((i4 | 0) != (i2 | 0) ? (i1 = __ZN10__cxxabiv112_GLOBAL__N_117parse_source_nameINS0_2DbEEEPKcS4_S4_RT_(i4, i2, i3) | 0, (i1 | 0) != (i4 | 0)) : 0) {
  i6 = __ZN10__cxxabiv112_GLOBAL__N_119parse_template_argsINS0_2DbEEEPKcS4_S4_RT_(i1, i2, i3) | 0;
  if ((i6 | 0) != (i1 | 0)) {
   i5 = i3 + 4 | 0;
   i1 = HEAP32[i5 >> 2] | 0;
   if (((i1 - (HEAP32[i3 >> 2] | 0) | 0) / 24 | 0) >>> 0 < 2) i1 = i4; else {
    __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i7, i1 + -24 | 0);
    i1 = HEAP32[i5 >> 2] | 0;
    i2 = i1 + -24 | 0;
    i3 = i1;
    while (1) {
     if ((i3 | 0) == (i2 | 0)) break;
     i4 = i3 + -24 | 0;
     HEAP32[i5 >> 2] = i4;
     __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i4);
     i3 = HEAP32[i5 >> 2] | 0;
    }
    i5 = HEAP8[i7 + 11 >> 0] | 0;
    i4 = i5 << 24 >> 24 < 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1 + -48 | 0, i4 ? HEAP32[i7 >> 2] | 0 : i7, i4 ? HEAP32[i7 + 4 >> 2] | 0 : i5 & 255) | 0;
    __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i7);
    i1 = i6;
   }
  }
 } else i1 = i4;
 STACKTOP = i8;
 return i1 | 0;
}

function __ZNSt3__210__stdinbufIwE9pbackfailEj(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9 + 16 | 0;
 i6 = i9 + 8 | 0;
 i3 = i9 + 4 | 0;
 i4 = i9;
 i8 = i5 + 52 | 0;
 i2 = (HEAP8[i8 >> 0] | 0) != 0;
 L1 : do if ((i1 | 0) == -1) if (i2) i1 = -1; else {
  i1 = HEAP32[i5 + 48 >> 2] | 0;
  HEAP8[i8 >> 0] = (i1 | 0) != -1 & 1;
 } else {
  do if (i2) {
   i2 = i5 + 48 | 0;
   HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
   i10 = HEAP32[i5 + 36 >> 2] | 0;
   switch (FUNCTION_TABLE_iiiiiiiii[HEAP32[(HEAP32[i10 >> 2] | 0) + 12 >> 2] & 15](i10, HEAP32[i5 + 40 >> 2] | 0, i3, i3 + 4 | 0, i4, i7, i7 + 8 | 0, i6) | 0) {
   case 1:
   case 2:
    {
     i1 = -1;
     break L1;
    }
   case 3:
    {
     HEAP8[i7 >> 0] = HEAP32[i2 >> 2];
     HEAP32[i6 >> 2] = i7 + 1;
     break;
    }
   default:
    {}
   }
   i3 = i5 + 32 | 0;
   while (1) {
    i4 = HEAP32[i6 >> 2] | 0;
    if (i4 >>> 0 <= i7 >>> 0) {
     i3 = 13;
     break;
    }
    i10 = i4 + -1 | 0;
    HEAP32[i6 >> 2] = i10;
    if ((_ungetc(HEAP8[i10 >> 0] | 0, HEAP32[i3 >> 2] | 0) | 0) == -1) {
     i3 = 12;
     break;
    }
   }
   if ((i3 | 0) == 12) {
    i1 = -1;
    break L1;
   } else if ((i3 | 0) == 13) break;
  } else i2 = i5 + 48 | 0; while (0);
  HEAP32[i2 >> 2] = i1;
  HEAP8[i8 >> 0] = 1;
 } while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNKSt3__28messagesIcE6do_getEiiiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE(i8, i1, i3, i5, i4, i2) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i6 = 0, i7 = 0, i9 = 0, i10 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i7;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i6 + 4 >> 2] = 0;
 HEAP32[i6 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i6 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i9 = HEAP8[i2 + 11 >> 0] | 0;
 i10 = i9 << 24 >> 24 < 0;
 i1 = i10 ? HEAP32[i2 >> 2] | 0 : i2;
 i2 = i1 + (i10 ? HEAP32[i2 + 4 >> 2] | 0 : i9 & 255) | 0;
 while (1) {
  if (i1 >>> 0 >= i2 >>> 0) break;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i6, HEAP8[i1 >> 0] | 0);
  i1 = i1 + 1 | 0;
 }
 i1 = _catgets((i3 | 0) == -1 ? -1 : i3 << 1, i5, i4, (HEAP8[i6 + 11 >> 0] | 0) < 0 ? HEAP32[i6 >> 2] | 0 : i6) | 0;
 HEAP32[i8 >> 2] = 0;
 HEAP32[i8 + 4 >> 2] = 0;
 HEAP32[i8 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i8 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 i2 = i1 + (_strlen(i1) | 0) | 0;
 while (1) {
  if (i1 >>> 0 >= i2 >>> 0) break;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i8, HEAP8[i1 >> 0] | 0);
  i1 = i1 + 1 | 0;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i6);
 STACKTOP = i7;
 return;
}

function __ZNSt3__210__stdinbufIcE9pbackfailEi(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9 + 16 | 0;
 i6 = i9 + 4 | 0;
 i3 = i9 + 8 | 0;
 i4 = i9;
 i8 = i5 + 52 | 0;
 i2 = (HEAP8[i8 >> 0] | 0) != 0;
 L1 : do if ((i1 | 0) == -1) if (i2) i1 = -1; else {
  i1 = HEAP32[i5 + 48 >> 2] | 0;
  HEAP8[i8 >> 0] = (i1 | 0) != -1 & 1;
 } else {
  do if (i2) {
   i2 = i5 + 48 | 0;
   HEAP8[i3 >> 0] = HEAP32[i2 >> 2];
   i10 = HEAP32[i5 + 36 >> 2] | 0;
   switch (FUNCTION_TABLE_iiiiiiiii[HEAP32[(HEAP32[i10 >> 2] | 0) + 12 >> 2] & 15](i10, HEAP32[i5 + 40 >> 2] | 0, i3, i3 + 1 | 0, i4, i7, i7 + 8 | 0, i6) | 0) {
   case 1:
   case 2:
    {
     i1 = -1;
     break L1;
    }
   case 3:
    {
     HEAP8[i7 >> 0] = HEAP32[i2 >> 2];
     HEAP32[i6 >> 2] = i7 + 1;
     break;
    }
   default:
    {}
   }
   i3 = i5 + 32 | 0;
   while (1) {
    i4 = HEAP32[i6 >> 2] | 0;
    if (i4 >>> 0 <= i7 >>> 0) {
     i3 = 13;
     break;
    }
    i10 = i4 + -1 | 0;
    HEAP32[i6 >> 2] = i10;
    if ((_ungetc(HEAP8[i10 >> 0] | 0, HEAP32[i3 >> 2] | 0) | 0) == -1) {
     i3 = 12;
     break;
    }
   }
   if ((i3 | 0) == 12) {
    i1 = -1;
    break L1;
   } else if ((i3 | 0) == 13) break;
  } else i2 = i5 + 48 | 0; while (0);
  HEAP32[i2 >> 2] = i1;
  HEAP8[i8 >> 0] = 1;
 } while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNSt3__27__sort5IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_S8_S8_T_(i5, i6, i7, i3, i2, i4) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i8 = 0;
 i1 = __ZNSt3__27__sort4IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_S8_T_(i5, i6, i7, i3, i4) | 0;
 if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i4, HEAP32[i2 >> 2] | 0, HEAP32[i3 >> 2] | 0) | 0) {
  i8 = HEAP32[i3 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i2 >> 2] = i8;
  i2 = i1 + 1 | 0;
  if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i4, HEAP32[i3 >> 2] | 0, HEAP32[i7 >> 2] | 0) | 0) {
   i2 = HEAP32[i7 >> 2] | 0;
   HEAP32[i7 >> 2] = HEAP32[i3 >> 2];
   HEAP32[i3 >> 2] = i2;
   i2 = i1 + 2 | 0;
   if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i4, HEAP32[i7 >> 2] | 0, HEAP32[i6 >> 2] | 0) | 0) {
    i8 = HEAP32[i6 >> 2] | 0;
    HEAP32[i6 >> 2] = HEAP32[i7 >> 2];
    HEAP32[i7 >> 2] = i8;
    if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i4, HEAP32[i6 >> 2] | 0, HEAP32[i5 >> 2] | 0) | 0) {
     i8 = HEAP32[i5 >> 2] | 0;
     HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
     HEAP32[i6 >> 2] = i8;
     i1 = i1 + 4 | 0;
    } else i1 = i1 + 3 | 0;
   } else i1 = i2;
  } else i1 = i2;
 }
 return i1 | 0;
}

function __ZN4wasm14ModuleInstance15getFinalAddressINS_5StoreEEENS_7AddressEPT_NS_7LiteralE(i2, i4, i1) {
 i2 = i2 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i3 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i7 + 4 | 0;
 i6 = i7 + 8 | 0;
 i5 = i7;
 HEAP32[i6 >> 2] = i2;
 __ZN4wasm7AddressC2Ey(i5, HEAP32[i2 + 20 >> 2] << 16, 0);
 if ((HEAP32[i1 >> 2] | 0) == 1) {
  i2 = __ZNK4wasm7Literal6geti32Ev(i1) | 0;
  i1 = i2;
  i2 = ((i2 | 0) < 0) << 31 >> 31;
 } else {
  i1 = __ZNK4wasm7Literal6geti64Ev(i1) | 0;
  i2 = tempRet0;
 }
 i9 = i4 + 12 | 0;
 i8 = HEAP32[i5 >> 2] | 0;
 __ZZN4wasm14ModuleInstance15getFinalAddressINS_5StoreEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i6, HEAP32[i9 >> 2] | 0, 0, i8, 0, 28385);
 __ZZN4wasm14ModuleInstance15getFinalAddressINS_5StoreEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i6, i1, i2, i8 - (HEAP32[i9 >> 2] | 0) | 0, 0, 28401);
 i2 = _i64Add(HEAP32[i9 >> 2] | 0, 0, i1 | 0, i2 | 0) | 0;
 i5 = tempRet0;
 i4 = i4 + 8 | 0;
 __ZZN4wasm14ModuleInstance15getFinalAddressINS_5StoreEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i6, HEAPU8[i4 >> 0] | 0, 0, i8, 0, 28416);
 __ZZN4wasm14ModuleInstance15getFinalAddressINS_5StoreEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i6, i2, i5, i8 - (HEAPU8[i4 >> 0] | 0) | 0, 0, 28431);
 __ZN4wasm7AddressC2Ey(i3, i2, i5);
 STACKTOP = i7;
 return HEAP32[i3 >> 2] | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS3_JRS3_S6_EEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i7, i6, i1, i3, i4) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i2 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i6, i5, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(40) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[i3 >> 2];
  i3 = i1 + 20 | 0;
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i3 + 4 >> 2] = HEAP32[i4 + 4 >> 2];
  HEAP32[i3 + 8 >> 2] = HEAP32[i4 + 8 >> 2];
  HEAP32[i3 + 12 >> 2] = HEAP32[i4 + 12 >> 2];
  HEAP32[i3 + 16 >> 2] = HEAP32[i4 + 16 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i6, HEAP32[i5 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i7 >> 2] = i1;
 HEAP8[i7 + 4 >> 0] = i2;
 STACKTOP = i8;
 return;
}

function __ZN4wasm19DeadCodeElimination10handleCallINS_12CallIndirectEEEvPT_PNS_10ExpressionE(i8, i1, i6) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i7 = i1 + 8 | 0;
 i1 = i1 + 16 | 0;
 i2 = 0;
 while (1) {
  if (i2 >>> 0 >= (HEAP32[i1 >> 2] | 0) >>> 0) break;
  i5 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, i2) | 0;
  i5 = HEAP32[i5 >> 2] | 0;
  if (i5 | 0 ? (HEAP32[i5 >> 2] | 0) == 20 : 0) {
   i3 = 5;
   break;
  }
  i2 = i2 + 1 | 0;
 }
 do if ((i3 | 0) == 5) {
  i1 = (i6 | 0) != 0;
  if (!(i1 | (i2 | 0) != 0)) {
   i7 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 0) | 0;
   HEAP32[i8 + 20 >> 2] = HEAP32[i7 >> 2];
   break;
  }
  i4 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v((HEAP32[i8 + 40 >> 2] | 0) + 88 | 0) | 0;
  i5 = i1 & 1;
  i2 = (i1 ? 2 : 1) + i2 | 0;
  i3 = i4 + 12 | 0;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i3, i2);
  if (i1) {
   i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, 0) | 0;
   HEAP32[i1 >> 2] = i6;
   i1 = 1;
  } else i1 = 0;
  while (1) {
   if (i1 >>> 0 >= i2 >>> 0) break;
   i9 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, i1 - i5 | 0) | 0;
   i9 = HEAP32[i9 >> 2] | 0;
   i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, i1) | 0;
   HEAP32[i6 >> 2] = i9;
   i1 = i1 + 1 | 0;
  }
  __ZN4wasm5Block8finalizeEv(i4);
  HEAP32[i8 + 20 >> 2] = i4;
 } while (0);
 return;
}

function __ZN4wasm19DeadCodeElimination10handleCallINS_10CallImportEEEvPT_PNS_10ExpressionE(i8, i1, i6) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i7 = i1 + 8 | 0;
 i1 = i1 + 16 | 0;
 i2 = 0;
 while (1) {
  if (i2 >>> 0 >= (HEAP32[i1 >> 2] | 0) >>> 0) break;
  i5 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, i2) | 0;
  i5 = HEAP32[i5 >> 2] | 0;
  if (i5 | 0 ? (HEAP32[i5 >> 2] | 0) == 20 : 0) {
   i3 = 5;
   break;
  }
  i2 = i2 + 1 | 0;
 }
 do if ((i3 | 0) == 5) {
  i1 = (i6 | 0) != 0;
  if (!(i1 | (i2 | 0) != 0)) {
   i7 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 0) | 0;
   HEAP32[i8 + 20 >> 2] = HEAP32[i7 >> 2];
   break;
  }
  i4 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v((HEAP32[i8 + 40 >> 2] | 0) + 88 | 0) | 0;
  i5 = i1 & 1;
  i2 = (i1 ? 2 : 1) + i2 | 0;
  i3 = i4 + 12 | 0;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i3, i2);
  if (i1) {
   i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, 0) | 0;
   HEAP32[i1 >> 2] = i6;
   i1 = 1;
  } else i1 = 0;
  while (1) {
   if (i1 >>> 0 >= i2 >>> 0) break;
   i9 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, i1 - i5 | 0) | 0;
   i9 = HEAP32[i9 >> 2] | 0;
   i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, i1) | 0;
   HEAP32[i6 >> 2] = i9;
   i1 = i1 + 1 | 0;
  }
  __ZN4wasm5Block8finalizeEv(i4);
  HEAP32[i8 + 20 >> 2] = i4;
 } while (0);
 return;
}

function __ZN4wasm14ModuleInstance15getFinalAddressINS_4LoadEEENS_7AddressEPT_NS_7LiteralE(i2, i4, i1) {
 i2 = i2 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i3 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i7 + 4 | 0;
 i6 = i7 + 8 | 0;
 i5 = i7;
 HEAP32[i6 >> 2] = i2;
 __ZN4wasm7AddressC2Ey(i5, HEAP32[i2 + 20 >> 2] << 16, 0);
 if ((HEAP32[i1 >> 2] | 0) == 1) {
  i2 = __ZNK4wasm7Literal6geti32Ev(i1) | 0;
  i1 = i2;
  i2 = ((i2 | 0) < 0) << 31 >> 31;
 } else {
  i1 = __ZNK4wasm7Literal6geti64Ev(i1) | 0;
  i2 = tempRet0;
 }
 i9 = i4 + 12 | 0;
 i8 = HEAP32[i5 >> 2] | 0;
 __ZZN4wasm14ModuleInstance15getFinalAddressINS_4LoadEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i6, HEAP32[i9 >> 2] | 0, 0, i8, 0, 28385);
 __ZZN4wasm14ModuleInstance15getFinalAddressINS_4LoadEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i6, i1, i2, i8 - (HEAP32[i9 >> 2] | 0) | 0, 0, 28401);
 i2 = _i64Add(HEAP32[i9 >> 2] | 0, 0, i1 | 0, i2 | 0) | 0;
 i5 = tempRet0;
 i4 = i4 + 8 | 0;
 __ZZN4wasm14ModuleInstance15getFinalAddressINS_4LoadEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i6, HEAPU8[i4 >> 0] | 0, 0, i8, 0, 28416);
 __ZZN4wasm14ModuleInstance15getFinalAddressINS_4LoadEEENS_7AddressEPT_NS_7LiteralEENKUlyyPKcE_clEyyS8_(i6, i2, i5, i8 - (HEAPU8[i4 >> 0] | 0) | 0, 0, 28431);
 __ZN4wasm7AddressC2Ey(i3, i2, i5);
 STACKTOP = i7;
 return HEAP32[i3 >> 2] | 0;
}

function __ZN4wasm14CoalesceLocals25mergeStartsAndCheckChangeERNSt3__26vectorIPNS_9CFGWalkerIS0_NS_7VisitorIS0_vEENS_8LivenessEE10BasicBlockENS1_9allocatorIS9_EEEERNS_8LocalSetESF_(i1, i6, i7, i8) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i9;
 i5 = i6 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 L1 : do if ((HEAP32[i5 >> 2] | 0) != (i1 | 0)) {
  __ZN4wasm8LocalSetaSERKS0_(i8, HEAP32[i1 >> 2] | 0) | 0;
  i2 = HEAP32[i5 >> 2] | 0;
  i1 = HEAP32[i6 >> 2] | 0;
  L3 : do if (i2 - i1 >> 2 >>> 0 > 1) {
   i3 = 1;
   while (1) {
    if (i3 >>> 0 >= i2 - i1 >> 2 >>> 0) break L3;
    __ZNK4wasm8LocalSet5mergeERKS0_(i4, i8, HEAP32[i1 + (i3 << 2) >> 2] | 0);
    __ZN4wasm8LocalSetaSEOS0_(i8, i4) | 0;
    __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i4);
    i1 = HEAP32[i6 >> 2] | 0;
    i2 = HEAP32[i5 >> 2] | 0;
    i3 = i3 + 1 | 0;
   }
  } while (0);
  i6 = HEAP32[i7 + 4 >> 2] | 0;
  i1 = HEAP32[i7 >> 2] | 0;
  i2 = HEAP32[i8 >> 2] | 0;
  i3 = i6;
  if ((i6 - i1 | 0) == ((HEAP32[i8 + 4 >> 2] | 0) - i2 | 0)) while (1) {
   if ((i1 | 0) == (i3 | 0)) {
    i1 = 0;
    break L1;
   }
   if ((HEAP32[i1 >> 2] | 0) != (HEAP32[i2 >> 2] | 0)) {
    i1 = 1;
    break L1;
   }
   i2 = i2 + 4 | 0;
   i1 = i1 + 4 | 0;
  } else i1 = 1;
 } else i1 = 0; while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZN4wasm19DeadCodeElimination10handleCallINS_4CallEEEvPT_PNS_10ExpressionE(i8, i1, i6) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i7 = i1 + 8 | 0;
 i1 = i1 + 16 | 0;
 i2 = 0;
 while (1) {
  if (i2 >>> 0 >= (HEAP32[i1 >> 2] | 0) >>> 0) break;
  i5 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, i2) | 0;
  i5 = HEAP32[i5 >> 2] | 0;
  if (i5 | 0 ? (HEAP32[i5 >> 2] | 0) == 20 : 0) {
   i3 = 5;
   break;
  }
  i2 = i2 + 1 | 0;
 }
 do if ((i3 | 0) == 5) {
  i1 = (i6 | 0) != 0;
  if (!(i1 | (i2 | 0) != 0)) {
   i7 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 0) | 0;
   HEAP32[i8 + 20 >> 2] = HEAP32[i7 >> 2];
   break;
  }
  i4 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v((HEAP32[i8 + 40 >> 2] | 0) + 88 | 0) | 0;
  i5 = i1 & 1;
  i2 = (i1 ? 2 : 1) + i2 | 0;
  i3 = i4 + 12 | 0;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i3, i2);
  if (i1) {
   i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, 0) | 0;
   HEAP32[i1 >> 2] = i6;
   i1 = 1;
  } else i1 = 0;
  while (1) {
   if (i1 >>> 0 >= i2 >>> 0) break;
   i9 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, i1 - i5 | 0) | 0;
   i9 = HEAP32[i9 >> 2] | 0;
   i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, i1) | 0;
   HEAP32[i6 >> 2] = i9;
   i1 = i1 + 1 | 0;
  }
  __ZN4wasm5Block8finalizeEv(i4);
  HEAP32[i8 + 20 >> 2] = i4;
 } while (0);
 return;
}

function ___stdio_read(i8, i7, i9) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i10 = 0, i11 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i3 = i10 + 16 | 0;
 i2 = i10;
 i1 = i10 + 32 | 0;
 HEAP32[i1 >> 2] = i7;
 i4 = i1 + 4 | 0;
 i6 = i8 + 48 | 0;
 i11 = HEAP32[i6 >> 2] | 0;
 HEAP32[i4 >> 2] = i9 - ((i11 | 0) != 0 & 1);
 i5 = i8 + 44 | 0;
 HEAP32[i1 + 8 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i1 + 12 >> 2] = i11;
 if (!(HEAP32[15018] | 0)) {
  HEAP32[i3 >> 2] = HEAP32[i8 + 60 >> 2];
  HEAP32[i3 + 4 >> 2] = i1;
  HEAP32[i3 + 8 >> 2] = 2;
  i1 = ___syscall_ret(___syscall145(145, i3 | 0) | 0) | 0;
 } else {
  _pthread_cleanup_push(288, i8 | 0);
  HEAP32[i2 >> 2] = HEAP32[i8 + 60 >> 2];
  HEAP32[i2 + 4 >> 2] = i1;
  HEAP32[i2 + 8 >> 2] = 2;
  i1 = ___syscall_ret(___syscall145(145, i2 | 0) | 0) | 0;
  _pthread_cleanup_pop(0);
 }
 if ((i1 | 0) >= 1) {
  i4 = HEAP32[i4 >> 2] | 0;
  if (i1 >>> 0 > i4 >>> 0) {
   i2 = HEAP32[i5 >> 2] | 0;
   i3 = i8 + 4 | 0;
   HEAP32[i3 >> 2] = i2;
   HEAP32[i8 + 8 >> 2] = i2 + (i1 - i4);
   if (!(HEAP32[i6 >> 2] | 0)) i1 = i9; else {
    HEAP32[i3 >> 2] = i2 + 1;
    HEAP8[i7 + (i9 + -1) >> 0] = HEAP8[i2 >> 0] | 0;
    i1 = i9;
   }
  }
 } else {
  HEAP32[i8 >> 2] = HEAP32[i8 >> 2] | i1 & 48 ^ 16;
  HEAP32[i8 + 8 >> 2] = 0;
  HEAP32[i8 + 4 >> 2] = 0;
 }
 STACKTOP = i10;
 return i1 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE23parseElementOrStatementERPcPKc(i4, i7, i3) {
 i4 = i4 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i9 + 4 | 0;
 i6 = i9;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i7);
 i1 = HEAP32[i7 >> 2] | 0;
 L1 : do switch (HEAP8[i1 >> 0] | 0) {
 case 59:
  {
   HEAP32[i7 >> 2] = i1 + 1;
   i1 = __ZN6cashew12ValueBuilder9makeBlockEv() | 0;
   break;
  }
 case 123:
  {
   HEAP32[i7 >> 2] = i1 + 1;
   __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i7);
   i2 = HEAP32[i7 >> 2] | 0;
   if ((HEAP8[i2 >> 0] | 0) == 125) {
    HEAP32[i7 >> 2] = i2 + 1;
    i1 = __ZN6cashew12ValueBuilder9makeBlockEv() | 0;
    break L1;
   } else {
    HEAP32[i7 >> 2] = i1;
    i8 = 6;
    break L1;
   }
  }
 default:
  i8 = 6;
 } while (0);
 if ((i8 | 0) == 6) {
  i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i4, i7, i3) | 0;
  __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i7);
  if ((HEAP8[HEAP32[i7 >> 2] >> 0] | 0) == 59) {
   HEAP32[i6 >> 2] = i1;
   HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
   i1 = __ZN6cashew12ValueBuilder13makeStatementENS_3RefE(i5) | 0;
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 1;
  }
 }
 STACKTOP = i9;
 return i1 | 0;
}

function __ZN4wasm14SimplifyLocals18checkInvalidationsERNS_14EffectAnalyzerE(i1, i7) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i10 = i11 + 4 | 0;
 i9 = i11;
 HEAP32[i10 >> 2] = 0;
 i6 = i10 + 4 | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i10 + 8 >> 2] = 0;
 i8 = i1 + 44 | 0;
 i3 = i1 + 48 | 0;
 i4 = i10 + 8 | 0;
 i5 = HEAP32[i8 >> 2] | 0;
 while (1) {
  if ((i5 | 0) == (i3 | 0)) break;
  do if (__ZN4wasm14EffectAnalyzer11invalidatesERS0_(i7, i5 + 24 | 0) | 0) {
   i1 = i5 + 16 | 0;
   i2 = HEAP32[i6 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i4 >> 2] | 0)) {
    __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIRKjEEvOT_(i10, i1);
    break;
   } else {
    HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i6 >> 2] = i2 + 4;
    break;
   }
  } while (0);
  i5 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i5) | 0;
 }
 i1 = HEAP32[i6 >> 2] | 0;
 i2 = HEAP32[i10 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE14__erase_uniqueIjEEjRKT_(i8, i9) | 0;
  i2 = i2 + 4 | 0;
 }
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i10);
 STACKTOP = i11;
 return;
}

function __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__7clENSt3__212basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i3 = i7 + 36 | 0;
 i4 = i7 + 24 | 0;
 i5 = i7 + 12 | 0;
 i6 = i7;
 __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_S6_(i5, i1, 36);
 i2 = HEAP32[i2 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 __ZNSt3__29to_stringEj(i6, i1);
 i1 = HEAP8[i6 + 11 >> 0] | 0;
 i2 = i1 << 24 >> 24 < 0;
 i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj(i5, i2 ? HEAP32[i6 >> 2] | 0 : i6, i2 ? HEAP32[i6 + 4 >> 2] | 0 : i1 & 255) | 0;
 HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i4 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i4 + 11 >> 0] | 0) < 0 ? HEAP32[i4 >> 2] | 0 : i4, 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i6);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
 STACKTOP = i7;
 return HEAP32[i3 >> 2] | 0;
}

function _instantiate() {
 var i1 = 0, i2 = 0, i3 = 0;
 if (HEAP8[63612] | 0 ? (i2 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17753) | 0, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasm11WasmPrinter11printModuleEPNS_6ModuleERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEE(HEAP32[14814] | 0, i2) | 0, 10) | 0, HEAP8[63612] | 0) : 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17777) | 0;
 _emscripten_asm_const_v(6);
 i2 = HEAP32[14814] | 0;
 i1 = HEAP32[i2 + 28 >> 2] | 0;
 i2 = HEAP32[i2 + 24 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  _emscripten_asm_const_ii(7, HEAP32[HEAP32[i2 >> 2] >> 2] | 0) | 0;
  i2 = i2 + 4 | 0;
 }
 i2 = HEAP32[14814] | 0;
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 i2 = HEAP32[i2 + 12 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  i3 = HEAP32[i2 >> 2] | 0;
  _emscripten_asm_const_iiii(8, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i3 + 8 >> 2] | 0, HEAP32[i3 >> 2] | 0) | 0;
  i2 = i2 + 4 | 0;
 }
 if (HEAP8[63612] | 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 18239) | 0;
 i3 = __Znwj(28) | 0;
 i1 = HEAP32[14814] | 0;
 i2 = __Znwj(4) | 0;
 HEAP32[i2 >> 2] = 4660;
 __ZN4wasm14ModuleInstanceC2ERNS_6ModuleEPNS0_17ExternalInterfaceE(i3, i1, i2);
 HEAP32[14813] = i3;
 _emscripten_asm_const_v(9);
 return;
}

function __ZN4wasm15Asm2WasmBuilder8optimizeEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 96 | 0;
 i4 = i6 + 60 | 0;
 i1 = i6 + 48 | 0;
 i3 = i6;
 i2 = HEAP32[i5 >> 2] | 0;
 HEAP32[i4 >> 2] = i2;
 HEAP32[i4 + 4 >> 2] = i2 + 88;
 HEAP32[i4 + 8 >> 2] = 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = 0;
 HEAP8[i4 + 24 >> 0] = 0;
 __ZN4wasm10PassRunner28addDefaultOptimizationPassesEv(i4);
 if ((HEAP32[i5 + 16 >> 2] | 0) >>> 0 < 1024) {
  HEAP32[i1 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = 0;
  HEAP32[i1 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 40260, 15);
  __ZN4wasm10PassRunner3addENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i4, i1);
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1);
 }
 __ZN4wasm10PassRunner3runEv(i4);
 i1 = i3;
 i2 = i1 + 44 | 0;
 do {
  HEAP32[i1 >> 2] = 0;
  i1 = i1 + 4 | 0;
 } while ((i1 | 0) < (i2 | 0));
 HEAP32[i3 >> 2] = 4272;
 HEAP32[i3 + 36 >> 2] = 0;
 HEAP32[i3 + 40 >> 2] = 0;
 HEAP32[i3 + 32 >> 2] = i3 + 36;
 HEAP32[i3 + 44 >> 2] = 5;
 if (__ZN4wasm13WasmValidator8validateERNS_6ModuleE(i3, HEAP32[i5 >> 2] | 0) | 0) {
  __ZN4wasm13WasmValidatorD2Ev(i3);
  __ZN4wasm10PassRunnerD2Ev(i4);
  STACKTOP = i6;
  return;
 } else ___assert_fail(17084, 16311, 1737, 34281);
}

function __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11Selectifier7visitIfEPNS_2IfE(i7, i1) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 224 | 0;
 i4 = i8 + 144 | 0;
 i6 = i8 + 72 | 0;
 i5 = i8;
 i2 = i1 + 16 | 0;
 if (HEAP32[i2 >> 2] | 0) {
  i3 = i1 + 8 | 0;
  __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i4, HEAP32[i3 >> 2] | 0);
  if (!(__ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i4) | 0)) {
   i1 = i1 + 12 | 0;
   __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i6, HEAP32[i1 >> 2] | 0);
   if (!(__ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i6) | 0)) {
    __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i5, HEAP32[i2 >> 2] | 0);
    if (!(__ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i5) | 0)) {
     i9 = __ZN10MixedArena5allocIN4wasm6SelectEEEPT_v((HEAP32[i7 + 40 >> 2] | 0) + 88 | 0) | 0;
     HEAP32[i9 + 16 >> 2] = HEAP32[i3 >> 2];
     i1 = HEAP32[i1 >> 2] | 0;
     HEAP32[i9 + 8 >> 2] = i1;
     i3 = HEAP32[i2 >> 2] | 0;
     HEAP32[i9 + 12 >> 2] = i3;
     i2 = HEAP32[i1 + 4 >> 2] | 0;
     HEAP32[i9 + 4 >> 2] = (i2 | 0) != 5 ? i2 : HEAP32[i3 + 4 >> 2] | 0;
     HEAP32[i7 + 20 >> 2] = i9;
    }
    __ZN4wasm14EffectAnalyzerD2Ev(i5);
   }
   __ZN4wasm14EffectAnalyzerD2Ev(i6);
  }
  __ZN4wasm14EffectAnalyzerD2Ev(i4);
 }
 STACKTOP = i8;
 return;
}

function __ZN4wasm10TypeSeeker10visitBlockEPNS_5BlockE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i6;
 L1 : do if ((i1 | 0) == (HEAP32[i5 + 28 >> 2] | 0)) {
  i4 = i5 + 36 | 0;
  if (!(HEAP32[i1 + 20 >> 2] | 0)) {
   HEAP32[i3 >> 2] = 0;
   i1 = i5 + 40 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if (i2 >>> 0 < (HEAP32[i5 + 44 >> 2] | 0) >>> 0) {
    HEAP32[i2 >> 2] = 0;
    HEAP32[i1 >> 2] = i2 + 4;
    break;
   } else {
    __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i4, i3);
    break;
   }
  } else {
   i1 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i1 + 12 | 0) | 0;
   i1 = (HEAP32[i1 >> 2] | 0) + 4 | 0;
   i2 = i5 + 40 | 0;
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (HEAP32[i5 + 44 >> 2] | 0)) {
    __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4, i1);
    break;
   } else {
    HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i2 >> 2] = i3 + 4;
    break;
   }
  }
 } else if ((HEAP32[i1 + 8 >> 2] | 0) == (HEAP32[i5 + 32 >> 2] | 0)) {
  i3 = HEAP32[i5 + 36 >> 2] | 0;
  i1 = i5 + 40 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break L1;
   i5 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i5;
   i2 = i5;
  }
 } while (0);
 STACKTOP = i6;
 return;
}

function __ZZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEEEN9Generator16calculateFitnessEPZNS0_11pickIndicesES6_E5Order(i7, i9) {
 i7 = i7 | 0;
 i9 = i9 | 0;
 var d1 = 0.0, i2 = 0, i3 = 0, d4 = 0.0, i5 = 0, i6 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i10;
 HEAP32[i8 >> 2] = 0;
 i6 = i8 + 4 | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i8 + 8 >> 2] = 0;
 __ZN4wasm14CoalesceLocals20pickIndicesFromOrderERNSt3__26vectorIjNS1_9allocatorIjEEEES6_(HEAP32[i7 >> 2] | 0, i9, i8);
 i3 = HEAP32[i8 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 L1 : do if ((i3 | 0) == (i6 | 0)) i2 = i3; else {
  i2 = i3;
  L3 : while (1) while (1) {
   i5 = i3 + 4 | 0;
   i3 = i5;
   if ((i5 | 0) == (i6 | 0)) break L1;
   if ((HEAP32[i2 >> 2] | 0) >>> 0 < (HEAP32[i5 >> 2] | 0) >>> 0) {
    i2 = i5;
    continue L3;
   }
  }
 } while (0);
 i2 = HEAP32[i2 >> 2] | 0;
 i3 = HEAP32[(HEAP32[i7 >> 2] | 0) + 112 >> 2] | 0;
 if (i3 >>> 0 < i2 >>> 0) ___assert_fail(46983, 46670, 492, 47013);
 d4 = 1.0 / (+(i3 >>> 0) * 2.0);
 d1 = +((i3 - i2 | 0) >>> 0);
 i2 = 0;
 while (1) {
  if ((i2 | 0) == (i3 | 0)) break;
  d1 = (HEAP32[(HEAP32[i9 >> 2] | 0) + (i2 << 2) >> 2] | 0) == (i2 | 0) ? d4 + d1 : d1;
  i2 = i2 + 1 | 0;
 }
 HEAPF64[i9 + 16 >> 3] = d1;
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i8);
 STACKTOP = i10;
 return;
}

function __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE8__appendEj(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i2 = HEAP32[i8 + 8 >> 2] | 0;
 i4 = i8 + 4 | 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i2 - i1 >> 4 >>> 0 < i6 >>> 0) {
  i5 = HEAP32[i8 >> 2] | 0;
  i3 = (i1 - i5 >> 4) + i6 | 0;
  if (i3 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
  i1 = i2 - i5 | 0;
  if (i1 >> 4 >>> 0 < 134217727) {
   i1 = i1 >> 3;
   i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
  } else i1 = 268435455;
  __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEEC2EjjS5_(i7, i1, (HEAP32[i4 >> 2] | 0) - i5 >> 4, i8 + 8 | 0);
  i3 = i7 + 8 | 0;
  i2 = HEAP32[i3 >> 2] | 0;
  i1 = i6;
  i4 = i2;
  while (1) {
   HEAP32[i4 >> 2] = 0;
   i5 = i4 + 8 | 0;
   HEAP32[i5 >> 2] = 0;
   HEAP32[i5 + 4 >> 2] = 0;
   i1 = i1 + -1 | 0;
   if (!i1) break; else i4 = i4 + 16 | 0;
  }
  HEAP32[i3 >> 2] = i2 + (i6 << 4);
  __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i8, i7);
  __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEED2Ev(i7);
 } else __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE18__construct_at_endEj(i8, i6);
 STACKTOP = i9;
 return;
}

function __ZN4wasm15Asm2WasmBuilder14allocateGlobalEN6cashew7IStringENS_8WasmTypeEbS2_S2_(i7, i6, i8, i4, i5, i3) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i8 = i8 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i9 = 0, i10 = 0, i11 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i9;
 i2 = i7 + 48 | 0;
 if ((__ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i2, i6) | 0) != (i7 + 52 | 0)) ___assert_fail(18727, 16311, 184, 18775);
 i10 = i7 + 12 | 0;
 i11 = HEAP32[i5 >> 2] | 0;
 i5 = HEAP32[i3 >> 2] | 0;
 HEAP32[i1 >> 2] = HEAP32[i10 >> 2];
 HEAP32[i1 + 4 >> 2] = i8;
 HEAP8[i1 + 8 >> 0] = i4 & 1;
 HEAP32[i1 + 12 >> 2] = i11;
 HEAP32[i1 + 16 >> 2] = i5;
 __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS3_JRS3_S6_EEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i9 + 24 | 0, i2, i6, i6, i1);
 i8 = (HEAP32[i10 >> 2] | 0) + 8 | 0;
 HEAP32[i10 >> 2] = i8;
 if (i8 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  STACKTOP = i9;
  return;
 } else ___assert_fail(18790, 16311, 187, 18775);
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIjJNS_4pairIjS4_EEEEENSE_INS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i7, i6, i1, i3) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 12 | 0;
 i4 = i8;
 i2 = __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESI_RKT_(i6, i5, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE16__construct_nodeIJNS_4pairIjS4_EEEEENS_10unique_ptrINS_11__tree_nodeIS5_PvEENS_22__tree_node_destructorINSA_ISJ_EEEEEEDpOT_(i4, i6, i3);
  i1 = HEAP32[i4 >> 2] | 0;
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSG_SG_(i6, HEAP32[i5 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i7 >> 2] = i1;
 HEAP8[i7 + 4 >> 0] = i2;
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZN4wasm5Unary8finalizeEv(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i2 + 8 | 0;
 do switch (HEAP32[i1 >> 2] | 0) {
 case 19:
 case 17:
 case 15:
 case 13:
 case 11:
 case 9:
 case 7:
 case 5:
 case 3:
 case 1:
 case 18:
 case 16:
 case 14:
 case 12:
 case 10:
 case 8:
 case 6:
 case 4:
 case 2:
 case 0:
  {
   HEAP32[i2 + 4 >> 2] = HEAP32[(HEAP32[i2 + 12 >> 2] | 0) + 4 >> 2];
   break;
  }
 case 21:
 case 20:
  {
   HEAP32[i2 + 4 >> 2] = 1;
   break;
  }
 case 23:
 case 22:
  {
   HEAP32[i2 + 4 >> 2] = 2;
   break;
  }
 case 24:
  {
   HEAP32[i2 + 4 >> 2] = 1;
   break;
  }
 case 43:
  {
   HEAP32[i2 + 4 >> 2] = 4;
   break;
  }
 case 44:
  {
   HEAP32[i2 + 4 >> 2] = 3;
   break;
  }
 case 33:
 case 31:
 case 29:
 case 27:
 case 25:
  {
   HEAP32[i2 + 4 >> 2] = 1;
   break;
  }
 case 34:
 case 32:
 case 30:
 case 28:
 case 26:
  {
   HEAP32[i2 + 4 >> 2] = 2;
   break;
  }
 case 41:
 case 39:
 case 37:
 case 35:
 case 45:
  {
   HEAP32[i2 + 4 >> 2] = 3;
   break;
  }
 case 42:
 case 40:
 case 38:
 case 36:
 case 46:
  {
   HEAP32[i2 + 4 >> 2] = 4;
   break;
  }
 default:
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 21986) | 0, HEAP32[i1 >> 2] | 0) | 0, 10) | 0;
 } while (0);
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZN4wasm17WasmBinaryBuilder10visitBreakEPNS_5BreakEh(i4, i3, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5;
 if (HEAP8[i4 + 12 >> 0] | 0) {
  i6 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24156) | 0;
  i7 = __ZNKSt3__28ios_base6getlocEv(i6 + (HEAP32[(HEAP32[i6 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i6, i7) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i6) | 0;
 }
 i1 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i4) | 0;
 if ((i1 | 1 | 0) != 1) ___assert_fail(24171, 22948, 1785, 24196);
 i7 = __ZN4wasm17WasmBinaryBuilder12getBreakNameEi(i4, __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i4) | 0) | 0;
 HEAP32[i3 + 8 >> 2] = i7;
 if (i2 << 24 >> 24 == 7) {
  i7 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i4) | 0;
  HEAP32[i3 + 16 >> 2] = i7;
 }
 if ((i1 | 0) == 1) {
  i7 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i4) | 0;
  HEAP32[i3 + 12 >> 2] = i7;
 }
 if (HEAP32[i3 + 16 >> 2] | 0) HEAP32[i3 + 4 >> 2] = 0;
 STACKTOP = i5;
 return;
}

function __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE21__push_back_slow_pathIRKS6_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementERNS_9allocatorIS6_EEEC2EjjS9_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i1 = i6;
 i2 = HEAP32[i1 + 4 >> 2] | 0;
 i6 = i3;
 HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i6 + 4 >> 2] = i2;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i7, i5);
 __ZNSt3__214__split_bufferIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementERNS_9allocatorIS6_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorINS0_INS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEEENS4_IS8_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS8_RS9_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i10 = HEAP32[i4 >> 2] | 0;
  i8 = i10 + -16 | 0;
  i7 = i1 + -16 | 0;
  HEAP32[i8 >> 2] = 0;
  i9 = i10 + -12 | 0;
  HEAP32[i9 >> 2] = 0;
  i11 = HEAP32[i1 + -4 >> 2] | 0;
  HEAP32[i10 + -8 >> 2] = 0;
  HEAP32[i10 + -4 >> 2] = i11;
  HEAP32[i8 >> 2] = HEAP32[i7 >> 2];
  i8 = i1 + -12 | 0;
  HEAP32[i9 >> 2] = HEAP32[i8 >> 2];
  i9 = i1 + -8 | 0;
  HEAP32[i10 + -8 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i9 >> 2] = 0;
  HEAP32[i8 >> 2] = 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -16;
  i1 = i7;
 }
 i9 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i9;
 i9 = i5 + 8 | 0;
 i11 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i9 >> 2] = i11;
 i9 = i6 + 8 | 0;
 i11 = i5 + 12 | 0;
 i10 = HEAP32[i9 >> 2] | 0;
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i11 >> 2] = i10;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementERNS_9allocatorIS6_EEEC2EjjS9_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i1 = i6;
 i2 = HEAP32[i1 + 4 >> 2] | 0;
 i6 = i3;
 HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i6 + 4 >> 2] = i2;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i7, i5);
 __ZNSt3__214__split_bufferIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementERNS_9allocatorIS6_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm14SimplifyLocals10visitBlockEPNS_5BlockE(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = i1 + 8 | 0;
 if (!(HEAP32[i2 >> 2] | 0)) i3 = 0; else {
  i3 = __ZNSt3__23mapIN4wasm4NameENS_6vectorINS1_14SimplifyLocals10BlockBreakENS_9allocatorIS5_EEEENS_4lessIS2_EENS6_INS_4pairIKS2_S8_EEEEEixERSC_(i4 + 56 | 0, i2) | 0;
  i3 = (HEAP32[i3 + 4 >> 2] | 0) != (HEAP32[i3 >> 2] | 0);
 }
 __ZN4wasm14SimplifyLocals19optimizeBlockReturnEPNS_5BlockE(i4, i1);
 if (HEAP32[i2 >> 2] | 0) {
  i1 = i4 + 68 | 0;
  if (__ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(i1, i2) | 0) {
   __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5clearEv(i4 + 44 | 0);
   __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__erase_uniqueIS2_EEjRKT_(i1, i2) | 0;
  }
  if (i3) {
   __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5clearEv(i4 + 44 | 0);
   __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE14__erase_uniqueIS3_EEjRKT_(i4 + 56 | 0, i2) | 0;
  }
 }
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSM_IJEEEEEENS_4pairINS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESN_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSL_SL_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZN4wasm16PrintSExpression7visitIfEPNS_2IfE(i6, i3) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0;
 __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i6 >> 2] | 0, 47650, 0) | 0;
 __ZN4wasm16PrintSExpression9incIndentEv(i6);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i6, HEAP32[i3 + 8 >> 2] | 0);
 i5 = i6 + 20 | 0;
 i2 = HEAP32[i3 + 12 >> 2] | 0;
 if ((((HEAP8[i5 >> 0] | 0) == 0 ? (HEAP32[i2 >> 2] | 0) == 1 : 0) ? (HEAP32[i2 + 8 >> 2] | 0) == 0 : 0) ? (i1 = i2 + 12 | 0, (HEAP32[i1 + 8 >> 2] | 0) == 1) : 0) {
  i2 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i1) | 0;
  __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i6, HEAP32[i2 >> 2] | 0);
 } else __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i6, i2);
 i1 = HEAP32[i3 + 16 >> 2] | 0;
 do if (i1 | 0) {
  if ((((HEAP8[i5 >> 0] | 0) == 0 ? (HEAP32[i1 >> 2] | 0) == 1 : 0) ? (HEAP32[i1 + 8 >> 2] | 0) == 0 : 0) ? (i4 = i1 + 12 | 0, (HEAP32[i4 + 8 >> 2] | 0) == 1) : 0) {
   i5 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i4) | 0;
   __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i6, HEAP32[i5 >> 2] | 0);
   break;
  }
  __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i6, i1);
 } while (0);
 __ZN4wasm16PrintSExpression9decIndentEv(i6);
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZN6cashew12ValueBuilder18appendCodeToSwitchENS_3RefES1_b(i6, i5, i2) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i7 + 8 | 0;
 i4 = i7 + 4 | 0;
 i1 = i7;
 if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i6, 0) | 0, 59364) | 0)) ___assert_fail(31685, 48272, 1611, 31747);
 if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i5, 0) | 0, 59280) | 0)) ___assert_fail(31766, 48272, 1612, 31747);
 L7 : do if (i2) {
  i6 = __ZN6cashew3RefixEj(i6, 2) | 0;
  i6 = __ZN6cashew5Value4backEv(__ZN6cashew5Value4backEv(HEAP32[i6 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
  __ZN6cashew5Value9push_backENS_3RefE(i6, i3) | 0;
 } else {
  i1 = 0;
  while (1) {
   i2 = __ZN6cashew3RefixEj(i5, 1) | 0;
   if (i1 >>> 0 >= (__ZN6cashew5Value4sizeEv(HEAP32[i2 >> 2] | 0) | 0) >>> 0) break L7;
   i2 = __ZN6cashew3RefixEj(i6, 2) | 0;
   i2 = __ZN6cashew5Value4backEv(__ZN6cashew5Value4backEv(HEAP32[i2 >> 2] | 0) | 0) | 0;
   i8 = __ZN6cashew3RefixEj(__ZN6cashew3RefixEj(i5, 1) | 0, i1) | 0;
   HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
   HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
   __ZN6cashew5Value9push_backENS_3RefE(i2, i3) | 0;
   i1 = i1 + 1 | 0;
  }
 } while (0);
 STACKTOP = i7;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZN4wasm14SimplifyLocals8visitPreEPS0_PPNS_10ExpressionE(i6, i1) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i4 = i7 + 72 | 0;
 i5 = i7;
 i3 = HEAP32[i1 >> 2] | 0;
 HEAP32[i4 >> 2] = i3;
 i1 = i5 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 HEAP32[i1 + 20 >> 2] = 0;
 HEAP32[i5 >> 2] = 5392;
 i1 = i5 + 28 | 0;
 HEAP8[i1 >> 0] = 0;
 HEAP8[i5 + 29 >> 0] = 0;
 HEAP32[i5 + 36 >> 2] = 0;
 HEAP32[i5 + 40 >> 2] = 0;
 HEAP32[i5 + 32 >> 2] = i5 + 36;
 HEAP32[i5 + 48 >> 2] = 0;
 HEAP32[i5 + 52 >> 2] = 0;
 HEAP32[i5 + 44 >> 2] = i5 + 48;
 HEAP8[i5 + 56 >> 0] = 0;
 HEAP8[i5 + 57 >> 0] = 0;
 HEAP32[i5 + 64 >> 2] = 0;
 HEAP32[i5 + 68 >> 2] = 0;
 HEAP32[i5 + 60 >> 2] = i5 + 64;
 if ((HEAP32[i3 >> 2] | 0) == 3) {
  HEAP8[i1 >> 0] = 1;
  __ZN4wasm14SimplifyLocals18checkInvalidationsERNS_14EffectAnalyzerE(i6, i5);
 }
 i1 = i6 + 100 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[i6 + 104 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i6 + 96 | 0, i4); else {
  HEAP32[i2 >> 2] = i3;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
 }
 __ZN4wasm14EffectAnalyzerD2Ev(i5);
 STACKTOP = i7;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE21__push_back_slow_pathIRKS9_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockERNS_9allocatorIS9_EEEC2EjjSC_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSB_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockERNS_9allocatorIS9_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEjjjjjjPKw(i12, i11, i1, i3, i9, i10, i8, i4) {
 i12 = i12 | 0;
 i11 = i11 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i9 = i9 | 0;
 i10 = i10 | 0;
 i8 = i8 | 0;
 i4 = i4 | 0;
 var i2 = 0, i5 = 0, i6 = 0, i7 = 0;
 if ((1073741806 - i11 | 0) >>> 0 < i1 >>> 0) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i12);
 i6 = i12 + 8 | 0;
 if ((HEAP8[i6 + 3 >> 0] | 0) < 0) i7 = HEAP32[i12 >> 2] | 0; else i7 = i12;
 if (i11 >>> 0 < 536870887) {
  i1 = i1 + i11 | 0;
  i2 = i11 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
  if (i1 >>> 0 >= 2) {
   i1 = i1 + 4 & -4;
   if (i1 >>> 0 > 1073741823) ___assert_fail(55771, 55808, 1734, 55911); else i5 = i1;
  } else i5 = 2;
 } else i5 = 1073741807;
 i2 = __Znwj(i5 << 2) | 0;
 if (i9 | 0) __ZNSt3__211char_traitsIwE4copyEPwPKwj(i2, i7, i9) | 0;
 if (i8 | 0) __ZNSt3__211char_traitsIwE4copyEPwPKwj(i2 + (i9 << 2) | 0, i4, i8) | 0;
 i1 = i3 - i10 | 0;
 if ((i1 | 0) != (i9 | 0)) __ZNSt3__211char_traitsIwE4copyEPwPKwj(i2 + (i9 << 2) + (i8 << 2) | 0, i7 + (i9 << 2) + (i10 << 2) | 0, i1 - i9 | 0) | 0;
 if ((i11 | 0) != 1) __ZdlPv(i7);
 HEAP32[i12 >> 2] = i2;
 HEAP32[i6 >> 2] = i5 | -2147483648;
 i11 = i1 + i8 | 0;
 HEAP32[i12 + 4 >> 2] = i11;
 HEAP32[i2 + (i11 << 2) >> 2] = 0;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder14makeBreakTableERNS_7ElementE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i8 + 4 | 0;
 i3 = i8;
 i5 = __ZN10MixedArena5allocIN4wasm6SwitchEEEPT_v(HEAP32[i7 + 4 >> 2] | 0) | 0;
 i4 = i5 + 8 | 0;
 i1 = 1;
 while (1) {
  i9 = __ZN4wasm7ElementixEj(i6, i1) | 0;
  if (HEAP8[i9 >> 0] | 0) break;
  i9 = __ZN4wasm22SExpressionWasmBuilder8getLabelERNS_7ElementE(i7, __ZN4wasm7ElementixEj(i6, i1) | 0) | 0;
  HEAP32[i3 >> 2] = i9;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  __ZN11ArenaVectorIN4wasm4NameEE9push_backES1_(i4, i2);
  i1 = i1 + 1 | 0;
 }
 i2 = __ZNK11ArenaVectorIN4wasm4NameEE4backEv(i4) | 0;
 HEAP32[i5 + 24 >> 2] = HEAP32[i2 >> 2];
 __ZN11ArenaVectorIN4wasm4NameEE8pop_backEv(i4) | 0;
 i2 = i1 + 1 | 0;
 i9 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i7, __ZN4wasm7ElementixEj(i6, i1) | 0) | 0;
 i1 = i5 + 28 | 0;
 HEAP32[i1 >> 2] = i9;
 i9 = (__ZN4wasm7Element4listEv(i6) | 0) + 8 | 0;
 if (i2 >>> 0 < (HEAP32[i9 >> 2] | 0) >>> 0) {
  HEAP32[i5 + 32 >> 2] = HEAP32[i1 >> 2];
  i9 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i7, __ZN4wasm7ElementixEj(i6, i2) | 0) | 0;
  HEAP32[i1 >> 2] = i9;
 }
 STACKTOP = i8;
 return i5 | 0;
}

function __ZNSt3__26vectorINS0_IN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEENS4_IS6_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i10 = HEAP32[i4 >> 2] | 0;
  i8 = i10 + -16 | 0;
  i7 = i1 + -16 | 0;
  HEAP32[i8 >> 2] = 0;
  i9 = i10 + -12 | 0;
  HEAP32[i9 >> 2] = 0;
  i11 = HEAP32[i1 + -4 >> 2] | 0;
  HEAP32[i10 + -8 >> 2] = 0;
  HEAP32[i10 + -4 >> 2] = i11;
  HEAP32[i8 >> 2] = HEAP32[i7 >> 2];
  i8 = i1 + -12 | 0;
  HEAP32[i9 >> 2] = HEAP32[i8 >> 2];
  i9 = i1 + -8 | 0;
  HEAP32[i10 + -8 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i9 >> 2] = 0;
  HEAP32[i8 >> 2] = 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -16;
  i1 = i7;
 }
 i9 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i9;
 i9 = i5 + 8 | 0;
 i11 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i9 >> 2] = i11;
 i9 = i6 + 8 | 0;
 i11 = i5 + 12 | 0;
 i10 = HEAP32[i9 >> 2] | 0;
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i11 >> 2] = i10;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function _mbtowc(i2, i6, i4) {
 i2 = i2 | 0;
 i6 = i6 | 0;
 i4 = i4 | 0;
 var i1 = 0, i3 = 0, i5 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 L1 : do if (!i6) i1 = 0; else {
  do if (i4 | 0) {
   i5 = (i2 | 0) == 0 ? i1 : i2;
   i1 = HEAP8[i6 >> 0] | 0;
   i2 = i1 & 255;
   if (i1 << 24 >> 24 > -1) {
    HEAP32[i5 >> 2] = i2;
    i1 = i1 << 24 >> 24 != 0 & 1;
    break L1;
   }
   i1 = i2 + -194 | 0;
   if (i1 >>> 0 <= 50) {
    i2 = i6 + 1 | 0;
    i3 = HEAP32[8196 + (i1 << 2) >> 2] | 0;
    if (i4 >>> 0 < 4 ? i3 & -2147483648 >>> ((i4 * 6 | 0) + -6 | 0) | 0 : 0) break;
    i1 = HEAPU8[i2 >> 0] | 0;
    i4 = i1 >>> 3;
    if ((i4 + -16 | i4 + (i3 >> 26)) >>> 0 <= 7) {
     i1 = i1 + -128 | i3 << 6;
     if ((i1 | 0) >= 0) {
      HEAP32[i5 >> 2] = i1;
      i1 = 2;
      break L1;
     }
     i2 = HEAPU8[i6 + 2 >> 0] | 0;
     if ((i2 & 192 | 0) == 128) {
      i2 = i2 + -128 | i1 << 6;
      if ((i2 | 0) >= 0) {
       HEAP32[i5 >> 2] = i2;
       i1 = 3;
       break L1;
      }
      i1 = HEAPU8[i6 + 3 >> 0] | 0;
      if ((i1 & 192 | 0) == 128) {
       HEAP32[i5 >> 2] = i1 + -128 | i2 << 6;
       i1 = 4;
       break L1;
      }
     }
    }
   }
  } while (0);
  i1 = ___errno_location() | 0;
  HEAP32[i1 >> 2] = 84;
  i1 = -1;
 } while (0);
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__224uniform_int_distributionIiEclINS_23mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEEEEiRT_RKNS1_10param_typeE(i1, i3, i5) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i2 = 0, i4 = 0, i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i2 = i6;
 i1 = HEAP32[i5 + 4 >> 2] | 0;
 i7 = HEAP32[i5 >> 2] | 0;
 i4 = i1 - i7 + 1 | 0;
 do if ((i1 | 0) != (i7 | 0)) {
  if (!i4) {
   i1 = __ZNSt3__223mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEclEv(i3) | 0;
   break;
  }
  i7 = 32 - (Math_clz32(i4 | 0) | 0) | 0;
  __ZNSt3__225__independent_bits_engineINS_23mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEEjEC2ERS2_j(i2, i3, (((-1 >>> (33 - i7 | 0) & i4 | 0) == 0) << 31 >> 31) + i7 | 0);
  i3 = HEAP32[i2 >> 2] | 0;
  i2 = HEAP32[i2 + 28 >> 2] | 0;
  do i1 = i2 & (__ZNSt3__223mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEclEv(i3) | 0); while (i1 >>> 0 >= i4 >>> 0);
  i1 = (HEAP32[i5 >> 2] | 0) + i1 | 0;
 } while (0);
 STACKTOP = i6;
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERi(i9, i7) {
 i9 = i9 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i10 + 24 | 0;
 i1 = i10 + 20 | 0;
 i3 = i10 + 16 | 0;
 i4 = i10 + 12 | 0;
 i11 = i10 + 28 | 0;
 i6 = i10 + 8 | 0;
 i8 = i10 + 4 | 0;
 i5 = i10;
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b(i11, i9, 0);
 if (HEAP8[i11 >> 0] | 0) {
  HEAP32[i6 >> 2] = 0;
  i12 = __ZNKSt3__28ios_base6getlocEv(i9 + (HEAP32[(HEAP32[i9 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i5 >> 2] = i12;
  i12 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61704) | 0;
  i11 = i9 + (HEAP32[(HEAP32[i9 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i13 = HEAP32[(HEAP32[i12 >> 2] | 0) + 16 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i11 + 24 >> 2];
  HEAP32[i4 >> 2] = 0;
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  FUNCTION_TABLE_iiiiiii[i13 & 63](i12, i1, i2, i11, i6, i8) | 0;
  __ZNSt3__26localeD2Ev(i5);
  HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
  i8 = i9 + (HEAP32[(HEAP32[i9 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i11 = i8 + 16 | 0;
  HEAP32[i11 >> 2] = HEAP32[i11 >> 2] | HEAP32[i6 >> 2] | (HEAP32[i8 + 24 >> 2] | 0) == 0;
 }
 STACKTOP = i10;
 return i9 | 0;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE6rehashEj(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 if ((i1 | 0) != 1) {
  if (i1 + -1 & i1) i1 = __ZNSt3__212__next_primeEj(i1) | 0;
 } else i1 = 2;
 i4 = HEAP32[i5 + 4 >> 2] | 0;
 if (i1 >>> 0 <= i4 >>> 0) {
  if (i1 >>> 0 < i4 >>> 0) {
   if (i4 >>> 0 > 2) i3 = (i4 + -1 & i4 | 0) == 0; else i3 = 0;
   i2 = ~~+Math_ceil(+(+((HEAP32[i5 + 12 >> 2] | 0) >>> 0) / +HEAPF32[i5 + 16 >> 2])) >>> 0;
   if (i3) i2 = 1 << 32 - (Math_clz32(i2 + -1 | 0) | 0); else i2 = __ZNSt3__212__next_primeEj(i2) | 0;
   i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
   if (i1 >>> 0 < i4 >>> 0) __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE8__rehashEj(i5, i1);
  }
 } else __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE8__rehashEj(i5, i1);
 return;
}

function __ZN4wasm6Module15addFunctionTypeEPNS_12FunctionTypeE(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i9 + 4 | 0;
 i4 = i9;
 i5 = i8 + 164 | 0;
 i1 = __ZN4wasm4Name7fromIntEj(HEAP32[i5 >> 2] | 0) | 0;
 HEAP32[i7 >> 2] = i1;
 if (!(HEAP32[i6 >> 2] | 0)) HEAP32[i6 >> 2] = i1;
 i1 = i6;
 HEAP32[i4 >> 2] = i1;
 i2 = i8 + 4 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (i3 >>> 0 >= (HEAP32[i8 + 8 >> 2] | 0) >>> 0) {
  __ZNSt3__26vectorINS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i8, i4);
  i1 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  if (i1 | 0) {
   __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i1 + 8 | 0);
   __ZdlPv(i1);
  }
 } else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = i3 + 4;
  HEAP32[i4 >> 2] = 0;
 }
 i8 = i8 + 116 | 0;
 i4 = __ZNSt3__23mapIN4wasm4NameEPNS1_12FunctionTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i8, i6) | 0;
 HEAP32[i4 >> 2] = i6;
 i8 = __ZNSt3__23mapIN4wasm4NameEPNS1_12FunctionTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i8, i7) | 0;
 HEAP32[i8 >> 2] = i6;
 HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 1;
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8__appendEj(i8, i2) {
 i8 = i8 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i5 = HEAP32[i8 + 8 >> 2] | 0;
 i3 = i8 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 if (i5 - i1 >> 2 >>> 0 < i2 >>> 0) {
  i3 = HEAP32[i8 >> 2] | 0;
  i6 = i1 - i3 >> 2;
  i4 = i6 + i2 | 0;
  if (i4 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
  i1 = i5 - i3 | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i4 >>> 0 ? i4 : i1;
  } else i1 = 1073741823;
  __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEEC2EjjS6_(i7, i1, i6, i8 + 16 | 0);
  i6 = i7 + 8 | 0;
  i5 = HEAP32[i6 >> 2] | 0;
  _memset(i5 | 0, 0, i2 << 2 | 0) | 0;
  HEAP32[i6 >> 2] = i5 + (i2 << 2);
  __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i8, i7);
  __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEED2Ev(i7);
 } else do {
  HEAP32[i1 >> 2] = 0;
  i1 = (HEAP32[i3 >> 2] | 0) + 4 | 0;
  HEAP32[i3 >> 2] = i1;
  i2 = i2 + -1 | 0;
 } while ((i2 | 0) != 0);
 STACKTOP = i9;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendIPKcEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorISC_EE5valueERS7_E4typeESC_SC_(i10, i5, i8) {
 i10 = i10 | 0;
 i5 = i5 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i9 = 0;
 i3 = i5;
 i9 = i10 + 11 | 0;
 i1 = HEAP8[i9 >> 0] | 0;
 if (i1 << 24 >> 24 < 0) {
  i7 = HEAP32[i10 + 4 >> 2] | 0;
  i2 = (HEAP32[i10 + 8 >> 2] & 2147483647) + -1 | 0;
 } else {
  i7 = i1 & 255;
  i2 = 10;
 }
 i6 = i8 - i3 | 0;
 do if ((i8 | 0) != (i5 | 0)) {
  if ((i2 - i7 | 0) >>> 0 < i6 >>> 0) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9__grow_byEjjjjjj(i10, i2, i7 + i6 - i2 | 0, i7, i7, 0);
   i1 = HEAP8[i9 >> 0] | 0;
  }
  if (i1 << 24 >> 24 < 0) i4 = HEAP32[i10 >> 2] | 0; else i4 = i10;
  i3 = i8 + (i7 - i3) | 0;
  i1 = i5;
  i2 = i4 + i7 | 0;
  while (1) {
   if ((i1 | 0) == (i8 | 0)) break;
   HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
   i1 = i1 + 1 | 0;
   i2 = i2 + 1 | 0;
  }
  HEAP8[i4 + i3 >> 0] = 0;
  i1 = i7 + i6 | 0;
  if ((HEAP8[i9 >> 0] | 0) < 0) {
   HEAP32[i10 + 4 >> 2] = i1;
   break;
  } else {
   HEAP8[i9 >> 0] = i1;
   break;
  }
 } while (0);
 return;
}

function __ZN4wasm17WasmBinaryBuilder17readFunctionTableEv(i9) {
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i10;
 if (HEAP8[i9 + 12 >> 0] | 0) {
  i8 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25309) | 0;
  i7 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i7;
  i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i7 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i7 >> 2] | 0) + 28 >> 2] & 63](i7, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i8, i7) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i8) | 0;
 }
 i2 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i9) | 0;
 i3 = i9 + 116 | 0;
 i4 = i9 + 120 | 0;
 i5 = i9 + 112 | 0;
 i8 = 0;
 while (1) {
  if ((i8 | 0) == (i2 | 0)) break;
  i6 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i9) | 0;
  HEAP32[i1 >> 2] = i6;
  i7 = HEAP32[i3 >> 2] | 0;
  if ((i7 | 0) == (HEAP32[i4 >> 2] | 0)) __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIRKjEEvOT_(i5, i1); else {
   HEAP32[i7 >> 2] = i6;
   HEAP32[i3 >> 2] = i7 + 4;
  }
  i8 = i8 + 1 | 0;
 }
 STACKTOP = i10;
 return;
}

function __ZZN4wasm17WasmBinaryBuilder4readEvENKUlPKcE_clES2_(i11, i10) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i12 = 0;
 i2 = HEAP32[i11 + 4 >> 2] | 0;
 i5 = HEAP32[HEAP32[i11 >> 2] >> 2] | 0;
 i6 = i2 + 16 | 0;
 i7 = i2 + 8 | 0;
 i9 = 0;
 while (1) {
  if (i9 >>> 0 >= i5 >>> 0) {
   i12 = 6;
   break;
  }
  i8 = (HEAP32[i6 >> 2] | 0) + i9 | 0;
  i4 = HEAP32[i7 >> 2] | 0;
  i3 = HEAP32[i4 >> 2] | 0;
  if (i8 >>> 0 >= ((HEAP32[i4 + 4 >> 2] | 0) - i3 | 0) >>> 0) {
   i1 = 0;
   break;
  }
  i4 = HEAP8[i10 + i9 >> 0] | 0;
  if (!(i4 << 24 >> 24)) {
   i1 = 0;
   break;
  }
  if ((HEAP8[i3 + i8 >> 0] | 0) == i4 << 24 >> 24) i9 = i9 + 1 | 0; else {
   i1 = 0;
   break;
  }
 }
 if ((i12 | 0) == 6) if ((_strlen(i10) | 0) == (i5 | 0)) {
  HEAP32[i6 >> 2] = (HEAP32[i6 >> 2] | 0) + i5;
  i12 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i2) | 0;
  i10 = i11 + 8 | 0;
  HEAP32[HEAP32[i10 >> 2] >> 2] = i12;
  HEAP32[HEAP32[i11 + 12 >> 2] >> 2] = HEAP32[i6 >> 2];
  i12 = HEAP32[i7 >> 2] | 0;
  if (((HEAP32[HEAP32[i10 >> 2] >> 2] | 0) + (HEAP32[i6 >> 2] | 0) | 0) >>> 0 > ((HEAP32[i12 + 4 >> 2] | 0) - (HEAP32[i12 >> 2] | 0) | 0) >>> 0) ___assert_fail(23414, 22948, 1222, 57137); else i1 = 1;
 } else i1 = 0;
 return i1 | 0;
}

function __ZN4wasm7VisitorINS_14EffectAnalyzerEvE5visitEPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) ___assert_fail(41743, 49642, 68, 41748);
 do switch (HEAP32[i1 >> 2] | 0) {
 case 1:
  {
   __ZN4wasm14EffectAnalyzer10visitBlockEPNS_5BlockE(i2, i1);
   break;
  }
 case 19:
 case 16:
 case 15:
 case 14:
 case 13:
 case 2:
  break;
 case 3:
  {
   __ZN4wasm14EffectAnalyzer9visitLoopEPNS_4LoopE(i2, i1);
   break;
  }
 case 4:
  {
   __ZN4wasm14EffectAnalyzer10visitBreakEPNS_5BreakE(i2, i1);
   break;
  }
 case 5:
  {
   __ZN4wasm14EffectAnalyzer11visitSwitchEPNS_6SwitchE(i2, i1);
   break;
  }
 case 6:
  {
   HEAP8[i2 + 29 >> 0] = 1;
   break;
  }
 case 7:
  {
   HEAP8[i2 + 29 >> 0] = 1;
   break;
  }
 case 8:
  {
   HEAP8[i2 + 29 >> 0] = 1;
   break;
  }
 case 9:
  {
   __ZN4wasm14EffectAnalyzer13visitGetLocalEPNS_8GetLocalE(i2, i1);
   break;
  }
 case 10:
  {
   __ZN4wasm14EffectAnalyzer13visitSetLocalEPNS_8SetLocalE(i2, i1);
   break;
  }
 case 11:
  {
   HEAP8[i2 + 56 >> 0] = 1;
   break;
  }
 case 12:
  {
   HEAP8[i2 + 57 >> 0] = 1;
   break;
  }
 case 17:
  {
   HEAP8[i2 + 28 >> 0] = 1;
   break;
  }
 case 18:
  {
   HEAP8[i2 + 29 >> 0] = 1;
   break;
  }
 case 20:
  {
   HEAP8[i2 + 28 >> 0] = 1;
   break;
  }
 default:
  {}
 } while (0);
 return;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendIPwEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_(i11, i6, i9) {
 i11 = i11 | 0;
 i6 = i6 | 0;
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i10 = 0;
 i3 = i6;
 i1 = i11 + 8 | 0;
 i10 = i1 + 3 | 0;
 i2 = HEAP8[i10 >> 0] | 0;
 if (i2 << 24 >> 24 < 0) {
  i8 = HEAP32[i11 + 4 >> 2] | 0;
  i1 = (HEAP32[i1 >> 2] & 2147483647) + -1 | 0;
 } else {
  i8 = i2 & 255;
  i1 = 1;
 }
 i7 = i9 - i3 >> 2;
 do if (i7 | 0) {
  if ((i1 - i8 | 0) >>> 0 < i7 >>> 0) {
   __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEjjjjjj(i11, i1, i8 + i7 - i1 | 0, i8, i8, 0, 0);
   i1 = HEAP8[i10 >> 0] | 0;
  } else i1 = i2;
  i5 = i1 << 24 >> 24 < 0;
  if (i5) i4 = HEAP32[i11 >> 2] | 0; else i4 = i11;
  i3 = i8 + ((i9 - i3 | 0) >>> 2) | 0;
  i1 = i6;
  i2 = i4 + (i8 << 2) | 0;
  while (1) {
   if ((i1 | 0) == (i9 | 0)) break;
   HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
   i1 = i1 + 4 | 0;
   i2 = i2 + 4 | 0;
  }
  HEAP32[i4 + (i3 << 2) >> 2] = 0;
  i1 = i8 + i7 | 0;
  if (i5) {
   HEAP32[i11 + 4 >> 2] = i1;
   break;
  } else {
   HEAP8[i10 >> 0] = i1;
   break;
  }
 } while (0);
 return i11 | 0;
}

function __ZNSt3__27__sort3IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_T_(i4, i5, i6, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = __ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i3, HEAP32[i5 >> 2] | 0, HEAP32[i4 >> 2] | 0) | 0;
 i2 = __ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i3, HEAP32[i6 >> 2] | 0, HEAP32[i5 >> 2] | 0) | 0;
 do if (i1) {
  i1 = HEAP32[i4 >> 2] | 0;
  if (i2) {
   HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
   HEAP32[i6 >> 2] = i1;
   i1 = 1;
   break;
  }
  HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i5 >> 2] = i1;
  if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i3, HEAP32[i6 >> 2] | 0, i1) | 0) {
   i1 = HEAP32[i5 >> 2] | 0;
   HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
   HEAP32[i6 >> 2] = i1;
   i1 = 2;
  } else i1 = 1;
 } else if (i2) {
  i2 = HEAP32[i5 >> 2] | 0;
  HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i6 >> 2] = i2;
  if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i3, HEAP32[i5 >> 2] | 0, HEAP32[i4 >> 2] | 0) | 0) {
   i1 = HEAP32[i4 >> 2] | 0;
   HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
   HEAP32[i5 >> 2] = i1;
   i1 = 2;
  } else i1 = 1;
 } else i1 = 0; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS3_JRS3_S6_EEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i7, i6, i1, i3, i4) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i2 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i6, i5, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(32) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[i3 >> 2];
  i3 = i1 + 20 | 0;
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i3 + 4 >> 2] = HEAP32[i4 + 4 >> 2];
  HEAP32[i3 + 8 >> 2] = HEAP32[i4 + 8 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i6, HEAP32[i5 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i7 >> 2] = i1;
 HEAP8[i7 + 4 >> 0] = i2;
 STACKTOP = i8;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE11parseReturnERPcPKc(i4, i9, i6) {
 i4 = i4 | 0;
 i9 = i9 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0, i8 = 0, i10 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i11 + 4 | 0;
 i8 = i11;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i9);
 i2 = HEAP8[HEAP32[i9 >> 2] >> 0] | 0;
 i1 = i6;
 while (1) {
  i3 = HEAP8[i1 >> 0] | 0;
  if (!(i3 << 24 >> 24)) {
   i10 = 4;
   break;
  }
  if (i3 << 24 >> 24 == i2 << 24 >> 24) {
   i5 = 0;
   break;
  } else i1 = i1 + 1 | 0;
 }
 if ((i10 | 0) == 4) i5 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i4, i9, i6) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i9);
 i4 = HEAP32[i9 >> 2] | 0;
 i3 = HEAP8[i4 >> 0] | 0;
 i1 = i6;
 while (1) {
  i2 = HEAP8[i1 >> 0] | 0;
  if (!(i2 << 24 >> 24)) {
   i10 = 8;
   break;
  }
  if (i2 << 24 >> 24 == i3 << 24 >> 24) break; else i1 = i1 + 1 | 0;
 }
 if ((i10 | 0) == 8) ___assert_fail(31493, 31173, 463, 31513);
 if (i3 << 24 >> 24 == 59) HEAP32[i9 >> 2] = i4 + 1;
 HEAP32[i8 >> 2] = i5;
 HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
 i10 = __ZN6cashew12ValueBuilder10makeReturnENS_3RefE(i7) | 0;
 STACKTOP = i11;
 return i10 | 0;
}

function __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE8__appendEj(i7, i2) {
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i9;
 i3 = HEAP32[i7 + 8 >> 2] | 0;
 i8 = i7 + 4 | 0;
 i1 = HEAP32[i8 >> 2] | 0;
 if (i3 - i1 >> 2 >>> 0 < i2 >>> 0) {
  i5 = HEAP32[i7 >> 2] | 0;
  i4 = (i1 - i5 >> 2) + i2 | 0;
  if (i4 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
  i1 = i3 - i5 | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i4 >>> 0 ? i4 : i1;
  } else i1 = 1073741823;
  __ZNSt3__214__split_bufferIPPN4wasm10ExpressionERNS_9allocatorIS4_EEEC2EjjS7_(i6, i1, (HEAP32[i8 >> 2] | 0) - i5 >> 2, i7 + 8 | 0);
  i8 = i6 + 8 | 0;
  i5 = HEAP32[i8 >> 2] | 0;
  _memset(i5 | 0, 0, i2 << 2 | 0) | 0;
  HEAP32[i8 >> 2] = i5 + (i2 << 2);
  __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE(i7, i6);
  __ZNSt3__214__split_bufferIPPN4wasm10ExpressionERNS_9allocatorIS4_EEED2Ev(i6);
 } else do {
  HEAP32[i1 >> 2] = 0;
  i1 = (HEAP32[i8 >> 2] | 0) + 4 | 0;
  HEAP32[i8 >> 2] = i1;
  i2 = i2 + -1 | 0;
 } while ((i2 | 0) != 0);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA10_KcbNS2_4TypeEEEEvDpOT_(i9, i5, i6, i7) {
 i9 = i9 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i10;
 i3 = i9 + 4 | 0;
 i4 = HEAP32[i9 >> 2] | 0;
 i2 = (((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0) + 1 | 0;
 if (i2 >>> 0 > 107374182) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i9);
 i1 = ((HEAP32[i9 + 8 >> 2] | 0) - i4 | 0) / 40 | 0;
 if (i1 >>> 0 < 53687091) {
  i1 = i1 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 107374182;
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEEC2EjjS5_(i8, i1, ((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0, i9 + 8 | 0);
 i4 = i8 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP8[i6 >> 0] | 0;
 i7 = HEAP32[i7 >> 2] | 0;
 __ZN6cashew10IStringSetC2EPKc(i3, i5);
 HEAP8[i3 + 32 >> 0] = i6;
 HEAP32[i3 + 36 >> 2] = i7;
 HEAP32[i4 >> 2] = i3 + 40;
 __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i9, i8);
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEED2Ev(i8);
 STACKTOP = i10;
 return;
}

function __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA8_KcbNS2_4TypeEEEEvDpOT_(i9, i5, i6, i7) {
 i9 = i9 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i10;
 i3 = i9 + 4 | 0;
 i4 = HEAP32[i9 >> 2] | 0;
 i2 = (((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0) + 1 | 0;
 if (i2 >>> 0 > 107374182) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i9);
 i1 = ((HEAP32[i9 + 8 >> 2] | 0) - i4 | 0) / 40 | 0;
 if (i1 >>> 0 < 53687091) {
  i1 = i1 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 107374182;
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEEC2EjjS5_(i8, i1, ((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0, i9 + 8 | 0);
 i4 = i8 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP8[i6 >> 0] | 0;
 i7 = HEAP32[i7 >> 2] | 0;
 __ZN6cashew10IStringSetC2EPKc(i3, i5);
 HEAP8[i3 + 32 >> 0] = i6;
 HEAP32[i3 + 36 >> 2] = i7;
 HEAP32[i4 >> 2] = i3 + 40;
 __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i9, i8);
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEED2Ev(i8);
 STACKTOP = i10;
 return;
}

function __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA6_KcbNS2_4TypeEEEEvDpOT_(i9, i5, i6, i7) {
 i9 = i9 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i10;
 i3 = i9 + 4 | 0;
 i4 = HEAP32[i9 >> 2] | 0;
 i2 = (((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0) + 1 | 0;
 if (i2 >>> 0 > 107374182) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i9);
 i1 = ((HEAP32[i9 + 8 >> 2] | 0) - i4 | 0) / 40 | 0;
 if (i1 >>> 0 < 53687091) {
  i1 = i1 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 107374182;
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEEC2EjjS5_(i8, i1, ((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0, i9 + 8 | 0);
 i4 = i8 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP8[i6 >> 0] | 0;
 i7 = HEAP32[i7 >> 2] | 0;
 __ZN6cashew10IStringSetC2EPKc(i3, i5);
 HEAP8[i3 + 32 >> 0] = i6;
 HEAP32[i3 + 36 >> 2] = i7;
 HEAP32[i4 >> 2] = i3 + 40;
 __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i9, i8);
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEED2Ev(i8);
 STACKTOP = i10;
 return;
}

function __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA4_KcbNS2_4TypeEEEEvDpOT_(i9, i5, i6, i7) {
 i9 = i9 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i10;
 i3 = i9 + 4 | 0;
 i4 = HEAP32[i9 >> 2] | 0;
 i2 = (((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0) + 1 | 0;
 if (i2 >>> 0 > 107374182) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i9);
 i1 = ((HEAP32[i9 + 8 >> 2] | 0) - i4 | 0) / 40 | 0;
 if (i1 >>> 0 < 53687091) {
  i1 = i1 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 107374182;
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEEC2EjjS5_(i8, i1, ((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0, i9 + 8 | 0);
 i4 = i8 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP8[i6 >> 0] | 0;
 i7 = HEAP32[i7 >> 2] | 0;
 __ZN6cashew10IStringSetC2EPKc(i3, i5);
 HEAP8[i3 + 32 >> 0] = i6;
 HEAP32[i3 + 36 >> 2] = i7;
 HEAP32[i4 >> 2] = i3 + 40;
 __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i9, i8);
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEED2Ev(i8);
 STACKTOP = i10;
 return;
}

function __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRA2_KcbNS2_4TypeEEEEvDpOT_(i9, i5, i6, i7) {
 i9 = i9 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i10;
 i3 = i9 + 4 | 0;
 i4 = HEAP32[i9 >> 2] | 0;
 i2 = (((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0) + 1 | 0;
 if (i2 >>> 0 > 107374182) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i9);
 i1 = ((HEAP32[i9 + 8 >> 2] | 0) - i4 | 0) / 40 | 0;
 if (i1 >>> 0 < 53687091) {
  i1 = i1 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 107374182;
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEEC2EjjS5_(i8, i1, ((HEAP32[i3 >> 2] | 0) - i4 | 0) / 40 | 0, i9 + 8 | 0);
 i4 = i8 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP8[i6 >> 0] | 0;
 i7 = HEAP32[i7 >> 2] | 0;
 __ZN6cashew10IStringSetC2EPKc(i3, i5);
 HEAP8[i3 + 32 >> 0] = i6;
 HEAP32[i3 + 36 >> 2] = i7;
 HEAP32[i4 >> 2] = i3 + 40;
 __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i9, i8);
 __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEED2Ev(i8);
 STACKTOP = i10;
 return;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i3 >> 2] = i2;
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorINS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i7, i5);
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE8__appendEj(i7, i2) {
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i9;
 i3 = HEAP32[i7 + 8 >> 2] | 0;
 i8 = i7 + 4 | 0;
 i1 = HEAP32[i8 >> 2] | 0;
 if (i3 - i1 >> 2 >>> 0 < i2 >>> 0) {
  i5 = HEAP32[i7 >> 2] | 0;
  i4 = (i1 - i5 >> 2) + i2 | 0;
  if (i4 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
  i1 = i3 - i5 | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i4 >>> 0 ? i4 : i1;
  } else i1 = 1073741823;
  __ZNSt3__214__split_bufferIPN4wasm10ExpressionERNS_9allocatorIS3_EEEC2EjjS6_(i6, i1, (HEAP32[i8 >> 2] | 0) - i5 >> 2, i7 + 8 | 0);
  i8 = i6 + 8 | 0;
  i5 = HEAP32[i8 >> 2] | 0;
  _memset(i5 | 0, 0, i2 << 2 | 0) | 0;
  HEAP32[i8 >> 2] = i5 + (i2 << 2);
  __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6);
  __ZNSt3__214__split_bufferIPN4wasm10ExpressionERNS_9allocatorIS3_EEED2Ev(i6);
 } else do {
  HEAP32[i1 >> 2] = 0;
  i1 = (HEAP32[i8 >> 2] | 0) + 4 | 0;
  HEAP32[i8 >> 2] = i1;
  i2 = i2 + -1 | 0;
 } while ((i2 | 0) != 0);
 STACKTOP = i9;
 return;
}

function __ZN4wasm6Module12removeImportENS_4NameE(i11, i10) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i9 = i11 + 16 | 0;
 i7 = HEAP32[i9 >> 2] | 0;
 i3 = HEAP32[i11 + 12 >> 2] | 0;
 i1 = i7 - i3 >> 2;
 i2 = HEAP32[i10 >> 2] | 0;
 i8 = i7;
 i4 = 0;
 while (1) {
  if (i4 >>> 0 >= i1 >>> 0) break;
  i5 = i3 + (i4 << 2) | 0;
  if ((HEAP32[HEAP32[i5 >> 2] >> 2] | 0) == (i2 | 0)) {
   i6 = 4;
   break;
  } else i4 = i4 + 1 | 0;
 }
 L4 : do if ((i6 | 0) == 4) {
  i3 = i5 + 4 | 0;
  i1 = i5;
  i2 = i3;
  while (1) {
   if ((i2 | 0) == (i8 | 0)) break;
   i6 = HEAP32[i2 >> 2] | 0;
   HEAP32[i2 >> 2] = 0;
   i4 = HEAP32[i1 >> 2] | 0;
   HEAP32[i1 >> 2] = i6;
   if (i4 | 0) __ZdlPv(i4);
   i1 = i1 + 4 | 0;
   i2 = i2 + 4 | 0;
  }
  i2 = i5 + ((i7 - i3 | 0) >>> 2 << 2) | 0;
  while (1) {
   i1 = HEAP32[i9 >> 2] | 0;
   if ((i1 | 0) == (i2 | 0)) break L4;
   i8 = i1 + -4 | 0;
   HEAP32[i9 >> 2] = i8;
   i1 = HEAP32[i8 >> 2] | 0;
   HEAP32[i8 >> 2] = 0;
   if (!i1) continue;
   __ZdlPv(i1);
  }
 } while (0);
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE14__erase_uniqueIS3_EEjRKT_(i11 + 128 | 0, i10) | 0;
 return;
}

function __ZN4wasm17WasmBinaryBuilder9readNamesEv(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5;
 if (HEAP8[i4 + 12 >> 0] | 0) {
  i3 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 25330) | 0;
  i2 = __ZNKSt3__28ios_base6getlocEv(i3 + (HEAP32[(HEAP32[i3 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i2;
  i2 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i2 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i2 >> 2] | 0) + 28 >> 2] & 63](i2, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i3, i2) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i3) | 0;
 }
 i1 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i4) | 0;
 i2 = i4 + 40 | 0;
 i3 = 0;
 while (1) {
  if (i3 >>> 0 >= i1 >>> 0) {
   i1 = 5;
   break;
  }
  i6 = HEAP32[(HEAP32[i2 >> 2] | 0) + (i3 << 2) >> 2] | 0;
  i7 = __ZN4wasm17WasmBinaryBuilder15getInlineStringEv(i4) | 0;
  HEAP32[i6 >> 2] = i7;
  if (!(__ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i4) | 0)) i3 = i3 + 1 | 0; else {
   i1 = 7;
   break;
  }
 }
 if ((i1 | 0) == 5) {
  STACKTOP = i5;
  return;
 } else if ((i1 | 0) == 7) ___assert_fail(25343, 22948, 1638, 25358);
}

function __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSA_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i10 = HEAP32[i4 >> 2] | 0;
  i8 = i10 + -12 | 0;
  i7 = i1 + -12 | 0;
  HEAP32[i8 >> 2] = 0;
  i9 = i10 + -8 | 0;
  HEAP32[i9 >> 2] = 0;
  HEAP32[i10 + -4 >> 2] = 0;
  HEAP32[i8 >> 2] = HEAP32[i7 >> 2];
  i8 = i1 + -8 | 0;
  HEAP32[i9 >> 2] = HEAP32[i8 >> 2];
  i9 = i1 + -4 | 0;
  HEAP32[i10 + -4 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i9 >> 2] = 0;
  HEAP32[i8 >> 2] = 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -12;
  i1 = i7;
 }
 i8 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i8;
 i8 = i5 + 8 | 0;
 i10 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
 HEAP32[i8 >> 2] = i10;
 i8 = i6 + 8 | 0;
 i10 = i5 + 12 | 0;
 i9 = HEAP32[i8 >> 2] | 0;
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 HEAP32[i10 >> 2] = i9;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj(i6, i2, i5, i9) {
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 i9 = i9 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i10 = 0, i11 = 0;
 i8 = HEAP8[i6 + 11 >> 0] | 0;
 i7 = i8 << 24 >> 24 < 0;
 i4 = i6 + 4 | 0;
 i1 = HEAP32[i4 >> 2] | 0;
 i8 = i8 & 255;
 do if ((i7 ? i1 : i8) | 0) {
  if ((i2 | 0) != (i5 | 0)) {
   i1 = i5;
   i3 = i2;
   while (1) {
    i1 = i1 + -4 | 0;
    if (i3 >>> 0 >= i1 >>> 0) break;
    i11 = HEAP32[i3 >> 2] | 0;
    HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
    HEAP32[i1 >> 2] = i11;
    i3 = i3 + 4 | 0;
   }
   i1 = HEAP32[i4 >> 2] | 0;
  }
  i11 = i7 ? HEAP32[i6 >> 2] | 0 : i6;
  i6 = i5 + -4 | 0;
  i4 = i11 + (i7 ? i1 : i8) | 0;
  i5 = i11;
  while (1) {
   i1 = HEAP8[i5 >> 0] | 0;
   i3 = i1 << 24 >> 24 < 1 | i1 << 24 >> 24 == 127;
   if (i2 >>> 0 >= i6 >>> 0) break;
   if (!i3 ? (i1 << 24 >> 24 | 0) != (HEAP32[i2 >> 2] | 0) : 0) {
    i10 = 10;
    break;
   }
   i5 = (i4 - i5 | 0) > 1 ? i5 + 1 | 0 : i5;
   i2 = i2 + 4 | 0;
  }
  if ((i10 | 0) == 10) {
   HEAP32[i9 >> 2] = 4;
   break;
  }
  if (!i3 ? ((HEAP32[i6 >> 2] | 0) + -1 | 0) >>> 0 >= i1 << 24 >> 24 >>> 0 : 0) HEAP32[i9 >> 2] = 4;
 } while (0);
 return;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEE6rehashEj(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 if ((i1 | 0) != 1) {
  if (i1 + -1 & i1) i1 = __ZNSt3__212__next_primeEj(i1) | 0;
 } else i1 = 2;
 i4 = HEAP32[i5 + 4 >> 2] | 0;
 if (i1 >>> 0 <= i4 >>> 0) {
  if (i1 >>> 0 < i4 >>> 0) {
   if (i4 >>> 0 > 2) i3 = (i4 + -1 & i4 | 0) == 0; else i3 = 0;
   i2 = ~~+Math_ceil(+(+((HEAP32[i5 + 12 >> 2] | 0) >>> 0) / +HEAPF32[i5 + 16 >> 2])) >>> 0;
   if (i3) i2 = 1 << 32 - (Math_clz32(i2 + -1 | 0) | 0); else i2 = __ZNSt3__212__next_primeEj(i2) | 0;
   i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
   if (i1 >>> 0 < i4 >>> 0) __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEE8__rehashEj(i5, i1);
  }
 } else __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEE8__rehashEj(i5, i1);
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i10, i5, i7, i8, i6) {
 i1 = i1 | 0;
 i10 = i10 | 0;
 i5 = i5 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i11 + 4 | 0;
 i4 = i11;
 i9 = i1 + 8 | 0;
 i9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i9 >> 2] | 0) + 8 >> 2] & 255](i9) | 0;
 i1 = HEAP8[i9 + 8 + 3 >> 0] | 0;
 if (i1 << 24 >> 24 < 0) i2 = HEAP32[i9 + 4 >> 2] | 0; else i2 = i1 & 255;
 i1 = HEAP8[i9 + 20 + 3 >> 0] | 0;
 if (i1 << 24 >> 24 < 0) i1 = HEAP32[i9 + 16 >> 2] | 0; else i1 = i1 & 255;
 do if ((i2 | 0) != (0 - i1 | 0)) {
  HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  i1 = __ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb(i5, i3, i9, i9 + 24 | 0, i6, i8, 0) | 0;
  i2 = HEAP32[i10 >> 2] | 0;
  if ((i1 | 0) == (i9 | 0) & (i2 | 0) == 12) {
   HEAP32[i10 >> 2] = 0;
   break;
  }
  if ((i2 | 0) < 12 & (i1 - i9 | 0) == 12) HEAP32[i10 >> 2] = i2 + 12;
 } else HEAP32[i8 >> 2] = HEAP32[i8 >> 2] | 4; while (0);
 STACKTOP = i11;
 return;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i3 >> 2] = i2;
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i7, i5);
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE24__emplace_back_slow_pathIJS6_EEEvDpOT_(i7, i5) {
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i6, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i3 >> 2] = i2;
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i7, i6);
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i6);
 STACKTOP = i8;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i10, i5, i7, i8, i6) {
 i1 = i1 | 0;
 i10 = i10 | 0;
 i5 = i5 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i11 + 4 | 0;
 i4 = i11;
 i9 = i1 + 8 | 0;
 i9 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i9 >> 2] | 0) + 8 >> 2] & 255](i9) | 0;
 i1 = HEAP8[i9 + 11 >> 0] | 0;
 if (i1 << 24 >> 24 < 0) i2 = HEAP32[i9 + 4 >> 2] | 0; else i2 = i1 & 255;
 i1 = HEAP8[i9 + 12 + 11 >> 0] | 0;
 if (i1 << 24 >> 24 < 0) i1 = HEAP32[i9 + 16 >> 2] | 0; else i1 = i1 & 255;
 do if ((i2 | 0) != (0 - i1 | 0)) {
  HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  i1 = __ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb(i5, i3, i9, i9 + 24 | 0, i6, i8, 0) | 0;
  i2 = HEAP32[i10 >> 2] | 0;
  if ((i1 | 0) == (i9 | 0) & (i2 | 0) == 12) {
   HEAP32[i10 >> 2] = 0;
   break;
  }
  if ((i2 | 0) < 12 & (i1 - i9 | 0) == 12) HEAP32[i10 >> 2] = i2 + 12;
 } else HEAP32[i8 >> 2] = HEAP32[i8 >> 2] | 4; while (0);
 STACKTOP = i11;
 return;
}

function __ZN4wasm7Builder6addVarEPNS_8FunctionENS_4NameENS_8WasmTypeE(i6, i7, i5) {
 i6 = i6 | 0;
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8;
 HEAP32[i1 >> 2] = i5;
 i2 = i6 + 20 | 0;
 i3 = i6 + 24 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 i4 = i9;
 if ((HEAP32[i6 + 60 >> 2] | 0) != ((i9 - (HEAP32[i2 >> 2] | 0) >> 2) + ((HEAP32[i6 + 12 >> 2] | 0) - (HEAP32[i6 + 8 >> 2] | 0) >> 2) | 0)) ___assert_fail(20964, 20936, 177, 21033);
 if (i4 >>> 0 < (HEAP32[i6 + 28 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 4;
 } else __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRS2_EEEvDpOT_(i2, i1);
 i1 = i6 + 40 | 0;
 i2 = i6 + 44 | 0;
 i3 = (HEAP32[i2 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) >> 2;
 i4 = __ZNSt3__23mapIN4wasm4NameEjNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_jEEEEEixERS7_(i6 + 52 | 0, i7) | 0;
 HEAP32[i4 >> 2] = i3;
 i4 = HEAP32[i2 >> 2] | 0;
 if ((i4 | 0) == (HEAP32[i6 + 48 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i1, i7); else {
  HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
 }
 STACKTOP = i8;
 return i3 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE30__emplace_hint_unique_key_argsIS3_JRKNS_4pairIKS3_jEEEEENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEENS_21__tree_const_iteratorIS4_SM_iEERKT_DpOT0_(i5, i2, i1, i3) {
 i5 = i5 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i4 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i6 + 8 | 0;
 i4 = i6 + 4 | 0;
 i8 = i6;
 HEAP32[i8 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i7 >> 2] = HEAP32[i8 >> 2];
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS4_PNS_11__tree_nodeIS4_SE_EEiEESH_RKT_(i5, i7, i4, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  i7 = HEAP32[i3 + 4 >> 2] | 0;
  i8 = i1 + 16 | 0;
  HEAP32[i8 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i8 + 4 >> 2] = i7;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSF_SF_(i5, HEAP32[i4 >> 2] | 0, i2, i1);
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_7LiteralE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i2, 40) | 0;
 i3 = HEAP32[i1 >> 2] | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i2, __ZN4wasm13printWasmTypeENS_8WasmTypeE(i3) | 0) | 0, 29417) | 0;
 switch (i3 | 0) {
 case 0:
  {
   __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i2, 47966) | 0;
   break;
  }
 case 1:
  {
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi(i2, HEAP32[i1 + 8 >> 2] | 0) | 0;
   break;
  }
 case 2:
  {
   i3 = i1 + 8 | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx(i2, HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0) | 0;
   break;
  }
 case 3:
  {
   __ZN4wasm7Literal10printFloatERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEf(i2, +__ZNK4wasm7Literal6getf32Ev(i1));
   break;
  }
 case 4:
  {
   __ZN4wasm7Literal11printDoubleERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEd(i2, +__ZNK4wasm7Literal6getf64Ev(i1));
   break;
  }
 default:
  {}
 }
 return __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i2, 41) | 0;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7576;
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEjEENS_19__map_value_compareISA_SB_NS_4lessISA_EELb1EEENS_9allocatorISB_EEED2Ev(i1 + 84 | 0);
 __ZNSt3__213__vector_baseIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEED2Ev(i1 + 72 | 0);
 __ZNSt3__213__vector_baseIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEED2Ev(i1 + 60 | 0);
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEED2Ev(i1 + 48 | 0);
 __ZNSt3__213__vector_baseINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEENS_9allocatorISC_EEED2Ev(i1 + 32 | 0);
 HEAP32[i1 >> 2] = 7588;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 8 | 0);
 return;
}

function __ZNSt3__26vectorIN4wasm6ActionENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJNS2_4WhatERjRPPNS1_10ExpressionEEEEvDpOT_(i9, i5, i6, i7) {
 i9 = i9 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i8 = i10;
 i3 = i9 + 4 | 0;
 i4 = HEAP32[i9 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 4) + 1 | 0;
 if (i2 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i9);
 i1 = (HEAP32[i9 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 4 >>> 0 < 134217727) {
  i1 = i1 >> 3;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 268435455;
 __ZNSt3__214__split_bufferIN4wasm6ActionERNS_9allocatorIS2_EEEC2EjjS5_(i8, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 4, i9 + 8 | 0);
 i4 = i8 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 i7 = HEAP32[i7 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i3 + 8 >> 2] = i7;
 HEAP8[i3 + 12 >> 0] = 0;
 HEAP32[i4 >> 2] = i3 + 16;
 __ZNSt3__26vectorIN4wasm6ActionENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i9, i8);
 __ZNSt3__214__split_bufferIN4wasm6ActionERNS_9allocatorIS2_EEED2Ev(i8);
 STACKTOP = i10;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendIPcEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_(i10, i5, i8) {
 i10 = i10 | 0;
 i5 = i5 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i9 = 0;
 i3 = i5;
 i9 = i10 + 11 | 0;
 i1 = HEAP8[i9 >> 0] | 0;
 if (i1 << 24 >> 24 < 0) {
  i7 = HEAP32[i10 + 4 >> 2] | 0;
  i2 = (HEAP32[i10 + 8 >> 2] & 2147483647) + -1 | 0;
 } else {
  i7 = i1 & 255;
  i2 = 10;
 }
 i6 = i8 - i3 | 0;
 do if ((i8 | 0) != (i5 | 0)) {
  if ((i2 - i7 | 0) >>> 0 < i6 >>> 0) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj(i10, i2, i7 + i6 - i2 | 0, i7, i7, 0, 0);
   i1 = HEAP8[i9 >> 0] | 0;
  }
  if (i1 << 24 >> 24 < 0) i4 = HEAP32[i10 >> 2] | 0; else i4 = i10;
  i3 = i8 + (i7 - i3) | 0;
  i1 = i5;
  i2 = i4 + i7 | 0;
  while (1) {
   if ((i1 | 0) == (i8 | 0)) break;
   HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
   i1 = i1 + 1 | 0;
   i2 = i2 + 1 | 0;
  }
  HEAP8[i4 + i3 >> 0] = 0;
  i1 = i7 + i6 | 0;
  if ((HEAP8[i9 >> 0] | 0) < 0) {
   HEAP32[i10 + 4 >> 2] = i1;
   break;
  } else {
   HEAP8[i9 >> 0] = i1;
   break;
  }
 } while (0);
 return i10 | 0;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ImportENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ImportENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i3 >> 2] = i2;
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ImportENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i7, i5);
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ImportENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ExportENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ExportENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i3 >> 2] = i2;
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ExportENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i7, i5);
 __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ExportENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(32) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERy(i8, i7) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i9 + 20 | 0;
 i1 = i9 + 16 | 0;
 i3 = i9 + 12 | 0;
 i4 = i9 + 8 | 0;
 i10 = i9 + 24 | 0;
 i6 = i9 + 4 | 0;
 i5 = i9;
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b(i10, i8, 0);
 if (HEAP8[i10 >> 0] | 0) {
  HEAP32[i6 >> 2] = 0;
  i11 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i5 >> 2] = i11;
  i11 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61704) | 0;
  i10 = i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i12 = HEAP32[(HEAP32[i11 >> 2] | 0) + 36 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i10 + 24 >> 2];
  HEAP32[i4 >> 2] = 0;
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  FUNCTION_TABLE_iiiiiii[i12 & 63](i11, i1, i2, i10, i6, i7) | 0;
  __ZNSt3__26localeD2Ev(i5);
  i7 = i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i10 = i7 + 16 | 0;
  HEAP32[i10 >> 2] = HEAP32[i10 >> 2] | HEAP32[i6 >> 2] | (HEAP32[i7 + 24 >> 2] | 0) == 0;
 }
 STACKTOP = i9;
 return i8 | 0;
}

function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERx(i8, i7) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i9 + 20 | 0;
 i1 = i9 + 16 | 0;
 i3 = i9 + 12 | 0;
 i4 = i9 + 8 | 0;
 i10 = i9 + 24 | 0;
 i6 = i9 + 4 | 0;
 i5 = i9;
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b(i10, i8, 0);
 if (HEAP8[i10 >> 0] | 0) {
  HEAP32[i6 >> 2] = 0;
  i11 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i5 >> 2] = i11;
  i11 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61704) | 0;
  i10 = i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i12 = HEAP32[(HEAP32[i11 >> 2] | 0) + 20 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i10 + 24 >> 2];
  HEAP32[i4 >> 2] = 0;
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  FUNCTION_TABLE_iiiiiii[i12 & 63](i11, i1, i2, i10, i6, i7) | 0;
  __ZNSt3__26localeD2Ev(i5);
  i7 = i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i10 = i7 + 16 | 0;
  HEAP32[i10 >> 2] = HEAP32[i10 >> 2] | HEAP32[i6 >> 2] | (HEAP32[i7 + 24 >> 2] | 0) == 0;
 }
 STACKTOP = i9;
 return i8 | 0;
}

function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERj(i8, i7) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i9 + 20 | 0;
 i1 = i9 + 16 | 0;
 i3 = i9 + 12 | 0;
 i4 = i9 + 8 | 0;
 i10 = i9 + 24 | 0;
 i6 = i9 + 4 | 0;
 i5 = i9;
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b(i10, i8, 0);
 if (HEAP8[i10 >> 0] | 0) {
  HEAP32[i6 >> 2] = 0;
  i11 = __ZNKSt3__28ios_base6getlocEv(i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i5 >> 2] = i11;
  i11 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 61704) | 0;
  i10 = i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i12 = HEAP32[(HEAP32[i11 >> 2] | 0) + 28 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i10 + 24 >> 2];
  HEAP32[i4 >> 2] = 0;
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  FUNCTION_TABLE_iiiiiii[i12 & 63](i11, i1, i2, i10, i6, i7) | 0;
  __ZNSt3__26localeD2Ev(i5);
  i7 = i8 + (HEAP32[(HEAP32[i8 >> 2] | 0) + -12 >> 2] | 0) | 0;
  i10 = i7 + 16 | 0;
  HEAP32[i10 >> 2] = HEAP32[i10 >> 2] | HEAP32[i6 >> 2] | (HEAP32[i7 + 24 >> 2] | 0) == 0;
 }
 STACKTOP = i9;
 return i8 | 0;
}

function __ZN4wasm6Module11addFunctionEPNS_8FunctionE(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i9 + 4 | 0;
 i4 = i9;
 i5 = i8 + 176 | 0;
 i1 = __ZN4wasm4Name7fromIntEj(HEAP32[i5 >> 2] | 0) | 0;
 HEAP32[i7 >> 2] = i1;
 if (!(HEAP32[i6 >> 2] | 0)) HEAP32[i6 >> 2] = i1;
 i1 = i6;
 HEAP32[i4 >> 2] = i1;
 i2 = i8 + 40 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (i3 >>> 0 >= (HEAP32[i8 + 44 >> 2] | 0) >>> 0) {
  __ZNSt3__26vectorINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i8 + 36 | 0, i4);
  i1 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  if (i1 | 0) {
   __ZN4wasm8FunctionD2Ev(i1);
   __ZdlPv(i1);
  }
 } else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = i3 + 4;
  HEAP32[i4 >> 2] = 0;
 }
 i8 = i8 + 152 | 0;
 i4 = __ZNSt3__23mapIN4wasm4NameEPNS1_8FunctionENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i8, i6) | 0;
 HEAP32[i4 >> 2] = i6;
 i8 = __ZNSt3__23mapIN4wasm4NameEPNS1_8FunctionENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i8, i7) | 0;
 HEAP32[i8 >> 2] = i6;
 HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 1;
 STACKTOP = i9;
 return;
}

function __ZN4wasm17WasmBinaryBuilder7visitIfEPNS_2IfE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5;
 if (HEAP8[i4 + 12 >> 0] | 0) {
  i2 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24087) | 0;
  i6 = __ZNKSt3__28ios_base6getlocEv(i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i6;
  i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i2, i6) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i2) | 0;
 }
 i2 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i4) | 0;
 HEAP32[i3 + 8 >> 2] = i2;
 i2 = __ZN4wasm17WasmBinaryBuilder8getBlockEv(i4) | 0;
 HEAP32[i3 + 12 >> 2] = i2;
 i2 = i4 + 108 | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if ((i1 | 0) == 4) {
  i1 = __ZN4wasm17WasmBinaryBuilder8getBlockEv(i4) | 0;
  HEAP32[i3 + 16 >> 2] = i1;
  __ZN4wasm2If8finalizeEv(i3);
  i1 = HEAP32[i2 >> 2] | 0;
 }
 if ((i1 | 0) == 15) {
  STACKTOP = i5;
  return;
 } else ___assert_fail(24099, 22948, 1763, 24134);
}

function __ZNSt3__27__sort4IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_SL_T_(i6, i7, i5, i4, i1) {
 i6 = i6 | 0;
 i7 = i7 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __ZNSt3__27__sort3IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_T_(i6, i7, i5, i1) | 0;
 i2 = HEAP32[i4 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 if (+HEAPF64[i2 + 16 >> 3] > +HEAPF64[i3 + 16 >> 3]) {
  HEAP32[i5 >> 2] = i2;
  HEAP32[i4 >> 2] = i3;
  i2 = i1 + 1 | 0;
  i3 = HEAP32[i5 >> 2] | 0;
  i4 = HEAP32[i7 >> 2] | 0;
  if (+HEAPF64[i3 + 16 >> 3] > +HEAPF64[i4 + 16 >> 3]) {
   HEAP32[i7 >> 2] = i3;
   HEAP32[i5 >> 2] = i4;
   i2 = HEAP32[i7 >> 2] | 0;
   i3 = HEAP32[i6 >> 2] | 0;
   if (+HEAPF64[i2 + 16 >> 3] > +HEAPF64[i3 + 16 >> 3]) {
    HEAP32[i6 >> 2] = i2;
    HEAP32[i7 >> 2] = i3;
    i1 = i1 + 3 | 0;
   } else i1 = i1 + 2 | 0;
  } else i1 = i2;
 }
 return i1 | 0;
}

function __ZN4wasm13WasmValidator12shouldBeTrueINS_4NameEEEbbT_PKc(i6, i4, i3, i5) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7 + 4 | 0;
 i2 = i7;
 if (i4) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i5) | 0, 19438) | 0;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  i5 = __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i5, i1) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNSt3__27shuffleINS_11__wrap_iterIPjEERNS_23mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEEEEvT_S7_OT0_(i8, i2, i9) {
 i8 = i8 | 0;
 i2 = i2 | 0;
 i9 = i9 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i10 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i10 = i11 + 8 | 0;
 i7 = i11;
 i1 = HEAP32[i2 >> 2] | 0;
 i3 = HEAP32[i8 >> 2] | 0;
 i4 = i1 - i3 | 0;
 if ((i4 | 0) > 4) {
  HEAP32[i10 >> 2] = 0;
  HEAP32[i10 + 4 >> 2] = 2147483647;
  i6 = i1 + -4 | 0;
  HEAP32[i2 >> 2] = i6;
  i5 = i7 + 4 | 0;
  i1 = i4 >> 2;
  while (1) {
   i1 = i1 + -1 | 0;
   if (i3 >>> 0 >= i6 >>> 0) break;
   HEAP32[i7 >> 2] = 0;
   HEAP32[i5 >> 2] = i1;
   i2 = __ZNSt3__224uniform_int_distributionIiEclINS_23mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEEEEiRT_RKNS1_10param_typeE(i10, i9, i7) | 0;
   if (i2 | 0) {
    i4 = i3 + (i2 << 2) | 0;
    i2 = HEAP32[i3 >> 2] | 0;
    HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
    HEAP32[i4 >> 2] = i2;
   }
   i4 = i3 + 4 | 0;
   HEAP32[i8 >> 2] = i4;
   i3 = i4;
  }
 }
 STACKTOP = i11;
 return;
}

function __ZL25default_terminate_handlerv() {
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i7 = i5 + 32 | 0;
 i3 = i5 + 24 | 0;
 i8 = i5 + 16 | 0;
 i6 = i5;
 i5 = i5 + 36 | 0;
 i1 = ___cxa_get_globals_fast() | 0;
 if (i1 | 0 ? (i4 = HEAP32[i1 >> 2] | 0, i4 | 0) : 0) {
  i1 = i4 + 48 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  i1 = HEAP32[i1 + 4 >> 2] | 0;
  if (!((i2 & -256 | 0) == 1126902528 & (i1 | 0) == 1129074247)) {
   HEAP32[i3 >> 2] = HEAP32[3855];
   _abort_message(56340, i3);
  }
  if ((i2 | 0) == 1126902529 & (i1 | 0) == 1129074247) i1 = HEAP32[i4 + 44 >> 2] | 0; else i1 = i4 + 80 | 0;
  HEAP32[i5 >> 2] = i1;
  i4 = HEAP32[i4 >> 2] | 0;
  i1 = HEAP32[i4 + 4 >> 2] | 0;
  if (FUNCTION_TABLE_iiii[HEAP32[(HEAP32[1016] | 0) + 16 >> 2] & 31](4064, i4, i5) | 0) {
   i8 = HEAP32[i5 >> 2] | 0;
   i5 = HEAP32[3855] | 0;
   i8 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i8 >> 2] | 0) + 8 >> 2] & 255](i8) | 0;
   HEAP32[i6 >> 2] = i5;
   HEAP32[i6 + 4 >> 2] = i1;
   HEAP32[i6 + 8 >> 2] = i8;
   _abort_message(56254, i6);
  } else {
   HEAP32[i8 >> 2] = HEAP32[3855];
   HEAP32[i8 + 4 >> 2] = i1;
   _abort_message(56299, i8);
  }
 }
 _abort_message(56378, i7);
}

function __ZNSt3__26vectorIbNS_9allocatorIbEEE7reserveEj(i6, i4) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i7 + 16 | 0;
 i1 = i7 + 8 | 0;
 i2 = i7;
 i3 = i6 + 8 | 0;
 if (HEAP32[i3 >> 2] << 5 >>> 0 < i4 >>> 0) {
  HEAP32[i5 >> 2] = 0;
  i9 = i5 + 4 | 0;
  HEAP32[i9 >> 2] = 0;
  i8 = i5 + 8 | 0;
  HEAP32[i8 >> 2] = 0;
  __ZNSt3__26vectorIbNS_9allocatorIbEEE8allocateEj(i5, i4);
  i11 = HEAP32[i6 >> 2] | 0;
  HEAP32[i1 >> 2] = i11;
  HEAP32[i1 + 4 >> 2] = 0;
  i4 = i6 + 4 | 0;
  i10 = HEAP32[i4 >> 2] | 0;
  HEAP32[i2 >> 2] = i11 + (i10 >>> 5 << 2);
  HEAP32[i2 + 4 >> 2] = i10 & 31;
  __ZNSt3__26vectorIbNS_9allocatorIbEEE18__construct_at_endINS_14__bit_iteratorIS3_Lb0ELj0EEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_(i5, i1, i2);
  i2 = HEAP32[i6 >> 2] | 0;
  HEAP32[i6 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i5 >> 2] = i2;
  i6 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i9 >> 2] = i6;
  i6 = HEAP32[i3 >> 2] | 0;
  HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i8 >> 2] = i6;
  __ZNSt3__26vectorIbNS_9allocatorIbEEED2Ev(i5);
 }
 STACKTOP = i7;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm12CallIndirectEN6cashew7IStringEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS4_JRKNS_21piecewise_construct_tENS_5tupleIJRKS4_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIPN4wasm12CallIndirectEN6cashew7IStringEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEESK_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm12CallIndirectEN6cashew7IStringEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZN4wasm17WasmBinaryBuilder10readMemoryEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i4 + 4 | 0;
 i2 = i4;
 if (HEAP8[i3 + 12 >> 0] | 0) {
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23461) | 0;
  i6 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i6;
  i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i6) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
 }
 i6 = (HEAP32[i3 >> 2] | 0) + 60 | 0;
 __ZN4wasm7AddressaSEy(i6, __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i3) | 0, 0) | 0;
 i6 = (HEAP32[i3 >> 2] | 0) + 64 | 0;
 __ZN4wasm7AddressaSEy(i6, __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i3) | 0, 0) | 0;
 if ((__ZN4wasm17WasmBinaryBuilder7getInt8Ev(i3) | 0) << 24 >> 24) {
  i6 = (HEAP32[i3 >> 2] | 0) + 80 | 0;
  __ZN6cashew7IString3setEPKcb(i2, 49105, 0);
  HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 }
 STACKTOP = i4;
 return;
}

function __ZNSt3__26vectorINS_4pairIPN4wasm7ElementEPNS2_5BlockEEENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRS4_RS6_EEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferINS_4pairIPN4wasm7ElementEPNS2_5BlockEEERNS_9allocatorIS7_EEEC2EjjSA_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorINS_4pairIPN4wasm7ElementEPNS2_5BlockEEENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i8, i7);
 __ZNSt3__214__split_bufferINS_4pairIPN4wasm7ElementEPNS2_5BlockEEERNS_9allocatorIS7_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorINS0_IPPN4wasm10ExpressionENS_9allocatorIS4_EEEENS5_IS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS8_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i10 = HEAP32[i4 >> 2] | 0;
  i8 = i10 + -12 | 0;
  i7 = i1 + -12 | 0;
  HEAP32[i8 >> 2] = 0;
  i9 = i10 + -8 | 0;
  HEAP32[i9 >> 2] = 0;
  HEAP32[i10 + -4 >> 2] = 0;
  HEAP32[i8 >> 2] = HEAP32[i7 >> 2];
  i8 = i1 + -8 | 0;
  HEAP32[i9 >> 2] = HEAP32[i8 >> 2];
  i9 = i1 + -4 | 0;
  HEAP32[i10 + -4 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i9 >> 2] = 0;
  HEAP32[i8 >> 2] = 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -12;
  i1 = i7;
 }
 i8 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i8;
 i8 = i5 + 8 | 0;
 i10 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
 HEAP32[i8 >> 2] = i10;
 i8 = i6 + 8 | 0;
 i10 = i5 + 12 | 0;
 i9 = HEAP32[i8 >> 2] | 0;
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 HEAP32[i10 >> 2] = i9;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE21__push_back_slow_pathIS5_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = (((HEAP32[i3 >> 2] | 0) - i4 | 0) / 24 | 0) + 1 | 0;
 if (i2 >>> 0 > 178956970) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = ((HEAP32[i7 + 8 >> 2] | 0) - i4 | 0) / 24 | 0;
 if (i1 >>> 0 < 89478485) {
  i1 = i1 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 178956970;
 __ZNSt3__214__split_bufferINS_8functionIFN4wasm15ThreadWorkStateEvEEERNS_9allocatorIS5_EEEC2EjjS8_(i5, i1, ((HEAP32[i3 >> 2] | 0) - i4 | 0) / 24 | 0, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i3, i6);
 HEAP32[i4 >> 2] = i3 + 24;
 __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS5_RS7_EE(i7, i5);
 __ZNSt3__214__split_bufferINS_8functionIFN4wasm15ThreadWorkStateEvEEERNS_9allocatorIS5_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE13__move_assignERSG_NS_17integral_constantIbLb1EEE(i8, i2, i1) {
 i8 = i8 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE5clearEv(i8);
 i7 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = 0;
 i1 = HEAP32[i8 >> 2] | 0;
 HEAP32[i8 >> 2] = i7;
 if (i1 | 0) __ZdlPv(i1);
 i7 = i2 + 4 | 0;
 i4 = i8 + 4 | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = 0;
 i7 = i2 + 12 | 0;
 i3 = HEAP32[i7 >> 2] | 0;
 HEAP32[i8 + 12 >> 2] = i3;
 HEAP32[i8 + 16 >> 2] = HEAP32[i2 + 16 >> 2];
 i5 = i2 + 8 | 0;
 i1 = HEAP32[i5 >> 2] | 0;
 i6 = i8 + 8 | 0;
 HEAP32[i6 >> 2] = i1;
 if (i3 | 0) {
  i3 = HEAP32[i1 + 4 >> 2] | 0;
  i1 = HEAP32[i4 >> 2] | 0;
  i2 = i1 + -1 | 0;
  if (!(i2 & i1)) i1 = i2 & i3; else i1 = (i3 >>> 0) % (i1 >>> 0) | 0;
  HEAP32[(HEAP32[i8 >> 2] | 0) + (i1 << 2) >> 2] = i6;
  HEAP32[i5 >> 2] = 0;
  HEAP32[i7 >> 2] = 0;
 }
 return;
}

function __ZN4wasm22SExpressionWasmBuilder9makeBreakERNS_7ElementE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0;
 i4 = __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(HEAP32[i3 + 4 >> 2] | 0) | 0;
 i1 = __ZN4wasm22SExpressionWasmBuilder8getLabelERNS_7ElementE(i3, __ZN4wasm7ElementixEj(i2, 1) | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i1;
 i1 = (__ZN4wasm7Element4listEv(i2) | 0) + 8 | 0;
 if ((HEAP32[i1 >> 2] | 0) != 2) {
  i1 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i2, 0) | 0) | 0;
  if ((i1 | 0) == (HEAP32[14988] | 0)) {
   i1 = (__ZN4wasm7Element4listEv(i2) | 0) + 8 | 0;
   if ((HEAP32[i1 >> 2] | 0) >>> 0 > 3) {
    i1 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i3, __ZN4wasm7ElementixEj(i2, 2) | 0) | 0;
    HEAP32[i4 + 12 >> 2] = i1;
    i1 = 3;
   } else i1 = 2;
   i1 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i3, __ZN4wasm7ElementixEj(i2, i1) | 0) | 0;
   HEAP32[i4 + 16 >> 2] = i1;
  } else {
   i1 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i3, __ZN4wasm7ElementixEj(i2, 2) | 0) | 0;
   HEAP32[i4 + 12 >> 2] = i1;
   i1 = HEAP32[i4 + 16 >> 2] | 0;
  }
  if (i1 | 0) HEAP32[i4 + 4 >> 2] = 0;
 }
 return i4 | 0;
}

function __ZN4wasm17WasmBinaryBuilder13visitGetLocalEPNS_8GetLocalE(i3, i4) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5;
 if (HEAP8[i3 + 12 >> 0] | 0) {
  i2 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24460) | 0;
  i2 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i2, HEAP32[i3 + 16 >> 2] | 0) | 0;
  i6 = __ZNKSt3__28ios_base6getlocEv(i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i6;
  i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i2, i6) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i2) | 0;
 }
 i2 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i3) | 0;
 HEAP32[i4 + 8 >> 2] = i2;
 i1 = HEAP32[i3 + 64 >> 2] | 0;
 if (i2 >>> 0 < (__ZN4wasm8Function12getNumLocalsEv(i1) | 0) >>> 0) {
  i6 = __ZN4wasm8Function12getLocalTypeEj(i1, i2) | 0;
  HEAP32[i4 + 4 >> 2] = i6;
  STACKTOP = i5;
  return;
 } else ___assert_fail(24479, 22948, 1848, 24522);
}

function __ZN4wasm13WasmValidator13shouldBeFalseINS_4NameEEEbbT_PKc(i6, i4, i3, i5) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7 + 4 | 0;
 i2 = i7;
 if (i4) {
  __ZN4wasm13WasmValidator4failEv(i6) | 0;
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 20714) | 0, i5) | 0, 19438) | 0;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  i5 = __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i5, i1) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
  HEAP8[i6 + 28 >> 0] = 0;
 }
 STACKTOP = i7;
 return 0;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE8__appendEj(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i2 = HEAP32[i8 + 8 >> 2] | 0;
 i5 = i8 + 4 | 0;
 i1 = HEAP32[i5 >> 2] | 0;
 if (i2 - i1 >> 2 >>> 0 < i6 >>> 0) {
  i4 = HEAP32[i8 >> 2] | 0;
  i3 = (i1 - i4 >> 2) + i6 | 0;
  if (i3 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
  i1 = i2 - i4 | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
  } else i1 = 1073741823;
  __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEEC2EjjS5_(i7, i1, (HEAP32[i5 >> 2] | 0) - i4 >> 2, i8 + 8 | 0);
  i5 = i7 + 8 | 0;
  i4 = HEAP32[i5 >> 2] | 0;
  _memset(i4 | 0, 0, i6 << 2 | 0) | 0;
  HEAP32[i5 >> 2] = i4 + (i6 << 2);
  __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i8, i7);
  __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEED2Ev(i7);
 } else {
  _memset(i1 | 0, 0, i6 << 2 | 0) | 0;
  HEAP32[i5 >> 2] = i1 + (i6 << 2);
 }
 STACKTOP = i9;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE10doEndBreakEPS1_PPNS_10ExpressionE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i4 = __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i6 >> 2] | 0) | 0;
 i1 = __ZNSt3__23mapIN4wasm4NameENS_6vectorIPNS1_9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS5_vEENS1_8LivenessEE10BasicBlockENS_9allocatorISB_EEEENS_4lessIS2_EENSC_INS_4pairIKS2_SE_EEEEEixERSI_(i7 + 64 | 0, i4 + 8 | 0) | 0;
 i5 = i7 + 60 | 0;
 i2 = i1 + 4 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if ((i3 | 0) == (HEAP32[i1 + 8 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE21__push_back_slow_pathIRKS9_EEvOT_(i1, i5); else {
  HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
 }
 i1 = HEAP32[i5 >> 2] | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i7, i6);
 if (HEAP32[i4 + 16 >> 2] | 0) __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i7 + 16 | 0, i1, HEAP32[i5 >> 2] | 0);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESJ_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSH_SH_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKcj(i8, i5, i1, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i7 = i8 + 11 | 0;
 i2 = HEAP8[i7 >> 0] | 0;
 i3 = i2 << 24 >> 24 < 0;
 if (i3) i4 = HEAP32[i8 + 4 >> 2] | 0; else i4 = i2 & 255;
 if (i4 >>> 0 < i5 >>> 0) __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv(i8);
 if (i3) i2 = (HEAP32[i8 + 8 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
 if ((i2 - i4 | 0) >>> 0 >= i6 >>> 0) {
  if (i6 | 0) {
   if (i3) i3 = HEAP32[i8 >> 2] | 0; else i3 = i8;
   i2 = i3 + i5 | 0;
   if ((i4 | 0) != (i5 | 0)) {
    _memmove(i2 + i6 | 0, i2 | 0, i4 - i5 | 0) | 0;
    i1 = i2 >>> 0 <= i1 >>> 0 & (i3 + i4 | 0) >>> 0 > i1 >>> 0 ? i1 + i6 | 0 : i1;
   }
   _memmove(i2 | 0, i1 | 0, i6 | 0) | 0;
   i1 = i4 + i6 | 0;
   if ((HEAP8[i7 >> 0] | 0) < 0) HEAP32[i8 + 4 >> 2] = i1; else HEAP8[i7 >> 0] = i1;
   HEAP8[i3 + i1 >> 0] = 0;
  }
 } else __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE21__grow_by_and_replaceEjjjjjjPKc(i8, i2, i4 + i6 - i2 | 0, i4, i5, 0, i6, i1);
 return i8 | 0;
}

function __ZN4wasm8LocalSet6insertEj(i7, i10) {
 i7 = i7 | 0;
 i10 = i10 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i11;
 HEAP32[i1 >> 2] = i10;
 i9 = i7 + 4 | 0;
 i3 = HEAP32[i9 >> 2] | 0;
 i5 = HEAP32[i7 >> 2] | 0;
 i6 = i3 - i5 >> 2;
 i4 = 0;
 while (1) {
  if (i4 >>> 0 >= i6 >>> 0) {
   i8 = 10;
   break;
  }
  i2 = HEAP32[i5 + (i4 << 2) >> 2] | 0;
  if ((i2 | 0) == (i10 | 0)) break;
  if (i2 >>> 0 > i10 >>> 0) {
   i8 = 5;
   break;
  }
  i4 = i4 + 1 | 0;
 }
 do if ((i8 | 0) == 5) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i7, i6 + 1 | 0);
  i2 = HEAP32[i7 >> 2] | 0;
  i3 = i2;
  i2 = (HEAP32[i9 >> 2] | 0) - i2 >> 2;
  while (1) {
   i1 = i2 + -1 | 0;
   if (i1 >>> 0 <= i4 >>> 0) break;
   HEAP32[i3 + (i1 << 2) >> 2] = HEAP32[i3 + (i2 + -2 << 2) >> 2];
   i2 = i1;
  }
  HEAP32[i3 + (i4 << 2) >> 2] = i10;
 } else if ((i8 | 0) == 10) if ((i3 | 0) == (HEAP32[i7 + 8 >> 2] | 0)) {
  __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIRKjEEvOT_(i7, i1);
  break;
 } else {
  HEAP32[i3 >> 2] = i10;
  HEAP32[i9 >> 2] = i3 + 4;
  break;
 } while (0);
 STACKTOP = i11;
 return;
}

function __ZN4wasm15RemoveUnusedBrs4scanEPS0_PPNS_10ExpressionE(i1, i4) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i2 = i1 + 16 | 0;
 __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 207, i4);
 i3 = HEAP32[i4 >> 2] | 0;
 if ((i3 | 0) == 0 | (HEAP32[i3 >> 2] | 0) != 2) __ZN4wasm10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i1, i4); else {
  __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 208, i4);
  i1 = i3 + 16 | 0;
  if (HEAP32[i1 >> 2] | 0) {
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 206, i1);
   __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 209, i4);
  }
  __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 206, i3 + 12 | 0);
  __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 210, i4);
  __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 206, i3 + 8 | 0);
 }
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 >> 2] | 0;
 while (1) {
  i1 = HEAP8[i2 >> 0] | 0;
  if (!(i1 << 24 >> 24)) break;
  if (__ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE7isSpaceEc(i1) | 0) {
   i3 = i2 + 1 | 0;
   HEAP32[i4 >> 2] = i3;
   i2 = i3;
   continue;
  }
  if (i1 << 24 >> 24 != 47) break;
  if ((HEAP8[i2 + 1 >> 0] | 0) == 47) {
   i3 = i2 + 2 | 0;
   while (1) {
    HEAP32[i4 >> 2] = i3;
    i5 = HEAP8[i3 >> 0] | 0;
    i1 = i5 << 24 >> 24 == 0;
    i2 = i3 + 1 | 0;
    if (i5 << 24 >> 24 != 10 & (i1 ^ 1)) i3 = i2; else break;
   }
   if (i1) {
    i2 = i3;
    continue;
   }
   HEAP32[i4 >> 2] = i2;
   continue;
  }
  if ((HEAP8[i2 + 1 >> 0] | 0) != 42) break;
  i1 = i2 + 2 | 0;
  L16 : while (1) {
   HEAP32[i4 >> 2] = i1;
   switch (HEAP8[i1 >> 0] | 0) {
   case 0:
    break L16;
   case 42:
    {
     i2 = i1 + 1 | 0;
     if ((HEAP8[i2 >> 0] | 0) == 47) break L16; else {
      i1 = i2;
      continue L16;
     }
    }
   default:
    {
     i1 = i1 + 1 | 0;
     continue L16;
    }
   }
  }
  i2 = i1 + 2 | 0;
  HEAP32[i4 >> 2] = i2;
 }
 return;
}

function __ZNKSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strEv(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 48 >> 2] | 0;
 L1 : do if (!(i1 & 16)) {
  if (i1 & 8 | 0) {
   i3 = HEAP32[i4 + 8 >> 2] | 0;
   i4 = HEAP32[i4 + 16 >> 2] | 0;
   HEAP32[i5 >> 2] = 0;
   HEAP32[i5 + 4 >> 2] = 0;
   HEAP32[i5 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPcEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_(i5, i3, i4);
   break;
  };
  HEAP32[i5 >> 2] = 0;
  HEAP32[i5 + 4 >> 2] = 0;
  HEAP32[i5 + 8 >> 2] = 0;
  i1 = 0;
  while (1) {
   if ((i1 | 0) == 3) break L1;
   HEAP32[i5 + (i1 << 2) >> 2] = 0;
   i1 = i1 + 1 | 0;
  }
 } else {
  i2 = i4 + 44 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  i3 = HEAP32[i4 + 24 >> 2] | 0;
  if (i1 >>> 0 < i3 >>> 0) {
   HEAP32[i2 >> 2] = i3;
   i1 = i3;
  }
  i4 = HEAP32[i4 + 20 >> 2] | 0;
  HEAP32[i5 >> 2] = 0;
  HEAP32[i5 + 4 >> 2] = 0;
  HEAP32[i5 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPcEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_(i5, i4, i1);
 } while (0);
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE15parseAfterParenERPc(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = i1 + 4 | 0;
 __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE6resizeEj(i1, (((HEAP32[i4 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) | 0) / 12 | 0) + 1 | 0);
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i2);
 i3 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i1, i2, 56966) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i2);
 i1 = HEAP32[i2 >> 2] | 0;
 if ((HEAP8[i1 >> 0] | 0) != 41) ___assert_fail(31539, 31173, 662, 32113);
 HEAP32[i2 >> 2] = i1 + 1;
 i1 = HEAP32[i4 >> 2] | 0;
 i2 = i1 + -12 | 0;
 if ((HEAP32[i1 + -8 >> 2] | 0) == (HEAP32[i2 >> 2] | 0)) i5 = i1; else ___assert_fail(31817, 31173, 664, 32113);
 while (1) {
  if ((i5 | 0) == (i2 | 0)) break;
  i1 = i5 + -12 | 0;
  HEAP32[i4 >> 2] = i1;
  __ZNSt3__213__vector_baseIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEED2Ev(i1);
  i5 = HEAP32[i4 >> 2] | 0;
 }
 return i3 | 0;
}

function _memchr(i1, i5, i2) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i6 = 0, i7 = 0;
 i6 = i5 & 255;
 i3 = (i2 | 0) != 0;
 L1 : do if (i3 & (i1 & 3 | 0) != 0) {
  i4 = i5 & 255;
  while (1) {
   if ((HEAP8[i1 >> 0] | 0) == i4 << 24 >> 24) {
    i7 = 6;
    break L1;
   }
   i1 = i1 + 1 | 0;
   i2 = i2 + -1 | 0;
   i3 = (i2 | 0) != 0;
   if (!(i3 & (i1 & 3 | 0) != 0)) {
    i7 = 5;
    break;
   }
  }
 } else i7 = 5; while (0);
 if ((i7 | 0) == 5) if (i3) i7 = 6; else i2 = 0;
 L8 : do if ((i7 | 0) == 6) {
  i4 = i5 & 255;
  if ((HEAP8[i1 >> 0] | 0) != i4 << 24 >> 24) {
   i3 = Math_imul(i6, 16843009) | 0;
   L11 : do if (i2 >>> 0 > 3) while (1) {
    i6 = HEAP32[i1 >> 2] ^ i3;
    if ((i6 & -2139062144 ^ -2139062144) & i6 + -16843009 | 0) break;
    i1 = i1 + 4 | 0;
    i2 = i2 + -4 | 0;
    if (i2 >>> 0 <= 3) {
     i7 = 11;
     break L11;
    }
   } else i7 = 11; while (0);
   if ((i7 | 0) == 11) if (!i2) {
    i2 = 0;
    break;
   }
   while (1) {
    if ((HEAP8[i1 >> 0] | 0) == i4 << 24 >> 24) break L8;
    i1 = i1 + 1 | 0;
    i2 = i2 + -1 | 0;
    if (!i2) {
     i2 = 0;
     break;
    }
   }
  }
 } while (0);
 return (i2 | 0 ? i1 : 0) | 0;
}

function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE4findIS7_EENS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE13__lower_boundIS7_EENS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEERKT_SN_SN_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? (i6 = i2 + 16 | 0, i5 = HEAP8[i3 + 11 >> 0] | 0, i8 = i5 << 24 >> 24 < 0, i5 = i8 ? HEAP32[i3 + 4 >> 2] | 0 : i5 & 255, i4 = HEAP8[i6 + 11 >> 0] | 0, i7 = i4 << 24 >> 24 < 0, i4 = i7 ? HEAP32[i2 + 20 >> 2] | 0 : i4 & 255, i3 = __ZNSt3__211char_traitsIcE7compareEPKcS3_j(i8 ? HEAP32[i3 >> 2] | 0 : i3, i7 ? HEAP32[i6 >> 2] | 0 : i6, i4 >>> 0 < i5 >>> 0 ? i4 : i5) | 0, (((i3 | 0) == 0 ? (i5 >>> 0 < i4 >>> 0 ? -2147483648 : 0) : i3) | 0) >= 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZN4wasm6Module9addImportEPNS_6ImportE(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i9 + 4 | 0;
 i4 = i9;
 i5 = i8 + 168 | 0;
 i1 = __ZN4wasm4Name7fromIntEj(HEAP32[i5 >> 2] | 0) | 0;
 HEAP32[i7 >> 2] = i1;
 if (!(HEAP32[i6 >> 2] | 0)) HEAP32[i6 >> 2] = i1;
 i1 = i6;
 HEAP32[i4 >> 2] = i1;
 i2 = i8 + 16 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (i3 >>> 0 >= (HEAP32[i8 + 20 >> 2] | 0) >>> 0) {
  __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ImportENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i8 + 12 | 0, i4);
  i1 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  if (i1 | 0) __ZdlPv(i1);
 } else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = i3 + 4;
  HEAP32[i4 >> 2] = 0;
 }
 i8 = i8 + 128 | 0;
 i4 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ImportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i8, i6) | 0;
 HEAP32[i4 >> 2] = i6;
 i8 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ImportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i8, i7) | 0;
 HEAP32[i8 >> 2] = i6;
 HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 1;
 STACKTOP = i9;
 return;
}

function __ZN4wasm6Module9addExportEPNS_6ExportE(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i9 + 4 | 0;
 i4 = i9;
 i5 = i8 + 172 | 0;
 i1 = __ZN4wasm4Name7fromIntEj(HEAP32[i5 >> 2] | 0) | 0;
 HEAP32[i7 >> 2] = i1;
 if (!(HEAP32[i6 >> 2] | 0)) HEAP32[i6 >> 2] = i1;
 i1 = i6;
 HEAP32[i4 >> 2] = i1;
 i2 = i8 + 28 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (i3 >>> 0 >= (HEAP32[i8 + 32 >> 2] | 0) >>> 0) {
  __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ExportENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_(i8 + 24 | 0, i4);
  i1 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  if (i1 | 0) __ZdlPv(i1);
 } else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = i3 + 4;
  HEAP32[i4 >> 2] = 0;
 }
 i8 = i8 + 140 | 0;
 i4 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ExportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i8, i6) | 0;
 HEAP32[i4 >> 2] = i6;
 i8 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ExportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i8, i7) | 0;
 HEAP32[i8 >> 2] = i6;
 HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 1;
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE8__appendEj(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i2 = HEAP32[i8 + 8 >> 2] | 0;
 i5 = i8 + 4 | 0;
 i1 = HEAP32[i5 >> 2] | 0;
 if (i2 - i1 >> 2 >>> 0 < i6 >>> 0) {
  i4 = HEAP32[i8 >> 2] | 0;
  i3 = (i1 - i4 >> 2) + i6 | 0;
  if (i3 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
  i1 = i2 - i4 | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
  } else i1 = 1073741823;
  __ZNSt3__214__split_bufferIN4wasm4NameERNS_9allocatorIS2_EEEC2EjjS5_(i7, i1, (HEAP32[i5 >> 2] | 0) - i4 >> 2, i8 + 8 | 0);
  i5 = i7 + 8 | 0;
  i4 = HEAP32[i5 >> 2] | 0;
  _memset(i4 | 0, 0, i6 << 2 | 0) | 0;
  HEAP32[i5 >> 2] = i4 + (i6 << 2);
  __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i8, i7);
  __ZNSt3__214__split_bufferIN4wasm4NameERNS_9allocatorIS2_EEED2Ev(i7);
 } else {
  _memset(i1 | 0, 0, i6 << 2 | 0) | 0;
  HEAP32[i5 >> 2] = i1 + (i6 << 2);
 }
 STACKTOP = i9;
 return;
}

function ___stpncpy(i2, i3, i1) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0, i6 = 0;
 i5 = i3;
 do if (!((i5 ^ i2) & 3)) {
  i4 = (i1 | 0) != 0;
  L3 : do if (i4 & (i5 & 3 | 0) != 0) while (1) {
   i5 = HEAP8[i3 >> 0] | 0;
   HEAP8[i2 >> 0] = i5;
   if (!(i5 << 24 >> 24)) break L3;
   i1 = i1 + -1 | 0;
   i3 = i3 + 1 | 0;
   i2 = i2 + 1 | 0;
   i4 = (i1 | 0) != 0;
   if (!(i4 & (i3 & 3 | 0) != 0)) {
    i6 = 5;
    break;
   }
  } else i6 = 5; while (0);
  if ((i6 | 0) == 5) if (!i4) {
   i1 = 0;
   break;
  }
  if (HEAP8[i3 >> 0] | 0) {
   L11 : do if (i1 >>> 0 > 3) do {
    i4 = HEAP32[i3 >> 2] | 0;
    if ((i4 & -2139062144 ^ -2139062144) & i4 + -16843009 | 0) break L11;
    HEAP32[i2 >> 2] = i4;
    i1 = i1 + -4 | 0;
    i3 = i3 + 4 | 0;
    i2 = i2 + 4 | 0;
   } while (i1 >>> 0 > 3); while (0);
   i6 = 11;
  }
 } else i6 = 11; while (0);
 L16 : do if ((i6 | 0) == 11) if (!i1) i1 = 0; else while (1) {
  i6 = HEAP8[i3 >> 0] | 0;
  HEAP8[i2 >> 0] = i6;
  if (!(i6 << 24 >> 24)) break L16;
  i1 = i1 + -1 | 0;
  i2 = i2 + 1 | 0;
  if (!i1) {
   i1 = 0;
   break;
  } else i3 = i3 + 1 | 0;
 } while (0);
 _memset(i2 | 0, 0, i1 | 0) | 0;
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESJ_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSH_SH_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZN4wasm17WasmBinaryBuilder11visitSelectEPNS_6SelectE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i4;
 if (HEAP8[i3 + 12 >> 0] | 0) {
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24568) | 0;
  i6 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i6;
  i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i6) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
 }
 i5 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i3) | 0;
 HEAP32[i2 + 16 >> 2] = i5;
 i5 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i3) | 0;
 i6 = i2 + 12 | 0;
 HEAP32[i6 >> 2] = i5;
 i5 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i3) | 0;
 HEAP32[i2 + 8 >> 2] = i5;
 i5 = HEAP32[i5 + 4 >> 2] | 0;
 HEAP32[i2 + 4 >> 2] = (i5 | 0) != 5 ? i5 : HEAP32[(HEAP32[i6 >> 2] | 0) + 4 >> 2] | 0;
 STACKTOP = i4;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE14__erase_uniqueIS3_EEjRKT_(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5 + 4 | 0;
 i3 = i5;
 i1 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE4findIS3_EENS_15__tree_iteratorISG_PNS_11__tree_nodeISG_PvEEiEERKT_(i4, i1) | 0;
 if ((i1 | 0) == (i4 + 4 | 0)) i1 = 0; else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE5eraseENS_21__tree_const_iteratorISG_PNS_11__tree_nodeISG_PvEEiEE(i4, i2) | 0;
  i1 = 1;
 }
 STACKTOP = i5;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESI_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSG_SG_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 4) + 1 | 0;
 if (i2 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 4 >>> 0 < 134217727) {
  i1 = i1 >> 3;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 268435455;
 __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEEC2EjjS5_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 4, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i3 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
 HEAP32[i3 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
 HEAP32[i3 + 12 >> 2] = HEAP32[i6 + 12 >> 2];
 HEAP32[i4 >> 2] = i3 + 16;
 __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i5);
 __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJOS3_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESI_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSG_SG_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZN4wasm7Builder8addParamEPNS_8FunctionENS_4NameENS_8WasmTypeE(i6, i7, i5) {
 i6 = i6 | 0;
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8;
 HEAP32[i1 >> 2] = i5;
 i3 = i6 + 8 | 0;
 i4 = i6 + 12 | 0;
 i9 = HEAP32[i4 >> 2] | 0;
 i2 = i9;
 if ((HEAP32[i6 + 60 >> 2] | 0) != (i9 - (HEAP32[i3 >> 2] | 0) >> 2 | 0)) ___assert_fail(20887, 20936, 167, 20955);
 if ((i2 | 0) == (HEAP32[i6 + 16 >> 2] | 0)) __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i3, i1); else {
  HEAP32[i2 >> 2] = i5;
  HEAP32[i4 >> 2] = i2 + 4;
 }
 i1 = i6 + 40 | 0;
 i2 = i6 + 44 | 0;
 i3 = (HEAP32[i2 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) >> 2;
 i4 = __ZNSt3__23mapIN4wasm4NameEjNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_jEEEEEixERS7_(i6 + 52 | 0, i7) | 0;
 HEAP32[i4 >> 2] = i3;
 i4 = HEAP32[i2 >> 2] | 0;
 if ((i4 | 0) == (HEAP32[i6 + 48 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i1, i7); else {
  HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
 }
 STACKTOP = i8;
 return i3 | 0;
}

function __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 4) + 1 | 0;
 if (i2 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 4 >>> 0 < 134217727) {
  i1 = i1 >> 3;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 268435455;
 __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEEC2EjjS5_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 4, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i3 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
 HEAP32[i3 + 8 >> 2] = HEAP32[i6 + 8 >> 2];
 HEAP32[i3 + 12 >> 2] = HEAP32[i6 + 12 >> 2];
 HEAP32[i4 >> 2] = i3 + 16;
 __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i5);
 __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESJ_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSH_SH_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESJ_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSH_SH_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJOS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESJ_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSH_SH_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE7doEndIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = i2 + 16 | 0;
 i5 = i2 + 60 | 0;
 i4 = HEAP32[i5 >> 2] | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i2, i1);
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i6, i4, HEAP32[i5 >> 2] | 0);
 i4 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0) + 16 | 0;
 i4 = (HEAP32[i4 >> 2] | 0) == 0;
 i3 = i2 + 80 | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i6, HEAP32[(HEAP32[i3 >> 2] | 0) + -4 >> 2] | 0, HEAP32[i5 >> 2] | 0);
 i1 = HEAP32[i3 >> 2] | 0;
 L1 : do if (!i4) {
  i2 = i1 + -4 | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) {
    i1 = i2;
    break L1;
   }
   i6 = i1 + -4 | 0;
   HEAP32[i3 >> 2] = i6;
   i1 = i6;
  }
 } while (0);
 i2 = i1 + -4 | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i6 = i1 + -4 | 0;
  HEAP32[i3 >> 2] = i6;
  i1 = i6;
 }
 return;
}

function __ZN4wasm13WasmValidator12shouldBeTrueIPNS_12CallIndirectEEEbbT_PKc(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i4) | 0, 19438) | 0, 0) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZNSt3__27__sort3IRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEjT0_SL_SL_T_(i7, i8, i6, i1) {
 i7 = i7 | 0;
 i8 = i8 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, d9 = 0.0;
 i2 = HEAP32[i8 >> 2] | 0;
 d9 = +HEAPF64[i2 + 16 >> 3];
 i5 = HEAP32[i7 >> 2] | 0;
 i3 = HEAP32[i6 >> 2] | 0;
 i1 = +HEAPF64[i3 + 16 >> 3] > d9;
 i4 = i5;
 do if (d9 > +HEAPF64[i5 + 16 >> 3]) {
  if (i1) {
   HEAP32[i7 >> 2] = i3;
   HEAP32[i6 >> 2] = i4;
   i1 = 1;
   break;
  }
  HEAP32[i7 >> 2] = i2;
  HEAP32[i8 >> 2] = i4;
  i1 = HEAP32[i6 >> 2] | 0;
  if (+HEAPF64[i1 + 16 >> 3] > +HEAPF64[i5 + 16 >> 3]) {
   HEAP32[i8 >> 2] = i1;
   HEAP32[i6 >> 2] = i4;
   i1 = 2;
  } else i1 = 1;
 } else if (i1) {
  HEAP32[i8 >> 2] = i3;
  HEAP32[i6 >> 2] = i2;
  i1 = HEAP32[i8 >> 2] | 0;
  i2 = HEAP32[i7 >> 2] | 0;
  if (+HEAPF64[i1 + 16 >> 3] > +HEAPF64[i2 + 16 >> 3]) {
   HEAP32[i7 >> 2] = i1;
   HEAP32[i8 >> 2] = i2;
   i1 = 2;
  } else i1 = 1;
 } else i1 = 0; while (0);
 return i1 | 0;
}

function __ZN4wasm13WasmValidator12shouldBeTrueIPNS_10CallImportEEEbbT_PKc(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i4) | 0, 19438) | 0, 0) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator10visitBlockEPNS_5BlockE(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i1 = i4 + 8 | 0;
 if (HEAP32[i1 >> 2] | 0) {
  i2 = i5 + 32 | 0;
  L3 : do if (__ZNKSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE14__count_uniqueIS3_EEjRKT_(i2, i1) | 0) {
   i3 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i2, i1) | 0;
   switch (HEAP32[i3 >> 2] | 0) {
   case 0:
   case 5:
    break L3;
   default:
    {}
   }
   i3 = HEAP32[i4 + 4 >> 2] | 0;
   switch (i3 | 0) {
   case 0:
   case 5:
    break L3;
   default:
    {}
   }
   i6 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i2, i1) | 0;
   __ZN4wasm13WasmValidator13shouldBeEqualIPNS_5BlockENS_8WasmTypeEEEbT0_S5_T_PKc(i5, i3, HEAP32[i6 >> 2] | 0, i4, 19371) | 0;
  } while (0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE14__erase_uniqueIS3_EEjRKT_(i2, i1) | 0;
 }
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i2, 251, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i2, 230, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm22SExpressionWasmBuilder15getPrefixedNameENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i6 + 24 | 0;
 i4 = i6 + 12 | 0;
 i5 = i6;
 i7 = i2 + 60 | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i2 + 1;
 __ZNSt3__29to_stringEj(i5, i2);
 i2 = HEAP8[i1 + 11 >> 0] | 0;
 i7 = i2 << 24 >> 24 < 0;
 i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKcj(i5, 0, i7 ? HEAP32[i1 >> 2] | 0 : i1, i7 ? HEAP32[i1 + 4 >> 2] | 0 : i2 & 255) | 0;
 HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i4 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i4 + 11 >> 0] | 0) < 0 ? HEAP32[i4 >> 2] | 0 : i4, 0);
 i7 = HEAP32[i3 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
 STACKTOP = i6;
 return i7 | 0;
}

function __ZN6cashew12ValueBuilder7makeForENS_3RefES1_S1_S1_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i5 + 20 | 0;
 i12 = i5 + 16 | 0;
 i11 = i5 + 12 | 0;
 i9 = i5 + 8 | 0;
 i8 = i5 + 4 | 0;
 i7 = i5;
 i10 = __ZN6cashew12ValueBuilder12makeRawArrayEi(5) | 0;
 i13 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59332) | 0;
 HEAP32[i12 >> 2] = i13;
 HEAP32[i6 >> 2] = HEAP32[i12 >> 2];
 i10 = __ZN6cashew5Value9push_backENS_3RefE(i10, i6) | 0;
 HEAP32[i11 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i6 >> 2] = HEAP32[i11 >> 2];
 i4 = __ZN6cashew5Value9push_backENS_3RefE(i10, i6) | 0;
 HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i6 >> 2] = HEAP32[i9 >> 2];
 i4 = __ZN6cashew5Value9push_backENS_3RefE(i4, i6) | 0;
 HEAP32[i8 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i6 >> 2] = HEAP32[i8 >> 2];
 i4 = __ZN6cashew5Value9push_backENS_3RefE(i4, i6) | 0;
 HEAP32[i7 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i6 >> 2] = HEAP32[i7 >> 2];
 i4 = __ZN6cashew5Value9push_backENS_3RefE(i4, i6) | 0;
 STACKTOP = i5;
 return i4 | 0;
}

function __ZN4wasm15Asm2WasmBuilderC2ERNS_6ModuleEbbb(i5, i4, i3, i1, i2) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i5 >> 2] = i4;
 i4 = i4 + 88 | 0;
 HEAP32[i5 + 4 >> 2] = i4;
 HEAP32[i5 + 8 >> 2] = i4;
 HEAP32[i5 + 12 >> 2] = 8;
 HEAP32[i5 + 16 >> 2] = 1e3;
 HEAP32[i5 + 24 >> 2] = 0;
 HEAP32[i5 + 28 >> 2] = 0;
 HEAP32[i5 + 20 >> 2] = i5 + 24;
 HEAP32[i5 + 36 >> 2] = 0;
 HEAP32[i5 + 40 >> 2] = 0;
 HEAP32[i5 + 32 >> 2] = i5 + 36;
 HEAP8[i5 + 44 >> 0] = i3 & 1;
 HEAP8[i5 + 45 >> 0] = i1 & 1;
 HEAP8[i5 + 46 >> 0] = i2 & 1;
 HEAP32[i5 + 52 >> 2] = 0;
 HEAP32[i5 + 56 >> 2] = 0;
 HEAP32[i5 + 48 >> 2] = i5 + 52;
 HEAP32[i5 + 64 >> 2] = 0;
 HEAP32[i5 + 68 >> 2] = 0;
 HEAP32[i5 + 60 >> 2] = i5 + 64;
 i1 = i5 + 116 | 0;
 HEAP32[i5 + 120 >> 2] = 0;
 HEAP32[i5 + 124 >> 2] = 0;
 i2 = i5 + 120 | 0;
 i3 = i5 + 72 | 0;
 i4 = i3 + 44 | 0;
 do {
  HEAP32[i3 >> 2] = 0;
  i3 = i3 + 4 | 0;
 } while ((i3 | 0) < (i4 | 0));
 HEAP32[i1 >> 2] = i2;
 HEAP32[i5 + 132 >> 2] = 0;
 HEAP32[i5 + 136 >> 2] = 0;
 HEAP32[i5 + 128 >> 2] = i5 + 132;
 HEAP32[i5 + 144 >> 2] = 0;
 HEAP32[i5 + 148 >> 2] = 0;
 HEAP32[i5 + 140 >> 2] = i5 + 144;
 return;
}

function __ZN4wasm13WasmValidator12shouldBeTrueIPNS_6SwitchEEEbbT_PKc(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i4) | 0, 19438) | 0, 0) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator12shouldBeTrueIPNS_5UnaryEEEbbT_PKc(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i4) | 0, 19438) | 0, 0) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator12shouldBeTrueIPNS_5BreakEEEbbT_PKc(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i4) | 0, 19438) | 0, 0) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator12shouldBeTrueIPNS_4CallEEEbbT_PKc(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i4) | 0, 19438) | 0, 0) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator12shouldBeTrueIPNS_2IfEEEbbT_PKc(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i4) | 0, 19438) | 0, 0) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSG_IJEEEEEENS_4pairINS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESH_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSF_SF_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function ___cxx_global_array_dtor_46(i1) {
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62720);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62708);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62696);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62684);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62672);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62660);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62648);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62636);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62624);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62612);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62600);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62588);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62576);
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(62564);
 return;
}

function __ZNSt3__26vectorIcNS_9allocatorIcEEE8__appendEj(i7, i2) {
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i9;
 i3 = HEAP32[i7 + 8 >> 2] | 0;
 i8 = i7 + 4 | 0;
 i1 = HEAP32[i8 >> 2] | 0;
 if ((i3 - i1 | 0) >>> 0 < i2 >>> 0) {
  i5 = HEAP32[i7 >> 2] | 0;
  i4 = i1 - i5 + i2 | 0;
  if ((i4 | 0) < 0) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
  i1 = i3 - i5 | 0;
  if (i1 >>> 0 < 1073741823) {
   i1 = i1 << 1;
   i1 = i1 >>> 0 < i4 >>> 0 ? i4 : i1;
  } else i1 = 2147483647;
  __ZNSt3__214__split_bufferIcRNS_9allocatorIcEEEC2EjjS3_(i6, i1, (HEAP32[i8 >> 2] | 0) - i5 | 0, i7 + 8 | 0);
  i8 = i6 + 8 | 0;
  i5 = HEAP32[i8 >> 2] | 0;
  _memset(i5 | 0, 0, i2 | 0) | 0;
  HEAP32[i8 >> 2] = i5 + i2;
  __ZNSt3__26vectorIcNS_9allocatorIcEEE26__swap_out_circular_bufferERNS_14__split_bufferIcRS2_EE(i7, i6);
  __ZNSt3__214__split_bufferIcRNS_9allocatorIcEEED2Ev(i6);
 } else do {
  HEAP8[i1 >> 0] = 0;
  i1 = (HEAP32[i8 >> 2] | 0) + 1 | 0;
  HEAP32[i8 >> 2] = i1;
  i2 = i2 + -1 | 0;
 } while ((i2 | 0) != 0);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRN6cashew7IStringERNS1_8WasmTypeEEEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm8NameTypeERNS_9allocatorIS2_EEEC2EjjS5_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm8NameTypeERNS_9allocatorIS2_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS4_JRKNS_21piecewise_construct_tENS_5tupleIJOS4_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEESI_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSG_SG_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function ___cxx_global_array_dtor(i1) {
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61908);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61896);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61884);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61872);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61860);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61848);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61836);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61824);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61812);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61800);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61788);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61776);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61764);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(61752);
 return;
}

function __ZN4wasm17WasmBinaryBuilder13visitSetLocalEPNS_8SetLocalE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i4;
 if (HEAP8[i3 + 12 >> 0] | 0) {
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24536) | 0;
  i6 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i6;
  i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i6) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
 }
 i6 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i3) | 0;
 HEAP32[i2 + 8 >> 2] = i6;
 if (i6 >>> 0 < (__ZN4wasm8Function12getNumLocalsEv(HEAP32[i3 + 64 >> 2] | 0) | 0) >>> 0) {
  i6 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i3) | 0;
  HEAP32[i2 + 12 >> 2] = i6;
  HEAP32[i2 + 4 >> 2] = HEAP32[i6 + 4 >> 2];
  STACKTOP = i4;
  return;
 } else ___assert_fail(24479, 22948, 1854, 24554);
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS4_JRKNS_21piecewise_construct_tENS_5tupleIJRKS4_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEESI_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSG_SG_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6rehashEj(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 if ((i1 | 0) != 1) {
  if (i1 + -1 & i1) i1 = __ZNSt3__212__next_primeEj(i1) | 0;
 } else i1 = 2;
 i4 = HEAP32[i5 + 4 >> 2] | 0;
 if (i1 >>> 0 <= i4 >>> 0) {
  if (i1 >>> 0 < i4 >>> 0) {
   if (i4 >>> 0 > 2) i3 = (i4 + -1 & i4 | 0) == 0; else i3 = 0;
   i2 = ~~+Math_ceil(+(+((HEAP32[i5 + 12 >> 2] | 0) >>> 0) / +HEAPF32[i5 + 16 >> 2])) >>> 0;
   if (i3) i2 = 1 << 32 - (Math_clz32(i2 + -1 | 0) | 0); else i2 = __ZNSt3__212__next_primeEj(i2) | 0;
   i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
   if (i1 >>> 0 < i4 >>> 0) __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE8__rehashEj(i5, i1);
  }
 } else __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE8__rehashEj(i5, i1);
 return;
}

function __ZNSt3__214__num_put_base14__format_floatEPcPKcj(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 if (i2 & 2048) {
  HEAP8[i1 >> 0] = 43;
  i1 = i1 + 1 | 0;
 }
 if (i2 & 1024) {
  HEAP8[i1 >> 0] = 35;
  i1 = i1 + 1 | 0;
 }
 i6 = i2 & 260;
 i4 = i2 >>> 14;
 i7 = (i6 | 0) == 260;
 if (i7) i5 = 0; else {
  HEAP8[i1 >> 0] = 46;
  HEAP8[i1 + 1 >> 0] = 42;
  i1 = i1 + 2 | 0;
  i5 = 1;
 }
 while (1) {
  i2 = HEAP8[i3 >> 0] | 0;
  if (!(i2 << 24 >> 24)) break;
  HEAP8[i1 >> 0] = i2;
  i3 = i3 + 1 | 0;
  i1 = i1 + 1 | 0;
 }
 L14 : do switch (i6 | 0) {
 case 4:
  if (!(i4 & 1)) {
   HEAP8[i1 >> 0] = 102;
   break L14;
  } else {
   HEAP8[i1 >> 0] = 70;
   break L14;
  }
 case 256:
  if (!(i4 & 1)) {
   HEAP8[i1 >> 0] = 101;
   break L14;
  } else {
   HEAP8[i1 >> 0] = 69;
   break L14;
  }
 default:
  {
   i2 = (i4 & 1 | 0) != 0;
   if (i7) if (i2) {
    HEAP8[i1 >> 0] = 65;
    break L14;
   } else {
    HEAP8[i1 >> 0] = 97;
    break L14;
   } else if (i2) {
    HEAP8[i1 >> 0] = 71;
    break L14;
   } else {
    HEAP8[i1 >> 0] = 103;
    break L14;
   }
  }
 } while (0);
 return i5 | 0;
}

function __ZN4wasm13WasmValidator12shouldBeTrueIPNS_6ModuleEEEbbT_PKc(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZN4wasm11WasmPrinter11printModuleEPNS_6ModuleERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEE(i2, __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i4) | 0, 19438) | 0) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJNS1_4NameERNS1_8WasmTypeEEEEvDpOT_(i8, i5, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i3 = i8 + 4 | 0;
 i4 = HEAP32[i8 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 3) + 1 | 0;
 if (i2 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
 i1 = (HEAP32[i8 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 3 >>> 0 < 268435455) {
  i1 = i1 >> 2;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 536870911;
 __ZNSt3__214__split_bufferIN4wasm8NameTypeERNS_9allocatorIS2_EEEC2EjjS5_(i7, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 3, i8 + 8 | 0);
 i4 = i7 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i6;
 HEAP32[i4 >> 2] = i3 + 8;
 __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i8, i7);
 __ZNSt3__214__split_bufferIN4wasm8NameTypeERNS_9allocatorIS2_EEED2Ev(i7);
 STACKTOP = i9;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSG_IJEEEEEENS_4pairINS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESH_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSF_SF_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__26vectorIN4wasm14SimplifyLocals10BlockBreakENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 4) + 1 | 0;
 if (i2 >>> 0 > 268435455) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 4 >>> 0 < 134217727) {
  i1 = i1 >> 3;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 268435455;
 __ZNSt3__214__split_bufferIN4wasm14SimplifyLocals10BlockBreakERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 4, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 __ZN4wasm14SimplifyLocals10BlockBreakC2EOS1_(i3, i6);
 HEAP32[i4 >> 2] = i3 + 16;
 __ZNSt3__26vectorIN4wasm14SimplifyLocals10BlockBreakENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIN4wasm14SimplifyLocals10BlockBreakERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSG_IJEEEEEENS_4pairINS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESH_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSF_SF_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKcj(i8, i5, i1, i6) {
 i8 = i8 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i7 = i8 + 11 | 0;
 i2 = HEAP8[i7 >> 0] | 0;
 i3 = i2 << 24 >> 24 < 0;
 if (i3) i4 = HEAP32[i8 + 4 >> 2] | 0; else i4 = i2 & 255;
 if (i4 >>> 0 < i5 >>> 0) __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv(i8);
 if (i3) i2 = (HEAP32[i8 + 8 >> 2] & 2147483647) + -1 | 0; else i2 = 10;
 if ((i2 - i4 | 0) >>> 0 >= i6 >>> 0) {
  if (i6 | 0) {
   if (i3) i3 = HEAP32[i8 >> 2] | 0; else i3 = i8;
   i2 = i3 + i5 | 0;
   if ((i4 | 0) != (i5 | 0)) {
    _memmove(i2 + i6 | 0, i2 | 0, i4 - i5 | 0) | 0;
    i1 = i2 >>> 0 <= i1 >>> 0 & (i3 + i4 | 0) >>> 0 > i1 >>> 0 ? i1 + i6 | 0 : i1;
   }
   _memmove(i2 | 0, i1 | 0, i6 | 0) | 0;
   i1 = i4 + i6 | 0;
   if ((HEAP8[i7 >> 0] | 0) < 0) HEAP32[i8 + 4 >> 2] = i1; else HEAP8[i7 >> 0] = i1;
   HEAP8[i3 + i1 >> 0] = 0;
  }
 } else __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc(i8, i2, i4 + i6 - i2 | 0, i4, i5, 0, i6, i1);
 return i8 | 0;
}

function __ZN6cashew5ArenaD2Ev(i7) {
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i3 = HEAP32[i7 + 4 >> 2] | 0;
 i5 = HEAP32[i7 >> 2] | 0;
 while (1) {
  if ((i5 | 0) == (i3 | 0)) break;
  i4 = HEAP32[i5 >> 2] | 0;
  if (i4 | 0) {
   i2 = i4 + -8 | 0;
   i1 = HEAP32[i2 + 4 >> 2] | 0;
   if (i1 | 0) {
    i1 = i4 + (i1 << 4) | 0;
    do {
     i1 = i1 + -16 | 0;
     __ZN6cashew5Value4freeEv(i1);
    } while ((i1 | 0) != (i4 | 0));
   }
   __ZdaPv(i2);
  }
  i5 = i5 + 4 | 0;
 }
 i4 = i7 + 16 | 0;
 i5 = HEAP32[i7 + 20 >> 2] | 0;
 i6 = HEAP32[i4 >> 2] | 0;
 while (1) {
  if ((i6 | 0) == (i5 | 0)) break;
  i2 = HEAP32[i6 >> 2] | 0;
  if (i2 | 0) {
   i3 = i2 + -4 | 0;
   i1 = HEAP32[i3 >> 2] | 0;
   if (i1 | 0) {
    i1 = i2 + (i1 * 12 | 0) | 0;
    do {
     i1 = i1 + -12 | 0;
     __ZNSt3__213__vector_baseIN6cashew3RefENS_9allocatorIS2_EEED2Ev(i1);
    } while ((i1 | 0) != (i2 | 0));
   }
   __ZdaPv(i3);
  }
  i6 = i6 + 4 | 0;
 }
 __ZNSt3__213__vector_baseIPNS_6vectorIN6cashew3RefENS_9allocatorIS3_EEEENS4_IS7_EEED2Ev(i4);
 __ZNSt3__213__vector_baseIPN6cashew5ValueENS_9allocatorIS3_EEED2Ev(i7);
 return;
}

function __ZZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(48) | 0;
   i2 = i1 + 4 | 0;
   HEAP32[i2 >> 2] = 0;
   HEAP32[i2 + 4 >> 2] = 0;
   HEAP32[i2 + 8 >> 2] = 0;
   HEAP32[i2 + 12 >> 2] = 0;
   HEAP32[i2 + 16 >> 2] = 0;
   HEAP32[i2 + 20 >> 2] = 0;
   HEAP32[i1 >> 2] = 4272;
   i2 = i1 + 36 | 0;
   HEAP32[i2 >> 2] = 0;
   HEAP32[i1 + 40 >> 2] = 0;
   HEAP32[i1 + 32 >> 2] = i2;
   HEAP32[i1 + 44 >> 2] = 5;
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 24 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 20 >> 2] = i5;
 __ZN4wasm13WasmValidator14doWalkFunctionEPNS_8FunctionE(i3, i5);
 __ZN4wasm13WasmValidator13visitFunctionEPNS_8FunctionE(i3, i5);
 if (i4 | 0) {
  __ZN4wasm13WasmValidatorD2Ev(i4);
  __ZdlPv(i4);
 }
 return;
}

function __ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji(i1, i6, i7, i2) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i9;
 if ((i1 | 0) == (i6 | 0)) {
  HEAP32[i7 >> 2] = 4;
  i1 = 0;
 } else {
  i4 = ___errno_location() | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  i1 = _strtoll_l(i1, i8, i2, __ZNSt3__26__clocEv() | 0) | 0;
  i2 = tempRet0;
  i3 = HEAP32[i4 >> 2] | 0;
  if (!i3) HEAP32[i4 >> 2] = i5;
  L7 : do if ((HEAP32[i8 >> 2] | 0) == (i6 | 0)) {
   do if ((i3 | 0) == 34) {
    HEAP32[i7 >> 2] = 4;
    if ((i2 | 0) > 0 | (i2 | 0) == 0 & i1 >>> 0 > 0) {
     i1 = 2147483647;
     break L7;
    }
   } else {
    if ((i2 | 0) < -1 | (i2 | 0) == -1 & i1 >>> 0 < 2147483648) {
     HEAP32[i7 >> 2] = 4;
     break;
    }
    if ((i2 | 0) > 0 | (i2 | 0) == 0 & i1 >>> 0 > 2147483647) {
     HEAP32[i7 >> 2] = 4;
     i1 = 2147483647;
     break L7;
    } else break L7;
   } while (0);
   i1 = -2147483648;
  } else {
   HEAP32[i7 >> 2] = 4;
   i1 = 0;
  } while (0);
 }
 STACKTOP = i9;
 return i1 | 0;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE4walkERPNS_10ExpressionE(i8, i1) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i6 = i8 + 8 | 0;
 i7 = i8 + 12 | 0;
 if ((HEAP32[i7 >> 2] | 0) != (HEAP32[i6 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i8, 404, i1);
 i5 = i8 + 4 | 0;
 while (1) {
  i4 = HEAP32[i7 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i6 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i7 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i8, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEj(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i2 = HEAP32[i8 + 8 >> 2] | 0;
 i5 = i8 + 4 | 0;
 i1 = HEAP32[i5 >> 2] | 0;
 if (i2 - i1 >> 2 >>> 0 < i6 >>> 0) {
  i4 = HEAP32[i8 >> 2] | 0;
  i3 = (i1 - i4 >> 2) + i6 | 0;
  if (i3 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
  i1 = i2 - i4 | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
  } else i1 = 1073741823;
  __ZNSt3__214__split_bufferIjRNS_9allocatorIjEEEC2EjjS3_(i7, i1, (HEAP32[i5 >> 2] | 0) - i4 >> 2, i8 + 8 | 0);
  i5 = i7 + 8 | 0;
  i4 = HEAP32[i5 >> 2] | 0;
  _memset(i4 | 0, 0, i6 << 2 | 0) | 0;
  HEAP32[i5 >> 2] = i4 + (i6 << 2);
  __ZNSt3__26vectorIjNS_9allocatorIjEEE26__swap_out_circular_bufferERNS_14__split_bufferIjRS2_EE(i8, i7);
  __ZNSt3__214__split_bufferIjRNS_9allocatorIjEEED2Ev(i7);
 } else {
  _memset(i1 | 0, 0, i6 << 2 | 0) | 0;
  HEAP32[i5 >> 2] = i1 + (i6 << 2);
 }
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEj(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i7 = i9;
 i2 = HEAP32[i8 + 8 >> 2] | 0;
 i5 = i8 + 4 | 0;
 i1 = HEAP32[i5 >> 2] | 0;
 if (i2 - i1 >> 2 >>> 0 < i6 >>> 0) {
  i4 = HEAP32[i8 >> 2] | 0;
  i3 = (i1 - i4 >> 2) + i6 | 0;
  if (i3 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i8);
  i1 = i2 - i4 | 0;
  if (i1 >> 2 >>> 0 < 536870911) {
   i1 = i1 >> 1;
   i1 = i1 >>> 0 < i3 >>> 0 ? i3 : i1;
  } else i1 = 1073741823;
  __ZNSt3__214__split_bufferIiRNS_9allocatorIiEEEC2EjjS3_(i7, i1, (HEAP32[i5 >> 2] | 0) - i4 >> 2, i8 + 8 | 0);
  i5 = i7 + 8 | 0;
  i4 = HEAP32[i5 >> 2] | 0;
  _memset(i4 | 0, 0, i6 << 2 | 0) | 0;
  HEAP32[i5 >> 2] = i4 + (i6 << 2);
  __ZNSt3__26vectorIiNS_9allocatorIiEEE26__swap_out_circular_bufferERNS_14__split_bufferIiRS2_EE(i8, i7);
  __ZNSt3__214__split_bufferIiRNS_9allocatorIiEEED2Ev(i7);
 } else {
  _memset(i1 | 0, 0, i6 << 2 | 0) | 0;
  HEAP32[i5 >> 2] = i1 + (i6 << 2);
 }
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIPNS0_IN6cashew3RefENS_9allocatorIS2_EEEENS3_IS6_EEE21__push_back_slow_pathIS6_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPNS_6vectorIN6cashew3RefENS_9allocatorIS3_EEEERNS4_IS7_EEEC2EjjS9_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPNS0_IN6cashew3RefENS_9allocatorIS2_EEEENS3_IS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i7, i5);
 __ZNSt3__214__split_bufferIPNS_6vectorIN6cashew3RefENS_9allocatorIS3_EEEERNS4_IS7_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE7parseDoERPcPKc(i8, i7, i1) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i9 + 28 | 0;
 i2 = i9 + 24 | 0;
 i6 = i9;
 i4 = i9 + 20 | 0;
 i5 = i9 + 16 | 0;
 i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseMaybeBracketedERPcPKc(i8, i7, i1) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i7);
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i6, HEAP32[i7 >> 2] | 0);
 if ((HEAP32[i6 + 12 >> 2] | 0) == 0 ? (HEAP32[i6 >> 2] | 0) == (HEAP32[14831] | 0) : 0) {
  HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + (HEAP32[i6 + 8 >> 2] | 0);
  i8 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseParennedERPc(i8, i7) | 0;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = i8;
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
  i8 = __ZN6cashew12ValueBuilder6makeDoENS_3RefES1_(i2, i3) | 0;
  STACKTOP = i9;
  return i8 | 0;
 }
 ___assert_fail(31551, 31173, 487, 31593);
 return 0;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE5eraseENS_11__wrap_iterIPKS6_EESD_(i4, i1, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i8 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 i8 = i8 + (i2 - i8 >> 2 << 2) | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 L1 : do if ((i2 | 0) != (i1 | 0)) {
  i6 = i8 + (i1 - i2 >> 2 << 2) | 0;
  i7 = i4 + 4 | 0;
  i3 = HEAP32[i7 >> 2] | 0;
  i4 = i3;
  i1 = i8;
  i2 = i6;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i9 = HEAP32[i2 >> 2] | 0;
   HEAP32[i2 >> 2] = 0;
   i5 = HEAP32[i1 >> 2] | 0;
   HEAP32[i1 >> 2] = i9;
   if (i5 | 0) {
    __ZN4wasm8FunctionD2Ev(i5);
    __ZdlPv(i5);
   }
   i1 = i1 + 4 | 0;
   i2 = i2 + 4 | 0;
  }
  i2 = i8 + ((i4 - i6 | 0) >>> 2 << 2) | 0;
  while (1) {
   i1 = HEAP32[i7 >> 2] | 0;
   if ((i1 | 0) == (i2 | 0)) break L1;
   i9 = i1 + -4 | 0;
   HEAP32[i7 >> 2] = i9;
   i1 = HEAP32[i9 >> 2] | 0;
   HEAP32[i9 >> 2] = 0;
   if (!i1) continue;
   __ZN4wasm8FunctionD2Ev(i1);
   __ZdlPv(i1);
  }
 } while (0);
 return i8 | 0;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEjjjjjj(i11, i10, i1, i3, i8, i9, i7) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i8 = i8 | 0;
 i9 = i9 | 0;
 i7 = i7 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0;
 if ((1073741807 - i10 | 0) >>> 0 < i1 >>> 0) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i11);
 i5 = i11 + 8 | 0;
 if ((HEAP8[i5 + 3 >> 0] | 0) < 0) i6 = HEAP32[i11 >> 2] | 0; else i6 = i11;
 if (i10 >>> 0 < 536870887) {
  i1 = i1 + i10 | 0;
  i2 = i10 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
  if (i1 >>> 0 >= 2) {
   i1 = i1 + 4 & -4;
   if (i1 >>> 0 > 1073741823) ___assert_fail(55771, 55808, 1734, 55911); else i4 = i1;
  } else i4 = 2;
 } else i4 = 1073741807;
 i2 = __Znwj(i4 << 2) | 0;
 if (i8 | 0) __ZNSt3__211char_traitsIwE4copyEPwPKwj(i2, i6, i8) | 0;
 i1 = i3 - i9 | 0;
 if ((i1 | 0) != (i8 | 0)) __ZNSt3__211char_traitsIwE4copyEPwPKwj(i2 + (i8 << 2) + (i7 << 2) | 0, i6 + (i8 << 2) + (i9 << 2) | 0, i1 - i8 | 0) | 0;
 if ((i10 | 0) != 1) __ZdlPv(i6);
 HEAP32[i11 >> 2] = i2;
 HEAP32[i5 >> 2] = i4 | -2147483648;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE14doWalkFunctionEPNS_8FunctionE(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i2 = HEAP32[i5 + 32 >> 2] | 0;
 i3 = i5 + 36 | 0;
 while (1) {
  i1 = HEAP32[i3 >> 2] | 0;
  if ((i1 | 0) == (i2 | 0)) break;
  i6 = i1 + -4 | 0;
  HEAP32[i3 >> 2] = i6;
  i1 = HEAP32[i6 >> 2] | 0;
  HEAP32[i6 >> 2] = 0;
  if (!i1) continue;
  __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE10BasicBlockD2Ev(i1);
  __ZdlPv(i1);
 }
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i5 + -16 | 0, 0);
 HEAP32[i5 + 28 >> 2] = HEAP32[i5 + 44 >> 2];
 __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i5, i4 + 36 | 0);
 if (HEAP32[i5 + 56 >> 2] | 0) ___assert_fail(46528, 46549, 251, 46573);
 if ((HEAP32[i5 + 64 >> 2] | 0) != (HEAP32[i5 + 60 >> 2] | 0)) ___assert_fail(46588, 46549, 252, 46573);
 if ((HEAP32[i5 + 76 >> 2] | 0) == (HEAP32[i5 + 72 >> 2] | 0)) return; else ___assert_fail(46608, 46549, 253, 46573);
}

function __ZN4wasm13WasmValidator9noteBreakENS_4NameEPNS_10ExpressionE(i2, i4, i1) {
 i2 = i2 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i3 = 0, i5 = 0;
 if (!i1) i3 = 0; else i3 = HEAP32[i1 + 4 >> 2] | 0;
 i1 = i2 + 32 | 0;
 i5 = (__ZNKSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE14__count_uniqueIS3_EEjRKT_(i1, i4) | 0) == 0;
 i2 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i1, i4) | 0;
 do if (!i5) {
  if ((HEAP32[i2 >> 2] | 0) == 5) {
   i5 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i1, i4) | 0;
   HEAP32[i5 >> 2] = i3;
   break;
  }
  if ((i3 | 0) != 5 ? (i5 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i1, i4) | 0, (i3 | 0) != (HEAP32[i5 >> 2] | 0)) : 0) {
   i5 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i1, i4) | 0;
   HEAP32[i5 >> 2] = 0;
  }
 } else HEAP32[i2 >> 2] = i3; while (0);
 return;
}

function __ZNSt3__27__sort4IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_S8_T_(i4, i5, i6, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i7 = 0;
 i1 = __ZNSt3__27__sort3IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_T_(i4, i5, i6, i3) | 0;
 if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i3, HEAP32[i2 >> 2] | 0, HEAP32[i6 >> 2] | 0) | 0) {
  i7 = HEAP32[i6 >> 2] | 0;
  HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i2 >> 2] = i7;
  i2 = i1 + 1 | 0;
  if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i3, HEAP32[i6 >> 2] | 0, HEAP32[i5 >> 2] | 0) | 0) {
   i7 = HEAP32[i5 >> 2] | 0;
   HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
   HEAP32[i6 >> 2] = i7;
   if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i3, HEAP32[i5 >> 2] | 0, HEAP32[i4 >> 2] | 0) | 0) {
    i7 = HEAP32[i4 >> 2] | 0;
    HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
    HEAP32[i5 >> 2] = i7;
    i1 = i1 + 3 | 0;
   } else i1 = i1 + 2 | 0;
  } else i1 = i2;
 }
 return i1 | 0;
}

function __ZN6cashew5Arena10allocArrayEv(i9) {
 i9 = i9 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i10;
 i6 = i9 + 16 | 0;
 i7 = i9 + 20 | 0;
 i8 = HEAP32[i7 >> 2] | 0;
 i1 = i8;
 if (!((i8 | 0) != (HEAP32[i6 >> 2] | 0) ? (i3 = i9 + 28 | 0, i2 = HEAP32[i3 >> 2] | 0, (i2 | 0) != 1e3) : 0)) {
  i3 = __Znaj(12004) | 0;
  HEAP32[i3 >> 2] = 1e3;
  i2 = i3 + 4 | 0;
  i3 = i3 + 12004 | 0;
  i4 = i2;
  do {
   HEAP32[i4 >> 2] = 0;
   HEAP32[i4 + 4 >> 2] = 0;
   HEAP32[i4 + 8 >> 2] = 0;
   i4 = i4 + 12 | 0;
  } while ((i4 | 0) != (i3 | 0));
  HEAP32[i5 >> 2] = i2;
  if (i1 >>> 0 < (HEAP32[i9 + 24 >> 2] | 0) >>> 0) {
   HEAP32[i8 >> 2] = i2;
   i1 = (HEAP32[i7 >> 2] | 0) + 4 | 0;
   HEAP32[i7 >> 2] = i1;
  } else {
   __ZNSt3__26vectorIPNS0_IN6cashew3RefENS_9allocatorIS2_EEEENS3_IS6_EEE21__push_back_slow_pathIS6_EEvOT_(i6, i5);
   i1 = HEAP32[i7 >> 2] | 0;
  }
  i3 = i9 + 28 | 0;
  HEAP32[i3 >> 2] = 0;
  i2 = 0;
 }
 HEAP32[i3 >> 2] = i2 + 1;
 STACKTOP = i10;
 return (HEAP32[i1 + -4 >> 2] | 0) + (i2 * 12 | 0) | 0;
}

function __ZN4wasm13WasmValidator12shouldBeTrueIPKcEEbbT_S3_(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) i1 = 1; else {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19600) | 0, i4) | 0, 19438) | 0, i2) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
  i1 = 0;
 }
 STACKTOP = i6;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESS_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEE26__swap_out_circular_bufferERNS_14__split_bufferISD_RSE_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i7 = i1 + -20 | 0;
  __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEEC2EOSF_((HEAP32[i4 >> 2] | 0) + -20 | 0, i7);
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -20;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i2;
 i3 = i6 + 8 | 0;
 i7 = i5 + 12 | 0;
 i6 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i6;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZNKSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE4findIS9_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEERKT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i8;
 i5 = HEAP32[i1 >> 2] | 0;
 HEAP32[i4 >> 2] = i5;
 i1 = __ZNSt3__221__murmur2_or_cityhashIjLj32EEclEPKvj(i8 + 4 | 0, i4, 4) | 0;
 i4 = HEAP32[i2 + 4 >> 2] | 0;
 L1 : do if (i4) {
  i6 = i4 + -1 | 0;
  i7 = (i6 & i4 | 0) == 0;
  if (i7) i3 = i6 & i1; else i3 = (i1 >>> 0) % (i4 >>> 0) | 0;
  i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + (i3 << 2) >> 2] | 0;
  if (i1) do {
   i1 = HEAP32[i1 >> 2] | 0;
   if (!i1) {
    i1 = 0;
    break L1;
   }
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   if (i7) i2 = i2 & i6; else i2 = (i2 >>> 0) % (i4 >>> 0) | 0;
   if ((i2 | 0) != (i3 | 0)) {
    i1 = 0;
    break L1;
   }
  } while ((HEAP32[i1 + 8 >> 2] | 0) != (i5 | 0)); else i1 = 0;
 } else i1 = 0; while (0);
 STACKTOP = i8;
 return i1 | 0;
}

function __ZZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i5, i2, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i3 = 0, i6 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(32) | 0;
   i2 = i1 + 4 | 0;
   HEAP32[i2 >> 2] = 0;
   HEAP32[i2 + 4 >> 2] = 0;
   HEAP32[i2 + 8 >> 2] = 0;
   HEAP32[i2 + 12 >> 2] = 0;
   HEAP32[i2 + 16 >> 2] = 0;
   HEAP32[i2 + 20 >> 2] = 0;
   HEAP32[i1 >> 2] = 7464;
  }
  if (!i5) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 24 >> 2] = i5;
   i3 = i1;
   i6 = i1;
   break;
  }
 } else {
  i3 = i2;
  i6 = 0;
 } while (0);
 HEAP32[i3 + 20 >> 2] = i4;
 __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3, i4 + 36 | 0);
 i1 = i6;
 if (i6 | 0) {
  HEAP32[i1 >> 2] = 7520;
  __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 8 | 0);
  __ZdlPv(i6);
 }
 return;
}

function __ZN4wasm16PrintSExpression11visitImportEPNS_6ImportE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 4 | 0;
 i6 = i3;
 i5 = __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i2 >> 2] | 0, 34603, 0) | 0;
 HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i5, i4) | 0, 32) | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__Z9printTextRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i2 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0) | 0, 32) | 0;
 __Z9printTextRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i2 >> 2] | 0, HEAP32[i1 + 8 >> 2] | 0) | 0;
 i1 = HEAP32[i1 + 12 >> 2] | 0;
 if (i1 | 0) __ZN4wasm16PrintSExpression17visitFunctionTypeEPNS_12FunctionTypeEb(i2, i1, 0);
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i2 >> 2] | 0, 41) | 0;
 STACKTOP = i3;
 return;
}

function __ZN6cashew12ValueBuilder6makeIfENS_3RefES1_S1_(i1, i2, i5) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i6 + 16 | 0;
 i10 = i6 + 12 | 0;
 i9 = i6 + 8 | 0;
 i7 = i6 + 4 | 0;
 i4 = i6;
 i8 = __ZN6cashew12ValueBuilder12makeRawArrayEi(4) | 0;
 i11 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59316) | 0;
 HEAP32[i10 >> 2] = i11;
 HEAP32[i3 >> 2] = HEAP32[i10 >> 2];
 i8 = __ZN6cashew5Value9push_backENS_3RefE(i8, i3) | 0;
 HEAP32[i9 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i3 >> 2] = HEAP32[i9 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i8, i3) | 0;
 HEAP32[i7 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i1, i3) | 0;
 if (__ZN6cashew3RefntEv(i5) | 0) {
  i11 = __ZN6cashew12ValueBuilder8makeNullEv() | 0;
  HEAP32[i4 >> 2] = i11;
 } else HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
 i11 = __ZN6cashew5Value9push_backENS_3RefE(i1, i3) | 0;
 STACKTOP = i6;
 return i11 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE7destroyEPNS_11__tree_nodeISG_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE7destroyEPNS_11__tree_nodeISG_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE7destroyEPNS_11__tree_nodeISG_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZNSt3__213__vector_baseIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEED2Ev(i1 + 20 | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZZN4wasm6WalkerINS_14FunctionHasherENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i5, i2, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i3 = 0, i6 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(36) | 0;
   i2 = i1 + 4 | 0;
   HEAP32[i2 >> 2] = 0;
   HEAP32[i2 + 4 >> 2] = 0;
   HEAP32[i2 + 8 >> 2] = 0;
   HEAP32[i2 + 12 >> 2] = 0;
   HEAP32[i2 + 16 >> 2] = 0;
   HEAP32[i2 + 20 >> 2] = 0;
   HEAP32[i1 >> 2] = 7396;
   HEAP32[i1 + 32 >> 2] = 0;
  }
  if (!i5) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 24 >> 2] = i5;
   i3 = i1;
   i6 = i1;
   break;
  }
 } else {
  i3 = i2;
  i6 = 0;
 } while (0);
 HEAP32[i3 + 20 >> 2] = i4;
 __ZN4wasm14FunctionHasher14doWalkFunctionEPNS_8FunctionE(i3, i4);
 i1 = i6;
 if (i6 | 0) {
  HEAP32[i1 >> 2] = 7452;
  __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14FunctionHasherENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 8 | 0);
  __ZdlPv(i6);
 }
 return;
}

function __ZN4wasm7Literal10printFloatERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEf(i3, d2) {
 i3 = i3 | 0;
 d2 = +d2;
 var i1 = 0, d4 = 0.0, i5 = 0;
 d4 = +Math_abs(+d2);
 if ((HEAPF32[tempDoublePtr >> 2] = d4, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 2139095040) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i3, ((HEAPF32[tempDoublePtr >> 2] = d2, HEAP32[tempDoublePtr >> 2] | 0) | 0) < 0 ? 58036 : 67717) | 0, 52371) | 0;
  i1 = __ZN4wasm7Literal10NaNPayloadEf(d2) | 0;
  if (i1 | 0) {
   i3 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i3, 29425) | 0;
   i5 = i3 + (HEAP32[(HEAP32[i3 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
   HEAP32[i5 >> 2] = HEAP32[i5 >> 2] & -75 | 8;
   i3 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i3, i1) | 0;
   i3 = i3 + (HEAP32[(HEAP32[i3 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0;
   HEAP32[i3 >> 2] = HEAP32[i3 >> 2] & -75 | 2;
  }
 } else __ZN4wasm7Literal11printDoubleERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEd(i3, d2);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE25__emplace_unique_key_argsIjJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSE_IJEEEEEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i8, i6, i3, i1, i5, i2) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESF_RKT_(i6, i4, i3) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(24) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[HEAP32[i5 >> 2] >> 2];
  HEAP32[i1 + 20 >> 2] = 0;
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSD_SD_(i6, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i8 >> 2] = i1;
 HEAP8[i8 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE21__grow_by_and_replaceEjjjjjjPKc(i11, i10, i1, i4, i8, i9, i7, i5) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i8 = i8 | 0;
 i9 = i9 | 0;
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i2 = 0, i3 = 0, i6 = 0;
 if ((-18 - i10 | 0) >>> 0 < i1 >>> 0) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i11);
 if ((HEAP8[i11 + 11 >> 0] | 0) < 0) i6 = HEAP32[i11 >> 2] | 0; else i6 = i11;
 if (i10 >>> 0 < 2147483623) {
  i2 = i1 + i10 | 0;
  i3 = i10 << 1;
  i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
  i2 = i2 >>> 0 < 11 ? 11 : i2 + 16 & -16;
 } else i2 = -17;
 i3 = _malloc(i2) | 0;
 if (i8 | 0) _memcpy(i3 | 0, i6 | 0, i8 | 0) | 0;
 if (i7 | 0) _memcpy(i3 + i8 | 0, i5 | 0, i7 | 0) | 0;
 i1 = i4 - i9 | 0;
 if ((i1 | 0) != (i8 | 0)) _memcpy(i3 + i8 + i7 | 0, i6 + i8 + i9 | 0, i1 - i8 | 0) | 0;
 if ((i10 | 0) != 10) _free(i6);
 HEAP32[i11 >> 2] = i3;
 HEAP32[i11 + 8 >> 2] = i2 | -2147483648;
 i10 = i1 + i7 | 0;
 HEAP32[i11 + 4 >> 2] = i10;
 HEAP8[i3 + i10 >> 0] = 0;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder14makeMaybeBlockERNS_7ElementEjj(i6, i4, i2, i5) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i1 = 0, i3 = 0, i7 = 0;
 i3 = (__ZN4wasm7Element4listEv(i4) | 0) + 8 | 0;
 do if ((HEAP32[i3 >> 2] | 0) == (i2 | 0)) i1 = __ZN10MixedArena5allocIN4wasm3NopEEEPT_v(HEAP32[i6 + 4 >> 2] | 0) | 0; else {
  i3 = (__ZN4wasm7Element4listEv(i4) | 0) + 8 | 0;
  if ((HEAP32[i3 >> 2] | 0) == (i2 + 1 | 0)) {
   i1 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i6, __ZN4wasm7ElementixEj(i4, i2) | 0) | 0;
   break;
  }
  i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i6 + 4 >> 2] | 0) | 0;
  i3 = i1 + 12 | 0;
  while (1) {
   i7 = (__ZN4wasm7Element4listEv(i4) | 0) + 8 | 0;
   if (!(i2 >>> 0 < i5 >>> 0 ? i2 >>> 0 < (HEAP32[i7 >> 2] | 0) >>> 0 : 0)) break;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i3, __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i6, __ZN4wasm7ElementixEj(i4, i2) | 0) | 0);
   i2 = i2 + 1 | 0;
  }
  __ZN4wasm5Block8finalizeEv(i1);
 } while (0);
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 185, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN6cashew12ValueBuilder12makeFunctionENS_7IStringE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i2 + 16 | 0;
 i8 = i2 + 12 | 0;
 i7 = i2 + 8 | 0;
 i5 = i2 + 4 | 0;
 i4 = i2;
 i6 = __ZN6cashew12ValueBuilder12makeRawArrayEi(4) | 0;
 i9 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59276) | 0;
 HEAP32[i8 >> 2] = i9;
 HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
 i6 = __ZN6cashew5Value9push_backENS_3RefE(i6, i3) | 0;
 i1 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i1) | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i6, i3) | 0;
 i6 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
 HEAP32[i5 >> 2] = i6;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i1, i3) | 0;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
 HEAP32[i4 >> 2] = i5;
 HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i1, i3) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 118, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm13WasmValidator13shouldBeFalseIPKcEEbbT_S3_(i5, i3, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6;
 if (i3) {
  __ZN4wasm13WasmValidator4failEv(i5) | 0;
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 20714) | 0, i4) | 0, 19438) | 0, i2) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
  HEAP8[i5 + 28 >> 0] = 0;
 }
 STACKTOP = i6;
 return 0;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 272, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10makeBinaryES1_NS_7IStringES1_(i1, i11, i2, i12) {
 i1 = i1 | 0;
 i11 = i11 | 0;
 i2 = i2 | 0;
 i12 = i12 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i13 = 0;
 i13 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i13 + 28 | 0;
 i4 = i13 + 24 | 0;
 i3 = i13 + 20 | 0;
 i6 = i13 + 16 | 0;
 i7 = i13 + 12 | 0;
 i8 = i13 + 8 | 0;
 i9 = i13 + 4 | 0;
 i10 = i13;
 i2 = HEAP32[i2 >> 2] | 0;
 i1 = HEAP32[i11 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[14898] | 0)) {
  HEAP32[i6 >> 2] = i1;
  HEAP32[i7 >> 2] = HEAP32[i12 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
  i1 = __ZN6cashew12ValueBuilder7makeDotENS_3RefES1_(i4, i5) | 0;
 } else {
  HEAP32[i8 >> 2] = i1;
  HEAP32[i9 >> 2] = i2;
  HEAP32[i10 >> 2] = HEAP32[i12 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i5 >> 2] = HEAP32[i10 >> 2];
  i1 = __ZN6cashew12ValueBuilder10makeBinaryENS_3RefENS_7IStringES1_(i3, i4, i5) | 0;
 }
 STACKTOP = i13;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator15visitCallImportEPNS_10CallImportE(i6, i4) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0, i8 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i7 + 4 | 0;
 i3 = i7;
 i2 = HEAP32[i6 + 24 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i4 + 24 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i3 >> 2];
 i5 = (__ZN4wasm6Module9getImportENS_4NameE(i2, i5) | 0) + 12 | 0;
 i5 = HEAP32[i5 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = i4 + 16 | 0;
 i1 = i5 + 8 | 0;
 __ZN4wasm13WasmValidator12shouldBeTrueIPNS_10CallImportEEEbbT_PKc(i6, (HEAP32[i3 >> 2] | 0) == ((HEAP32[i5 + 12 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) >> 2 | 0), i4, 19678) | 0;
 i5 = 0;
 while (1) {
  if (i5 >>> 0 >= (HEAP32[i3 >> 2] | 0) >>> 0) break;
  i8 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i2, i5) | 0;
  __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_10CallImportENS_8WasmTypeEEEbT0_S5_T_PKc(i6, HEAP32[(HEAP32[i8 >> 2] | 0) + 4 >> 2] | 0, HEAP32[(HEAP32[i1 >> 2] | 0) + (i5 << 2) >> 2] | 0, i4, 19707) | 0;
  i5 = i5 + 1 | 0;
 }
 STACKTOP = i7;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 362, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 206, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 341, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm17WasmBinaryBuilder9ungetInt8Ev(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5;
 i4 = i3 + 16 | 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (!i1) ___assert_fail(24054, 22948, 1384, 24062);
 if (HEAP8[i3 + 12 >> 0] | 0) {
  i1 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24072) | 0;
  i1 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(i1, HEAP32[i4 >> 2] | 0) | 0, 56966) | 0;
  i3 = __ZNKSt3__28ios_base6getlocEv(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i2 >> 2] = i3;
  i3 = __ZNKSt3__26locale9use_facetERNS0_2idE(i2, 61680) | 0;
  i3 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 63](i3, 10) | 0;
  __ZNSt3__26localeD2Ev(i2);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i1, i3) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i1) | 0;
  i1 = HEAP32[i4 >> 2] | 0;
 }
 HEAP32[i4 >> 2] = i1 + -1;
 STACKTOP = i5;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 314, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 293, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 469, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZNSt3__26vectorIPN4wasm12FunctionTypeENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm12FunctionTypeERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm12FunctionTypeENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm12FunctionTypeERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 383, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE21__push_back_slow_pathIRKS4_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPPN4wasm10ExpressionERNS_9allocatorIS4_EEEC2EjjS7_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE(i7, i5);
 __ZNSt3__214__split_bufferIPPN4wasm10ExpressionERNS_9allocatorIS4_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESN_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 4;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 9;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 8;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 4) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 8) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 143, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm20Asm2WasmPreProcessor7processEPc(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 L1 : do if ((HEAP8[i1 >> 0] | 0) == 77) {
  i2 = i1;
  i3 = 77;
  i1 = _strlen(i1) | 0;
  while (1) {
   if (i3 << 24 >> 24 == 102) break;
   i3 = i2 + 1 | 0;
   i2 = i3;
   i3 = HEAP8[i3 >> 0] | 0;
   i1 = i1 + -1 | 0;
  }
  i1 = i2 + i1 | 0;
  while (1) {
   i1 = i1 + -1 | 0;
   if ((HEAP8[i1 >> 0] | 0) == 125) {
    i1 = i2;
    break L1;
   }
   HEAP8[i1 >> 0] = 0;
  }
 } while (0);
 i5 = _strstr(i1, 21243) | 0;
 if (i5 | 0) {
  HEAP8[i5 >> 0] = 0;
  i2 = _strstr(i1, 21269) | 0;
  do if (i2 | 0) {
   HEAP8[i4 >> 0] = 1;
   i3 = _strstr(i1, 21282) | 0;
   i4 = i3 + 1 | 0;
   if (_strstr(i4, 21282) | 0) ___assert_fail(21292, 16311, 112, 21338);
   i2 = _strchr(i2, 125) | 0;
   if (i2 >>> 0 > (i3 + 5 | 0) >>> 0) {
    HEAP8[i3 >> 0] = 47;
    HEAP8[i4 >> 0] = 42;
    HEAP8[i2 + -1 >> 0] = 42;
    HEAP8[i2 >> 0] = 47;
    break;
   } else ___assert_fail(21346, 16311, 114, 21338);
  } while (0);
  HEAP8[i5 >> 0] = 47;
 }
 return i1 | 0;
}

function __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm10ExpressionERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm10ExpressionERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIPN4wasm10CallImportENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm10CallImportERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm10CallImportENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm10CallImportERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm10ExpressionERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm10ExpressionERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm10ThreadPool3getEv() {
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i5;
 i1 = HEAP32[14940] | 0;
 if (!i1) {
  i1 = __ZNSt3__26thread20hardware_concurrencyEv() | 0;
  i2 = _getenv(48575) | 0;
  if (!i2) i4 = i1 >>> 0 > 1 ? i1 : 1; else {
   HEAP32[i3 >> 2] = 0;
   HEAP32[i3 + 4 >> 2] = 0;
   HEAP32[i3 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i3, i2, _strlen(i2) | 0);
   i4 = __ZNSt3__24stoiERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPji(i3, 0, 10) | 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i3);
  }
  i1 = __Znwj(96) | 0;
  i2 = i1;
  i3 = i2 + 96 | 0;
  do {
   HEAP32[i2 >> 2] = 0;
   i2 = i2 + 4 | 0;
  } while ((i2 | 0) < (i3 | 0));
  i2 = HEAP32[14940] | 0;
  HEAP32[14940] = i1;
  if (i2) {
   __ZN4wasm10ThreadPoolD2Ev(i2);
   __ZdlPv(i2);
   i1 = HEAP32[14940] | 0;
  }
  __ZN4wasm10ThreadPool10initializeEj(i1, i4);
  i1 = HEAP32[14940] | 0;
 }
 STACKTOP = i5;
 return i1 | 0;
}

function ___fwritex(i3, i4, i6) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i7 = 0;
 i1 = i6 + 16 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if (!i2) if (!(___towrite(i6) | 0)) {
  i2 = HEAP32[i1 >> 2] | 0;
  i5 = 5;
 } else i1 = 0; else i5 = 5;
 L5 : do if ((i5 | 0) == 5) {
  i7 = i6 + 20 | 0;
  i1 = HEAP32[i7 >> 2] | 0;
  i5 = i1;
  if ((i2 - i1 | 0) >>> 0 < i4 >>> 0) {
   i1 = FUNCTION_TABLE_iiii[HEAP32[i6 + 36 >> 2] & 31](i6, i3, i4) | 0;
   break;
  }
  L10 : do if ((HEAP8[i6 + 75 >> 0] | 0) > -1) {
   i1 = i4;
   while (1) {
    if (!i1) {
     i2 = i5;
     i1 = 0;
     break L10;
    }
    i2 = i1 + -1 | 0;
    if ((HEAP8[i3 + i2 >> 0] | 0) == 10) break; else i1 = i2;
   }
   if ((FUNCTION_TABLE_iiii[HEAP32[i6 + 36 >> 2] & 31](i6, i3, i1) | 0) >>> 0 < i1 >>> 0) break L5;
   i4 = i4 - i1 | 0;
   i3 = i3 + i1 | 0;
   i2 = HEAP32[i7 >> 2] | 0;
  } else {
   i2 = i5;
   i1 = 0;
  } while (0);
  _memcpy(i2 | 0, i3 | 0, i4 | 0) | 0;
  HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + i4;
  i1 = i1 + i4 | 0;
 } while (0);
 return i1 | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc(i11, i10, i1, i4, i8, i9, i7, i5) {
 i11 = i11 | 0;
 i10 = i10 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i8 = i8 | 0;
 i9 = i9 | 0;
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i2 = 0, i3 = 0, i6 = 0;
 if ((-18 - i10 | 0) >>> 0 < i1 >>> 0) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i11);
 if ((HEAP8[i11 + 11 >> 0] | 0) < 0) i6 = HEAP32[i11 >> 2] | 0; else i6 = i11;
 if (i10 >>> 0 < 2147483623) {
  i2 = i1 + i10 | 0;
  i3 = i10 << 1;
  i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
  i2 = i2 >>> 0 < 11 ? 11 : i2 + 16 & -16;
 } else i2 = -17;
 i3 = __Znwj(i2) | 0;
 if (i8 | 0) _memcpy(i3 | 0, i6 | 0, i8 | 0) | 0;
 if (i7 | 0) _memcpy(i3 + i8 | 0, i5 | 0, i7 | 0) | 0;
 i1 = i4 - i9 | 0;
 if ((i1 | 0) != (i8 | 0)) _memcpy(i3 + i8 + i7 | 0, i6 + i8 + i9 | 0, i1 - i8 | 0) | 0;
 if ((i10 | 0) != 10) __ZdlPv(i6);
 HEAP32[i11 >> 2] = i3;
 HEAP32[i11 + 8 >> 2] = i2 | -2147483648;
 i10 = i1 + i7 | 0;
 HEAP32[i11 + 4 >> 2] = i10;
 HEAP8[i3 + i10 >> 0] = 0;
 return;
}

function __ZN4wasm14SimplifyLocalsD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 6900;
 HEAP32[i1 + 16 >> 2] = 6928;
 __ZNSt3__213__vector_baseIPN4wasm2IfENS_9allocatorIS3_EEED2Ev(i1 + 120 | 0);
 __ZNSt3__213__vector_baseIPN4wasm5BlockENS_9allocatorIS3_EEED2Ev(i1 + 108 | 0);
 __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i1 + 96 | 0);
 __ZNSt3__213__vector_baseINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEED2Ev(i1 + 80 | 0);
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEED2Ev(i1 + 68 | 0);
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEED2Ev(i1 + 56 | 0);
 __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEED2Ev(i1 + 44 | 0);
 __ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEED2Ev(i1);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESM_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i8, i1) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i6 = i8 + 8 | 0;
 i7 = i8 + 12 | 0;
 if ((HEAP32[i7 >> 2] | 0) != (HEAP32[i6 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i8, 448, i1);
 i5 = i8 + 4 | 0;
 while (1) {
  i4 = HEAP32[i7 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i6 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i7 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i8, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm17getExpressionNameEPNS_10ExpressionE(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 do switch (HEAP32[i2 >> 2] | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 1:
  {
   i1 = 49182;
   break;
  }
 case 2:
  {
   i1 = 47650;
   break;
  }
 case 3:
  {
   i1 = 34638;
   break;
  }
 case 4:
  {
   i1 = 47684;
   break;
  }
 case 5:
  {
   i1 = 47699;
   break;
  }
 case 6:
  {
   i1 = 49151;
   break;
  }
 case 7:
  {
   i1 = 49156;
   break;
  }
 case 8:
  {
   i1 = 49168;
   break;
  }
 case 9:
  {
   i1 = 21992;
   break;
  }
 case 10:
  {
   i1 = 22002;
   break;
  }
 case 11:
  {
   i1 = 22012;
   break;
  }
 case 12:
  {
   i1 = 22017;
   break;
  }
 case 13:
  {
   i1 = 47618;
   break;
  }
 case 14:
  {
   i1 = 22023;
   break;
  }
 case 15:
  {
   i1 = 47636;
   break;
  }
 case 16:
  {
   i1 = 36082;
   break;
  }
 case 17:
  {
   i1 = 47643;
   break;
  }
 case 18:
  {
   i1 = 22029;
   break;
  }
 case 19:
  {
   i1 = 36137;
   break;
  }
 case 20:
  {
   i1 = 36141;
   break;
  }
 default:
  {}
 } while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJRS2_EEEvDpOT_(i7, i5) {
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEEC2EjjS5_(i6, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i6);
 __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEED2Ev(i6);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 12 | 0;
 if ((HEAP32[i8 >> 2] | 0) != (HEAP32[i7 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i2, 425, i1);
 i6 = i2 + -16 | 0;
 i5 = i2 + 4 | 0;
 while (1) {
  i4 = HEAP32[i8 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i7 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i8 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i6, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZNSt3__26vectorIPN4wasm8FunctionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm8FunctionERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm8FunctionENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm8FunctionERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIN6cashew7IStringERNS_9allocatorIS2_EEEC2EjjS5_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i5);
 __ZNSt3__214__split_bufferIN6cashew7IStringERNS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i8, i1) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i6 = i8 + 8 | 0;
 i7 = i8 + 12 | 0;
 if ((HEAP32[i7 >> 2] | 0) != (HEAP32[i6 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i8, 164, i1);
 i5 = i8 + 4 | 0;
 while (1) {
  i4 = HEAP32[i7 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i6 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i7 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i8, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZNSt3__26vectorIPN4wasm8FunctionENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm8FunctionERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm8FunctionENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm8FunctionERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i6;
 i1 = __Znwj(60) | 0;
 i2 = i1;
 i3 = i2 + 60 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 HEAP32[i5 + 60 >> 2] = i1;
 HEAP32[i4 >> 2] = i1;
 i2 = i5 + 52 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (i3 >>> 0 >= (HEAP32[i5 + 56 >> 2] | 0) >>> 0) {
  __ZNSt3__26vectorINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEENS_9allocatorISC_EEE21__push_back_slow_pathISC_EEvOT_(i5 + 48 | 0, i4);
  i1 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  if (i1 | 0) {
   __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE10BasicBlockD2Ev(i1);
   __ZdlPv(i1);
  }
 } else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = i3 + 4;
  HEAP32[i4 >> 2] = 0;
 }
 STACKTOP = i6;
 return;
}

function __ZNSt3__26vectorIPN4wasm7ElementENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm7ElementERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm7ElementENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm7ElementERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEEC2EjjS5_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i5);
 __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i8, i1) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i6 = i8 + 8 | 0;
 i7 = i8 + 12 | 0;
 if ((HEAP32[i7 >> 2] | 0) != (HEAP32[i6 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i8, 76, i1);
 i5 = i8 + 4 | 0;
 while (1) {
  i4 = HEAP32[i7 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i6 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i7 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i8, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__6clENS1_7IStringE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i6 + 24 | 0;
 i4 = i6 + 12 | 0;
 i5 = i6;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP32[i5 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i5, 30524, 15);
 i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i5, HEAP32[i1 >> 2] | 0) | 0;
 HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i4 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i4 + 11 >> 0] | 0) < 0 ? HEAP32[i4 >> 2] | 0 : i4, 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
 STACKTOP = i6;
 return HEAP32[i3 >> 2] | 0;
}

function __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__5clENS1_7IStringE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i6 + 24 | 0;
 i4 = i6 + 12 | 0;
 i5 = i6;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP32[i5 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i5, 30511, 12);
 i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i5, HEAP32[i1 >> 2] | 0) | 0;
 HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i4 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i4 + 11 >> 0] | 0) < 0 ? HEAP32[i4 >> 2] | 0 : i4, 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
 STACKTOP = i6;
 return HEAP32[i3 >> 2] | 0;
}

function __ZNSt3__26vectorIPN6cashew5ValueENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN6cashew5ValueERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN6cashew5ValueENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN6cashew5ValueERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEEC2EjjS5_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i5);
 __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS7_EEEEEENS_19__map_value_compareIS3_SB_NS_4lessIS3_EELb1EEENS8_ISB_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESN_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 4;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 9;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 8;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 4) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 8) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i8, i1) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i6 = i8 + 8 | 0;
 i7 = i8 + 12 | 0;
 if ((HEAP32[i7 >> 2] | 0) != (HEAP32[i6 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i8, 97, i1);
 i5 = i8 + 4 | 0;
 while (1) {
  i4 = HEAP32[i7 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i6 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i7 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i8, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i1, i6, i7) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i5 + 4 | 0;
 i1 = i5;
 HEAP32[i4 >> 2] = i6;
 HEAP32[i1 >> 2] = i7;
 i2 = i6 + 40 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if ((i3 | 0) == (HEAP32[i6 + 44 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE21__push_back_slow_pathIRKS9_EEvOT_(i6 + 36 | 0, i1); else {
  HEAP32[i3 >> 2] = i7;
  HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
 }
 i1 = i7 + 52 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[i7 + 56 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE21__push_back_slow_pathIRKS9_EEvOT_(i7 + 48 | 0, i4); else {
  HEAP32[i2 >> 2] = i6;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
 }
 STACKTOP = i5;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i8, i1) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i6 = i8 + 8 | 0;
 i7 = i8 + 12 | 0;
 if ((HEAP32[i7 >> 2] | 0) != (HEAP32[i6 >> 2] | 0)) ___assert_fail(49624, 49642, 292, 49663);
 __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i8, 499, i1);
 i5 = i8 + 4 | 0;
 while (1) {
  i4 = HEAP32[i7 >> 2] | 0;
  i1 = i4;
  if ((i4 | 0) == (HEAP32[i6 >> 2] | 0)) {
   i1 = 12;
   break;
  }
  i2 = i1 + -8 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = HEAP32[i1 + -4 >> 2] | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break;
   i9 = i1 + -8 | 0;
   HEAP32[i7 >> 2] = i9;
   i1 = i9;
  }
  if (!(HEAP32[i4 >> 2] | 0)) {
   i1 = 9;
   break;
  }
  FUNCTION_TABLE_vii[i3 & 1023](i8, i4);
  i1 = HEAP32[i5 >> 2] | 0;
  if (!i1) continue;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i5 >> 2] = 0;
 }
 if ((i1 | 0) == 9) ___assert_fail(49668, 49642, 296, 49663); else if ((i1 | 0) == 12) return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 4;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 9;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 8;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 4) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 8) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function _vsnprintf(i3, i1, i10, i8) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i10 = i10 | 0;
 i8 = i8 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0, i11 = 0;
 i11 = STACKTOP;
 STACKTOP = STACKTOP + 128 | 0;
 i2 = i11 + 112 | 0;
 i9 = i11;
 i4 = i9;
 i5 = 8432;
 i6 = i4 + 112 | 0;
 do {
  HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
  i4 = i4 + 4 | 0;
  i5 = i5 + 4 | 0;
 } while ((i4 | 0) < (i6 | 0));
 if ((i1 + -1 | 0) >>> 0 > 2147483646) if (!i1) {
  i1 = 1;
  i7 = 4;
 } else {
  i1 = ___errno_location() | 0;
  HEAP32[i1 >> 2] = 75;
  i1 = -1;
 } else {
  i2 = i3;
  i7 = 4;
 }
 if ((i7 | 0) == 4) {
  i7 = -2 - i2 | 0;
  i7 = i1 >>> 0 > i7 >>> 0 ? i7 : i1;
  HEAP32[i9 + 48 >> 2] = i7;
  i3 = i9 + 20 | 0;
  HEAP32[i3 >> 2] = i2;
  HEAP32[i9 + 44 >> 2] = i2;
  i1 = i2 + i7 | 0;
  i2 = i9 + 16 | 0;
  HEAP32[i2 >> 2] = i1;
  HEAP32[i9 + 28 >> 2] = i1;
  i1 = _vfprintf(i9, i10, i8) | 0;
  if (i7) {
   i10 = HEAP32[i3 >> 2] | 0;
   HEAP8[i10 + (((i10 | 0) == (HEAP32[i2 >> 2] | 0)) << 31 >> 31) >> 0] = 0;
  }
 }
 STACKTOP = i11;
 return i1 | 0;
}

function __ZNSt3__26vectorIPN4wasm5BlockENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm5BlockERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm5BlockENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm5BlockERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE26__swap_out_circular_bufferERNS_14__split_bufferISC_RSD_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i7 = i1 + -12 | 0;
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEEC2EOSC_((HEAP32[i4 >> 2] | 0) + -12 | 0, i7);
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -12;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i2;
 i3 = i6 + 8 | 0;
 i7 = i5 + 12 | 0;
 i6 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i6;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZNSt3__26vectorIPN4wasm4PassENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm4PassERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm4PassENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm4PassERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIPN4wasm4CallENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm4CallERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm4CallENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm4CallERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIN6cashew3RefERNS_9allocatorIS2_EEEC2EjjS5_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i5);
 __ZNSt3__214__split_bufferIN6cashew3RefERNS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIPN4wasm4PassENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm4PassERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm4PassENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm4PassERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIN4wasm4NameERNS_9allocatorIS2_EEEC2EjjS5_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i5);
 __ZNSt3__214__split_bufferIN4wasm4NameERNS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 4;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 9;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 8;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 4) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 8) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIN4wasm4NameERNS_9allocatorIS2_EEEC2EjjS5_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i5);
 __ZNSt3__214__split_bufferIN4wasm4NameERNS_9allocatorIS2_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6Thread8mainLoopEPv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i8;
 i2 = i1 + 4 | 0;
 i3 = i1 + 88 | 0;
 i4 = i1 + 104 | 0;
 i5 = i1 + 80 | 0;
 i6 = i7 + 4 | 0;
 i1 = i1 + 32 | 0;
 while (1) {
  __ZNSt3__25mutex4lockEv(i2);
  if (!(HEAP32[i4 >> 2] | 0)) {
   if (HEAP8[i5 >> 0] | 0) break;
  } else {
   do {} while (!(__ZNKSt3__28functionIFN4wasm15ThreadWorkStateEvEEclEv(i3) | 0));
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEaSEDn(i3, 0) | 0;
  }
  __ZNSt3__25mutex6unlockEv(i2);
  __ZN4wasm10ThreadPool19notifyThreadIsReadyEv(__ZN4wasm10ThreadPool3getEv() | 0);
  HEAP32[i7 >> 2] = i2;
  HEAP8[i6 >> 0] = 1;
  __ZNSt3__25mutex4lockEv(i2);
  if ((HEAP8[i5 >> 0] | 0) == 0 ? (HEAP32[i4 >> 2] | 0) == 0 : 0) __ZNSt3__218condition_variable4waitERNS_11unique_lockINS_5mutexEEE(i1, i7);
  if (HEAP8[i6 >> 0] | 0) __ZNSt3__25mutex6unlockEv(HEAP32[i7 >> 2] | 0);
 }
 __ZNSt3__25mutex6unlockEv(i2);
 STACKTOP = i8;
 return;
}

function __ZN6cashew5Arena5allocEv(i8) {
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i9;
 i6 = i8 + 4 | 0;
 i7 = HEAP32[i6 >> 2] | 0;
 i1 = i7;
 if (!((i7 | 0) != (HEAP32[i8 >> 2] | 0) ? (i3 = i8 + 12 | 0, i2 = HEAP32[i3 >> 2] | 0, (i2 | 0) != 1e3) : 0)) {
  i3 = __Znaj(16008) | 0;
  HEAP32[i3 + 4 >> 2] = 1e3;
  i2 = i3 + 8 | 0;
  i3 = i3 + 16008 | 0;
  i4 = i2;
  do {
   HEAP32[i4 >> 2] = 3;
   HEAPF64[i4 + 8 >> 3] = 0.0;
   i4 = i4 + 16 | 0;
  } while ((i4 | 0) != (i3 | 0));
  HEAP32[i5 >> 2] = i2;
  if (i1 >>> 0 < (HEAP32[i8 + 8 >> 2] | 0) >>> 0) {
   HEAP32[i7 >> 2] = i2;
   i1 = (HEAP32[i6 >> 2] | 0) + 4 | 0;
   HEAP32[i6 >> 2] = i1;
  } else {
   __ZNSt3__26vectorIPN6cashew5ValueENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i8, i5);
   i1 = HEAP32[i6 >> 2] | 0;
  }
  i3 = i8 + 12 | 0;
  HEAP32[i3 >> 2] = 0;
  i2 = 0;
 }
 HEAP32[i3 >> 2] = i2 + 1;
 STACKTOP = i9;
 return (HEAP32[i1 + -4 >> 2] | 0) + (i2 << 4) | 0;
}

function __ZNSt3__26vectorIPN4wasm2IfENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPN4wasm2IfERNS_9allocatorIS3_EEEC2EjjS6_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPN4wasm2IfENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i5);
 __ZNSt3__214__split_bufferIPN4wasm2IfERNS_9allocatorIS3_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZN6cashew12ValueBuilder11appendToVarENS_3RefENS_7IStringES1_(i7, i2, i6) {
 i7 = i7 | 0;
 i2 = i2 | 0;
 i6 = i6 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i8 + 12 | 0;
 i1 = i8 + 8 | 0;
 i4 = i8 + 4 | 0;
 i5 = i8;
 if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i7, 0) | 0, 59296) | 0)) ___assert_fail(31467, 48272, 1519, 31481);
 i9 = __ZN6cashew12ValueBuilder12makeRawArrayEi(1) | 0;
 i2 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i2) | 0;
 HEAP32[i1 >> 2] = i2;
 HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i9, i3) | 0;
 if (!(__ZN6cashew3RefntEv(i6) | 0)) {
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  __ZN6cashew5Value9push_backENS_3RefE(i1, i3) | 0;
 }
 i9 = __ZN6cashew3RefixEj(i7, 1) | 0;
 i9 = HEAP32[i9 >> 2] | 0;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 __ZN6cashew5Value9push_backENS_3RefE(i9, i3) | 0;
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE14__erase_uniqueIS3_EEjRKT_(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5 + 4 | 0;
 i3 = i5;
 i1 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE4findIS3_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_(i4, i1) | 0;
 if ((i1 | 0) == (i4 + 4 | 0)) i1 = 0; else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE5eraseENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_PvEEiEE(i4, i2) | 0;
  i1 = 1;
 }
 STACKTOP = i5;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm12CallIndirectEN6cashew7IStringEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEESK_RKT_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESK_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEENS_9allocatorISC_EEE26__swap_out_circular_bufferERNS_14__split_bufferISC_RSE_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i8 = (HEAP32[i4 >> 2] | 0) + -4 | 0;
  i7 = i1 + -4 | 0;
  i9 = HEAP32[i7 >> 2] | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i8 >> 2] = i9;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -4;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i9;
 i7 = i6 + 8 | 0;
 i9 = i5 + 12 | 0;
 i8 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i9 >> 2] = i8;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESL_RKT_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESJ_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNK4wasm7Literal3negEv(i3, i4) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i5 + 16 | 0;
 i2 = i5;
 switch (HEAP32[i4 >> 2] | 0) {
 case 1:
  {
   i4 = HEAP32[i4 + 8 >> 2] ^ -2147483648;
   HEAP32[i3 >> 2] = 1;
   HEAP32[i3 + 8 >> 2] = i4;
   break;
  }
 case 2:
  {
   i2 = i4 + 8 | 0;
   i1 = HEAP32[i2 >> 2] | 0;
   i2 = HEAP32[i2 + 4 >> 2] ^ -2147483648;
   HEAP32[i3 >> 2] = 2;
   i4 = i3 + 8 | 0;
   HEAP32[i4 >> 2] = i1;
   HEAP32[i4 + 4 >> 2] = i2;
   break;
  }
 case 3:
  {
   i4 = HEAP32[i4 + 8 >> 2] ^ -2147483648;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i4;
   __ZN4wasm7Literal9castToF32Ev(i3, i1);
   break;
  }
 case 4:
  {
   i1 = i4 + 8 | 0;
   i6 = HEAP32[i1 >> 2] | 0;
   i1 = HEAP32[i1 + 4 >> 2] ^ -2147483648;
   HEAP32[i2 >> 2] = 2;
   i4 = i2 + 8 | 0;
   HEAP32[i4 >> 2] = i6;
   HEAP32[i4 + 4 >> 2] = i1;
   __ZN4wasm7Literal9castToF64Ev(i3, i2);
   break;
  }
 default:
  {}
 }
 STACKTOP = i5;
 return;
}

function __ZN4wasm17WasmBinaryBuilder11visitReturnEPNS_6ReturnE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i4;
 if (HEAP8[i3 + 12 >> 0] | 0) {
  i5 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24584) | 0;
  i6 = __ZNKSt3__28ios_base6getlocEv(i5 + (HEAP32[(HEAP32[i5 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i6;
  i6 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i6 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 63](i6, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i5, i6) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i5) | 0;
 }
 i1 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i3) | 0;
 if ((i1 | 1 | 0) != 1) ___assert_fail(24171, 22948, 2057, 24600);
 if ((i1 | 0) == 1) {
  i6 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i3) | 0;
  HEAP32[i2 + 8 >> 2] = i6;
 }
 STACKTOP = i4;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESI_RKT_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESL_RKT_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__212__hash_tableIPKcN6cashew7IString11CStringHashENS4_12CStringEqualENS_9allocatorIS2_EEE4findIS2_EENS_15__hash_iteratorIPNS_11__hash_nodeIS2_PvEEEERKT_(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i8 = HEAP32[i1 >> 2] | 0;
 i1 = i8;
 i3 = 5381;
 while (1) {
  i2 = HEAP8[i1 >> 0] | 0;
  if (!(i2 << 24 >> 24)) break;
  i1 = i1 + 1 | 0;
  i3 = i2 << 24 >> 24 ^ i3 * 33;
 }
 i7 = HEAP32[i4 + 4 >> 2] | 0;
 L5 : do if (i7) {
  i5 = i7 + -1 | 0;
  i6 = (i5 & i7 | 0) == 0;
  if (i6) i3 = i5 & i3; else i3 = (i3 >>> 0) % (i7 >>> 0) | 0;
  i1 = HEAP32[(HEAP32[i4 >> 2] | 0) + (i3 << 2) >> 2] | 0;
  if (i1) do {
   i1 = HEAP32[i1 >> 2] | 0;
   if (!i1) {
    i1 = 0;
    break L5;
   }
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   if (i6) i2 = i2 & i5; else i2 = (i2 >>> 0) % (i7 >>> 0) | 0;
   if ((i2 | 0) != (i3 | 0)) {
    i1 = 0;
    break L5;
   }
  } while ((_strcmp(HEAP32[i1 + 8 >> 2] | 0, i8) | 0) != 0); else i1 = 0;
 } else i1 = 0; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESJ_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNK4wasm7Literal3absEv(i3, i4) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i5 + 16 | 0;
 i2 = i5;
 switch (HEAP32[i4 >> 2] | 0) {
 case 1:
  {
   i4 = HEAP32[i4 + 8 >> 2] & 2147483647;
   HEAP32[i3 >> 2] = 1;
   HEAP32[i3 + 8 >> 2] = i4;
   break;
  }
 case 2:
  {
   i2 = i4 + 8 | 0;
   i1 = HEAP32[i2 >> 2] | 0;
   i2 = HEAP32[i2 + 4 >> 2] & 2147483647;
   HEAP32[i3 >> 2] = 2;
   i4 = i3 + 8 | 0;
   HEAP32[i4 >> 2] = i1;
   HEAP32[i4 + 4 >> 2] = i2;
   break;
  }
 case 3:
  {
   i4 = HEAP32[i4 + 8 >> 2] & 2147483647;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i4;
   __ZN4wasm7Literal9castToF32Ev(i3, i1);
   break;
  }
 case 4:
  {
   i1 = i4 + 8 | 0;
   i6 = HEAP32[i1 >> 2] | 0;
   i1 = HEAP32[i1 + 4 >> 2] & 2147483647;
   HEAP32[i2 >> 2] = 2;
   i4 = i2 + 8 | 0;
   HEAP32[i4 >> 2] = i6;
   HEAP32[i4 + 4 >> 2] = i1;
   __ZN4wasm7Literal9castToF64Ev(i3, i2);
   break;
  }
 default:
  {}
 }
 STACKTOP = i5;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESI_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZN4wasm28DuplicateFunctionElimination5equalEPNS_8FunctionES2_(i1, i3, i4) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i2 = 0, i5 = 0;
 L1 : do if (((HEAP32[i3 + 12 >> 2] | 0) - (HEAP32[i3 + 8 >> 2] | 0) | 0) == ((HEAP32[i4 + 12 >> 2] | 0) - (HEAP32[i4 + 8 >> 2] | 0) | 0) ? ((HEAP32[i3 + 24 >> 2] | 0) - (HEAP32[i3 + 20 >> 2] | 0) | 0) == ((HEAP32[i4 + 24 >> 2] | 0) - (HEAP32[i4 + 20 >> 2] | 0) | 0) : 0) {
  i1 = __ZN4wasm8Function12getNumLocalsEv(i3) | 0;
  i2 = 0;
  while (1) {
   if (i2 >>> 0 >= i1 >>> 0) break;
   i5 = __ZN4wasm8Function12getLocalTypeEj(i3, i2) | 0;
   if ((i5 | 0) == (__ZN4wasm8Function12getLocalTypeEj(i4, i2) | 0)) i2 = i2 + 1 | 0; else {
    i1 = 0;
    break L1;
   }
  }
  if ((HEAP32[i3 + 4 >> 2] | 0) == (HEAP32[i4 + 4 >> 2] | 0) ? (HEAP32[i3 + 32 >> 2] | 0) == (HEAP32[i4 + 32 >> 2] | 0) : 0) i1 = __ZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_(HEAP32[i3 + 36 >> 2] | 0, HEAP32[i4 + 36 >> 2] | 0) | 0; else i1 = 0;
 } else i1 = 0; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESJ_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESJ_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE13__lower_boundIS7_EENS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEERKT_SN_SN_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i5 = 0, i6 = 0, i7 = 0;
 i5 = HEAP8[i4 + 11 >> 0] | 0;
 i3 = i5 << 24 >> 24 < 0;
 i5 = i3 ? HEAP32[i4 + 4 >> 2] | 0 : i5 & 255;
 i3 = i3 ? HEAP32[i4 >> 2] | 0 : i4;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   i4 = i2 + 16 | 0;
   i6 = HEAP8[i4 + 11 >> 0] | 0;
   i7 = i6 << 24 >> 24 < 0;
   i6 = i7 ? HEAP32[i2 + 20 >> 2] | 0 : i6 & 255;
   i4 = __ZNSt3__211char_traitsIcE7compareEPKcS3_j(i7 ? HEAP32[i4 >> 2] | 0 : i4, i3, i5 >>> 0 < i6 >>> 0 ? i5 : i6) | 0;
   if ((((i4 | 0) == 0 ? (i6 >>> 0 < i5 >>> 0 ? -2147483648 : 0) : i4) | 0) >= 0) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZN4wasm19DeadCodeElimination10visitBlockEPNS_5BlockE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i1 = i7 + 64 | 0;
 i3 = HEAP32[i1 >> 2] | 0;
 i2 = i3 + -4 | 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  i4 = i3 + -4 | 0;
  HEAP32[i1 >> 2] = i4;
  i3 = i4;
 }
 i3 = i6 + 8 | 0;
 if (HEAP32[i3 >> 2] | 0) {
  i4 = i7 + 44 | 0;
  i1 = i7 + 48 | 0;
  if (!(HEAP8[i4 >> 0] | 0)) i2 = (__ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(i1, i3) | 0) != 0 & 1; else i2 = 1;
  HEAP8[i4 >> 0] = i2;
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__erase_uniqueIS2_EEjRKT_(i1, i3) | 0;
 }
 i1 = i6 + 12 | 0;
 if (((HEAP32[i6 + 20 >> 2] | 0) == 1 ? (i5 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, 0) | 0, i5 = HEAP32[i5 >> 2] | 0, i5 | 0) : 0) ? (HEAP32[i5 >> 2] | 0) == 20 : 0) {
  i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, 0) | 0;
  HEAP32[i7 + 20 >> 2] = HEAP32[i6 >> 2];
 }
 return;
}

function __ZN6cashew12ValueBuilder14appendToObjectENS_3RefENS_7IStringES1_(i5, i6, i7) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 12 | 0;
 i2 = i8 + 8 | 0;
 i3 = i8 + 4 | 0;
 i4 = i8;
 if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i5, 0) | 0, 59604) | 0) {
  i5 = __ZN6cashew3RefixEj(i5, 1) | 0;
  i5 = HEAP32[i5 >> 2] | 0;
  i9 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
  i6 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i6) | 0;
  HEAP32[i3 >> 2] = i6;
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  i6 = __ZN6cashew5Value9push_backENS_3RefE(i9, i1) | 0;
  HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
  i7 = __ZN6cashew5Value9push_backENS_3RefE(i6, i1) | 0;
  HEAP32[i2 >> 2] = i7;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN6cashew5Value9push_backENS_3RefE(i5, i1) | 0;
  STACKTOP = i8;
  return;
 } else ___assert_fail(32244, 48272, 1654, 32263);
}

function __ZN4wasm13WasmValidator9visitCallEPNS_4CallE(i6, i4) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0, i8 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i7 + 4 | 0;
 i2 = i7;
 i1 = HEAP32[i6 + 24 >> 2] | 0;
 HEAP32[i2 >> 2] = HEAP32[i4 + 24 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i2 >> 2];
 i5 = __ZN4wasm6Module11getFunctionENS_4NameE(i1, i5) | 0;
 i1 = i4 + 8 | 0;
 i2 = i4 + 16 | 0;
 i3 = i5 + 8 | 0;
 __ZN4wasm13WasmValidator12shouldBeTrueIPNS_4CallEEEbbT_PKc(i6, (HEAP32[i2 >> 2] | 0) == ((HEAP32[i5 + 12 >> 2] | 0) - (HEAP32[i3 >> 2] | 0) >> 2 | 0), i4, 19678) | 0;
 i5 = 0;
 while (1) {
  if (i5 >>> 0 >= (HEAP32[i2 >> 2] | 0) >>> 0) break;
  i8 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i5) | 0;
  __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_4CallENS_8WasmTypeEEEbT0_S5_T_PKc(i6, HEAP32[(HEAP32[i8 >> 2] | 0) + 4 >> 2] | 0, HEAP32[(HEAP32[i3 >> 2] | 0) + (i5 << 2) >> 2] | 0, i4, 19707) | 0;
  i5 = i5 + 1 | 0;
 }
 STACKTOP = i7;
 return;
}

function __ZN4wasm14SimplifyLocals17doNoteIfElseFalseEPS0_PPNS_10ExpressionE(i4, i2) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i5 = 0;
 i1 = __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i2 >> 2] | 0) | 0;
 if (!(HEAP32[i1 + 16 >> 2] | 0)) ___assert_fail(41989, 41949, 151, 42002);
 i3 = i4 + 84 | 0;
 __ZN4wasm14SimplifyLocals16optimizeIfReturnEPNS_2IfEPPNS_10ExpressionERNSt3__23mapIjNS0_12SinkableInfoENS6_4lessIjEENS6_9allocatorINS6_4pairIKjS8_EEEEEE(i4, i1, i2, (HEAP32[i3 >> 2] | 0) + -12 | 0);
 i1 = HEAP32[i3 >> 2] | 0;
 i2 = i1 + -12 | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i5 = i1 + -12 | 0;
  HEAP32[i3 >> 2] = i5;
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEED2Ev(i5);
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5clearEv(i4 + 44 | 0);
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 i12 = i6 + 8 | 0;
 i12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i12 >> 2] | 0) + 20 >> 2] & 255](i12) | 0;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 i2 = HEAP8[i12 + 8 + 3 >> 0] | 0;
 i13 = i2 << 24 >> 24 < 0;
 i1 = i13 ? HEAP32[i12 >> 2] | 0 : i12;
 i2 = i1 + ((i13 ? HEAP32[i12 + 4 >> 2] | 0 : i2 & 255) << 2) | 0;
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i6, i9, i8, i4, i3, i5, i1, i2) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZN4wasm13WasmValidator11visitSwitchEPNS_6SwitchE(i9, i8) {
 i9 = i9 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i10 = 0, i11 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i10 + 8 | 0;
 i2 = i10 + 4 | 0;
 i3 = i10;
 i4 = i8 + 8 | 0;
 i5 = HEAP32[i8 + 16 >> 2] | 0;
 i6 = i8 + 32 | 0;
 i7 = 0;
 while (1) {
  if ((i7 | 0) == (i5 | 0)) break;
  i11 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i4, i7) | 0;
  HEAP32[i2 >> 2] = HEAP32[i11 >> 2];
  i11 = HEAP32[i6 >> 2] | 0;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN4wasm13WasmValidator9noteBreakENS_4NameEPNS_10ExpressionE(i9, i1, i11);
  i7 = i7 + 1 | 0;
 }
 HEAP32[i3 >> 2] = HEAP32[i8 + 24 >> 2];
 i11 = HEAP32[i6 >> 2] | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 __ZN4wasm13WasmValidator9noteBreakENS_4NameEPNS_10ExpressionE(i9, i1, i11);
 __ZN4wasm13WasmValidator12shouldBeTrueIPNS_6SwitchEEEbbT_PKc(i9, (HEAP32[(HEAP32[i8 + 28 >> 2] | 0) + 4 >> 2] | 4 | 0) == 5, i8, 19647) | 0;
 STACKTOP = i10;
 return;
}

function __ZN4wasm14SimplifyLocals13visitGetLocalEPNS_8GetLocalE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7 + 4 | 0;
 i2 = i7;
 i3 = i6 + 44 | 0;
 i4 = __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE4findIjEENS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEERKT_(i3, i5 + 8 | 0) | 0;
 if ((i4 | 0) != (i6 + 48 | 0)) {
  i8 = HEAP32[i4 + 20 >> 2] | 0;
  HEAP32[i6 + 20 >> 2] = HEAP32[i8 >> 2];
  HEAP32[i8 >> 2] = i5;
  HEAP32[i5 >> 2] = 19;
  HEAP32[i5 + 4 >> 2] = 0;
  HEAP32[i2 >> 2] = i4;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5eraseENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEE(i3, i1) | 0;
  HEAP8[i6 + 92 >> 0] = 1;
 }
 STACKTOP = i7;
 return;
}

function __ZN4wasm10TypeSeeker11visitSwitchEPNS_6SwitchE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0;
 i12 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i12;
 i8 = i1 + 8 | 0;
 i9 = HEAP32[i1 + 16 >> 2] | 0;
 i10 = i2 + 32 | 0;
 i11 = i2 + 36 | 0;
 i5 = i1 + 32 | 0;
 i6 = i2 + 40 | 0;
 i3 = i2 + 44 | 0;
 i4 = 0;
 while (1) {
  if ((i4 | 0) == (i9 | 0)) break;
  i2 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i8, i4) | 0;
  do if ((HEAP32[i2 >> 2] | 0) == (HEAP32[i10 >> 2] | 0)) {
   i1 = HEAP32[i5 >> 2] | 0;
   if (!i1) i1 = 0; else i1 = HEAP32[i1 + 4 >> 2] | 0;
   HEAP32[i7 >> 2] = i1;
   i2 = HEAP32[i6 >> 2] | 0;
   if (i2 >>> 0 < (HEAP32[i3 >> 2] | 0) >>> 0) {
    HEAP32[i2 >> 2] = i1;
    HEAP32[i6 >> 2] = i2 + 4;
    break;
   } else {
    __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i11, i7);
    break;
   }
  } while (0);
  i4 = i4 + 1 | 0;
 }
 STACKTOP = i12;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESH_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 4;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 9;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 8;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 4) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 8) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__221__murmur2_or_cityhashIjLj32EEclEPKvj(i1, i7, i4) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0, i8 = 0;
 i5 = i4 + ~(i4 >>> 0 < 3 ? i4 : 3) + 4 & -4;
 i6 = i4 - i5 | 0;
 i2 = i4;
 i3 = i7;
 i1 = i4;
 while (1) {
  if (i2 >>> 0 <= 3) break;
  i4 = Math_imul(HEAPU8[i3 >> 0] | HEAPU8[i3 + 1 >> 0] << 8 | HEAPU8[i3 + 2 >> 0] << 16 | HEAPU8[i3 + 3 >> 0] << 24, 1540483477) | 0;
  i2 = i2 + -4 | 0;
  i3 = i3 + 4 | 0;
  i1 = (Math_imul(i4 >>> 24 ^ i4, 1540483477) | 0) ^ (Math_imul(i1, 1540483477) | 0);
 }
 i2 = i7 + i5 | 0;
 switch (i6 | 0) {
 case 3:
  {
   i1 = (HEAPU8[i2 + 2 >> 0] | 0) << 16 ^ i1;
   i8 = 6;
   break;
  }
 case 2:
  {
   i8 = 6;
   break;
  }
 case 1:
  {
   i8 = 7;
   break;
  }
 default:
  {}
 }
 if ((i8 | 0) == 6) {
  i1 = (HEAPU8[i2 + 1 >> 0] | 0) << 8 ^ i1;
  i8 = 7;
 }
 if ((i8 | 0) == 7) i1 = Math_imul((HEAPU8[i2 >> 0] | 0) ^ i1, 1540483477) | 0;
 i8 = Math_imul(i1 >>> 13 ^ i1, 1540483477) | 0;
 return i8 >>> 15 ^ i8 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEESI_RKT_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESH_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEESI_RKT_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESH_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZN4wasm16PrintSExpression17visitCallIndirectEPNS_12CallIndirectE(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i5 + 4 | 0;
 i6 = i5;
 i2 = __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i4 >> 2] | 0, 34727, 0) | 0;
 HEAP32[i6 >> 2] = HEAP32[HEAP32[i1 + 24 >> 2] >> 2];
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i2, i3) | 0;
 __ZN4wasm16PrintSExpression9incIndentEv(i4);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i4, HEAP32[i1 + 28 >> 2] | 0);
 i3 = i1 + 8 | 0;
 i1 = HEAP32[i1 + 16 >> 2] | 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, i2) | 0;
  __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i4, HEAP32[i6 >> 2] | 0);
  i2 = i2 + 1 | 0;
 }
 __ZN4wasm16PrintSExpression9decIndentEv(i4);
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0, i12 = 0, i13 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 i12 = i6 + 8 | 0;
 i12 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i12 >> 2] | 0) + 20 >> 2] & 255](i12) | 0;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 i2 = HEAP8[i12 + 11 >> 0] | 0;
 i13 = i2 << 24 >> 24 < 0;
 i1 = i13 ? HEAP32[i12 >> 2] | 0 : i12;
 i2 = i1 + (i13 ? HEAP32[i12 + 4 >> 2] | 0 : i2 & 255) | 0;
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i6, i9, i8, i4, i3, i5, i1, i2) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZN6cashew12ValueBuilder21appendDefaultToSwitchENS_3RefE(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6 + 12 | 0;
 i2 = i6 + 8 | 0;
 i3 = i6 + 4 | 0;
 i4 = i6;
 if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i5, 0) | 0, 59364) | 0) {
  i5 = __ZN6cashew3RefixEj(i5, 2) | 0;
  i5 = HEAP32[i5 >> 2] | 0;
  i7 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
  i8 = __ZN6cashew12ValueBuilder8makeNullEv() | 0;
  HEAP32[i3 >> 2] = i8;
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  i3 = __ZN6cashew5Value9push_backENS_3RefE(i7, i1) | 0;
  i7 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
  HEAP32[i4 >> 2] = i7;
  HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
  i4 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
  HEAP32[i2 >> 2] = i4;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN6cashew5Value9push_backENS_3RefE(i5, i1) | 0;
  STACKTOP = i6;
  return;
 } else ___assert_fail(31685, 48272, 1605, 31725);
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner11visitReturnEPNS_6ReturnE(i4, i5, i1) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i6;
 HEAP32[i4 >> 2] = 0;
 i3 = i4 + 8 | 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 i3 = i4 + 16 | 0;
 HEAP32[i3 >> 2] = 0;
 i1 = HEAP32[i1 + 8 >> 2] | 0;
 if (!((i1 | 0) != 0 ? (__ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i2, i5, i1), HEAP32[i4 >> 2] = HEAP32[i2 >> 2], HEAP32[i4 + 4 >> 2] = HEAP32[i2 + 4 >> 2], HEAP32[i4 + 8 >> 2] = HEAP32[i2 + 8 >> 2], HEAP32[i4 + 12 >> 2] = HEAP32[i2 + 12 >> 2], HEAP32[i4 + 16 >> 2] = HEAP32[i2 + 16 >> 2], (HEAP32[i3 >> 2] | 0) != 0) : 0)) HEAP32[i4 + 16 >> 2] = HEAP32[14808];
 STACKTOP = i6;
 return;
}

function __ZNKSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS6_PvEEEERKT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = HEAP32[i1 >> 2] | 0;
 i1 = i5 * 33 ^ 5381;
 i4 = HEAP32[i2 + 4 >> 2] | 0;
 L1 : do if (i4) {
  i6 = i4 + -1 | 0;
  i7 = (i6 & i4 | 0) == 0;
  if (i7) i3 = i6 & i1; else i3 = (i1 >>> 0) % (i4 >>> 0) | 0;
  i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + (i3 << 2) >> 2] | 0;
  if (i1) do {
   i1 = HEAP32[i1 >> 2] | 0;
   if (!i1) {
    i1 = 0;
    break L1;
   }
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   if (i7) i2 = i2 & i6; else i2 = (i2 >>> 0) % (i4 >>> 0) | 0;
   if ((i2 | 0) != (i3 | 0)) {
    i1 = 0;
    break L1;
   }
  } while ((HEAP32[i1 + 8 >> 2] | 0) != (i5 | 0)); else i1 = 0;
 } else i1 = 0; while (0);
 return i1 | 0;
}

function __ZN4wasm17WasmBinaryBuilder8getBlockEv(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i7 + 4 | 0;
 i1 = i7;
 i6 = __ZN4wasm17WasmBinaryBuilder12getNextLabelEv(i4) | 0;
 HEAP32[i3 >> 2] = i6;
 i5 = i4 + 88 | 0;
 i2 = HEAP32[i5 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[i4 + 92 >> 2] | 0)) __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4 + 84 | 0, i3); else {
  HEAP32[i2 >> 2] = i6;
  HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 4;
 }
 HEAP32[i1 >> 2] = (HEAP32[i4 >> 2] | 0) + 88;
 i1 = __ZN4wasm7Builder8blockifyEPNS_10ExpressionES2_(i1, __ZN4wasm17WasmBinaryBuilder13getMaybeBlockEv(i4) | 0, 0) | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i3 + -4 | 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  i4 = i3 + -4 | 0;
  HEAP32[i5 >> 2] = i4;
  i3 = i4;
 }
 i5 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(i1) | 0) + 8 | 0;
 HEAP32[i5 >> 2] = i6;
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm13WasmValidator17visitCallIndirectEPNS_12CallIndirectE(i6, i4) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0;
 i5 = HEAP32[i4 + 24 >> 2] | 0;
 __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_12CallIndirectENS_8WasmTypeEEEbT0_S5_T_PKc(i6, HEAP32[(HEAP32[i4 + 28 >> 2] | 0) + 4 >> 2] | 0, 1, i4, 19762) | 0;
 i1 = i4 + 8 | 0;
 i2 = i4 + 16 | 0;
 i3 = i5 + 8 | 0;
 __ZN4wasm13WasmValidator12shouldBeTrueIPNS_12CallIndirectEEEbbT_PKc(i6, (HEAP32[i2 >> 2] | 0) == ((HEAP32[i5 + 12 >> 2] | 0) - (HEAP32[i3 >> 2] | 0) >> 2 | 0), i4, 19678) | 0;
 i5 = 0;
 while (1) {
  if (i5 >>> 0 >= (HEAP32[i2 >> 2] | 0) >>> 0) break;
  i7 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1, i5) | 0;
  __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_12CallIndirectENS_8WasmTypeEEEbT0_S5_T_PKc(i6, HEAP32[(HEAP32[i7 >> 2] | 0) + 4 >> 2] | 0, HEAP32[(HEAP32[i3 >> 2] | 0) + (i5 << 2) >> 2] | 0, i4, 19707) | 0;
  i5 = i5 + 1 | 0;
 }
 return;
}

function __ZNSt3__26vectorIPcNS_9allocatorIS1_EEE21__push_back_slow_pathIS1_EEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIPcRNS_9allocatorIS1_EEEC2EjjS4_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIPcNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE(i7, i5);
 __ZNSt3__214__split_bufferIPcRNS_9allocatorIS1_EEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__hash_iteratorIPNS_11__hash_nodeIS6_PvEEEERKT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = HEAP32[i1 >> 2] | 0;
 i1 = i5 * 33 ^ 5381;
 i4 = HEAP32[i2 + 4 >> 2] | 0;
 L1 : do if (i4) {
  i6 = i4 + -1 | 0;
  i7 = (i6 & i4 | 0) == 0;
  if (i7) i3 = i6 & i1; else i3 = (i1 >>> 0) % (i4 >>> 0) | 0;
  i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + (i3 << 2) >> 2] | 0;
  if (i1) do {
   i1 = HEAP32[i1 >> 2] | 0;
   if (!i1) {
    i1 = 0;
    break L1;
   }
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   if (i7) i2 = i2 & i6; else i2 = (i2 >>> 0) % (i4 >>> 0) | 0;
   if ((i2 | 0) != (i3 | 0)) {
    i1 = 0;
    break L1;
   }
  } while ((HEAP32[i1 + 8 >> 2] | 0) != (i5 | 0)); else i1 = 0;
 } else i1 = 0; while (0);
 return i1 | 0;
}

function __ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc(i6, i7, i1, i2, i5, i3, i4) {
 i6 = i6 | 0;
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i2 >> 2] = i1 + 100;
 __ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc(i6 + 8 | 0, i1, i2, i5, i3, i4);
 i6 = HEAP32[i2 >> 2] | 0;
 i5 = i1;
 i1 = HEAP32[i7 >> 2] | 0;
 while (1) {
  if ((i5 | 0) == (i6 | 0)) break;
  i3 = HEAP8[i5 >> 0] | 0;
  do if (i1) {
   i4 = i1 + 24 | 0;
   i2 = HEAP32[i4 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i1 + 28 >> 2] | 0)) {
    i7 = (FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 52 >> 2] & 63](i1, i3 & 255) | 0) == -1;
    i1 = i7 ? 0 : i1;
    break;
   } else {
    HEAP32[i4 >> 2] = i2 + 1;
    HEAP8[i2 >> 0] = i3;
    break;
   }
  } else i1 = 0; while (0);
  i5 = i5 + 1 | 0;
 }
 STACKTOP = i8;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj9EEERAT__Kc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP8[i2 + 11 >> 0] = 8;
 i3 = i1;
 i5 = i3;
 i5 = HEAPU8[i5 >> 0] | HEAPU8[i5 + 1 >> 0] << 8 | HEAPU8[i5 + 2 >> 0] << 16 | HEAPU8[i5 + 3 >> 0] << 24;
 i3 = i3 + 4 | 0;
 i3 = HEAPU8[i3 >> 0] | HEAPU8[i3 + 1 >> 0] << 8 | HEAPU8[i3 + 2 >> 0] << 16 | HEAPU8[i3 + 3 >> 0] << 24;
 i1 = i2;
 i4 = i1;
 HEAP8[i4 >> 0] = i5;
 HEAP8[i4 + 1 >> 0] = i5 >> 8;
 HEAP8[i4 + 2 >> 0] = i5 >> 16;
 HEAP8[i4 + 3 >> 0] = i5 >> 24;
 i1 = i1 + 4 | 0;
 HEAP8[i1 >> 0] = i3;
 HEAP8[i1 + 1 >> 0] = i3 >> 8;
 HEAP8[i1 + 2 >> 0] = i3 >> 16;
 HEAP8[i1 + 3 >> 0] = i3 >> 24;
 HEAP8[i2 + 8 >> 0] = 0;
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZN6cashew12ValueBuilder15makeConditionalENS_3RefES1_S1_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i4 + 16 | 0;
 i10 = i4 + 12 | 0;
 i9 = i4 + 8 | 0;
 i7 = i4 + 4 | 0;
 i6 = i4;
 i8 = __ZN6cashew12ValueBuilder12makeRawArrayEi(4) | 0;
 i11 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59304) | 0;
 HEAP32[i10 >> 2] = i11;
 HEAP32[i5 >> 2] = HEAP32[i10 >> 2];
 i8 = __ZN6cashew5Value9push_backENS_3RefE(i8, i5) | 0;
 HEAP32[i9 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i9 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i8, i5) | 0;
 HEAP32[i7 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i1, i5) | 0;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i3, i5) | 0;
 STACKTOP = i4;
 return i3 | 0;
}

function __ZNSt3__218__insertion_sort_3IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEvT0_S8_T_(i5, i7, i4) {
 i5 = i5 | 0;
 i7 = i7 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0, i8 = 0;
 i1 = i5 + 8 | 0;
 __ZNSt3__27__sort3IRZN4wasm13ReorderLocals13visitFunctionEPNS1_8FunctionEEUljjE_PjEEjT0_S8_S8_T_(i5, i5 + 4 | 0, i1, i4) | 0;
 i6 = i5 + 12 | 0;
 while (1) {
  if ((i6 | 0) == (i7 | 0)) break;
  if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i4, HEAP32[i6 >> 2] | 0, HEAP32[i1 >> 2] | 0) | 0) {
   i3 = HEAP32[i6 >> 2] | 0;
   i2 = i6;
   while (1) {
    HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
    if ((i1 | 0) == (i5 | 0)) {
     i1 = i5;
     break;
    }
    i2 = i1 + -4 | 0;
    if (__ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEENKUljjE_clEjj(i4, i3, HEAP32[i2 >> 2] | 0) | 0) {
     i8 = i1;
     i1 = i2;
     i2 = i8;
    } else break;
   }
   HEAP32[i1 >> 2] = i3;
  }
  i1 = i6;
  i6 = i6 + 4 | 0;
 }
 return;
}

function ___shgetc(i6) {
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0;
 i2 = i6 + 104 | 0;
 i5 = HEAP32[i2 >> 2] | 0;
 if ((i5 | 0) != 0 ? (HEAP32[i6 + 108 >> 2] | 0) >= (i5 | 0) : 0) i7 = 4; else {
  i1 = ___uflow(i6) | 0;
  if ((i1 | 0) >= 0) {
   i2 = HEAP32[i2 >> 2] | 0;
   i5 = HEAP32[i6 + 8 >> 2] | 0;
   if (i2) {
    i4 = HEAP32[i6 + 4 >> 2] | 0;
    i2 = i2 - (HEAP32[i6 + 108 >> 2] | 0) | 0;
    i3 = i5;
    if ((i5 - i4 | 0) < (i2 | 0)) i7 = 9; else HEAP32[i6 + 100 >> 2] = i4 + (i2 + -1);
   } else {
    i3 = i5;
    i7 = 9;
   }
   if ((i7 | 0) == 9) HEAP32[i6 + 100 >> 2] = i5;
   i2 = i6 + 4 | 0;
   if (!i3) i2 = HEAP32[i2 >> 2] | 0; else {
    i2 = HEAP32[i2 >> 2] | 0;
    i6 = i6 + 108 | 0;
    HEAP32[i6 >> 2] = i3 + 1 - i2 + (HEAP32[i6 >> 2] | 0);
   }
   i2 = i2 + -1 | 0;
   if ((HEAPU8[i2 >> 0] | 0 | 0) != (i1 | 0)) HEAP8[i2 >> 0] = i1;
  } else i7 = 4;
 }
 if ((i7 | 0) == 4) {
  HEAP32[i6 + 100 >> 2] = 0;
  i1 = -1;
 }
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESF_RKT_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIRKjEEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIjRNS_9allocatorIjEEEC2EjjS3_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE26__swap_out_circular_bufferERNS_14__split_bufferIjRS2_EE(i7, i5);
 __ZNSt3__214__split_bufferIjRNS_9allocatorIjEEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder16makeCallIndirectERNS_7ElementE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5 + 4 | 0;
 i7 = i5;
 i1 = __ZN10MixedArena5allocIN4wasm12CallIndirectEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
 i8 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i3, 1) | 0) | 0;
 i6 = HEAP32[i4 >> 2] | 0;
 HEAP32[i7 >> 2] = i8;
 HEAP32[i2 >> 2] = HEAP32[i7 >> 2];
 i2 = __ZN4wasm6Module15getFunctionTypeENS_4NameE(i6, i2) | 0;
 HEAP32[i1 + 24 >> 2] = i2;
 if (!i2) ___assert_fail(22524, 21446, 1092, 22538); else {
  HEAP32[i1 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
  i8 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i4, __ZN4wasm7ElementixEj(i3, 2) | 0) | 0;
  HEAP32[i1 + 28 >> 2] = i8;
  __ZN4wasm22SExpressionWasmBuilder17parseCallOperandsINS_12CallIndirectEEEvRNS_7ElementEjPT_(i4, i3, 3, i1);
  STACKTOP = i5;
  return i1 | 0;
 }
 return 0;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIjEEvOT_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i8;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i7 >> 2] | 0;
 i2 = ((HEAP32[i3 >> 2] | 0) - i4 >> 2) + 1 | 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i7);
 i1 = (HEAP32[i7 + 8 >> 2] | 0) - i4 | 0;
 if (i1 >> 2 >>> 0 < 536870911) {
  i1 = i1 >> 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
 } else i1 = 1073741823;
 __ZNSt3__214__split_bufferIjRNS_9allocatorIjEEEC2EjjS3_(i5, i1, (HEAP32[i3 >> 2] | 0) - i4 >> 2, i7 + 8 | 0);
 i4 = i5 + 8 | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i4 >> 2] = i3 + 4;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE26__swap_out_circular_bufferERNS_14__split_bufferIjRS2_EE(i7, i5);
 __ZNSt3__214__split_bufferIjRNS_9allocatorIjEEED2Ev(i5);
 STACKTOP = i8;
 return;
}

function __ZZN4wasm17WasmBinaryBuilder13readFunctionsEvENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i6 + 24 | 0;
 i4 = i6 + 12 | 0;
 i5 = i6;
 i2 = HEAP32[i1 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 __ZNSt3__29to_stringEj(i5, i1);
 i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKc(i5, 0, 23909) | 0;
 HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i4 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i4 + 11 >> 0] | 0) < 0 ? HEAP32[i4 >> 2] | 0 : i4, 0);
 i3 = HEAP32[i3 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
 STACKTOP = i6;
 return i3 | 0;
}

function __ZNKSt3__23mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS3_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS8_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZN6cashew12ValueBuilder18appendCaseToSwitchENS_3RefES1_(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7 + 12 | 0;
 i2 = i7 + 8 | 0;
 i3 = i7 + 4 | 0;
 i4 = i7;
 if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i6, 0) | 0, 59364) | 0) {
  i6 = __ZN6cashew3RefixEj(i6, 2) | 0;
  i6 = HEAP32[i6 >> 2] | 0;
  i8 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
  HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  i5 = __ZN6cashew5Value9push_backENS_3RefE(i8, i1) | 0;
  i3 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
  HEAP32[i4 >> 2] = i3;
  HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
  i5 = __ZN6cashew5Value9push_backENS_3RefE(i5, i1) | 0;
  HEAP32[i2 >> 2] = i5;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN6cashew5Value9push_backENS_3RefE(i6, i1) | 0;
  STACKTOP = i7;
  return;
 } else ___assert_fail(31685, 48272, 1599, 31706);
}

function __ZN4wasm14ModuleInstanceC2ERNS_6ModuleEPNS0_17ExternalInterfaceE(i6, i2, i1) {
 i6 = i6 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i3 = i7 + 32 | 0;
 i5 = i7 + 20 | 0;
 i4 = i7 + 16 | 0;
 HEAP32[i6 >> 2] = i2;
 i8 = i6 + 8 | 0;
 HEAP32[i8 >> 2] = 0;
 HEAP32[i8 + 4 >> 2] = 0;
 HEAP32[i8 + 8 >> 2] = 0;
 HEAP32[i8 + 12 >> 2] = 0;
 HEAP32[i6 + 24 >> 2] = i1;
 HEAP32[i6 + 20 >> 2] = HEAP32[i2 + 60 >> 2];
 FUNCTION_TABLE_vii[HEAP32[HEAP32[i1 >> 2] >> 2] & 1023](i1, i2);
 i1 = HEAP32[i2 + 84 >> 2] | 0;
 if (i1 | 0) {
  HEAP32[i5 >> 2] = 0;
  HEAP32[i5 + 4 >> 2] = 0;
  HEAP32[i5 + 8 >> 2] = 0;
  HEAP32[i4 >> 2] = i1;
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  __ZN4wasm14ModuleInstance12callFunctionEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEE(i7, i6, i3, i5);
  __ZNSt3__213__vector_baseIN4wasm7LiteralENS_9allocatorIS2_EEED2Ev(i5);
 }
 STACKTOP = i7;
 return;
}

function __ZNSt3__26vectorINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = (i1 - i3 | 0) / 20 | 0;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 * 20 | 0) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -20 | 0;
    HEAP32[i6 >> 2] = i5;
    __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i5);
    i1 = HEAP32[i6 >> 2] | 0;
   }
  }
 } else __ZNSt3__26vectorINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseDottingES1_RPc(i1, i9, i8) {
 i1 = i1 | 0;
 i9 = i9 | 0;
 i8 = i8 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i7 + 28 | 0;
 i1 = i7 + 24 | 0;
 i6 = i7;
 i3 = i7 + 20 | 0;
 i4 = i7 + 16 | 0;
 i5 = HEAP32[i8 >> 2] | 0;
 if ((HEAP8[i5 >> 0] | 0) != 46) ___assert_fail(31924, 31173, 649, 31936);
 i5 = i5 + 1 | 0;
 HEAP32[i8 >> 2] = i5;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i6, i5);
 if ((HEAP32[i6 + 12 >> 2] | 0) == 2) {
  HEAP32[i8 >> 2] = (HEAP32[i8 >> 2] | 0) + (HEAP32[i6 + 8 >> 2] | 0);
  HEAP32[i3 >> 2] = HEAP32[i9 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  i9 = __ZN6cashew12ValueBuilder7makeDotENS_3RefENS_7IStringE(i1, i2) | 0;
  STACKTOP = i7;
  return i9 | 0;
 } else ___assert_fail(31949, 31173, 652, 31936);
 return 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseToplevelEPc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3 + 24 | 0;
 i5 = i3 + 20 | 0;
 i8 = i3 + 16 | 0;
 i7 = i3 + 12 | 0;
 i6 = i3 + 8 | 0;
 i10 = i3 + 4 | 0;
 i9 = i3;
 HEAP32[i8 >> 2] = i1;
 HEAP32[i2 + 12 >> 2] = i1;
 i1 = _strlen(i1) | 0;
 HEAP32[i2 + 16 >> 2] = i1;
 i1 = __ZN6cashew12ValueBuilder12makeToplevelEv() | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i10 >> 2] = 0;
 HEAP32[i9 >> 2] = 0;
 HEAP32[i5 >> 2] = HEAP32[i10 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i9 >> 2];
 i2 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10parseBlockERPcPKcNS_7IStringES8_(i2, i8, 31140, i5, i4) | 0;
 HEAP32[i6 >> 2] = i2;
 HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
 __ZN6cashew12ValueBuilder15setBlockContentENS_3RefES1_(i5, i4);
 STACKTOP = i3;
 return i1 | 0;
}

function __ZN4wasm16PrintSExpression13printCallBodyINS_10CallImportEEEvPT_(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i5 + 4 | 0;
 i6 = i5;
 i2 = HEAP32[i4 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i1 + 24 >> 2];
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i2, i3) | 0;
 i3 = i1 + 8 | 0;
 i1 = i1 + 16 | 0;
 if (!(HEAP32[i1 >> 2] | 0)) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i4 >> 2] | 0, 41) | 0; else {
  __ZN4wasm16PrintSExpression9incIndentEv(i4);
  i1 = HEAP32[i1 >> 2] | 0;
  i2 = 0;
  while (1) {
   if ((i2 | 0) == (i1 | 0)) break;
   i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, i2) | 0;
   __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i4, HEAP32[i6 >> 2] | 0);
   i2 = i2 + 1 | 0;
  }
  __ZN4wasm16PrintSExpression9decIndentEv(i4);
 }
 STACKTOP = i5;
 return;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i7, i5) {
 i7 = i7 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i8;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i6, i7);
 L1 : do if (HEAP8[i6 >> 0] | 0) {
  i3 = HEAP32[i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0;
  i4 = i3;
  do if (i3 | 0) {
   i1 = i4 + 24 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
   if ((i2 | 0) == (HEAP32[i4 + 28 >> 2] | 0)) if ((FUNCTION_TABLE_iii[HEAP32[(HEAP32[i3 >> 2] | 0) + 52 >> 2] & 63](i4, i5 & 255) | 0) == -1) break; else break L1; else {
    HEAP32[i1 >> 2] = i2 + 1;
    HEAP8[i2 >> 0] = i5;
    break L1;
   }
  } while (0);
  i5 = i7 + (HEAP32[(HEAP32[i7 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
  HEAP32[i5 >> 2] = HEAP32[i5 >> 2] | 1;
 } while (0);
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i6);
 STACKTOP = i8;
 return i7 | 0;
}

function __ZN4wasm16PrintSExpression13printCallBodyINS_4CallEEEvPT_(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i5 + 4 | 0;
 i6 = i5;
 i2 = HEAP32[i4 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i1 + 24 >> 2];
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i2, i3) | 0;
 i3 = i1 + 8 | 0;
 i1 = i1 + 16 | 0;
 if (!(HEAP32[i1 >> 2] | 0)) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i4 >> 2] | 0, 41) | 0; else {
  __ZN4wasm16PrintSExpression9incIndentEv(i4);
  i1 = HEAP32[i1 >> 2] | 0;
  i2 = 0;
  while (1) {
   if ((i2 | 0) == (i1 | 0)) break;
   i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i3, i2) | 0;
   __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i4, HEAP32[i6 >> 2] | 0);
   i2 = i2 + 1 | 0;
  }
  __ZN4wasm16PrintSExpression9decIndentEv(i4);
 }
 STACKTOP = i5;
 return;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i8 = (HEAP32[i4 >> 2] | 0) + -4 | 0;
  i7 = i1 + -4 | 0;
  i9 = HEAP32[i7 >> 2] | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i8 >> 2] = i9;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -4;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i9;
 i7 = i6 + 8 | 0;
 i9 = i5 + 12 | 0;
 i8 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i9 >> 2] = i8;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doWalkModuleEPNS_6ModuleEENKUlS9_PS4_S3_E_clES9_SA_S3_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(44) | 0;
   __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11TypeUpdaterC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doWalkModuleEPNS_6ModuleEENKUlS9_PS4_S3_E_clES9_SA_S3_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(44) | 0;
   __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11SelectifierC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE13doStartIfTrueEPS1_PPNS_10ExpressionE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i6;
 i2 = i5 + 60 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 HEAP32[i4 >> 2] = i3;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i5, i1);
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i5 + 16 | 0, i3, HEAP32[i2 >> 2] | 0);
 i1 = i5 + 80 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[i5 + 84 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE21__push_back_slow_pathIRKS9_EEvOT_(i5 + 76 | 0, i4); else {
  HEAP32[i2 >> 2] = i3;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
 }
 STACKTOP = i6;
 return;
}

function __ZN4wasm13WasmValidator17validateAlignmentEj(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i4;
 switch (i2 | 0) {
 case 8:
 case 4:
 case 2:
 case 1:
  break;
 default:
  {
   __ZN4wasm13WasmValidator4failEv(i3) | 0;
   i2 = __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19859) | 0, i2) | 0;
   i5 = __ZNKSt3__28ios_base6getlocEv(i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
   HEAP32[i1 >> 2] = i5;
   i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
   i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
   __ZNSt3__26localeD2Ev(i1);
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i2, i5) | 0;
   __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i2) | 0;
   HEAP8[i3 + 28 >> 0] = 0;
  }
 }
 STACKTOP = i4;
 return;
}

function __ZNSt3__212_GLOBAL__N_117as_integer_helperIlNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFlPKcPPciEEET_RKS7_RKT0_PjiT1_(i5, i1, i6, i2) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 HEAP32[i4 >> 2] = 0;
 i3 = (HEAP8[i1 + 11 >> 0] | 0) < 0 ? HEAP32[i1 >> 2] | 0 : i1;
 i8 = ___errno_location() | 0;
 i9 = HEAP32[i8 >> 2] | 0;
 HEAP32[i8 >> 2] = 0;
 i2 = _strtol(i3, i4, i2) | 0;
 i1 = HEAP32[i8 >> 2] | 0;
 HEAP32[i8 >> 2] = i9;
 if ((i1 | 0) == 34) __ZNSt3__212_GLOBAL__N_130throw_from_string_out_of_rangeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE(i5);
 i1 = HEAP32[i4 >> 2] | 0;
 if ((i1 | 0) == (i3 | 0)) __ZNSt3__212_GLOBAL__N_129throw_from_string_invalid_argERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE(i5);
 if (i6 | 0) HEAP32[i6 >> 2] = i1 - i3;
 STACKTOP = i7;
 return i2 | 0;
}

function __ZNKSt3__23mapIPN4wasm8FunctionEjNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS8_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i8 = (HEAP32[i4 >> 2] | 0) + -4 | 0;
  i7 = i1 + -4 | 0;
  i9 = HEAP32[i7 >> 2] | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i8 >> 2] = i9;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -4;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i9;
 i7 = i6 + 8 | 0;
 i9 = i5 + 12 | 0;
 i8 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i9 >> 2] = i8;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZN4wasm22SExpressionWasmBuilder8getLabelERNS_7ElementE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i6;
 do if (!(HEAP8[i1 + 24 >> 0] | 0)) {
  i3 = _atol(__ZN4wasm7Element5c_strEv(i1) | 0) | 0;
  i1 = HEAP32[i5 + 64 >> 2] | 0;
  i2 = (HEAP32[i5 + 68 >> 2] | 0) - i1 >> 2;
  if (i3 >>> 0 < i2 >>> 0) {
   i1 = HEAP32[i1 + (i2 + ~i3 << 2) >> 2] | 0;
   break;
  } else {
   HEAP32[i4 >> 2] = 0;
   HEAP32[i4 + 4 >> 2] = 0;
   HEAP32[i4 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i4, 22516, 7);
   i1 = __ZN4wasm22SExpressionWasmBuilder15getPrefixedNameENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i5, i4) | 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
   break;
  }
 } else i1 = __ZN4wasm7Element3strEv(i1) | 0; while (0);
 STACKTOP = i6;
 return i1 | 0;
}

function __ZN4wasm17WasmBinaryBuilder12getNextLabelEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i6 + 24 | 0;
 i4 = i6 + 12 | 0;
 i5 = i6;
 i2 = i1 + 36 | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 __ZNSt3__29to_stringEj(i5, i1);
 i1 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKc(i5, 0, 24047) | 0;
 HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i4 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 __ZN6cashew7IStringC2EPKcb(i3, (HEAP8[i4 + 11 >> 0] | 0) < 0 ? HEAP32[i4 >> 2] | 0 : i4, 0);
 i3 = HEAP32[i3 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
 STACKTOP = i6;
 return i3 | 0;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i8 = (HEAP32[i4 >> 2] | 0) + -4 | 0;
  i7 = i1 + -4 | 0;
  i9 = HEAP32[i7 >> 2] | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i8 >> 2] = i9;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -4;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i9;
 i7 = i6 + 8 | 0;
 i9 = i5 + 12 | 0;
 i8 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i9 >> 2] = i8;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ImportENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i8 = (HEAP32[i4 >> 2] | 0) + -4 | 0;
  i7 = i1 + -4 | 0;
  i9 = HEAP32[i7 >> 2] | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i8 >> 2] = i9;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -4;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i9;
 i7 = i6 + 8 | 0;
 i9 = i5 + 12 | 0;
 i8 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i9 >> 2] = i8;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZNSt3__26vectorINS_10unique_ptrIN4wasm6ExportENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i8 = (HEAP32[i4 >> 2] | 0) + -4 | 0;
  i7 = i1 + -4 | 0;
  i9 = HEAP32[i7 >> 2] | 0;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i8 >> 2] = i9;
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -4;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i9 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i9;
 i7 = i6 + 8 | 0;
 i9 = i5 + 12 | 0;
 i8 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i9 >> 2] = i8;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZNSt3__212__hash_tableIPKcN6cashew7IString11CStringHashENS4_12CStringEqualENS_9allocatorIS2_EEE6rehashEj(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 if ((i1 | 0) != 1) {
  if (i1 + -1 & i1) i1 = __ZNSt3__212__next_primeEj(i1) | 0;
 } else i1 = 2;
 i4 = HEAP32[i5 + 4 >> 2] | 0;
 if (i1 >>> 0 <= i4 >>> 0) {
  if (i1 >>> 0 < i4 >>> 0) {
   if (i4 >>> 0 > 2) i3 = (i4 + -1 & i4 | 0) == 0; else i3 = 0;
   i2 = ~~+Math_ceil(+(+((HEAP32[i5 + 12 >> 2] | 0) >>> 0) / +HEAPF32[i5 + 16 >> 2])) >>> 0;
   if (i3) i2 = 1 << 32 - (Math_clz32(i2 + -1 | 0) | 0); else i2 = __ZNSt3__212__next_primeEj(i2) | 0;
   i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
   if (i1 >>> 0 < i4 >>> 0) __ZNSt3__212__hash_tableIPKcN6cashew7IString11CStringHashENS4_12CStringEqualENS_9allocatorIS2_EEE8__rehashEj(i5, i1);
  }
 } else __ZNSt3__212__hash_tableIPKcN6cashew7IString11CStringHashENS4_12CStringEqualENS_9allocatorIS2_EEE8__rehashEj(i5, i1);
 return;
}

function __ZN6cashew12ValueBuilder13makeStatementENS_3RefE(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 8 | 0;
 i2 = i5 + 4 | 0;
 i3 = i5;
 i6 = __ZN6cashew3RefixEj(i4, 0) | 0;
 if (!(__ZNKSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE4findIS2_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS2_PvEEEERKT_(59704, __ZN6cashew5Value10getIStringEv(HEAP32[i6 >> 2] | 0) | 0) | 0)) i1 = HEAP32[i4 >> 2] | 0; else {
  i6 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
  i7 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59284) | 0;
  HEAP32[i2 >> 2] = i7;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  i6 = __ZN6cashew5Value9push_backENS_3RefE(i6, i1) | 0;
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  i1 = __ZN6cashew5Value9push_backENS_3RefE(i6, i1) | 0;
 }
 STACKTOP = i5;
 return i1 | 0;
}

function __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i3;
 HEAP32[i5 >> 2] = i1;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 HEAP32[i1 + 20 >> 2] = 0;
 HEAP32[i2 >> 2] = 5392;
 i1 = i2 + 28 | 0;
 HEAP8[i1 >> 0] = 0;
 HEAP8[i2 + 29 >> 0] = 0;
 HEAP32[i2 + 36 >> 2] = 0;
 HEAP32[i2 + 40 >> 2] = 0;
 HEAP32[i2 + 32 >> 2] = i2 + 36;
 HEAP32[i2 + 48 >> 2] = 0;
 HEAP32[i2 + 52 >> 2] = 0;
 HEAP32[i2 + 44 >> 2] = i2 + 48;
 HEAP8[i2 + 56 >> 0] = 0;
 HEAP8[i2 + 57 >> 0] = 0;
 HEAP32[i2 + 64 >> 2] = 0;
 i4 = i2 + 68 | 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i2 + 60 >> 2] = i2 + 64;
 __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i5);
 if (HEAP32[i4 >> 2] | 0) HEAP8[i1 >> 0] = 1;
 STACKTOP = i3;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE14doStartIfFalseEPS1_PPNS_10ExpressionE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0;
 i1 = i6 + 76 | 0;
 i2 = i6 + 60 | 0;
 i3 = i6 + 80 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if ((i4 | 0) == (HEAP32[i6 + 84 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE21__push_back_slow_pathIRKS9_EEvOT_(i1, i2); else {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 4;
 }
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i6, i5);
 i5 = HEAP32[i1 >> 2] | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i6 + 16 | 0, HEAP32[i5 + (((HEAP32[i3 >> 2] | 0) - i5 >> 2) + -2 << 2) >> 2] | 0, HEAP32[i2 >> 2] | 0);
 return;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEESD_RKT_(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  while (1) {
   i1 = i2 + 16 | 0;
   if (__ZNK6cashew7IStringltERKS0_(i4, i1) | 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (!(__ZNK6cashew7IStringltERKS0_(i1, i4) | 0)) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE6rehashEj(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 if ((i1 | 0) != 1) {
  if (i1 + -1 & i1) i1 = __ZNSt3__212__next_primeEj(i1) | 0;
 } else i1 = 2;
 i4 = HEAP32[i5 + 4 >> 2] | 0;
 if (i1 >>> 0 <= i4 >>> 0) {
  if (i1 >>> 0 < i4 >>> 0) {
   if (i4 >>> 0 > 2) i3 = (i4 + -1 & i4 | 0) == 0; else i3 = 0;
   i2 = ~~+Math_ceil(+(+((HEAP32[i5 + 12 >> 2] | 0) >>> 0) / +HEAPF32[i5 + 16 >> 2])) >>> 0;
   if (i3) i2 = 1 << 32 - (Math_clz32(i2 + -1 | 0) | 0); else i2 = __ZNSt3__212__next_primeEj(i2) | 0;
   i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
   if (i1 >>> 0 < i4 >>> 0) __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE8__rehashEj(i5, i1);
  }
 } else __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE8__rehashEj(i5, i1);
 return;
}

function __ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc(i6, i7, i1, i2, i5, i3, i4) {
 i6 = i6 | 0;
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 416 | 0;
 i1 = i8 + 8 | 0;
 i2 = i8;
 HEAP32[i2 >> 2] = i1 + 400;
 __ZNKSt3__210__time_put8__do_putEPwRS1_PK2tmcc(i6 + 8 | 0, i1, i2, i5, i3, i4);
 i6 = HEAP32[i2 >> 2] | 0;
 i5 = i1;
 i1 = HEAP32[i7 >> 2] | 0;
 while (1) {
  if ((i5 | 0) == (i6 | 0)) break;
  i2 = HEAP32[i5 >> 2] | 0;
  if (!i1) i1 = 0; else {
   i4 = i1 + 24 | 0;
   i3 = HEAP32[i4 >> 2] | 0;
   if ((i3 | 0) == (HEAP32[i1 + 28 >> 2] | 0)) i2 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 52 >> 2] & 63](i1, i2) | 0; else {
    HEAP32[i4 >> 2] = i3 + 4;
    HEAP32[i3 >> 2] = i2;
   }
   i1 = (i2 | 0) == -1 ? 0 : i1;
  }
  i5 = i5 + 4 | 0;
 }
 STACKTOP = i8;
 return i1 | 0;
}

function __ZN4wasm3LEBIiaE4readENSt3__28functionIFavEEE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 HEAP32[i7 >> 2] = 0;
 i3 = 0;
 while (1) {
  i4 = (__ZNKSt3__28functionIFavEEclEv(i6) | 0) << 24 >> 24;
  i2 = i4 & 127;
  if (!i3) i1 = -1; else i1 = (1 << 32 - i3) + -1 | 0;
  i1 = i1 & i2;
  i5 = (i4 & 128 | 0) == 0;
  if (!(i5 | (i1 | 0) == (i2 | 0))) {
   i2 = 5;
   break;
  }
  i2 = HEAP32[i7 >> 2] | i1 << i3;
  HEAP32[i7 >> 2] = i2;
  i1 = i3;
  i3 = i3 + 7 | 0;
  if (i5) {
   i5 = i2;
   i2 = 9;
   break;
  }
  if (i3 >>> 0 >= 32) {
   i2 = 8;
   break;
  }
 }
 if ((i2 | 0) == 5) ___assert_fail(23085, 22948, 99, 22966); else if ((i2 | 0) == 8) ___assert_fail(23162, 22948, 104, 22966); else if ((i2 | 0) == 9) {
  if (i3 >>> 0 < 32 & (i4 & 64 | 0) != 0 ? (i6 = 25 - i1 | 0, i6 = i5 << i6 >> i6, HEAP32[i7 >> 2] = i6, (i6 | 0) >= 0) : 0) ___assert_fail(24692, 22948, 114, 22966);
  return;
 }
}

function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJOS7_EEENSM_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISB_PvEENS_22__tree_node_destructorINS5_IST_EEEEEEDpOT_(i3, i4, i1, i6, i2) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 var i5 = 0;
 i5 = __Znwj(72) | 0;
 HEAP32[i3 >> 2] = i5;
 HEAP32[i3 + 4 >> 2] = i4 + 4;
 i3 = i3 + 8 | 0;
 HEAP8[i3 >> 0] = 0;
 i2 = i5 + 16 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 __ZN4wasm12PassRegistry8PassInfoC2Ev(i5 + 32 | 0);
 HEAP8[i3 >> 0] = 1;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE26__swap_out_circular_bufferERNS_14__split_bufferISA_RSC_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE26__swap_out_circular_bufferERNS_14__split_bufferISA_RSC_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_119parse_discriminatorEPKcS2_(i1, i4) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 L1 : do if ((i1 | 0) != (i4 | 0)) {
  i2 = HEAP8[i1 >> 0] | 0;
  if (i2 << 24 >> 24 != 95) {
   if (((i2 << 24 >> 24) + -48 | 0) >>> 0 >= 10) break;
   while (1) {
    i1 = i1 + 1 | 0;
    if ((i1 | 0) == (i4 | 0)) {
     i1 = i4;
     break L1;
    }
    if (((HEAP8[i1 >> 0] | 0) + -48 | 0) >>> 0 >= 10) break L1;
   }
  }
  i2 = i1 + 1 | 0;
  if ((i2 | 0) != (i4 | 0)) {
   i2 = HEAP8[i2 >> 0] | 0;
   if (((i2 << 24 >> 24) + -48 | 0) >>> 0 < 10) {
    i1 = i1 + 2 | 0;
    break;
   }
   if (i2 << 24 >> 24 == 95) {
    i2 = i1 + 2 | 0;
    while (1) {
     if ((i2 | 0) == (i4 | 0)) break L1;
     i3 = HEAP8[i2 >> 0] | 0;
     if (((i3 << 24 >> 24) + -48 | 0) >>> 0 >= 10) break;
     i2 = i2 + 1 | 0;
    }
    return (i3 << 24 >> 24 == 95 ? i2 + 1 | 0 : i1) | 0;
   }
  }
 } while (0);
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder9makeConstERNS_7ElementENS_8WasmTypeE(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i5 + 16 | 0;
 i7 = i5 + 12 | 0;
 i4 = i5;
 i1 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 1) | 0) | 0;
 HEAP32[i7 >> 2] = i1;
 i1 = HEAP32[i2 + 4 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i7 >> 2];
 i1 = __ZN4wasm10parseConstEN6cashew7IStringENS_8WasmTypeER10MixedArena(i6, i3, i1) | 0;
 if (!i1) {
  i7 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i4 >> 2] = 0;
  HEAP32[i4 + 4 >> 2] = 0;
  HEAP32[i4 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i4, 22055, 9);
  __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i7, i4);
  ___cxa_throw(i7 | 0, 64, 279);
 } else {
  STACKTOP = i5;
  return i1 | 0;
 }
 return 0;
}

function __ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji(i1, i6, i7, i2) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i9;
 do if ((i1 | 0) == (i6 | 0)) {
  HEAP32[i7 >> 2] = 4;
  i1 = 0;
 } else {
  if ((HEAP8[i1 >> 0] | 0) == 45) {
   HEAP32[i7 >> 2] = 4;
   i1 = 0;
   break;
  }
  i4 = ___errno_location() | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  i1 = _strtoull_l(i1, i8, i2, __ZNSt3__26__clocEv() | 0) | 0;
  i2 = tempRet0;
  i3 = HEAP32[i4 >> 2] | 0;
  if (!i3) HEAP32[i4 >> 2] = i5;
  do if ((HEAP32[i8 >> 2] | 0) == (i6 | 0)) if (i2 >>> 0 > 0 | (i2 | 0) == 0 & i1 >>> 0 > 65535 | (i3 | 0) == 34) {
   HEAP32[i7 >> 2] = 4;
   i1 = -1;
   break;
  } else {
   i1 = i1 & 65535;
   break;
  } else {
   HEAP32[i7 >> 2] = 4;
   i1 = 0;
  } while (0);
 } while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE26__swap_out_circular_bufferERNS_14__split_bufferISA_RSC_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(56) | 0;
   __ZN4wasm17RemoveUnusedNamesC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE5clearEv(i3 + 44 | 0);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESB_RKT_(i1, i5, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  i4 = HEAP32[i3 >> 2] | 0;
  while (1) {
   i1 = HEAP32[i2 + 16 >> 2] | 0;
   if (i4 >>> 0 < i1 >>> 0) {
    i1 = HEAP32[i2 >> 2] | 0;
    if (!i1) {
     i1 = i2;
     i3 = 5;
     break;
    }
   } else {
    if (i1 >>> 0 >= i4 >>> 0) {
     i1 = i2;
     i3 = 10;
     break;
    }
    i1 = i2 + 4 | 0;
    i3 = HEAP32[i1 >> 2] | 0;
    if (!i3) {
     i3 = 9;
     break;
    } else i1 = i3;
   }
   i2 = i1;
  }
  if ((i3 | 0) == 5) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 9) {
   HEAP32[i5 >> 2] = i2;
   break;
  } else if ((i3 | 0) == 10) {
   HEAP32[i5 >> 2] = i1;
   i1 = i5;
   break;
  }
 } else HEAP32[i5 >> 2] = i1; while (0);
 return i1 | 0;
}

function __ZN4wasm19DeadCodeElimination11visitSwitchEPNS_6SwitchE(i8, i7) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0, i10 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i9 + 8 | 0;
 i5 = i9 + 4 | 0;
 i6 = i9;
 i3 = HEAP32[i7 + 32 >> 2] | 0;
 i1 = i3;
 if ((i3 | 0) != 0 ? (HEAP32[i3 >> 2] | 0) == 20 : 0) HEAP32[i8 + 20 >> 2] = i1; else {
  i2 = i7 + 8 | 0;
  i1 = HEAP32[i7 + 16 >> 2] | 0;
  i3 = 0;
  while (1) {
   if ((i3 | 0) == (i1 | 0)) break;
   i10 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i2, i3) | 0;
   HEAP32[i5 >> 2] = HEAP32[i10 >> 2];
   HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
   __ZN4wasm19DeadCodeElimination8addBreakENS_4NameE(i8, i4);
   i3 = i3 + 1 | 0;
  }
  HEAP32[i6 >> 2] = HEAP32[i7 + 24 >> 2];
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  __ZN4wasm19DeadCodeElimination8addBreakENS_4NameE(i8, i4);
  HEAP8[i8 + 44 >> 0] = 0;
 }
 STACKTOP = i9;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE14__erase_uniqueIjEEjRKT_(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5 + 4 | 0;
 i3 = i5;
 i1 = __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE4findIjEENS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEERKT_(i4, i1) | 0;
 if ((i1 | 0) == (i4 + 4 | 0)) i1 = 0; else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5eraseENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEE(i4, i2) | 0;
  i1 = 1;
 }
 STACKTOP = i5;
 return i1 | 0;
}

function __ZNK4wasm7Literal3mulERKS0_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var d4 = 0.0;
 switch (HEAP32[i3 >> 2] | 0) {
 case 1:
  {
   i3 = Math_imul(HEAP32[i2 + 8 >> 2] | 0, HEAP32[i3 + 8 >> 2] | 0) | 0;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i3;
   break;
  }
 case 2:
  {
   i3 = i3 + 8 | 0;
   i2 = i2 + 8 | 0;
   i2 = ___muldi3(HEAP32[i2 >> 2] | 0, HEAP32[i2 + 4 >> 2] | 0, HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0) | 0;
   HEAP32[i1 >> 2] = 2;
   i3 = i1 + 8 | 0;
   HEAP32[i3 >> 2] = i2;
   HEAP32[i3 + 4 >> 2] = tempRet0;
   break;
  }
 case 3:
  {
   d4 = +__ZNK4wasm7Literal6getf32Ev(i3) * +__ZNK4wasm7Literal6getf32Ev(i2);
   HEAP32[i1 >> 2] = 3;
   HEAPF32[i1 + 8 >> 2] = d4;
   break;
  }
 case 4:
  {
   d4 = +__ZNK4wasm7Literal6getf64Ev(i3) * +__ZNK4wasm7Literal6getf64Ev(i2);
   HEAP32[i1 >> 2] = 4;
   HEAPF64[i1 + 8 >> 3] = d4;
   break;
  }
 default:
  {}
 }
 return;
}

function __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(i2, i5, i3, i1, i4) {
 i2 = i2 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 HEAP8[i5 + 53 >> 0] = 1;
 do if ((HEAP32[i5 + 4 >> 2] | 0) == (i1 | 0)) {
  HEAP8[i5 + 52 >> 0] = 1;
  i1 = i5 + 16 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  if (!i2) {
   HEAP32[i1 >> 2] = i3;
   HEAP32[i5 + 24 >> 2] = i4;
   HEAP32[i5 + 36 >> 2] = 1;
   if (!((i4 | 0) == 1 ? (HEAP32[i5 + 48 >> 2] | 0) == 1 : 0)) break;
   HEAP8[i5 + 54 >> 0] = 1;
   break;
  }
  if ((i2 | 0) != (i3 | 0)) {
   i4 = i5 + 36 | 0;
   HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
   HEAP8[i5 + 54 >> 0] = 1;
   break;
  }
  i2 = i5 + 24 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == 2) {
   HEAP32[i2 >> 2] = i4;
   i1 = i4;
  }
  if ((i1 | 0) == 1 ? (HEAP32[i5 + 48 >> 2] | 0) == 1 : 0) HEAP8[i5 + 54 >> 0] = 1;
 } while (0);
 return;
}

function __ZNK4wasm7Literal3subERKS0_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var d4 = 0.0;
 switch (HEAP32[i3 >> 2] | 0) {
 case 1:
  {
   i3 = (HEAP32[i3 + 8 >> 2] | 0) - (HEAP32[i2 + 8 >> 2] | 0) | 0;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i3;
   break;
  }
 case 2:
  {
   i3 = i3 + 8 | 0;
   i2 = i2 + 8 | 0;
   i2 = _i64Subtract(HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0, HEAP32[i2 >> 2] | 0, HEAP32[i2 + 4 >> 2] | 0) | 0;
   HEAP32[i1 >> 2] = 2;
   i3 = i1 + 8 | 0;
   HEAP32[i3 >> 2] = i2;
   HEAP32[i3 + 4 >> 2] = tempRet0;
   break;
  }
 case 3:
  {
   d4 = +__ZNK4wasm7Literal6getf32Ev(i3) - +__ZNK4wasm7Literal6getf32Ev(i2);
   HEAP32[i1 >> 2] = 3;
   HEAPF32[i1 + 8 >> 2] = d4;
   break;
  }
 case 4:
  {
   d4 = +__ZNK4wasm7Literal6getf64Ev(i3) - +__ZNK4wasm7Literal6getf64Ev(i2);
   HEAP32[i1 >> 2] = 4;
   HEAPF64[i1 + 8 >> 3] = d4;
   break;
  }
 default:
  {}
 }
 return;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEEC2EOSF_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i4 = HEAP32[i1 >> 2] | 0;
 HEAP32[i1 >> 2] = 0;
 i6 = i1 + 4 | 0;
 i5 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i2 >> 2] = i4;
 HEAP32[i2 + 4 >> 2] = i5;
 i6 = i2 + 8 | 0;
 i7 = i1 + 8 | 0;
 i3 = HEAP32[i7 >> 2] | 0;
 HEAP32[i6 >> 2] = i3;
 i8 = i1 + 12 | 0;
 i9 = HEAP32[i8 >> 2] | 0;
 HEAP32[i2 + 12 >> 2] = i9;
 HEAP32[i2 + 16 >> 2] = HEAP32[i1 + 16 >> 2];
 if (i9 | 0) {
  i1 = HEAP32[i3 + 4 >> 2] | 0;
  i2 = i5 + -1 | 0;
  if (!(i2 & i5)) i1 = i2 & i1; else i1 = (i1 >>> 0) % (i5 >>> 0) | 0;
  HEAP32[i4 + (i1 << 2) >> 2] = i6;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i8 >> 2] = 0;
 }
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseBracketedBlockERPc(i6, i7) {
 i6 = i6 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i8 + 12 | 0;
 i1 = i8 + 8 | 0;
 i3 = i8 + 4 | 0;
 i4 = i8;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i7);
 i5 = HEAP32[i7 >> 2] | 0;
 if ((HEAP8[i5 >> 0] | 0) != 123) ___assert_fail(31389, 31173, 859, 31401);
 HEAP32[i7 >> 2] = i5 + 1;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10parseBlockERPcPKcNS_7IStringES8_(i6, i7, 31421, i1, i2) | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 if ((HEAP8[i2 >> 0] | 0) == 125) {
  HEAP32[i7 >> 2] = i2 + 1;
  STACKTOP = i8;
  return i1 | 0;
 } else ___assert_fail(31424, 31173, 862, 31401);
 return 0;
}

function __ZN4wasm17RemoveUnusedNames11visitSwitchEPNS_6SwitchE(i1, i6) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i8 + 8 | 0;
 i7 = i8;
 i4 = i6 + 8 | 0;
 i5 = HEAP32[i6 + 16 >> 2] | 0;
 i1 = i1 + 44 | 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == (i5 | 0)) break;
  i9 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i4, i2) | 0;
  HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i3, i1, i7, i7);
  i2 = i2 + 1 | 0;
 }
 i9 = i6 + 24 | 0;
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i3, i1, i9, i9);
 STACKTOP = i8;
 return;
}

function __ZZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(84) | 0;
   __ZN4wasm19DeadCodeEliminationC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 __ZN4wasm19DeadCodeElimination13visitFunctionEPNS_8FunctionE(i3, i5);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE24__emplace_back_slow_pathIJRPFvPS6_PPNS1_10ExpressionEERSI_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE24__emplace_back_slow_pathIJRPFvPS6_PPNS1_10ExpressionEERSI_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSB_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function ___strchrnul(i1, i4) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 i3 = i4 & 255;
 L1 : do if (!i3) i1 = i1 + (_strlen(i1) | 0) | 0; else {
  if (i1 & 3) {
   i2 = i4 & 255;
   do {
    i5 = HEAP8[i1 >> 0] | 0;
    if (i5 << 24 >> 24 == 0 ? 1 : i5 << 24 >> 24 == i2 << 24 >> 24) break L1;
    i1 = i1 + 1 | 0;
   } while ((i1 & 3 | 0) != 0);
  }
  i3 = Math_imul(i3, 16843009) | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  L10 : do if (!((i2 & -2139062144 ^ -2139062144) & i2 + -16843009)) do {
   i5 = i2 ^ i3;
   if ((i5 & -2139062144 ^ -2139062144) & i5 + -16843009 | 0) break L10;
   i1 = i1 + 4 | 0;
   i2 = HEAP32[i1 >> 2] | 0;
  } while (!((i2 & -2139062144 ^ -2139062144) & i2 + -16843009 | 0)); while (0);
  i2 = i4 & 255;
  while (1) {
   i5 = HEAP8[i1 >> 0] | 0;
   if (i5 << 24 >> 24 == 0 ? 1 : i5 << 24 >> 24 == i2 << 24 >> 24) break; else i1 = i1 + 1 | 0;
  }
 } while (0);
 return i1 | 0;
}

function __ZN4wasm14EffectAnalyzer11visitSwitchEPNS_6SwitchE(i1, i6) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i8 + 8 | 0;
 i7 = i8;
 i4 = i6 + 8 | 0;
 i5 = HEAP32[i6 + 16 >> 2] | 0;
 i1 = i1 + 60 | 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == (i5 | 0)) break;
  i9 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i4, i2) | 0;
  HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i3, i1, i7, i7);
  i2 = i2 + 1 | 0;
 }
 i9 = i6 + 24 | 0;
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i3, i1, i9, i9);
 STACKTOP = i8;
 return;
}

function __ZNK4wasm7Literal3addERKS0_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var d4 = 0.0;
 switch (HEAP32[i3 >> 2] | 0) {
 case 1:
  {
   i3 = (HEAP32[i2 + 8 >> 2] | 0) + (HEAP32[i3 + 8 >> 2] | 0) | 0;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i3;
   break;
  }
 case 2:
  {
   i3 = i3 + 8 | 0;
   i2 = i2 + 8 | 0;
   i2 = _i64Add(HEAP32[i2 >> 2] | 0, HEAP32[i2 + 4 >> 2] | 0, HEAP32[i3 >> 2] | 0, HEAP32[i3 + 4 >> 2] | 0) | 0;
   HEAP32[i1 >> 2] = 2;
   i3 = i1 + 8 | 0;
   HEAP32[i3 >> 2] = i2;
   HEAP32[i3 + 4 >> 2] = tempRet0;
   break;
  }
 case 3:
  {
   d4 = +__ZNK4wasm7Literal6getf32Ev(i3) + +__ZNK4wasm7Literal6getf32Ev(i2);
   HEAP32[i1 >> 2] = 3;
   HEAPF32[i1 + 8 >> 2] = d4;
   break;
  }
 case 4:
  {
   d4 = +__ZNK4wasm7Literal6getf64Ev(i3) + +__ZNK4wasm7Literal6getf64Ev(i2);
   HEAP32[i1 >> 2] = 4;
   HEAPF64[i1 + 8 >> 3] = d4;
   break;
  }
 default:
  {}
 }
 return;
}

function __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i7 = i1 + -24 | 0;
  __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_((HEAP32[i4 >> 2] | 0) + -24 | 0, i7);
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -24;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i2;
 i3 = i6 + 8 | 0;
 i7 = i5 + 12 | 0;
 i6 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i6;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZN4wasm22SExpressionWasmBuilder6makeIfERNS_7ElementE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5;
 i1 = __ZN10MixedArena5allocIN4wasm2IfEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
 i6 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i4, __ZN4wasm7ElementixEj(i3, 1) | 0) | 0;
 HEAP32[i1 + 8 >> 2] = i6;
 HEAP32[i2 >> 2] = i4;
 i4 = __ZZN4wasm22SExpressionWasmBuilder6makeIfERNS_7ElementEENKUlPKcS2_E_clES4_S2_(i2, 22598, __ZN4wasm7ElementixEj(i3, 2) | 0) | 0;
 HEAP32[i1 + 12 >> 2] = i4;
 i4 = (__ZN4wasm7Element4listEv(i3) | 0) + 8 | 0;
 if ((HEAP32[i4 >> 2] | 0) == 4) {
  i6 = __ZZN4wasm22SExpressionWasmBuilder6makeIfERNS_7ElementEENKUlPKcS2_E_clES4_S2_(i2, 22606, __ZN4wasm7ElementixEj(i3, 3) | 0) | 0;
  HEAP32[i1 + 16 >> 2] = i6;
  __ZN4wasm2If8finalizeEv(i1);
 }
 STACKTOP = i5;
 return i1 | 0;
}

function __ZN4wasm14PostEmscripten13visitMemoryOpINS_5StoreEEEvPT_(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = i2 + 12 | 0;
 do if (((HEAP32[i5 >> 2] | 0) == 0 ? (i6 = i2 + 20 | 0, i7 = HEAP32[i6 >> 2] | 0, !((i7 | 0) == 0 | (HEAP32[i7 >> 2] | 0) != 15)) : 0) ? (HEAP32[i7 + 8 >> 2] | 0) == 0 : 0) {
  if ((HEAP32[i7 + 4 >> 2] | 0) != 1) ___assert_fail(40852, 40869, 51, 40899);
  i3 = i7 + 16 | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  i4 = i1;
  if ((i1 | 0) == 0 | (HEAP32[i1 >> 2] | 0) != 13) {
   i2 = i7 + 12 | 0;
   i1 = HEAP32[i2 >> 2] | 0;
   if ((i1 | 0) == 0 | (HEAP32[i1 >> 2] | 0) != 13) break;
   HEAP32[i2 >> 2] = i4;
   HEAP32[i3 >> 2] = i1;
  }
  i1 = __ZNK4wasm7Literal6geti32Ev(i1 + 8 | 0) | 0;
  if (i1 >>> 0 < 1024) {
   HEAP32[i6 >> 2] = HEAP32[i7 + 12 >> 2];
   __ZN4wasm7AddressaSEy(i5, i1, ((i1 | 0) < 0) << 31 >> 31) | 0;
  }
 } while (0);
 return;
}

function __ZN4wasm14PostEmscripten13visitMemoryOpINS_4LoadEEEvPT_(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = i2 + 12 | 0;
 do if (((HEAP32[i5 >> 2] | 0) == 0 ? (i6 = i2 + 20 | 0, i7 = HEAP32[i6 >> 2] | 0, !((i7 | 0) == 0 | (HEAP32[i7 >> 2] | 0) != 15)) : 0) ? (HEAP32[i7 + 8 >> 2] | 0) == 0 : 0) {
  if ((HEAP32[i7 + 4 >> 2] | 0) != 1) ___assert_fail(40852, 40869, 51, 40899);
  i3 = i7 + 16 | 0;
  i1 = HEAP32[i3 >> 2] | 0;
  i4 = i1;
  if ((i1 | 0) == 0 | (HEAP32[i1 >> 2] | 0) != 13) {
   i2 = i7 + 12 | 0;
   i1 = HEAP32[i2 >> 2] | 0;
   if ((i1 | 0) == 0 | (HEAP32[i1 >> 2] | 0) != 13) break;
   HEAP32[i2 >> 2] = i4;
   HEAP32[i3 >> 2] = i1;
  }
  i1 = __ZNK4wasm7Literal6geti32Ev(i1 + 8 | 0) | 0;
  if (i1 >>> 0 < 1024) {
   HEAP32[i6 >> 2] = HEAP32[i7 + 12 >> 2];
   __ZN4wasm7AddressaSEy(i5, i1, ((i1 | 0) < 0) << 31 >> 31) | 0;
  }
 } while (0);
 return;
}

function __ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji(i1, i6, i7, i2) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i9;
 do if ((i1 | 0) == (i6 | 0)) {
  HEAP32[i7 >> 2] = 4;
  i1 = 0;
 } else {
  if ((HEAP8[i1 >> 0] | 0) == 45) {
   HEAP32[i7 >> 2] = 4;
   i1 = 0;
   break;
  }
  i4 = ___errno_location() | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  i1 = _strtoull_l(i1, i8, i2, __ZNSt3__26__clocEv() | 0) | 0;
  i2 = tempRet0;
  i3 = HEAP32[i4 >> 2] | 0;
  if (!i3) HEAP32[i4 >> 2] = i5;
  do if ((HEAP32[i8 >> 2] | 0) == (i6 | 0)) if (i2 >>> 0 > 0 | (i2 | 0) == 0 & i1 >>> 0 > 4294967295 | (i3 | 0) == 34) {
   HEAP32[i7 >> 2] = 4;
   i1 = -1;
   break;
  } else break; else {
   HEAP32[i7 >> 2] = 4;
   i1 = 0;
  } while (0);
 } while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji(i1, i6, i7, i2) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i9;
 do if ((i1 | 0) == (i6 | 0)) {
  HEAP32[i7 >> 2] = 4;
  i1 = 0;
 } else {
  if ((HEAP8[i1 >> 0] | 0) == 45) {
   HEAP32[i7 >> 2] = 4;
   i1 = 0;
   break;
  }
  i4 = ___errno_location() | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  i1 = _strtoull_l(i1, i8, i2, __ZNSt3__26__clocEv() | 0) | 0;
  i2 = tempRet0;
  i3 = HEAP32[i4 >> 2] | 0;
  if (!i3) HEAP32[i4 >> 2] = i5;
  do if ((HEAP32[i8 >> 2] | 0) == (i6 | 0)) if (i2 >>> 0 > 0 | (i2 | 0) == 0 & i1 >>> 0 > 4294967295 | (i3 | 0) == 34) {
   HEAP32[i7 >> 2] = 4;
   i1 = -1;
   break;
  } else break; else {
   HEAP32[i7 >> 2] = 4;
   i1 = 0;
  } while (0);
 } while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPKwEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_(i5, i1, i6) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i2 = i1;
 i4 = i6 - i2 >> 2;
 if (i4 >>> 0 > 1073741807) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i5);
 do if (i4 >>> 0 >= 2) {
  i3 = i4 + 4 & -4;
  if (i3 >>> 0 > 1073741823) ___assert_fail(55771, 55808, 1734, 55911); else {
   i7 = __Znwj(i3 << 2) | 0;
   HEAP32[i5 >> 2] = i7;
   HEAP32[i5 + 8 >> 2] = i3 | -2147483648;
   HEAP32[i5 + 4 >> 2] = i4;
   break;
  }
 } else {
  HEAP8[i5 + 8 + 3 >> 0] = i4;
  i7 = i5;
 } while (0);
 i3 = (i6 - i2 | 0) >>> 2;
 i2 = i7;
 while (1) {
  if ((i1 | 0) == (i6 | 0)) break;
  HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
  i1 = i1 + 4 | 0;
  i2 = i2 + 4 | 0;
 }
 HEAP32[i7 + (i3 << 2) >> 2] = 0;
 return;
}

function __ZN4wasm6ModuleC2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0;
 i1 = i2 + 64 | 0;
 i3 = i2;
 i4 = i3 + 64 | 0;
 do {
  HEAP32[i3 >> 2] = 0;
  i3 = i3 + 4 | 0;
 } while ((i3 | 0) < (i4 | 0));
 HEAP32[i1 >> 2] = 65535;
 i4 = i2 + 68 | 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = 0;
 __ZN10MixedArenaC2Ev(i2 + 88 | 0);
 HEAP32[i2 + 120 >> 2] = 0;
 HEAP32[i2 + 124 >> 2] = 0;
 HEAP32[i2 + 116 >> 2] = i2 + 120;
 HEAP32[i2 + 132 >> 2] = 0;
 HEAP32[i2 + 136 >> 2] = 0;
 HEAP32[i2 + 128 >> 2] = i2 + 132;
 HEAP32[i2 + 144 >> 2] = 0;
 HEAP32[i2 + 148 >> 2] = 0;
 HEAP32[i2 + 140 >> 2] = i2 + 144;
 HEAP32[i2 + 156 >> 2] = 0;
 HEAP32[i2 + 160 >> 2] = 0;
 HEAP32[i2 + 152 >> 2] = i2 + 156;
 i4 = i2 + 164 | 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 HEAP32[i4 + 12 >> 2] = 0;
 return;
}

function _atoll(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 while (1) {
  i2 = i1 + 1 | 0;
  if (!(_isspace(HEAP8[i1 >> 0] | 0) | 0)) break; else i1 = i2;
 }
 i3 = HEAP8[i1 >> 0] | 0;
 switch (i3 << 24 >> 24 | 0) {
 case 45:
  {
   i4 = 1;
   i5 = 5;
   break;
  }
 case 43:
  {
   i4 = 0;
   i5 = 5;
   break;
  }
 default:
  i4 = 0;
 }
 if ((i5 | 0) == 5) {
  i1 = i2;
  i3 = HEAP8[i2 >> 0] | 0;
 }
 i5 = (i3 << 24 >> 24) + -48 | 0;
 if (i5 >>> 0 < 10) {
  i3 = 0;
  i2 = 0;
  do {
   i2 = ___muldi3(i2 | 0, i3 | 0, 10, 0) | 0;
   i1 = i1 + 1 | 0;
   i2 = _i64Subtract(i2 | 0, tempRet0 | 0, i5 | 0, ((i5 | 0) < 0) << 31 >> 31 | 0) | 0;
   i3 = tempRet0;
   i5 = (HEAP8[i1 >> 0] | 0) + -48 | 0;
  } while (i5 >>> 0 < 10);
  i1 = i3;
 } else {
  i2 = 0;
  i1 = 0;
 }
 i4 = (i4 | 0) != 0;
 i5 = _i64Subtract(0, 0, i2 | 0, i1 | 0) | 0;
 tempRet0 = i4 ? i1 : tempRet0;
 return (i4 ? i2 : i5) | 0;
}

function __ZNSt3__26vectorINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS5_RS7_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i7 = i1 + -24 | 0;
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_((HEAP32[i4 >> 2] | 0) + -24 | 0, i7);
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -24;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i2;
 i3 = i6 + 8 | 0;
 i7 = i5 + 12 | 0;
 i6 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i6;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9parseFragERNS3_4FragE(i1, i6) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i4 + 8 | 0;
 i2 = i4 + 4 | 0;
 i3 = i4;
 switch (HEAP32[i6 + 12 >> 2] | 0) {
 case 2:
  {
   HEAP32[i2 >> 2] = HEAP32[i6 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
   i5 = __ZN6cashew12ValueBuilder8makeNameENS_7IStringE(i1) | 0;
   break;
  }
 case 3:
  {
   HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
   HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
   i5 = __ZN6cashew12ValueBuilder10makeStringENS_7IStringE(i1) | 0;
   break;
  }
 case 4:
  {
   i5 = __ZN6cashew12ValueBuilder10makeDoubleEd(+(~~+HEAPF64[i6 >> 3] >>> 0 >>> 0)) | 0;
   break;
  }
 case 5:
  {
   i5 = __ZN6cashew19DotZeroValueBuilder10makeDoubleEd(+HEAPF64[i6 >> 3]) | 0;
   break;
  }
 default:
  _abort();
 }
 STACKTOP = i4;
 return i5 | 0;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13maybePushTaskEPFvPS4_PPNS_10ExpressionEESB_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE24__emplace_back_slow_pathIJRPFvPS6_PPNS1_10ExpressionEERSI_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner13visitSetLocalEPNS_8SetLocalE(i2, i4, i3) {
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = HEAP32[i3 + 8 >> 2] | 0;
 __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i2, i4, HEAP32[i3 + 12 >> 2] | 0);
 do if (!(HEAP32[i2 + 16 >> 2] | 0)) if ((HEAP32[i2 >> 2] | 0) == (HEAP32[i3 + 4 >> 2] | 0)) {
  i4 = (HEAP32[HEAP32[i4 + 4 >> 2] >> 2] | 0) + (i1 << 4) | 0;
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  HEAP32[i4 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
  HEAP32[i4 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
  HEAP32[i4 + 12 >> 2] = HEAP32[i2 + 12 >> 2];
  break;
 } else ___assert_fail(28355, 28043, 379, 24554); while (0);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE14__erase_uniqueIS3_EEjRKT_(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5 + 4 | 0;
 i3 = i5;
 i1 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE4findIS3_EENS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEERKT_(i4, i1) | 0;
 if ((i1 | 0) == (i4 + 4 | 0)) i1 = 0; else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE5eraseENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEE(i4, i2) | 0;
  i1 = 1;
 }
 STACKTOP = i5;
 return i1 | 0;
}

function __ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_(i5, i3, i1, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i6;
 i3 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
 HEAP32[i7 >> 2] = i3;
 i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i7, 61712) | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i8 >> 2] | 0) + 48 >> 2] & 7](i8, 53246, 53278, i1) | 0;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i7, 61720) | 0;
 i7 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 12 >> 2] & 255](i1) | 0;
 HEAP32[i2 >> 2] = i7;
 i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 255](i1) | 0;
 HEAP32[i4 >> 2] = i2;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 1023](i5, i1);
 __ZNSt3__214__shared_count16__release_sharedEv(i3) | 0;
 STACKTOP = i6;
 return;
}

function __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZN4wasm19DeadCodeElimination11visitBinaryEPNS_6BinaryE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0;
 i1 = i5 + 12 | 0;
 i8 = HEAP32[i1 >> 2] | 0;
 i2 = i8;
 if ((i8 | 0) != 0 ? (HEAP32[i8 >> 2] | 0) == 20 : 0) HEAP32[i6 + 20 >> 2] = i2; else i7 = 4;
 if (((i7 | 0) == 4 ? (i3 = i5 + 16 | 0, i4 = HEAP32[i3 >> 2] | 0, i4 | 0) : 0) ? (HEAP32[i4 >> 2] | 0) == 20 : 0) {
  i8 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v((HEAP32[i6 + 40 >> 2] | 0) + 88 | 0) | 0;
  i7 = i8 + 12 | 0;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i7, 2);
  i4 = HEAP32[i1 >> 2] | 0;
  i5 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 0) | 0;
  HEAP32[i5 >> 2] = i4;
  i5 = HEAP32[i3 >> 2] | 0;
  i7 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 1) | 0;
  HEAP32[i7 >> 2] = i5;
  __ZN4wasm5Block8finalizeEv(i8);
  HEAP32[i6 + 20 >> 2] = i8;
 }
 return;
}

function __ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_(i5, i3, i1, i2, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i6;
 i3 = __ZNKSt3__28ios_base6getlocEv(i3) | 0;
 HEAP32[i7 >> 2] = i3;
 i8 = __ZNKSt3__26locale9use_facetERNS0_2idE(i7, 61680) | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i8 >> 2] | 0) + 32 >> 2] & 7](i8, 53246, 53278, i1) | 0;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i7, 61692) | 0;
 i7 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 12 >> 2] & 255](i1) | 0;
 HEAP8[i2 >> 0] = i7;
 i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 255](i1) | 0;
 HEAP8[i4 >> 0] = i2;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 1023](i5, i1);
 __ZNSt3__214__shared_count16__release_sharedEv(i3) | 0;
 STACKTOP = i6;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE14__erase_uniqueIS3_EEjRKT_(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5 + 4 | 0;
 i3 = i5;
 i1 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_(i4, i1) | 0;
 if ((i1 | 0) == (i4 + 4 | 0)) i1 = 0; else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE5eraseENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEE(i4, i2) | 0;
  i1 = 1;
 }
 STACKTOP = i5;
 return i1 | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i7, i5, i4) {
 i7 = i7 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i7 + 11 | 0;
 i1 = HEAP8[i6 >> 0] | 0;
 i2 = i1 << 24 >> 24 < 0;
 if (i2) {
  i3 = HEAP32[i7 + 4 >> 2] | 0;
  i1 = (HEAP32[i7 + 8 >> 2] & 2147483647) + -1 | 0;
 } else {
  i3 = i1 & 255;
  i1 = 10;
 }
 if ((i1 - i3 | 0) >>> 0 >= i4 >>> 0) {
  if (i4 | 0) {
   if (i2) i2 = HEAP32[i7 >> 2] | 0; else i2 = i7;
   _memcpy(i2 + i3 | 0, i5 | 0, i4 | 0) | 0;
   i1 = i3 + i4 | 0;
   if ((HEAP8[i6 >> 0] | 0) < 0) HEAP32[i7 + 4 >> 2] = i1; else HEAP8[i6 >> 0] = i1;
   HEAP8[i2 + i1 >> 0] = 0;
  }
 } else __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE21__grow_by_and_replaceEjjjjjjPKc(i7, i1, i4 - i1 + i3 | 0, i3, i3, 0, i4, i5);
 return i7 | 0;
}

function __ZN4wasm19DeadCodeElimination10visitStoreEPNS_5StoreE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0;
 i1 = i5 + 20 | 0;
 i8 = HEAP32[i1 >> 2] | 0;
 i2 = i8;
 if ((i8 | 0) != 0 ? (HEAP32[i8 >> 2] | 0) == 20 : 0) HEAP32[i6 + 20 >> 2] = i2; else i7 = 4;
 if (((i7 | 0) == 4 ? (i3 = i5 + 24 | 0, i4 = HEAP32[i3 >> 2] | 0, i4 | 0) : 0) ? (HEAP32[i4 >> 2] | 0) == 20 : 0) {
  i8 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v((HEAP32[i6 + 40 >> 2] | 0) + 88 | 0) | 0;
  i7 = i8 + 12 | 0;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i7, 2);
  i4 = HEAP32[i1 >> 2] | 0;
  i5 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 0) | 0;
  HEAP32[i5 >> 2] = i4;
  i5 = HEAP32[i3 >> 2] | 0;
  i7 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i7, 1) | 0;
  HEAP32[i7 >> 2] = i5;
  __ZN4wasm5Block8finalizeEv(i8);
  HEAP32[i6 + 20 >> 2] = i8;
 }
 return;
}

function __ZN4wasm15Asm2WasmBuilder15getFunctionTypeEN6cashew3RefER11ArenaVectorIPNS_10ExpressionEE(i6, i3, i5) {
 i6 = i6 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i7 + 16 | 0;
 i2 = i7 + 12 | 0;
 i4 = i7;
 if (__ZN6cashew3RefntEv(i3) | 0) i1 = 0; else {
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  i1 = __ZN4wasm15Asm2WasmBuilder14detectWasmTypeEN6cashew3RefEP7AsmData(i6, i1, 0) | 0;
 }
 __ZN4wasm6getSigI11ArenaVectorIPNS_10ExpressionEEEENSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEENS_8WasmTypeERKT_(i4, i1, i5);
 i6 = __ZN4wasm18ensureFunctionTypeENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPNS_6ModuleE(i4, HEAP32[i6 >> 2] | 0) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i4);
 STACKTOP = i7;
 return i6 | 0;
}

function __ZN6cashew12ValueBuilder12makeContinueENS_7IStringE(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6 + 8 | 0;
 i7 = i6 + 4 | 0;
 i2 = i6;
 i3 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i8 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59360) | 0;
 HEAP32[i7 >> 2] = i8;
 HEAP32[i1 >> 2] = HEAP32[i7 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 i7 = HEAP32[i4 >> 2] | 0;
 if ((i7 | 0) != 0 ? (HEAP8[i7 >> 0] | 0) != 0 : 0) {
  i8 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i4) | 0;
  HEAP32[i2 >> 2] = i8;
 } else i5 = 4;
 if ((i5 | 0) == 4) {
  i8 = __ZN6cashew12ValueBuilder8makeNullEv() | 0;
  HEAP32[i2 >> 2] = i8;
 };
 HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
 i8 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 STACKTOP = i6;
 return i8 | 0;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZNSt3__213__vector_baseIN4wasm14SimplifyLocals10BlockBreakENS_9allocatorIS3_EEED2Ev(i1 + 20 | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZN10__cxxabiv112_GLOBAL__N_117parse_call_offsetEPKcS2_(i1, i4) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 L1 : do if ((i1 | 0) != (i4 | 0)) {
  switch (HEAP8[i1 >> 0] | 0) {
  case 104:
   {
    i3 = i1 + 1 | 0;
    i2 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i3, i4) | 0;
    if ((i2 | 0) == (i3 | 0) | (i2 | 0) == (i4 | 0)) break L1;
    return ((HEAP8[i2 >> 0] | 0) == 95 ? i2 + 1 | 0 : i1) | 0;
   }
  case 118:
   break;
  default:
   break L1;
  }
  i5 = i1 + 1 | 0;
  i2 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i5, i4) | 0;
  if ((!((i2 | 0) == (i5 | 0) | (i2 | 0) == (i4 | 0)) ? (HEAP8[i2 >> 0] | 0) == 95 : 0) ? (i5 = i2 + 1 | 0, i3 = __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i5, i4) | 0, !((i3 | 0) == (i5 | 0) | (i3 | 0) == (i4 | 0))) : 0) i1 = (HEAP8[i3 >> 0] | 0) == 95 ? i3 + 1 | 0 : i1;
 } while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6assignEPKcj(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0;
 i3 = i7 + 11 | 0;
 i1 = HEAP8[i3 >> 0] | 0;
 i2 = i1 << 24 >> 24 < 0;
 if (i2) i4 = (HEAP32[i7 + 8 >> 2] & 2147483647) + -1 | 0; else i4 = 10;
 do if (i4 >>> 0 >= i5 >>> 0) {
  if (i2) i1 = HEAP32[i7 >> 2] | 0; else i1 = i7;
  if (i5 | 0) _memmove(i1 | 0, i6 | 0, i5 | 0) | 0;
  HEAP8[i1 + i5 >> 0] = 0;
  if ((HEAP8[i3 >> 0] | 0) < 0) {
   HEAP32[i7 + 4 >> 2] = i5;
   break;
  } else {
   HEAP8[i3 >> 0] = i5;
   break;
  }
 } else {
  if (i2) i1 = HEAP32[i7 + 4 >> 2] | 0; else i1 = i1 & 255;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE21__grow_by_and_replaceEjjjjjjPKc(i7, i4, i5 - i4 | 0, i1, 0, i1, i5, i6);
 } while (0);
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZN6cashew5Value4freeEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 switch (HEAP32[i5 >> 2] | 0) {
 case 2:
  {
   i1 = i5 + 8 | 0;
   i3 = HEAP32[i1 >> 2] | 0;
   i2 = HEAP32[i3 >> 2] | 0;
   i3 = i3 + 4 | 0;
   i4 = HEAP32[i3 >> 2] | 0;
   while (1) {
    if ((i4 | 0) == (i2 | 0)) break;
    i6 = i4 + -4 | 0;
    HEAP32[i3 >> 2] = i6;
    i4 = i6;
   }
   __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE13shrink_to_fitEv(HEAP32[i1 >> 2] | 0);
   break;
  }
 case 5:
  {
   i1 = HEAP32[i5 + 8 >> 2] | 0;
   if (i1 | 0) {
    __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringENS2_3RefEEENS_22__unordered_map_hasherIS3_S5_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S5_NS_8equal_toIS3_EELb1EEENS_9allocatorIS5_EEED2Ev(i1);
    __ZdlPv(i1);
   }
   break;
  }
 default:
  {}
 }
 HEAP32[i5 >> 2] = 3;
 HEAPF64[i5 + 8 >> 3] = 0.0;
 return;
}

function __ZN6cashew12ValueBuilder9makeBreakENS_7IStringE(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6 + 8 | 0;
 i7 = i6 + 4 | 0;
 i2 = i6;
 i3 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i8 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59356) | 0;
 HEAP32[i7 >> 2] = i8;
 HEAP32[i1 >> 2] = HEAP32[i7 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 i7 = HEAP32[i4 >> 2] | 0;
 if ((i7 | 0) != 0 ? (HEAP8[i7 >> 0] | 0) != 0 : 0) {
  i8 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i4) | 0;
  HEAP32[i2 >> 2] = i8;
 } else i5 = 4;
 if ((i5 | 0) == 4) {
  i8 = __ZN6cashew12ValueBuilder8makeNullEv() | 0;
  HEAP32[i2 >> 2] = i8;
 };
 HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
 i8 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 STACKTOP = i6;
 return i8 | 0;
}

function __ZZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(68) | 0;
   __ZN4wasm13ReorderLocalsC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 __ZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionE(i3, i5);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj(i10, i9, i1, i4, i7, i8, i6) {
 i10 = i10 | 0;
 i9 = i9 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 if ((-17 - i9 | 0) >>> 0 < i1 >>> 0) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i10);
 if ((HEAP8[i10 + 11 >> 0] | 0) < 0) i5 = HEAP32[i10 >> 2] | 0; else i5 = i10;
 if (i9 >>> 0 < 2147483623) {
  i2 = i1 + i9 | 0;
  i3 = i9 << 1;
  i2 = i2 >>> 0 < i3 >>> 0 ? i3 : i2;
  i2 = i2 >>> 0 < 11 ? 11 : i2 + 16 & -16;
 } else i2 = -17;
 i3 = __Znwj(i2) | 0;
 if (i7 | 0) _memcpy(i3 | 0, i5 | 0, i7 | 0) | 0;
 i1 = i4 - i8 | 0;
 if ((i1 | 0) != (i7 | 0)) _memcpy(i3 + i7 + i6 | 0, i5 + i7 + i8 | 0, i1 - i7 | 0) | 0;
 if ((i9 | 0) != 10) __ZdlPv(i5);
 HEAP32[i10 >> 2] = i3;
 HEAP32[i10 + 8 >> 2] = i2 | -2147483648;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji(i1, i6, i7, i2) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i9;
 do if ((i1 | 0) == (i6 | 0)) {
  HEAP32[i7 >> 2] = 4;
  i2 = 0;
  i1 = 0;
 } else {
  if ((HEAP8[i1 >> 0] | 0) == 45) {
   HEAP32[i7 >> 2] = 4;
   i2 = 0;
   i1 = 0;
   break;
  }
  i4 = ___errno_location() | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  i1 = _strtoull_l(i1, i8, i2, __ZNSt3__26__clocEv() | 0) | 0;
  i2 = tempRet0;
  i3 = HEAP32[i4 >> 2] | 0;
  if (!i3) HEAP32[i4 >> 2] = i5;
  if ((HEAP32[i8 >> 2] | 0) == (i6 | 0)) {
   if ((i3 | 0) == 34) {
    HEAP32[i7 >> 2] = 4;
    i1 = -1;
    i2 = -1;
   }
  } else {
   HEAP32[i7 >> 2] = 4;
   i1 = 0;
   i2 = 0;
  }
 } while (0);
 tempRet0 = i2;
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm14SimplifyLocals10BlockBreakENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i7 = i1 + -16 | 0;
  __ZN4wasm14SimplifyLocals10BlockBreakC2EOS1_((HEAP32[i4 >> 2] | 0) + -16 | 0, i7);
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -16;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i2;
 i3 = i6 + 8 | 0;
 i7 = i5 + 12 | 0;
 i6 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i6;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZN4wasm13WasmValidator11visitMemoryEPNS_6MemoryE(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i2 = i4 + 4 | 0;
 __ZN4wasm13WasmValidator13shouldBeFalseIPKcEEbbT_S3_(i5, (HEAP32[i4 >> 2] | 0) >>> 0 > (HEAP32[i2 >> 2] | 0) >>> 0, 49105, 20597) | 0;
 __ZN4wasm13WasmValidator12shouldBeTrueIPKcEEbbT_S3_(i5, (HEAP32[i2 >> 2] | 0) >>> 0 < 65536, 49105, 20619) | 0;
 i2 = HEAP32[i4 + 12 >> 2] | 0;
 i3 = HEAP32[i4 + 8 >> 2] | 0;
 i1 = 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  __ZN4wasm13WasmValidator13shouldBeFalseIPKcEEbbT_S3_(i5, (HEAP32[i3 >> 2] | 0) >>> 0 < i1 >>> 0, 49105, 20647) | 0;
  i6 = (HEAP32[i3 + 8 >> 2] | 0) + (HEAP32[i3 >> 2] | 0) - (HEAP32[i3 + 4 >> 2] | 0) | 0;
  i3 = i3 + 16 | 0;
  i1 = i6;
 }
 __ZN4wasm13WasmValidator13shouldBeFalseIPKcEEbbT_S3_(i5, i1 >>> 0 > HEAP32[i4 >> 2] << 16 >>> 0, 49105, 20678) | 0;
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = (i1 - i3 | 0) / 12 | 0;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 * 12 | 0) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -12 | 0;
    HEAP32[i6 >> 2] = i5;
    __ZNSt3__213__vector_baseIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEED2Ev(i5);
    i1 = HEAP32[i6 >> 2] | 0;
   }
  }
 } else __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwj(i8, i7, i6) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i1 = i8 + 8 | 0;
 i5 = i1 + 3 | 0;
 i2 = HEAP8[i5 >> 0] | 0;
 i3 = i2 << 24 >> 24 < 0;
 if (i3) i4 = (HEAP32[i1 >> 2] & 2147483647) + -1 | 0; else i4 = 1;
 do if (i4 >>> 0 >= i6 >>> 0) {
  if (i3) i1 = HEAP32[i8 >> 2] | 0; else i1 = i8;
  __ZNSt3__211char_traitsIwE4moveEPwPKwj(i1, i7, i6) | 0;
  HEAP32[i1 + (i6 << 2) >> 2] = 0;
  if ((HEAP8[i5 >> 0] | 0) < 0) {
   HEAP32[i8 + 4 >> 2] = i6;
   break;
  } else {
   HEAP8[i5 >> 0] = i6;
   break;
  }
 } else {
  if (i3) i1 = HEAP32[i8 + 4 >> 2] | 0; else i1 = i2 & 255;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEjjjjjjPKw(i8, i4, i6 - i4 | 0, i1, 0, i1, i6, i7);
 } while (0);
 return i8 | 0;
}

function __ZNKSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE4findIS2_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS2_PvEEEERKT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = HEAP32[i1 >> 2] | 0;
 i1 = i5 * 33 ^ 5381;
 i4 = HEAP32[i2 + 4 >> 2] | 0;
 L1 : do if (i4) {
  i6 = i4 + -1 | 0;
  i7 = (i6 & i4 | 0) == 0;
  if (i7) i3 = i6 & i1; else i3 = (i1 >>> 0) % (i4 >>> 0) | 0;
  i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + (i3 << 2) >> 2] | 0;
  if (i1) do {
   i1 = HEAP32[i1 >> 2] | 0;
   if (!i1) {
    i1 = 0;
    break L1;
   }
   i2 = HEAP32[i1 + 4 >> 2] | 0;
   if (i7) i2 = i2 & i6; else i2 = (i2 >>> 0) % (i4 >>> 0) | 0;
   if ((i2 | 0) != (i3 | 0)) {
    i1 = 0;
    break L1;
   }
  } while ((HEAP32[i1 + 8 >> 2] | 0) != (i5 | 0)); else i1 = 0;
 } else i1 = 0; while (0);
 return i1 | 0;
}

function __ZNK4wasm7Literal2neERKS0_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i4 = 0;
 switch (HEAP32[i3 >> 2] | 0) {
 case 1:
  {
   i3 = (HEAP32[i3 + 8 >> 2] | 0) != (HEAP32[i2 + 8 >> 2] | 0) & 1;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i3;
   break;
  }
 case 2:
  {
   i4 = i3 + 8 | 0;
   i3 = i2 + 8 | 0;
   i3 = ((HEAP32[i4 >> 2] | 0) != (HEAP32[i3 >> 2] | 0) ? 1 : (HEAP32[i4 + 4 >> 2] | 0) != (HEAP32[i3 + 4 >> 2] | 0)) & 1;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i3;
   break;
  }
 case 3:
  {
   i4 = +__ZNK4wasm7Literal6getf32Ev(i3) != +__ZNK4wasm7Literal6getf32Ev(i2) & 1;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i4;
   break;
  }
 case 4:
  {
   i4 = +__ZNK4wasm7Literal6getf64Ev(i3) != +__ZNK4wasm7Literal6getf64Ev(i2) & 1;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i4;
   break;
  }
 default:
  {}
 }
 return;
}

function __ZNK4wasm7Literal2eqERKS0_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i4 = 0;
 switch (HEAP32[i3 >> 2] | 0) {
 case 1:
  {
   i3 = (HEAP32[i3 + 8 >> 2] | 0) == (HEAP32[i2 + 8 >> 2] | 0) & 1;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i3;
   break;
  }
 case 2:
  {
   i4 = i3 + 8 | 0;
   i3 = i2 + 8 | 0;
   i3 = ((HEAP32[i4 >> 2] | 0) == (HEAP32[i3 >> 2] | 0) ? (HEAP32[i4 + 4 >> 2] | 0) == (HEAP32[i3 + 4 >> 2] | 0) : 0) & 1;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i3;
   break;
  }
 case 3:
  {
   i4 = +__ZNK4wasm7Literal6getf32Ev(i3) == +__ZNK4wasm7Literal6getf32Ev(i2) & 1;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i4;
   break;
  }
 case 4:
  {
   i4 = +__ZNK4wasm7Literal6getf64Ev(i3) == +__ZNK4wasm7Literal6getf64Ev(i2) & 1;
   HEAP32[i1 >> 2] = 1;
   HEAP32[i1 + 8 >> 2] = i4;
   break;
  }
 default:
  {}
 }
 return;
}

function __ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi(i1, i5, i4, i6) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0;
 L1 : do if ((i1 | 0) != (HEAP32[i5 + 8 >> 2] | 0)) {
  i3 = HEAP32[i1 + 12 >> 2] | 0;
  i2 = i1 + 16 + (i3 << 3) | 0;
  __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi(i1 + 16 | 0, i5, i4, i6);
  if ((i3 | 0) > 1) {
   i3 = i5 + 54 | 0;
   i1 = i1 + 24 | 0;
   do {
    __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi(i1, i5, i4, i6);
    if (HEAP8[i3 >> 0] | 0) break L1;
    i1 = i1 + 8 | 0;
   } while (i1 >>> 0 < i2 >>> 0);
  }
 } else __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0, i5, i4, i6); while (0);
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9push_backEc(i1, i7) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i5 = i1 + 11 | 0;
 i2 = HEAP8[i5 >> 0] | 0;
 i3 = i2 << 24 >> 24 < 0;
 if (i3) {
  i4 = (HEAP32[i1 + 8 >> 2] & 2147483647) + -1 | 0;
  i6 = HEAP32[i1 + 4 >> 2] | 0;
 } else {
  i4 = 10;
  i6 = i2 & 255;
 }
 if ((i6 | 0) == (i4 | 0)) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9__grow_byEjjjjjj(i1, i4, 1, i4, i4, 0);
  if ((HEAP8[i5 >> 0] | 0) < 0) i2 = 8; else i2 = 7;
 } else if (i3) i2 = 8; else i2 = 7;
 if ((i2 | 0) == 7) HEAP8[i5 >> 0] = i6 + 1; else if ((i2 | 0) == 8) {
  i5 = HEAP32[i1 >> 2] | 0;
  HEAP32[i1 + 4 >> 2] = i6 + 1;
  i1 = i5;
 }
 i6 = i1 + i6 | 0;
 HEAP8[i6 >> 0] = i7;
 HEAP8[i6 + 1 >> 0] = 0;
 return;
}

function __ZN4wasm10TypeSeeker9visitLoopEPNS_4LoopE(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 L1 : do if ((i1 | 0) == (HEAP32[i4 + 28 >> 2] | 0)) {
  i1 = (HEAP32[i1 + 16 >> 2] | 0) + 4 | 0;
  i2 = i4 + 40 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (HEAP32[i4 + 44 >> 2] | 0)) {
   __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4 + 36 | 0, i1);
   break;
  } else {
   HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
   HEAP32[i2 >> 2] = i3 + 4;
   break;
  }
 } else {
  i3 = HEAP32[i4 + 32 >> 2] | 0;
  if ((HEAP32[i1 + 12 >> 2] | 0) != (i3 | 0) ? (HEAP32[i1 + 8 >> 2] | 0) != (i3 | 0) : 0) break;
  i3 = HEAP32[i4 + 36 >> 2] | 0;
  i1 = i4 + 40 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break L1;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
 } while (0);
 return;
}

function __ZN4wasm22SExpressionWasmBuilder15getFunctionNameERNS_7ElementE(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i5;
 i2 = (HEAP8[i1 + 24 >> 0] | 0) == 0;
 i1 = __ZN4wasm7Element3strEv(i1) | 0;
 do if (i2) {
  i2 = _atoi(i1) | 0;
  i1 = HEAP32[i4 + 8 >> 2] | 0;
  if (i2 >>> 0 < (HEAP32[i4 + 12 >> 2] | 0) - i1 >> 2 >>> 0) {
   i1 = HEAP32[i1 + (i2 << 2) >> 2] | 0;
   break;
  } else {
   i5 = ___cxa_allocate_exception(20) | 0;
   HEAP32[i3 >> 2] = 0;
   HEAP32[i3 + 4 >> 2] = 0;
   HEAP32[i3 + 8 >> 2] = 0;
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i3, 21659, 16);
   __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i5, i3);
   ___cxa_throw(i5 | 0, 64, 279);
  }
 } while (0);
 STACKTOP = i5;
 return i1 | 0;
}

function __ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib(i6, i4, i3, i5, i7) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0;
 do if ((i6 | 0) == (HEAP32[i4 + 8 >> 2] | 0)) {
  if ((HEAP32[i4 + 4 >> 2] | 0) == (i3 | 0) ? (i2 = i4 + 28 | 0, (HEAP32[i2 >> 2] | 0) != 1) : 0) HEAP32[i2 >> 2] = i5;
 } else if ((i6 | 0) == (HEAP32[i4 >> 2] | 0)) {
  if ((HEAP32[i4 + 16 >> 2] | 0) != (i3 | 0) ? (i1 = i4 + 20 | 0, (HEAP32[i1 >> 2] | 0) != (i3 | 0)) : 0) {
   HEAP32[i4 + 32 >> 2] = i5;
   HEAP32[i1 >> 2] = i3;
   i7 = i4 + 40 | 0;
   HEAP32[i7 >> 2] = (HEAP32[i7 >> 2] | 0) + 1;
   if ((HEAP32[i4 + 36 >> 2] | 0) == 1 ? (HEAP32[i4 + 24 >> 2] | 0) == 2 : 0) HEAP8[i4 + 54 >> 0] = 1;
   HEAP32[i4 + 44 >> 2] = 4;
   break;
  }
  if ((i5 | 0) == 1) HEAP32[i4 + 32 >> 2] = 1;
 } while (0);
 return;
}

function _load_s_expr2wasm(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 __ZL12prepare2wasmv();
 if (HEAP8[63612] | 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17699) | 0;
 i2 = __Znwj(44) | 0;
 __ZN4wasm17SExpressionParserC2EPc(i2, i1);
 HEAP32[14811] = i2;
 i1 = HEAP32[i2 + 40 >> 2] | 0;
 if (HEAP8[63612] | 0 ? (__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEERNS_7ElementE(60808, i1) | 0, 10) | 0, HEAP8[63612] | 0) : 0) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17420) | 0;
 i3 = __Znwj(180) | 0;
 __ZN4wasm6ModuleC2Ev(i3);
 HEAP32[14814] = i3;
 i2 = __Znwj(80) | 0;
 __ZN4wasm22SExpressionWasmBuilderC2ERNS_6ModuleERNS_7ElementE(i2, i3, __ZN4wasm7ElementixEj(i1, 0) | 0);
 HEAP32[14812] = i2;
 __Z14finalizeModulev();
 return;
}

function __ZN4wasm17WasmBinaryBuilder10readHeaderEv(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i3;
 if (HEAP8[i2 + 12 >> 0] | 0) {
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 22971) | 0;
  i5 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i5;
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i5) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
 }
 __ZN4wasm17WasmBinaryBuilder11verifyInt32Ei(i2, 1836278016);
 __ZN4wasm17WasmBinaryBuilder11verifyInt32Ei(i2, 11);
 STACKTOP = i3;
 return;
}

function __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE5eraseENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i4 + 16 | 0;
 i5 = i4 + 4 | 0;
 i7 = i4;
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i6 >> 2] = HEAP32[i7 >> 2];
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE6removeENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEE(i5, i3, i6);
 i1 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = 0;
 if (i1 | 0) __ZdlPv(i1);
 STACKTOP = i4;
 return i2 | 0;
}

function __ZN4wasm6getSigI11ArenaVectorIPNS_10ExpressionEEEENSt3__212basic_stringIcNS5_11char_traitsIcEENS5_9allocatorIcEEEENS_8WasmTypeERKT_(i3, i2, i4) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i1 = 0, i5 = 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i3 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i3, __ZN4wasm6getSigENS_8WasmTypeE(i2) | 0);
 i1 = HEAP32[i4 + 8 >> 2] | 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  i5 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i4, i2) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i3, __ZN4wasm6getSigENS_8WasmTypeE(HEAP32[(HEAP32[i5 >> 2] | 0) + 4 >> 2] | 0) | 0);
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZNSt3__26vectorINS_4pairIPN4wasm7ElementEPNS2_5BlockEEENS_9allocatorIS7_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS9_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZN6cashew12ValueBuilder10makePrefixENS_7IStringENS_3RefE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 12 | 0;
 i8 = i3 + 8 | 0;
 i7 = i3 + 4 | 0;
 i5 = i3;
 i6 = __ZN6cashew12ValueBuilder12makeRawArrayEi(3) | 0;
 i9 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59396) | 0;
 HEAP32[i8 >> 2] = i9;
 HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
 i6 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 i1 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i1) | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 HEAP32[i5 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i1, i4) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji(i1, i6, i7, i2) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i9;
 if ((i1 | 0) == (i6 | 0)) {
  HEAP32[i7 >> 2] = 4;
  i2 = 0;
  i1 = 0;
 } else {
  i4 = ___errno_location() | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  i1 = _strtoll_l(i1, i8, i2, __ZNSt3__26__clocEv() | 0) | 0;
  i2 = tempRet0;
  i3 = HEAP32[i4 >> 2] | 0;
  if (!i3) HEAP32[i4 >> 2] = i5;
  if ((HEAP32[i8 >> 2] | 0) == (i6 | 0)) {
   if ((i3 | 0) == 34) {
    HEAP32[i7 >> 2] = 4;
    i2 = (i2 | 0) > 0 | (i2 | 0) == 0 & i1 >>> 0 > 0;
    i1 = i2 ? -1 : 0;
    i2 = i2 ? 2147483647 : -2147483648;
   }
  } else {
   HEAP32[i7 >> 2] = 4;
   i1 = 0;
   i2 = 0;
  }
 }
 tempRet0 = i2;
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNSt3__26vectorIN6cashew13OperatorClassENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i7 = i1 + -40 | 0;
  __ZN6cashew13OperatorClassC2EOS0_((HEAP32[i4 >> 2] | 0) + -40 | 0, i7);
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -40;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i2;
 i3 = i6 + 8 | 0;
 i7 = i5 + 12 | 0;
 i6 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i6;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZN6cashew12ValueBuilder9makeLabelENS_7IStringENS_3RefE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 12 | 0;
 i8 = i3 + 8 | 0;
 i7 = i3 + 4 | 0;
 i5 = i3;
 i6 = __ZN6cashew12ValueBuilder12makeRawArrayEi(3) | 0;
 i9 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59352) | 0;
 HEAP32[i8 >> 2] = i9;
 HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
 i6 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 i2 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i2) | 0;
 HEAP32[i7 >> 2] = i2;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 HEAP32[i5 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i2, i4) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZN6cashew12ValueBuilder7makeDotENS_3RefENS_7IStringE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 12 | 0;
 i8 = i3 + 8 | 0;
 i7 = i3 + 4 | 0;
 i5 = i3;
 i6 = __ZN6cashew12ValueBuilder12makeRawArrayEi(3) | 0;
 i9 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59588) | 0;
 HEAP32[i8 >> 2] = i9;
 HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
 i6 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 HEAP32[i7 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 i1 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i1) | 0;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i2, i4) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE5eraseENS_21__tree_const_iteratorISG_PNS_11__tree_nodeISG_PvEEiEE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i1) | 0;
 if ((HEAP32[i3 >> 2] | 0) == (i1 | 0)) HEAP32[i3 >> 2] = i2;
 i4 = i3 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -1;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i3 + 4 >> 2] | 0, i1);
 __ZNSt3__213__vector_baseIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEED2Ev(i1 + 20 | 0);
 __ZdlPv(i1);
 return i2 | 0;
}

function __ZNSt3__211__stdoutbufIwE4syncEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i10 + 8 | 0;
 i7 = i10;
 i3 = i1 + 36 | 0;
 i4 = i1 + 40 | 0;
 i5 = i8 + 8 | 0;
 i6 = i8;
 i2 = i1 + 32 | 0;
 L1 : while (1) {
  i1 = HEAP32[i3 >> 2] | 0;
  i1 = FUNCTION_TABLE_iiiiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 31](i1, HEAP32[i4 >> 2] | 0, i8, i5, i7) | 0;
  i11 = (HEAP32[i7 >> 2] | 0) - i6 | 0;
  if ((_fwrite(i8, 1, i11, HEAP32[i2 >> 2] | 0) | 0) != (i11 | 0)) {
   i1 = -1;
   break;
  }
  switch (i1 | 0) {
  case 1:
   break;
  case 2:
   {
    i1 = -1;
    break L1;
   }
  default:
   {
    i9 = 4;
    break L1;
   }
  }
 }
 if ((i9 | 0) == 4) i1 = ((_fflush(HEAP32[i2 >> 2] | 0) | 0) != 0) << 31 >> 31;
 STACKTOP = i10;
 return i1 | 0;
}

function __ZNSt3__211__stdoutbufIcE4syncEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i10 + 8 | 0;
 i7 = i10;
 i3 = i1 + 36 | 0;
 i4 = i1 + 40 | 0;
 i5 = i8 + 8 | 0;
 i6 = i8;
 i2 = i1 + 32 | 0;
 L1 : while (1) {
  i1 = HEAP32[i3 >> 2] | 0;
  i1 = FUNCTION_TABLE_iiiiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 31](i1, HEAP32[i4 >> 2] | 0, i8, i5, i7) | 0;
  i11 = (HEAP32[i7 >> 2] | 0) - i6 | 0;
  if ((_fwrite(i8, 1, i11, HEAP32[i2 >> 2] | 0) | 0) != (i11 | 0)) {
   i1 = -1;
   break;
  }
  switch (i1 | 0) {
  case 1:
   break;
  case 2:
   {
    i1 = -1;
    break L1;
   }
  default:
   {
    i9 = 4;
    break L1;
   }
  }
 }
 if ((i9 | 0) == 4) i1 = ((_fflush(HEAP32[i2 >> 2] | 0) | 0) != 0) << 31 >> 31;
 STACKTOP = i10;
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm6Memory7SegmentENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i2 = HEAP32[i6 >> 2] | 0;
 i3 = i6 + 4 | 0;
 i4 = i5 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  i7 = i1 + -16 | 0;
  __ZN4wasm6Memory7SegmentC2EOS1_((HEAP32[i4 >> 2] | 0) + -16 | 0, i7);
  HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -16;
  i1 = i7;
 }
 i7 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i7;
 i7 = i5 + 8 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i2;
 i3 = i6 + 8 | 0;
 i7 = i5 + 12 | 0;
 i6 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i6;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 return;
}

function __ZZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(56) | 0;
   __ZN4wasm6VacuumC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 __ZN4wasm6Vacuum13visitFunctionEPNS_8FunctionE(i3, i5);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZNSt3__26vectorIPNS0_IN6cashew3RefENS_9allocatorIS2_EEEENS3_IS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEERNS_7ElementE(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 if (!(HEAP8[i1 >> 0] | 0)) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i4, HEAP32[i1 + 20 >> 2] | 0) | 0; else {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i4, 40) | 0;
  i3 = i1 + 4 | 0;
  i1 = HEAP32[i1 + 12 >> 2] | 0;
  i2 = 0;
  while (1) {
   if ((i2 | 0) == (i1 | 0)) break;
   i5 = __ZNK11ArenaVectorIPN4wasm7ElementEEixEj(i3, i2) | 0;
   i5 = HEAP32[i5 >> 2] | 0;
   __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEERNS_7ElementE(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i4, 32) | 0, i5) | 0;
   i2 = i2 + 1 | 0;
  }
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i4, 21529) | 0;
 }
 return i4 | 0;
}

function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE9__grow_byEjjjjjj(i8, i6, i1, i7, i5, i4) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i7 = i7 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 if ((-17 - i6 | 0) >>> 0 < i1 >>> 0) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i8);
 if ((HEAP8[i8 + 11 >> 0] | 0) < 0) i3 = HEAP32[i8 >> 2] | 0; else i3 = i8;
 if (i6 >>> 0 < 2147483623) {
  i1 = i1 + i6 | 0;
  i2 = i6 << 1;
  i1 = i1 >>> 0 < i2 >>> 0 ? i2 : i1;
  i1 = i1 >>> 0 < 11 ? 11 : i1 + 16 & -16;
 } else i1 = -17;
 i2 = _malloc(i1) | 0;
 if (i5 | 0) _memcpy(i2 | 0, i3 | 0, i5 | 0) | 0;
 if ((i7 | 0) != (i5 | 0)) _memcpy(i2 + i5 + i4 | 0, i3 + i5 | 0, i7 - i5 | 0) | 0;
 if ((i6 | 0) != 10) _free(i3);
 HEAP32[i8 >> 2] = i2;
 HEAP32[i8 + 8 >> 2] = i1 | -2147483648;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE11doStartLoopEPS1_PPNS_10ExpressionE(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i3 = i4 + 60 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE(i4, i1);
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4linkEPNS5_10BasicBlockES7_(i4 + 16 | 0, i2, HEAP32[i3 >> 2] | 0);
 i1 = i4 + 92 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[i4 + 96 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE21__push_back_slow_pathIRKS9_EEvOT_(i4 + 88 | 0, i3); else {
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
 }
 return;
}

function __ZN4wasm16PrintSExpression10visitTableEPNS_5TableE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i6 + 4 | 0;
 i3 = i6;
 __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i5 >> 2] | 0, 49134, 0) | 0;
 i4 = HEAP32[i1 + 4 >> 2] | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i4 | 0)) break;
  i8 = HEAP32[i1 >> 2] | 0;
  i7 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i5 >> 2] | 0, 32) | 0;
  HEAP32[i3 >> 2] = i8;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i7, i2) | 0;
  i1 = i1 + 4 | 0;
 }
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i5 >> 2] | 0, 41) | 0;
 STACKTOP = i6;
 return;
}

function __ZN4wasm14CoalesceLocals15doVisitSetLocalEPS0_PPNS_10ExpressionE(i1, i7) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i7;
 i2 = __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i7 >> 2] | 0) | 0;
 i1 = HEAP32[i1 + 60 >> 2] | 0;
 HEAP32[i6 >> 2] = 1;
 i2 = i2 + 8 | 0;
 i3 = i1 + 28 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i1 + 32 >> 2] | 0) >>> 0) {
  i6 = HEAP32[i2 >> 2] | 0;
  HEAP32[i4 >> 2] = 1;
  HEAP32[i4 + 4 >> 2] = i6;
  HEAP32[i4 + 8 >> 2] = i7;
  HEAP8[i4 + 12 >> 0] = 0;
  HEAP32[i3 >> 2] = i4 + 16;
 } else __ZNSt3__26vectorIN4wasm6ActionENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJNS2_4WhatERjRPPNS1_10ExpressionEEEEvDpOT_(i1 + 24 | 0, i6, i2, i5);
 STACKTOP = i8;
 return;
}

function __ZN4wasm14CoalesceLocals15doVisitGetLocalEPS0_PPNS_10ExpressionE(i1, i7) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i7;
 i2 = __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i7 >> 2] | 0) | 0;
 i1 = HEAP32[i1 + 60 >> 2] | 0;
 HEAP32[i6 >> 2] = 0;
 i2 = i2 + 8 | 0;
 i3 = i1 + 28 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i1 + 32 >> 2] | 0) >>> 0) {
  i6 = HEAP32[i2 >> 2] | 0;
  HEAP32[i4 >> 2] = 0;
  HEAP32[i4 + 4 >> 2] = i6;
  HEAP32[i4 + 8 >> 2] = i7;
  HEAP8[i4 + 12 >> 0] = 0;
  HEAP32[i3 >> 2] = i4 + 16;
 } else __ZNSt3__26vectorIN4wasm6ActionENS_9allocatorIS2_EEE24__emplace_back_slow_pathIJNS2_4WhatERjRPPNS1_10ExpressionEEEEvDpOT_(i1 + 24 | 0, i6, i2, i5);
 STACKTOP = i8;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEjc(i7, i5, i4) {
 i7 = i7 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 if (i5 | 0) {
  i6 = i7 + 11 | 0;
  i1 = HEAP8[i6 >> 0] | 0;
  if (i1 << 24 >> 24 < 0) {
   i3 = HEAP32[i7 + 4 >> 2] | 0;
   i2 = (HEAP32[i7 + 8 >> 2] & 2147483647) + -1 | 0;
  } else {
   i3 = i1 & 255;
   i2 = 10;
  }
  if ((i2 - i3 | 0) >>> 0 < i5 >>> 0) {
   __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj(i7, i2, i5 - i2 + i3 | 0, i3, i3, 0, 0);
   i1 = HEAP8[i6 >> 0] | 0;
  }
  if (i1 << 24 >> 24 < 0) i2 = HEAP32[i7 >> 2] | 0; else i2 = i7;
  _memset(i2 + i3 | 0, i4 | 0, i5 | 0) | 0;
  i1 = i3 + i5 | 0;
  if ((HEAP8[i6 >> 0] | 0) < 0) HEAP32[i7 + 4 >> 2] = i1; else HEAP8[i6 >> 0] = i1;
  HEAP8[i2 + i1 >> 0] = 0;
 }
 return i7 | 0;
}

function __ZN4wasm6Vacuum7visitIfEPNS_2IfE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i8;
 i3 = i5 + 16 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 i4 = i1;
 do if (i1) {
  if ((HEAP32[i1 >> 2] | 0) == 19) {
   HEAP32[i3 >> 2] = 0;
   i7 = 6;
   break;
  }
  i1 = i5 + 12 | 0;
  if ((HEAP32[HEAP32[i1 >> 2] >> 2] | 0) == 19 ? (HEAP32[i1 >> 2] = i4, HEAP32[i3 >> 2] = 0, HEAP32[i2 >> 2] = (HEAP32[i6 + 40 >> 2] | 0) + 88, i4 = i5 + 8 | 0, i2 = __ZN4wasm7Builder9makeUnaryENS_7UnaryOpEPNS_10ExpressionE(i2, 20, HEAP32[i4 >> 2] | 0) | 0, HEAP32[i4 >> 2] = i2, (HEAP32[i3 >> 2] | 0) == 0) : 0) i7 = 6;
 } else i7 = 6; while (0);
 if ((i7 | 0) == 6 ? (HEAP32[HEAP32[i5 + 12 >> 2] >> 2] | 0) == 19 : 0) HEAP32[i6 + 20 >> 2] = HEAP32[i5 + 8 >> 2];
 STACKTOP = i8;
 return;
}

function _wcrtomb(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 do if (i1) {
  if (i3 >>> 0 < 128) {
   HEAP8[i1 >> 0] = i3;
   i1 = 1;
   break;
  }
  if (i3 >>> 0 < 2048) {
   HEAP8[i1 >> 0] = i3 >>> 6 | 192;
   HEAP8[i1 + 1 >> 0] = i3 & 63 | 128;
   i1 = 2;
   break;
  }
  if (i3 >>> 0 < 55296 | (i3 & -8192 | 0) == 57344) {
   HEAP8[i1 >> 0] = i3 >>> 12 | 224;
   HEAP8[i1 + 1 >> 0] = i3 >>> 6 & 63 | 128;
   HEAP8[i1 + 2 >> 0] = i3 & 63 | 128;
   i1 = 3;
   break;
  }
  if ((i3 + -65536 | 0) >>> 0 < 1048576) {
   HEAP8[i1 >> 0] = i3 >>> 18 | 240;
   HEAP8[i1 + 1 >> 0] = i3 >>> 12 & 63 | 128;
   HEAP8[i1 + 2 >> 0] = i3 >>> 6 & 63 | 128;
   HEAP8[i1 + 3 >> 0] = i3 & 63 | 128;
   i1 = 4;
   break;
  } else {
   i1 = ___errno_location() | 0;
   HEAP32[i1 >> 2] = 84;
   i1 = -1;
   break;
  }
 } else i1 = 1; while (0);
 return i1 | 0;
}

function __ZZN4wasm22SExpressionWasmBuilder13parseFunctionERNS_7ElementEENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i2 + 8 | 0;
 i8 = i2 + 4 | 0;
 i9 = i2;
 i6 = HEAP32[i1 >> 2] | 0;
 i3 = i6 + 40 | 0;
 HEAP32[i8 >> 2] = (HEAP32[i6 >> 2] | 0) + 88;
 HEAP32[i9 >> 2] = HEAP32[HEAP32[i1 + 4 >> 2] >> 2];
 i6 = HEAP32[i1 + 8 >> 2] | 0;
 i5 = HEAP32[HEAP32[i1 + 12 >> 2] >> 2] | 0;
 i4 = HEAP32[i1 + 16 >> 2] | 0;
 HEAP32[i7 >> 2] = HEAP32[i9 >> 2];
 i4 = __ZN4wasm7Builder12makeFunctionENS_4NameEONSt3__26vectorINS_8NameTypeENS2_9allocatorIS4_EEEENS_8WasmTypeES8_PNS_10ExpressionE(i8, i7, i6, i5, i4, 0) | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = i4;
 if (i1 | 0) {
  __ZN4wasm8FunctionD2Ev(i1);
  __ZdlPv(i1);
 }
 STACKTOP = i2;
 return;
}

function __ZN4wasm17WasmBinaryBuilder13getMaybeBlockEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i4 = i1 + 96 | 0;
 i6 = i1 + 100 | 0;
 i5 = (HEAP32[i6 >> 2] | 0) - (HEAP32[i4 >> 2] | 0) >> 2;
 __ZN4wasm17WasmBinaryBuilder18processExpressionsEv(i1);
 i6 = (HEAP32[i6 >> 2] | 0) - (HEAP32[i4 >> 2] | 0) >> 2;
 if ((i5 - i6 | 0) == 1) i1 = __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i1) | 0; else {
  i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i1 + 4 >> 2] | 0) | 0;
  i2 = i1 + 12 | 0;
  i3 = i5;
  while (1) {
   if (i3 >>> 0 >= i6 >>> 0) break;
   __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, HEAP32[(HEAP32[i4 >> 2] | 0) + (i3 << 2) >> 2] | 0);
   i3 = i3 + 1 | 0;
  }
  __ZN4wasm5Block8finalizeEv(i1);
  __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE6resizeEj(i4, i5);
 }
 return i1 | 0;
}

function __ZNSt3__23mapIN4wasm4NameENS_6vectorIPNS1_9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS5_vEENS1_8LivenessEE10BasicBlockENS_9allocatorISB_EEEENS_4lessIS2_EENSC_INS_4pairIKS2_SE_EEEEEixERSI_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSR_IJEEEEEENS_4pairINS_15__tree_iteratorISG_PNS_11__tree_nodeISG_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65640, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__26vectorIPN4wasm12FunctionTypeENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEjEENS_19__map_value_compareISA_SB_NS_4lessISA_EELb1EEENS_9allocatorISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEjEENS_19__map_value_compareISA_SB_NS_4lessISA_EELb1EEENS_9allocatorISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEjEENS_19__map_value_compareISA_SB_NS_4lessISA_EELb1EEENS_9allocatorISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__219__thread_struct_impD2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i3 = i4 + 12 | 0;
 i1 = HEAP32[i4 + 16 >> 2] | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __ZNSt3__25mutex6unlockEv(HEAP32[i2 + 4 >> 2] | 0);
  __ZNSt3__218condition_variable10notify_allEv(HEAP32[i2 >> 2] | 0);
  i2 = i2 + 8 | 0;
 }
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = HEAP32[i4 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __ZNSt3__217__assoc_sub_state12__make_readyEv(HEAP32[i2 >> 2] | 0);
  __ZNSt3__214__shared_count16__release_sharedEv(HEAP32[i2 >> 2] | 0) | 0;
  i2 = i2 + 4 | 0;
 }
 __ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev(i3);
 __ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev(i4);
 return;
}

function __ZN4wasm22SExpressionWasmBuilder10parseTableERNS_7ElementE(i8, i7) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i9;
 i6 = 1;
 while (1) {
  i5 = (__ZN4wasm7Element4listEv(i7) | 0) + 8 | 0;
  if (i6 >>> 0 >= (HEAP32[i5 >> 2] | 0) >>> 0) break;
  i2 = HEAP32[i8 >> 2] | 0;
  i3 = __ZN4wasm22SExpressionWasmBuilder15getFunctionNameERNS_7ElementE(i8, __ZN4wasm7ElementixEj(i7, i6) | 0) | 0;
  HEAP32[i1 >> 2] = i3;
  i4 = i2 + 52 | 0;
  i5 = HEAP32[i4 >> 2] | 0;
  if (i5 >>> 0 < (HEAP32[i2 + 56 >> 2] | 0) >>> 0) {
   HEAP32[i5 >> 2] = i3;
   HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 4;
  } else __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i2 + 48 | 0, i1);
  i6 = i6 + 1 | 0;
 }
 STACKTOP = i9;
 return;
}

function __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIPN4wasm10CallImportENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(44) | 0;
   __ZN4wasm20OptimizeInstructionsC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i6, i5, i1, i3) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEESD_RKT_(i5, i4, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(20) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[i3 >> 2];
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSB_SB_(i5, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i6 >> 2] = i1;
 HEAP8[i6 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNSt3__26vectorIPN4wasm8FunctionENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv(i6, i1, i4) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i5 = i7;
 if ((i6 | 0) != (i1 | 0)) if ((i1 | 0) != 0 ? (i3 = ___dynamic_cast(i1, 4104, 4072, 0) | 0, (i3 | 0) != 0) : 0) {
  i1 = i5;
  i2 = i1 + 56 | 0;
  do {
   HEAP32[i1 >> 2] = 0;
   i1 = i1 + 4 | 0;
  } while ((i1 | 0) < (i2 | 0));
  HEAP32[i5 >> 2] = i3;
  HEAP32[i5 + 8 >> 2] = i6;
  HEAP32[i5 + 12 >> 2] = -1;
  HEAP32[i5 + 48 >> 2] = 1;
  FUNCTION_TABLE_viiii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 15](i3, i5, HEAP32[i4 >> 2] | 0, 1);
  if ((HEAP32[i5 + 24 >> 2] | 0) == 1) {
   HEAP32[i4 >> 2] = HEAP32[i5 + 16 >> 2];
   i1 = 1;
  } else i1 = 0;
 } else i1 = 0; else i1 = 1;
 STACKTOP = i7;
 return i1 | 0;
}

function __ZNSt3__26vectorIPN6cashew5ValueENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIPN4wasm7ElementENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 3) << 3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0;
 i3 = i7 + 11 | 0;
 i1 = HEAP8[i3 >> 0] | 0;
 i2 = i1 << 24 >> 24 < 0;
 if (i2) i4 = (HEAP32[i7 + 8 >> 2] & 2147483647) + -1 | 0; else i4 = 10;
 do if (i4 >>> 0 >= i5 >>> 0) {
  if (i2) i1 = HEAP32[i7 >> 2] | 0; else i1 = i7;
  if (i5 | 0) _memmove(i1 | 0, i6 | 0, i5 | 0) | 0;
  HEAP8[i1 + i5 >> 0] = 0;
  if ((HEAP8[i3 >> 0] | 0) < 0) {
   HEAP32[i7 + 4 >> 2] = i5;
   break;
  } else {
   HEAP8[i3 >> 0] = i5;
   break;
  }
 } else {
  if (i2) i1 = HEAP32[i7 + 4 >> 2] | 0; else i1 = i1 & 255;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc(i7, i4, i5 - i4 | 0, i1, 0, i1, i5, i6);
 } while (0);
 return i7 | 0;
}

function __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 4) << 4) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9pbackfailEi(i6, i1) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i3 = i6 + 44 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i4 = HEAP32[i6 + 24 >> 2] | 0;
 if (i2 >>> 0 < i4 >>> 0) {
  HEAP32[i3 >> 2] = i4;
  i2 = i4;
 }
 i5 = i6 + 12 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 do if ((HEAP32[i6 + 8 >> 2] | 0) >>> 0 < i3 >>> 0) {
  if ((i1 | 0) == -1) {
   HEAP32[i5 >> 2] = i3 + -1;
   HEAP32[i6 + 16 >> 2] = i2;
   i1 = 0;
   break;
  }
  if (!(HEAP32[i6 + 48 >> 2] & 16)) {
   i4 = i1 & 255;
   i3 = i3 + -1 | 0;
   if (i4 << 24 >> 24 != (HEAP8[i3 >> 0] | 0)) {
    i1 = -1;
    break;
   }
  } else {
   i4 = i1 & 255;
   i3 = i3 + -1 | 0;
  }
  HEAP32[i5 >> 2] = i3;
  HEAP32[i6 + 16 >> 2] = i2;
  HEAP8[i3 >> 0] = i4;
 } else i1 = -1; while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorIPN4wasm5BlockENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN4wasm6ActionENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 4) << 4) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIPN4wasm4PassENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIPN4wasm4CallENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj(i7, i5, i4) {
 i7 = i7 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i7 + 11 | 0;
 i1 = HEAP8[i6 >> 0] | 0;
 i2 = i1 << 24 >> 24 < 0;
 if (i2) {
  i3 = HEAP32[i7 + 4 >> 2] | 0;
  i1 = (HEAP32[i7 + 8 >> 2] & 2147483647) + -1 | 0;
 } else {
  i3 = i1 & 255;
  i1 = 10;
 }
 if ((i1 - i3 | 0) >>> 0 >= i4 >>> 0) {
  if (i4 | 0) {
   if (i2) i2 = HEAP32[i7 >> 2] | 0; else i2 = i7;
   _memcpy(i2 + i3 | 0, i5 | 0, i4 | 0) | 0;
   i1 = i3 + i4 | 0;
   if ((HEAP8[i6 >> 0] | 0) < 0) HEAP32[i7 + 4 >> 2] = i1; else HEAP8[i6 >> 0] = i1;
   HEAP8[i2 + i1 >> 0] = 0;
  }
 } else __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc(i7, i1, i4 - i1 + i3 | 0, i3, i3, 0, i4, i5);
 return i7 | 0;
}

function __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIPN4wasm2IfENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE4findIS3_EENS_15__tree_iteratorISG_PNS_11__tree_nodeISG_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE13__lower_boundIS3_EENS_15__tree_iteratorISG_PNS_11__tree_nodeISG_PvEEiEERKT_SS_SS_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EEPKS8_RKSB_(i4, i2, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i5 = 0, i6 = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i4 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i6 = _strlen(i2) | 0;
 i5 = i3 + 11 | 0;
 i1 = HEAP8[i5 >> 0] | 0;
 i1 = i1 << 24 >> 24 < 0 ? HEAP32[i3 + 4 >> 2] | 0 : i1 & 255;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcjj(i4, i2, i6, i1 + i6 | 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4, (HEAP8[i5 >> 0] | 0) < 0 ? HEAP32[i3 >> 2] | 0 : i3, i1) | 0;
 return;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw(i1, i6) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = i1 + 8 | 0;
 i5 = i2 + 3 | 0;
 i3 = HEAP8[i5 >> 0] | 0;
 i4 = i3 << 24 >> 24 < 0;
 if (i4) {
  i2 = (HEAP32[i2 >> 2] & 2147483647) + -1 | 0;
  i3 = HEAP32[i1 + 4 >> 2] | 0;
 } else {
  i2 = 1;
  i3 = i3 & 255;
 }
 if ((i3 | 0) == (i2 | 0)) {
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEjjjjjj(i1, i2, 1, i2, i2, 0, 0);
  if ((HEAP8[i5 >> 0] | 0) < 0) i2 = 8; else i2 = 7;
 } else if (i4) i2 = 8; else i2 = 7;
 if ((i2 | 0) == 7) HEAP8[i5 >> 0] = i3 + 1; else if ((i2 | 0) == 8) {
  i5 = HEAP32[i1 >> 2] | 0;
  HEAP32[i1 + 4 >> 2] = i3 + 1;
  i1 = i5;
 }
 i5 = i1 + (i3 << 2) | 0;
 HEAP32[i5 >> 2] = i6;
 HEAP32[i5 + 4 >> 2] = 0;
 return;
}

function __ZN4wasm17WasmBinaryBuilder9readStartEv(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i3;
 if (HEAP8[i2 + 12 >> 0] | 0) {
  i4 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 23448) | 0;
  i5 = __ZNKSt3__28ios_base6getlocEv(i4 + (HEAP32[(HEAP32[i4 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i5;
  i5 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i5 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i5 >> 2] | 0) + 28 >> 2] & 63](i5, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i4, i5) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i4) | 0;
 }
 i5 = __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i2) | 0;
 HEAP32[i2 + 20 >> 2] = i5;
 STACKTOP = i3;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i9 = i7;
 i10 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i11 >> 2] = i10;
 i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i11, 61712) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
 HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE(i6, i5 + 16 | 0, i1, i8, i3, i4);
 STACKTOP = i7;
 return HEAP32[i1 >> 2] | 0;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i9 = i7;
 i10 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i11 >> 2] = i10;
 i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i11, 61712) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
 HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE(i6, i5 + 24 | 0, i1, i8, i3, i4);
 STACKTOP = i7;
 return HEAP32[i1 >> 2] | 0;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i9 = i7;
 i10 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i11 >> 2] = i10;
 i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i11, 61680) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
 HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE(i6, i5 + 16 | 0, i1, i8, i3, i4);
 STACKTOP = i7;
 return HEAP32[i1 >> 2] | 0;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i9 = i7;
 i10 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i11 >> 2] = i10;
 i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i11, 61680) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
 HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE(i6, i5 + 24 | 0, i1, i8, i3, i4);
 STACKTOP = i7;
 return HEAP32[i1 >> 2] | 0;
}

function __ZZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(48) | 0;
   __ZN4wasm15SetLocalRemoverC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(48) | 0;
   __ZN4wasm15GetLocalCounterC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZN6cashew12ValueBuilder15setBlockContentENS_3RefES1_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 do if (!(__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i2, 0) | 0, 59272) | 0)) if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i2, 0) | 0, 59276) | 0) {
  i3 = __ZN6cashew3RefixEj(i2, 3) | 0;
  i3 = HEAP32[i3 >> 2] | 0;
  i2 = __ZN6cashew3RefixEj(i1, 1) | 0;
  __ZN6cashew5Value8setArrayERNSt3__26vectorINS_3RefENS1_9allocatorIS3_EEEE(i3, __ZN6cashew5Value8getArrayEv(HEAP32[i2 >> 2] | 0) | 0) | 0;
  break;
 } else _abort(); else {
  i2 = __ZN6cashew3RefixEj(i2, 1) | 0;
  i2 = HEAP32[i2 >> 2] | 0;
  i3 = __ZN6cashew3RefixEj(i1, 1) | 0;
  __ZN6cashew5Value8setArrayERNSt3__26vectorINS_3RefENS1_9allocatorIS3_EEEE(i2, __ZN6cashew5Value8getArrayEv(HEAP32[i3 >> 2] | 0) | 0) | 0;
 } while (0);
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIPcNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZN4wasm14ModuleInstance10callExportENS_4NameERNSt3__26vectorINS_7LiteralENS2_9allocatorIS4_EEEE(i4, i6, i1, i5) {
 i4 = i4 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 var i2 = 0, i3 = 0, i7 = 0, i8 = 0, i9 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i7 + 8 | 0;
 i9 = i7 + 4 | 0;
 i3 = i7;
 i8 = HEAP32[i6 >> 2] | 0;
 HEAP32[i9 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i2 >> 2] = HEAP32[i9 >> 2];
 i1 = __ZN4wasm6Module11checkExportENS_4NameE(i8, i2) | 0;
 if (!i1) {
  i9 = HEAP32[i6 + 24 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i9 >> 2] | 0) + 20 >> 2] & 1023](i9, 29396);
 }
 HEAP32[i3 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 __ZN4wasm14ModuleInstance12callFunctionEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEE(i4, i6, i2, i5);
 STACKTOP = i7;
 return;
}

function __ZZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(44) | 0;
   __ZN4wasm14PostEmscriptenC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder10makeSelectERNS_7ElementE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i3 = __ZN10MixedArena5allocIN4wasm6SelectEEEPT_v(HEAP32[i2 + 4 >> 2] | 0) | 0;
 i6 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i2, __ZN4wasm7ElementixEj(i1, 1) | 0) | 0;
 i5 = i3 + 8 | 0;
 HEAP32[i5 >> 2] = i6;
 i6 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i2, __ZN4wasm7ElementixEj(i1, 2) | 0) | 0;
 i4 = i3 + 12 | 0;
 HEAP32[i4 >> 2] = i6;
 i2 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i2, __ZN4wasm7ElementixEj(i1, 3) | 0) | 0;
 HEAP32[i3 + 16 >> 2] = i2;
 i2 = HEAP32[(HEAP32[i5 >> 2] | 0) + 4 >> 2] | 0;
 HEAP32[i3 + 4 >> 2] = (i2 | 0) != 5 ? i2 : HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] | 0;
 return i3 | 0;
}

function __ZNKSt3__27codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_(i2, i4, i3, i5, i6) {
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7;
 HEAP32[i6 >> 2] = i3;
 i3 = _uselocale(HEAP32[i2 + 8 >> 2] | 0) | 0;
 i2 = _wcrtomb(i1, 0, i4) | 0;
 if (i3 | 0) _uselocale(i3) | 0;
 L4 : do switch (i2 | 0) {
 case 0:
 case -1:
  {
   i1 = 2;
   break;
  }
 default:
  {
   i2 = i2 + -1 | 0;
   if (i2 >>> 0 > (i5 - (HEAP32[i6 >> 2] | 0) | 0) >>> 0) i1 = 1; else while (1) {
    if (!i2) {
     i1 = 0;
     break L4;
    }
    i4 = HEAP8[i1 >> 0] | 0;
    i5 = HEAP32[i6 >> 2] | 0;
    HEAP32[i6 >> 2] = i5 + 1;
    HEAP8[i5 >> 0] = i4;
    i2 = i2 + -1 | 0;
    i1 = i1 + 1 | 0;
   }
  }
 } while (0);
 STACKTOP = i7;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEE26__swap_out_circular_bufferERNS_14__split_bufferIjRS2_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__26vectorIiNS_9allocatorIiEEE26__swap_out_circular_bufferERNS_14__split_bufferIiRS2_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - (i3 >> 2) << 2) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i9 = i7;
 i10 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i11 >> 2] = i10;
 i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i11, 61712) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
 HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE(i6, i5 + 20 | 0, i1, i8, i3, i4);
 STACKTOP = i7;
 return HEAP32[i1 >> 2] | 0;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i9 = i7;
 i10 = __ZNKSt3__28ios_base6getlocEv(i4) | 0;
 HEAP32[i11 >> 2] = i10;
 i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i11, 61680) | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(i10) | 0;
 HEAP32[i9 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE(i6, i5 + 20 | 0, i1, i8, i3, i4);
 STACKTOP = i7;
 return HEAP32[i1 >> 2] | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i1, i7) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i5 = i1 + 11 | 0;
 i2 = HEAP8[i5 >> 0] | 0;
 i3 = i2 << 24 >> 24 < 0;
 if (i3) {
  i4 = (HEAP32[i1 + 8 >> 2] & 2147483647) + -1 | 0;
  i6 = HEAP32[i1 + 4 >> 2] | 0;
 } else {
  i4 = 10;
  i6 = i2 & 255;
 }
 if ((i6 | 0) == (i4 | 0)) {
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj(i1, i4, 1, i4, i4, 0, 0);
  if ((HEAP8[i5 >> 0] | 0) < 0) i2 = 8; else i2 = 7;
 } else if (i3) i2 = 8; else i2 = 7;
 if ((i2 | 0) == 7) HEAP8[i5 >> 0] = i6 + 1; else if ((i2 | 0) == 8) {
  i5 = HEAP32[i1 >> 2] | 0;
  HEAP32[i1 + 4 >> 2] = i6 + 1;
  i1 = i5;
 }
 i6 = i1 + i6 | 0;
 HEAP8[i6 >> 0] = i7;
 HEAP8[i6 + 1 >> 0] = 0;
 return;
}

function __ZN6cashew12ValueBuilder10makeSwitchENS_3RefE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i2 + 12 | 0;
 i7 = i2 + 8 | 0;
 i6 = i2 + 4 | 0;
 i4 = i2;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(3) | 0;
 i8 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59364) | 0;
 HEAP32[i7 >> 2] = i8;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 i5 = __ZN6cashew5Value9push_backENS_3RefE(i5, i3) | 0;
 HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i5, i3) | 0;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
 HEAP32[i4 >> 2] = i5;
 HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i1, i3) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm11BreakSeeker3hasEPNS_10ExpressionENS_4NameE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 48 | 0;
 i5 = i3;
 i4 = i3 + 4 | 0;
 HEAP32[i5 >> 2] = i2;
 i2 = HEAP32[i1 >> 2] | 0;
 i1 = i4 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 HEAP32[i1 + 20 >> 2] = 0;
 HEAP32[i4 >> 2] = 4456;
 HEAP32[i4 + 28 >> 2] = i2;
 i2 = i4 + 32 | 0;
 HEAP32[i2 >> 2] = 0;
 __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i4, i5);
 i2 = (HEAP32[i2 >> 2] | 0) != 0;
 HEAP32[i4 >> 2] = 4468;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i4 + 8 | 0);
 STACKTOP = i3;
 return i2 | 0;
}

function __ZZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(44) | 0;
   __ZN4wasm11MergeBlocksC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3 + 16 + -16 + 16 | 0, i5 + 36 | 0);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE(i5, i6, i1, i3, i4, i2) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i7 = 0, i8 = 0, i9 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 4 | 0;
 i9 = i7;
 i5 = i5 + 8 | 0;
 i5 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 4 >> 2] & 255](i5) | 0;
 HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 i1 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb(i1, i8, i5, i5 + 288 | 0, i2, i4, 0) | 0) - i5 | 0;
 if ((i1 | 0) < 288) HEAP32[i6 >> 2] = ((i1 | 0) / 12 | 0 | 0) % 12 | 0;
 STACKTOP = i7;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE(i5, i6, i1, i3, i4, i2) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i7 = 0, i8 = 0, i9 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 4 | 0;
 i9 = i7;
 i5 = i5 + 8 | 0;
 i5 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i5 >> 2] | 0) + 4 >> 2] & 255](i5) | 0;
 HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 i1 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb(i1, i8, i5, i5 + 288 | 0, i2, i4, 0) | 0) - i5 | 0;
 if ((i1 | 0) < 288) HEAP32[i6 >> 2] = ((i1 | 0) / 12 | 0 | 0) % 12 | 0;
 STACKTOP = i7;
 return;
}

function __ZN6cashew12ValueBuilder8makeCallENS_3RefE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i2 + 12 | 0;
 i7 = i2 + 8 | 0;
 i6 = i2 + 4 | 0;
 i4 = i2;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(3) | 0;
 i8 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59344) | 0;
 HEAP32[i7 >> 2] = i8;
 HEAP32[i3 >> 2] = HEAP32[i7 >> 2];
 i5 = __ZN6cashew5Value9push_backENS_3RefE(i5, i3) | 0;
 HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i5, i3) | 0;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
 HEAP32[i4 >> 2] = i5;
 HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i1, i3) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZN4wasm11MergeBlocks10handleCallINS_12CallIndirectEEEvPT_PNS_5BlockE(i7, i6, i1) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i3 = i8;
 i4 = i6 + 8 | 0;
 i5 = i6 + 16 | 0;
 i2 = 0;
 while (1) {
  if (i2 >>> 0 >= (HEAP32[i5 >> 2] | 0) >>> 0) break;
  i1 = __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i7, i6, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i4, i2) | 0, i1, 0, 0) | 0;
  i9 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i4, i2) | 0;
  __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i3, HEAP32[i9 >> 2] | 0);
  i9 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i3) | 0;
  __ZN4wasm14EffectAnalyzerD2Ev(i3);
  if (i9) break; else i2 = i2 + 1 | 0;
 }
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE24__emplace_back_slow_pathIJRPFvPS6_PPNS1_10ExpressionEERSI_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE24__emplace_back_slow_pathIJRPFvPS6_PPNS1_10ExpressionEERSI_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm11MergeBlocks10handleCallINS_10CallImportEEEvPT_PNS_5BlockE(i7, i6, i1) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i3 = i8;
 i4 = i6 + 8 | 0;
 i5 = i6 + 16 | 0;
 i2 = 0;
 while (1) {
  if (i2 >>> 0 >= (HEAP32[i5 >> 2] | 0) >>> 0) break;
  i1 = __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i7, i6, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i4, i2) | 0, i1, 0, 0) | 0;
  i9 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i4, i2) | 0;
  __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i3, HEAP32[i9 >> 2] | 0);
  i9 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i3) | 0;
  __ZN4wasm14EffectAnalyzerD2Ev(i3);
  if (i9) break; else i2 = i2 + 1 | 0;
 }
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZNKSt3__220__time_get_c_storageIwE7__am_pmEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if ((HEAP8[58672] | 0) == 0 ? ___cxa_guard_acquire(58672) | 0 : 0) {
  if ((HEAP8[58680] | 0) == 0 ? ___cxa_guard_acquire(58680) | 0 : 0) {
   i1 = 63028;
   do {
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i1 = i1 + 12 | 0;
   } while ((i1 | 0) != 63316);
   ___cxa_atexit(298, 0, ___dso_handle | 0) | 0;
  }
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(63028, 14088) | 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(63040, 14100) | 0;
  HEAP32[15829] = 63028;
 }
 return HEAP32[15829] | 0;
}

function __ZNKSt3__220__time_get_c_storageIcE7__am_pmEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if ((HEAP8[58592] | 0) == 0 ? ___cxa_guard_acquire(58592) | 0 : 0) {
  if ((HEAP8[58600] | 0) == 0 ? ___cxa_guard_acquire(58600) | 0 : 0) {
   i1 = 62216;
   do {
    HEAP32[i1 >> 2] = 0;
    HEAP32[i1 + 4 >> 2] = 0;
    HEAP32[i1 + 8 >> 2] = 0;
    i2 = 0;
    while (1) {
     if ((i2 | 0) == 3) break;
     HEAP32[i1 + (i2 << 2) >> 2] = 0;
     i2 = i2 + 1 | 0;
    }
    i1 = i1 + 12 | 0;
   } while ((i1 | 0) != 62504);
   ___cxa_atexit(294, 0, ___dso_handle | 0) | 0;
  }
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62216, 53978) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(62228, 53981) | 0;
  HEAP32[15626] = 62216;
 }
 return HEAP32[15626] | 0;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26vectorIcNS_9allocatorIcEEE26__swap_out_circular_bufferERNS_14__split_bufferIcRS2_EE(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = HEAP32[i7 >> 2] | 0;
 i5 = i7 + 4 | 0;
 i4 = i6 + 4 | 0;
 i3 = (HEAP32[i5 >> 2] | 0) - i2 | 0;
 i1 = (HEAP32[i4 >> 2] | 0) + (0 - i3) | 0;
 HEAP32[i4 >> 2] = i1;
 if ((i3 | 0) > 0) {
  _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
  i2 = i4;
  i1 = HEAP32[i4 >> 2] | 0;
 } else i2 = i4;
 i4 = HEAP32[i7 >> 2] | 0;
 HEAP32[i7 >> 2] = i1;
 HEAP32[i2 >> 2] = i4;
 i4 = i6 + 8 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = i3;
 i4 = i7 + 8 | 0;
 i7 = i6 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i7 >> 2] = i5;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 return;
}

function __ZNSt3__2plIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEENS_12basic_stringIT_T0_T1_EERKSB_PKS8_(i4, i2, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i5 = 0, i6 = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i4 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i5 = HEAP8[i2 + 11 >> 0] | 0;
 i6 = i5 << 24 >> 24 < 0;
 i5 = i6 ? HEAP32[i2 + 4 >> 2] | 0 : i5 & 255;
 i1 = _strlen(i3) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcjj(i4, i6 ? HEAP32[i2 >> 2] | 0 : i2, i5, i5 + i1 | 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i4, i3, i1) | 0;
 return;
}

function __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEEC2EOS9_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i4 = HEAP32[i1 >> 2] | 0;
 HEAP32[i1 >> 2] = 0;
 i6 = i1 + 4 | 0;
 i5 = HEAP32[i6 >> 2] | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i2 >> 2] = i4;
 HEAP32[i2 + 4 >> 2] = i5;
 i6 = i2 + 8 | 0;
 i7 = i1 + 8 | 0;
 i3 = HEAP32[i7 >> 2] | 0;
 HEAP32[i6 >> 2] = i3;
 i8 = i1 + 12 | 0;
 i9 = HEAP32[i8 >> 2] | 0;
 HEAP32[i2 + 12 >> 2] = i9;
 HEAP32[i2 + 16 >> 2] = HEAP32[i1 + 16 >> 2];
 if (i9 | 0) {
  i1 = HEAP32[i3 + 4 >> 2] | 0;
  i2 = i5 + -1 | 0;
  if (!(i2 & i5)) i1 = i2 & i1; else i1 = (i1 >>> 0) % (i5 >>> 0) | 0;
  HEAP32[i4 + (i1 << 2) >> 2] = i6;
  HEAP32[i7 >> 2] = 0;
  HEAP32[i8 >> 2] = 0;
 }
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE(i5, i6, i1, i3, i4, i2) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i7 = 0, i8 = 0, i9 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 4 | 0;
 i9 = i7;
 i5 = i5 + 8 | 0;
 i5 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i5 >> 2] >> 2] & 255](i5) | 0;
 HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 i1 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb(i1, i8, i5, i5 + 168 | 0, i2, i4, 0) | 0) - i5 | 0;
 if ((i1 | 0) < 168) HEAP32[i6 >> 2] = ((i1 | 0) / 12 | 0 | 0) % 7 | 0;
 STACKTOP = i7;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE(i5, i6, i1, i3, i4, i2) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i7 = 0, i8 = 0, i9 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 4 | 0;
 i9 = i7;
 i5 = i5 + 8 | 0;
 i5 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i5 >> 2] >> 2] & 255](i5) | 0;
 HEAP32[i9 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i9 >> 2];
 i1 = (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb(i1, i8, i5, i5 + 168 | 0, i2, i4, 0) | 0) - i5 | 0;
 if ((i1 | 0) < 168) HEAP32[i6 >> 2] = ((i1 | 0) / 12 | 0 | 0) % 7 | 0;
 STACKTOP = i7;
 return;
}

function __ZN4wasm11MergeBlocks10handleCallINS_4CallEEEvPT_PNS_5BlockE(i7, i6, i1) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i8 = 0, i9 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i3 = i8;
 i4 = i6 + 8 | 0;
 i5 = i6 + 16 | 0;
 i2 = 0;
 while (1) {
  if (i2 >>> 0 >= (HEAP32[i5 >> 2] | 0) >>> 0) break;
  i1 = __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i7, i6, __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i4, i2) | 0, i1, 0, 0) | 0;
  i9 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i4, i2) | 0;
  __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i3, HEAP32[i9 >> 2] | 0);
  i9 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i3) | 0;
  __ZN4wasm14EffectAnalyzerD2Ev(i3);
  if (i9) break; else i2 = i2 + 1 | 0;
 }
 STACKTOP = i8;
 return;
}

function __ZN4wasm12PassRegistry10createPassENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if ((__ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE4findIS7_EENS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEERKT_(i2, i1) | 0) == (i2 + 4 | 0)) i1 = 0; else {
  i2 = __ZNKSt3__28functionIFPN4wasm4PassEvEEclEv((__ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_(i2, i1) | 0) + 16 | 0) | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_(i2 + 4 | 0, i1) | 0;
  i1 = i2;
 }
 return i1 | 0;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE8pushTaskEPFvPS4_PPNS_10ExpressionEESB_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEE24__emplace_back_slow_pathIJRPFvPS6_PPNS1_10ExpressionEERSI_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwi(i8, i1, i7) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0;
 i5 = i8 + 24 | 0;
 i6 = i8 + 28 | 0;
 i2 = i1;
 i1 = 0;
 while (1) {
  if ((i1 | 0) >= (i7 | 0)) break;
  i3 = HEAP32[i5 >> 2] | 0;
  i4 = HEAP32[i6 >> 2] | 0;
  if (i3 >>> 0 < i4 >>> 0) {
   i4 = i4 - i3 >> 2;
   i9 = i7 - i1 | 0;
   i4 = (i9 | 0) < (i4 | 0) ? i9 : i4;
   __ZNSt3__211char_traitsIwE4copyEPwPKwj(i3, i2, i4) | 0;
   HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + (i4 << 2);
   i2 = i2 + (i4 << 2) | 0;
   i1 = i4 + i1 | 0;
   continue;
  }
  if ((FUNCTION_TABLE_iii[HEAP32[(HEAP32[i8 >> 2] | 0) + 52 >> 2] & 63](i8, HEAP32[i2 >> 2] | 0) | 0) == -1) break;
  i2 = i2 + 4 | 0;
  i1 = i1 + 1 | 0;
 }
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13maybePushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i1, i2) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i8 + 4 | 0;
 i6 = i8;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i6 >> 2] = i2;
 i4 = i2;
 do if (HEAP32[i2 >> 2] | 0) {
  i2 = i7 + 12 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i3 + 4 >> 2] = i4;
   HEAP32[i2 >> 2] = i3 + 8;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i5, i6);
   break;
  }
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZN4wasm14SimplifyLocals16doNoteIfElseTrueEPS0_PPNS_10ExpressionE(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i3 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0) + 16 | 0;
 if (!(HEAP32[i3 >> 2] | 0)) ___assert_fail(42111, 41949, 143, 42141);
 i1 = i4 + 44 | 0;
 i2 = i4 + 84 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (i3 >>> 0 < (HEAP32[i4 + 88 >> 2] | 0) >>> 0) {
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEEC2EOSC_(i3, i1);
  HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 12;
 } else __ZNSt3__26vectorINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEE21__push_back_slow_pathISC_EEvOT_(i4 + 80 | 0, i1);
 return;
}

function __ZN6cashew12ValueBuilder12makeIndexingENS_3RefES1_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 12 | 0;
 i8 = i3 + 8 | 0;
 i7 = i3 + 4 | 0;
 i5 = i3;
 i6 = __ZN6cashew12ValueBuilder12makeRawArrayEi(3) | 0;
 i9 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59340) | 0;
 HEAP32[i8 >> 2] = i9;
 HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
 i6 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 HEAP32[i7 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 HEAP32[i5 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i2, i4) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZN4wasm5Block8finalizeEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i1 = i6 + 56 | 0;
 i4 = i6 + 8 | 0;
 i2 = i6;
 i3 = HEAP32[i5 + 8 >> 2] | 0;
 do if (!i3) if (!(HEAP32[i5 + 20 >> 2] | 0)) {
  HEAP32[i5 + 4 >> 2] = 5;
  break;
 } else {
  i4 = __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i5 + 12 | 0) | 0;
  HEAP32[i5 + 4 >> 2] = HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2];
  break;
 } else {
  HEAP32[i2 >> 2] = i3;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN4wasm10TypeSeekerC2EPNS_10ExpressionENS_4NameE(i4, i5, i1);
  i3 = __ZN4wasmL10mergeTypesERNSt3__26vectorINS_8WasmTypeENS0_9allocatorIS2_EEEE(i4 + 36 | 0) | 0;
  HEAP32[i5 + 4 >> 2] = i3;
  __ZN4wasm10TypeSeekerD2Ev(i4);
 } while (0);
 STACKTOP = i6;
 return;
}

function __ZN4wasm19DeadCodeElimination9visitLoopEPNS_4LoopE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0;
 i1 = i5 + 12 | 0;
 if (HEAP32[i1 >> 2] | 0) __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__erase_uniqueIS2_EEjRKT_(i6 + 48 | 0, i1) | 0;
 i3 = i5 + 8 | 0;
 if (HEAP32[i3 >> 2] | 0) {
  i4 = i6 + 44 | 0;
  i1 = i6 + 48 | 0;
  if (!(HEAP8[i4 >> 0] | 0)) i2 = (__ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(i1, i3) | 0) != 0 & 1; else i2 = 1;
  HEAP8[i4 >> 0] = i2;
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__erase_uniqueIS2_EEjRKT_(i1, i3) | 0;
 }
 i5 = HEAP32[i5 + 16 >> 2] | 0;
 i1 = i5;
 if (i5 | 0 ? (HEAP32[i5 >> 2] | 0) == 20 : 0) HEAP32[i6 + 20 >> 2] = i1;
 return;
}

function __ZN6cashew12ValueBuilder9makeWhileENS_3RefES1_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 12 | 0;
 i8 = i3 + 8 | 0;
 i7 = i3 + 4 | 0;
 i5 = i3;
 i6 = __ZN6cashew12ValueBuilder12makeRawArrayEi(3) | 0;
 i9 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59324) | 0;
 HEAP32[i8 >> 2] = i9;
 HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
 i6 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 HEAP32[i7 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 HEAP32[i5 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i2, i4) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZN6cashew12ValueBuilder6makeDoENS_3RefES1_(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 12 | 0;
 i8 = i3 + 8 | 0;
 i7 = i3 + 4 | 0;
 i5 = i3;
 i6 = __ZN6cashew12ValueBuilder12makeRawArrayEi(3) | 0;
 i9 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59328) | 0;
 HEAP32[i8 >> 2] = i9;
 HEAP32[i4 >> 2] = HEAP32[i8 >> 2];
 i6 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 HEAP32[i7 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i7 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i6, i4) | 0;
 HEAP32[i5 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i2, i4) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(72) | 0;
   __ZN4wasm15RemoveUnusedBrsC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionE(i3 + 16 + -16 | 0, i5);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKci(i8, i1, i7) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i9 = 0;
 i5 = i8 + 24 | 0;
 i6 = i8 + 28 | 0;
 i4 = i1;
 i1 = 0;
 while (1) {
  if ((i1 | 0) >= (i7 | 0)) break;
  i2 = HEAP32[i5 >> 2] | 0;
  i3 = HEAP32[i6 >> 2] | 0;
  if (i2 >>> 0 >= i3 >>> 0) {
   if ((FUNCTION_TABLE_iii[HEAP32[(HEAP32[i8 >> 2] | 0) + 52 >> 2] & 63](i8, HEAPU8[i4 >> 0] | 0) | 0) == -1) break;
   i4 = i4 + 1 | 0;
   i1 = i1 + 1 | 0;
   continue;
  }
  i3 = i3 - i2 | 0;
  i9 = i7 - i1 | 0;
  i3 = (i9 | 0) < (i3 | 0) ? i9 : i3;
  if (i3) {
   _memcpy(i2 | 0, i4 | 0, i3 | 0) | 0;
   i2 = HEAP32[i5 >> 2] | 0;
  }
  HEAP32[i5 >> 2] = i2 + i3;
  i4 = i4 + i3 | 0;
  i1 = i3 + i1 | 0;
 }
 return i1 | 0;
}

function __ZZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(132) | 0;
   __ZN4wasm14SimplifyLocalsC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm14SimplifyLocals14doWalkFunctionEPNS_8FunctionE(i3 + 16 + -16 | 0, i5);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i1, i6, i2, i5) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i3 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 do if (!i2) {
  i1 = FUNCTION_TABLE_ii[HEAP32[HEAP32[i1 >> 2] >> 2] & 255](i1) | 0;
  if (!i1) {
   i1 = __Znwj(148) | 0;
   __ZN4wasm14CoalesceLocalsC2Ev(i1);
  }
  if (!i6) ___assert_fail(49074, 49642, 221, 57137); else {
   HEAP32[i1 + 40 >> 2] = i6;
   i3 = i1;
   i4 = i1;
   break;
  }
 } else {
  i3 = i2;
  i4 = 0;
 } while (0);
 HEAP32[i3 + 36 >> 2] = i5;
 __ZN4wasm14CoalesceLocals14doWalkFunctionEPNS_8FunctionE(i3 + 16 + -16 | 0, i5);
 if (i4 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i4 >> 2] | 0) + 4 >> 2] & 511](i4);
 return;
}

function __ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlvE_clEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i6;
 i1 = (HEAP32[i5 >> 2] | 0) + 4 | 0;
 HEAP32[i4 >> 2] = HEAP32[(HEAP32[i1 >> 2] | 0) + -4 >> 2];
 i3 = HEAP32[i1 >> 2] | 0;
 i2 = i3 + -4 | 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  i7 = i3 + -4 | 0;
  HEAP32[i1 >> 2] = i7;
  i3 = i7;
 }
 i1 = (__ZNSt3__23mapIN4wasm4NameENS_6vectorIS2_NS_9allocatorIS2_EEEENS_4lessIS2_EENS4_INS_4pairIKS2_S6_EEEEEixERSA_(HEAP32[i5 + 4 >> 2] | 0, i4) | 0) + 4 | 0;
 i3 = HEAP32[i1 >> 2] | 0;
 i2 = i3 + -4 | 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  i7 = i3 + -4 | 0;
  HEAP32[i1 >> 2] = i7;
  i3 = i7;
 }
 STACKTOP = i6;
 return;
}

function __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE25__emplace_unique_key_argsIjJRKjEEENS_4pairINS_15__tree_iteratorIjPNS_11__tree_nodeIjPvEEiEEbEERKT_DpOT0_(i6, i5, i1, i3) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i7;
 i2 = __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE12__find_equalIjEERPNS_16__tree_node_baseIPvEESB_RKT_(i5, i4, i1) | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) {
  i1 = __Znwj(20) | 0;
  HEAP32[i1 + 16 >> 2] = HEAP32[i3 >> 2];
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE16__insert_node_atEPNS_16__tree_node_baseIPvEERS9_S9_(i5, HEAP32[i4 >> 2] | 0, i2, i1);
  i2 = 1;
 } else i2 = 0;
 HEAP32[i6 >> 2] = i1;
 HEAP8[i6 + 4 >> 0] = i2;
 STACKTOP = i7;
 return;
}

function __ZNK4wasm7LiteraleqERKS0_(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i2 = HEAP32[i4 >> 2] | 0;
 L1 : do if ((i2 | 0) == (HEAP32[i3 >> 2] | 0)) switch (i2 | 0) {
 case 0:
  {
   i1 = 1;
   break L1;
  }
 case 1:
  {
   i1 = (HEAP32[i4 + 8 >> 2] | 0) == (HEAP32[i3 + 8 >> 2] | 0);
   break L1;
  }
 case 3:
  {
   i1 = +__ZNK4wasm7Literal6getf32Ev(i4) == +__ZNK4wasm7Literal6getf32Ev(i3);
   break L1;
  }
 case 2:
  {
   i4 = i4 + 8 | 0;
   i1 = i3 + 8 | 0;
   i1 = (HEAP32[i4 >> 2] | 0) == (HEAP32[i1 >> 2] | 0) ? (HEAP32[i4 + 4 >> 2] | 0) == (HEAP32[i1 + 4 >> 2] | 0) : 0;
   break L1;
  }
 case 4:
  {
   i1 = +__ZNK4wasm7Literal6getf64Ev(i4) == +__ZNK4wasm7Literal6getf64Ev(i3);
   break L1;
  }
 default:
  _abort();
 } else i1 = 0; while (0);
 return i1 | 0;
}

function __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlvE_clEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i6;
 i1 = (HEAP32[i5 >> 2] | 0) + 4 | 0;
 HEAP32[i4 >> 2] = HEAP32[(HEAP32[i1 >> 2] | 0) + -4 >> 2];
 i3 = HEAP32[i1 >> 2] | 0;
 i2 = i3 + -4 | 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  i7 = i3 + -4 | 0;
  HEAP32[i1 >> 2] = i7;
  i3 = i7;
 }
 i1 = (__ZNSt3__23mapIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEENS_4lessIS2_EENS4_INS_4pairIKS2_S6_EEEEEixERSA_(HEAP32[i5 + 4 >> 2] | 0, i4) | 0) + 4 | 0;
 i3 = HEAP32[i1 >> 2] | 0;
 i2 = i3 + -4 | 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  i7 = i3 + -4 | 0;
  HEAP32[i1 >> 2] = i7;
  i3 = i7;
 }
 STACKTOP = i6;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZNSt3__213__vector_baseIPN4wasm8FunctionENS_9allocatorIS3_EEED2Ev(i1 + 20 | 0);
  __ZdlPv(i1);
  return;
 }
}

function ___remdi3(i1, i2, i3, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i5 | 0;
 i7 = i2 >> 31 | ((i2 | 0) < 0 ? -1 : 0) << 1;
 i6 = ((i2 | 0) < 0 ? -1 : 0) >> 31 | ((i2 | 0) < 0 ? -1 : 0) << 1;
 i10 = i4 >> 31 | ((i4 | 0) < 0 ? -1 : 0) << 1;
 i9 = ((i4 | 0) < 0 ? -1 : 0) >> 31 | ((i4 | 0) < 0 ? -1 : 0) << 1;
 i1 = _i64Subtract(i7 ^ i1 | 0, i6 ^ i2 | 0, i7 | 0, i6 | 0) | 0;
 i2 = tempRet0;
 ___udivmoddi4(i1, i2, _i64Subtract(i10 ^ i3 | 0, i9 ^ i4 | 0, i10 | 0, i9 | 0) | 0, tempRet0, i8) | 0;
 i4 = _i64Subtract(HEAP32[i8 >> 2] ^ i7 | 0, HEAP32[i8 + 4 >> 2] ^ i6 | 0, i7 | 0, i6 | 0) | 0;
 i3 = tempRet0;
 STACKTOP = i5;
 return (tempRet0 = i3, i4) | 0;
}

function __ZNSt3__26vectorIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEE5eraseENS_11__wrap_iterIPKS9_EESG_(i4, i1, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i5 = 0, i6 = 0;
 i6 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 i6 = i6 + (i2 - i6 >> 2 << 2) | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 L1 : do if ((i2 | 0) != (i1 | 0)) {
  i3 = i6 + (i1 - i2 >> 2 << 2) | 0;
  i5 = i4 + 4 | 0;
  i1 = HEAP32[i5 >> 2] | 0;
  i2 = i1 - i3 | 0;
  i4 = i2 >> 2;
  if (i4) {
   _memmove(i6 | 0, i3 | 0, i2 | 0) | 0;
   i1 = HEAP32[i5 >> 2] | 0;
  }
  i2 = i6 + (i4 << 2) | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break L1;
   i4 = i1 + -4 | 0;
   HEAP32[i5 >> 2] = i4;
   i1 = i4;
  }
 } while (0);
 return i6 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZNSt3__213__vector_baseIN4wasm4NameENS_9allocatorIS2_EEED2Ev(i1 + 20 | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEEEN16ExpressionRunner9visitLoopEPNS_4LoopE(i6, i8, i7) {
 i6 = i6 | 0;
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i9 = 0;
 i2 = i7 + 16 | 0;
 i3 = i6 + 16 | 0;
 i4 = i7 + 12 | 0;
 while (1) {
  __ZN4wasm7VisitorIZNS_14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS4_9allocatorIS6_EEEEE16ExpressionRunnerNS_4FlowEE5visitEPNS_10ExpressionE(i6, i8, HEAP32[i2 >> 2] | 0);
  i5 = HEAP32[i3 >> 2] | 0;
  if (!i5) break;
  if ((i5 | 0) != (HEAP32[i4 >> 2] | 0)) {
   i1 = i5;
   i9 = 4;
   break;
  }
 }
 if ((i9 | 0) == 4 ? (i1 | 0) == (HEAP32[i7 + 8 >> 2] | 0) : 0) HEAP32[i3 >> 2] = 0;
 return;
}

function __ZNSt3__26vectorIbNS_9allocatorIbEEE9push_backERKb(i4, i5) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i3 = i4 + 4 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 i2 = HEAP32[i4 + 8 >> 2] | 0;
 if ((i1 | 0) == (i2 << 5 | 0)) {
  if ((i1 + 1 | 0) < 0) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i4);
  if (i2 << 5 >>> 0 > 1073741822) i1 = 2147483647; else {
   i2 = i2 << 6;
   i1 = i1 + 32 & -32;
   i1 = i2 >>> 0 < i1 >>> 0 ? i1 : i2;
  }
  __ZNSt3__26vectorIbNS_9allocatorIbEEE7reserveEj(i4, i1);
  i1 = HEAP32[i3 >> 2] | 0;
 }
 HEAP32[i3 >> 2] = i1 + 1;
 i2 = (HEAP32[i4 >> 2] | 0) + (i1 >>> 5 << 2) | 0;
 i1 = 1 << (i1 & 31);
 if (!(HEAP8[i5 >> 0] | 0)) i1 = HEAP32[i2 >> 2] & ~i1; else i1 = HEAP32[i2 >> 2] | i1;
 HEAP32[i2 >> 2] = i1;
 return;
}

function __ZNSt3__214__num_put_base12__format_intEPcPKcbj(i1, i2, i5, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i3 = 0;
 if (i4 & 2048) {
  HEAP8[i1 >> 0] = 43;
  i1 = i1 + 1 | 0;
 }
 if (!(i4 & 512)) i3 = i2; else {
  HEAP8[i1 >> 0] = 35;
  i3 = i2;
  i1 = i1 + 1 | 0;
 }
 while (1) {
  i2 = HEAP8[i3 >> 0] | 0;
  if (!(i2 << 24 >> 24)) break;
  HEAP8[i1 >> 0] = i2;
  i3 = i3 + 1 | 0;
  i1 = i1 + 1 | 0;
 }
 L10 : do switch (i4 & 74 | 0) {
 case 64:
  {
   HEAP8[i1 >> 0] = 111;
   break;
  }
 case 8:
  if (!(i4 & 16384)) {
   HEAP8[i1 >> 0] = 120;
   break L10;
  } else {
   HEAP8[i1 >> 0] = 88;
   break L10;
  }
 default:
  if (i5) {
   HEAP8[i1 >> 0] = 100;
   break L10;
  } else {
   HEAP8[i1 >> 0] = 117;
   break L10;
  }
 } while (0);
 return;
}

function __ZN4wasm17WasmBinaryBuilder16visitUnreachableEPNS_11UnreachableE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i2;
 if (HEAP8[i3 + 12 >> 0] | 0) {
  i3 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24625) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i3 + (HEAP32[(HEAP32[i3 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i3, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i3) | 0;
 }
 STACKTOP = i2;
 return;
}

function __ZN4wasm17WasmBinaryBuilderD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1 + 112 | 0);
 __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i1 + 96 | 0);
 __ZNSt3__213__vector_baseIN4wasm4NameENS_9allocatorIS2_EEED2Ev(i1 + 84 | 0);
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEED2Ev(i1 + 72 | 0);
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEED2Ev(i1 + 52 | 0);
 __ZNSt3__213__vector_baseIPN4wasm8FunctionENS_9allocatorIS3_EEED2Ev(i1 + 40 | 0);
 __ZNSt3__213__vector_baseIPN4wasm12FunctionTypeENS_9allocatorIS3_EEED2Ev(i1 + 24 | 0);
 return;
}

function __ZNSt3__23mapIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS5_EEEENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S8_EEEEEixERSD_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSM_IJEEEEEENS_4pairINS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function _fputc(i5, i6) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 if ((HEAP32[i6 + 76 >> 2] | 0) >= 0 ? (___lockfile(i6) | 0) != 0 : 0) {
  if ((HEAP8[i6 + 75 >> 0] | 0) != (i5 | 0) ? (i2 = i6 + 20 | 0, i3 = HEAP32[i2 >> 2] | 0, i3 >>> 0 < (HEAP32[i6 + 16 >> 2] | 0) >>> 0) : 0) {
   HEAP32[i2 >> 2] = i3 + 1;
   HEAP8[i3 >> 0] = i5;
   i1 = i5 & 255;
  } else i1 = ___overflow(i6, i5) | 0;
  ___unlockfile(i6);
 } else i7 = 3;
 do if ((i7 | 0) == 3) {
  if ((HEAP8[i6 + 75 >> 0] | 0) != (i5 | 0) ? (i4 = i6 + 20 | 0, i1 = HEAP32[i4 >> 2] | 0, i1 >>> 0 < (HEAP32[i6 + 16 >> 2] | 0) >>> 0) : 0) {
   HEAP32[i4 >> 2] = i1 + 1;
   HEAP8[i1 >> 0] = i5;
   i1 = i5 & 255;
   break;
  }
  i1 = ___overflow(i6, i5) | 0;
 } while (0);
 return i1 | 0;
}

function __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw(i4, i2, i1, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i5 = 0, i6 = 0, i7 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i5;
 i2 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i6 >> 2] = i2;
 i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61712) | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i7 >> 2] | 0) + 48 >> 2] & 7](i7, 53246, 53272, i1) | 0;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61720) | 0;
 i6 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 255](i1) | 0;
 HEAP32[i3 >> 2] = i6;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 1023](i4, i1);
 __ZNSt3__214__shared_count16__release_sharedEv(i2) | 0;
 STACKTOP = i5;
 return;
}

function __ZNK4wasm7Literal4rotRERKS0_(i4, i3, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i5 = 0, i6 = 0, i7 = 0;
 i1 = i3 + 8 | 0;
 if ((HEAP32[i3 >> 2] | 0) == 1) {
  i3 = HEAP32[i1 >> 2] | 0;
  i1 = HEAP32[i2 + 8 >> 2] | 0;
  HEAP32[i4 + 8 >> 2] = i3 >>> (i1 & 31) | i3 << (0 - i1 & 31);
  i1 = 1;
 } else {
  i6 = HEAP32[i1 >> 2] | 0;
  i1 = HEAP32[i1 + 4 >> 2] | 0;
  i2 = i2 + 8 | 0;
  i7 = HEAP32[i2 >> 2] | 0;
  i2 = HEAP32[i2 + 4 >> 2] | 0;
  i5 = _bitshift64Lshr(i6 | 0, i1 | 0, i7 & 63 | 0) | 0;
  i3 = tempRet0;
  i2 = _i64Subtract(0, 0, i7 | 0, i2 | 0) | 0;
  i2 = _bitshift64Shl(i6 | 0, i1 | 0, i2 & 63 | 0) | 0;
  i1 = i4 + 8 | 0;
  HEAP32[i1 >> 2] = i5 | i2;
  HEAP32[i1 + 4 >> 2] = i3 | tempRet0;
  i1 = 2;
 }
 HEAP32[i4 >> 2] = i1;
 return;
}

function __ZNK4wasm7Literal4rotLERKS0_(i4, i3, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i5 = 0, i6 = 0, i7 = 0;
 i1 = i3 + 8 | 0;
 if ((HEAP32[i3 >> 2] | 0) == 1) {
  i3 = HEAP32[i1 >> 2] | 0;
  i1 = HEAP32[i2 + 8 >> 2] | 0;
  HEAP32[i4 + 8 >> 2] = i3 << (i1 & 31) | i3 >>> (0 - i1 & 31);
  i1 = 1;
 } else {
  i6 = HEAP32[i1 >> 2] | 0;
  i1 = HEAP32[i1 + 4 >> 2] | 0;
  i2 = i2 + 8 | 0;
  i7 = HEAP32[i2 >> 2] | 0;
  i2 = HEAP32[i2 + 4 >> 2] | 0;
  i5 = _bitshift64Shl(i6 | 0, i1 | 0, i7 & 63 | 0) | 0;
  i3 = tempRet0;
  i2 = _i64Subtract(0, 0, i7 | 0, i2 | 0) | 0;
  i2 = _bitshift64Lshr(i6 | 0, i1 | 0, i2 & 63 | 0) | 0;
  i1 = i4 + 8 | 0;
  HEAP32[i1 >> 2] = i5 | i2;
  HEAP32[i1 + 4 >> 2] = i3 | tempRet0;
  i1 = 2;
 }
 HEAP32[i4 >> 2] = i1;
 return;
}

function __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc(i4, i2, i1, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i5 = 0, i6 = 0, i7 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i5;
 i2 = __ZNKSt3__28ios_base6getlocEv(i2) | 0;
 HEAP32[i6 >> 2] = i2;
 i7 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61680) | 0;
 FUNCTION_TABLE_iiiii[HEAP32[(HEAP32[i7 >> 2] | 0) + 32 >> 2] & 7](i7, 53246, 53272, i1) | 0;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i6, 61692) | 0;
 i6 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 255](i1) | 0;
 HEAP8[i3 >> 0] = i6;
 FUNCTION_TABLE_vii[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 1023](i4, i1);
 __ZNSt3__214__shared_count16__release_sharedEv(i2) | 0;
 STACKTOP = i5;
 return;
}

function __ZNSt3__26vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEEC2EjRKS3_RKS5_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0;
 HEAP32[i3 >> 2] = 0;
 i4 = i3 + 4 | 0;
 HEAP32[i4 >> 2] = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 HEAP32[i3 + 8 >> 2] = 0;
 HEAP32[i3 + 12 >> 2] = i1;
 i1 = __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE8allocateEj(i1, 24) | 0;
 HEAP32[i4 >> 2] = i1;
 HEAP32[i3 >> 2] = i1;
 HEAP32[i3 + 8 >> 2] = i1 + 24;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1, i2);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i1 + 12 | 0, i2 + 12 | 0);
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 24;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder14makeCallImportERNS_7ElementE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 4 | 0;
 i7 = i4;
 i3 = __ZN10MixedArena5allocIN4wasm10CallImportEEEPT_v(HEAP32[i2 + 4 >> 2] | 0) | 0;
 i8 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 1) | 0) | 0;
 HEAP32[i3 + 24 >> 2] = i8;
 i6 = HEAP32[i2 >> 2] | 0;
 HEAP32[i7 >> 2] = i8;
 HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
 i5 = (__ZN4wasm6Module9getImportENS_4NameE(i6, i5) | 0) + 12 | 0;
 HEAP32[i3 + 4 >> 2] = HEAP32[(HEAP32[i5 >> 2] | 0) + 4 >> 2];
 __ZN4wasm22SExpressionWasmBuilder17parseCallOperandsINS_10CallImportEEEvRNS_7ElementEjPT_(i2, i1, 2, i3);
 STACKTOP = i4;
 return i3 | 0;
}

function __ZN4wasm14ModuleInstance12callFunctionEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEE(i6, i9, i8, i7) {
 i6 = i6 | 0;
 i9 = i9 | 0;
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i10 = 0, i11 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i10 + 4 | 0;
 i2 = i10;
 HEAP32[i9 + 4 >> 2] = 0;
 i3 = HEAP32[i9 + 8 >> 2] | 0;
 i4 = i9 + 12 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 while (1) {
  if ((i5 | 0) == (i3 | 0)) break;
  i11 = i5 + -4 | 0;
  HEAP32[i4 >> 2] = i11;
  i5 = i11;
 }
 HEAP32[i2 >> 2] = HEAP32[i8 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
 __ZN4wasm14ModuleInstance20callFunctionInternalEN6cashew7IStringERNSt3__26vectorINS_7LiteralENS3_9allocatorIS5_EEEE(i6, i9, i1, i7);
 STACKTOP = i10;
 return;
}

function __ZN4wasm16PrintSExpression13visitSetLocalEPNS_8SetLocalE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 4 | 0;
 i6 = i3;
 i5 = __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i2 >> 2] | 0, 34753, 0) | 0;
 i7 = __ZN4wasm16PrintSExpression14printableLocalEj(i2, HEAP32[i1 + 8 >> 2] | 0) | 0;
 HEAP32[i6 >> 2] = i7;
 HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
 __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i5, i4) | 0;
 __ZN4wasm16PrintSExpression9incIndentEv(i2);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i2, HEAP32[i1 + 12 >> 2] | 0);
 __ZN4wasm16PrintSExpression9decIndentEv(i2);
 STACKTOP = i3;
 return;
}

function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixERSD_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE25__emplace_unique_key_argsIS7_JRKNS_21piecewise_construct_tENS_5tupleIJRKS7_EEENSM_IJEEEEEENS_4pairINS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65623, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 32 | 0;
}

function __ZNSt3__23mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoENS_4lessIS6_EENS4_INS_4pairIKS6_S9_EEEEEixEOS6_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE25__emplace_unique_key_argsIS7_JRKNS_21piecewise_construct_tENS_5tupleIJOS7_EEENSM_IJEEEEEENS_4pairINS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65623, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 32 | 0;
}

function __ZNSt3__214__fill_n_falseINS_6vectorIbNS_9allocatorIbEEEEEEvNS_14__bit_iteratorIT_Lb0EXLi0EEEENS6_9size_typeE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0;
 i1 = HEAP32[i3 + 4 >> 2] | 0;
 if (!i1) {
  i4 = i3;
  i1 = HEAP32[i3 >> 2] | 0;
 } else {
  i6 = 32 - i1 | 0;
  i4 = i6 >>> 0 > i2 >>> 0 ? i2 : i6;
  i5 = HEAP32[i3 >> 2] | 0;
  HEAP32[i5 >> 2] = HEAP32[i5 >> 2] & ~(-1 >>> (i6 - i4 | 0) & -1 << i1);
  i1 = i5 + 4 | 0;
  HEAP32[i3 >> 2] = i1;
  i2 = i2 - i4 | 0;
  i4 = i3;
 }
 i3 = i2 >>> 5;
 _memset(i1 | 0, 0, i3 << 2 | 0) | 0;
 i1 = i3 << 5;
 if ((i1 | 0) != (i2 | 0)) {
  i6 = (HEAP32[i4 >> 2] | 0) + (i3 << 2) | 0;
  HEAP32[i4 >> 2] = i6;
  HEAP32[i6 >> 2] = HEAP32[i6 >> 2] & ~(-1 >>> (32 - i2 + i1 | 0));
 }
 return;
}

function __ZN4wasm15RemoveUnusedBrs10saveIfTrueEPS0_PPNS_10ExpressionE(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0, i6 = 0;
 i1 = i4 + 48 | 0;
 i2 = i4 + 64 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (i3 >>> 0 < (HEAP32[i4 + 68 >> 2] | 0) >>> 0) {
  HEAP32[i3 >> 2] = 0;
  i6 = i3 + 4 | 0;
  HEAP32[i6 >> 2] = 0;
  HEAP32[i3 + 8 >> 2] = 0;
  HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
  i5 = i4 + 52 | 0;
  HEAP32[i6 >> 2] = HEAP32[i5 >> 2];
  i4 = i4 + 56 | 0;
  HEAP32[i3 + 8 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i4 >> 2] = 0;
  HEAP32[i5 >> 2] = 0;
  HEAP32[i1 >> 2] = 0;
  HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 12;
 } else __ZNSt3__26vectorINS0_IPPN4wasm10ExpressionENS_9allocatorIS4_EEEENS5_IS7_EEE21__push_back_slow_pathIS7_EEvOT_(i4 + 60 | 0, i1);
 return;
}

function __ZNSt3__26vectorIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEE5eraseENS_11__wrap_iterIPKS6_EESD_(i4, i1, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i5 = 0, i6 = 0;
 i6 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 i6 = i6 + (i2 - i6 >> 3 << 3) | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 L1 : do if ((i2 | 0) != (i1 | 0)) {
  i3 = i6 + (i1 - i2 >> 3 << 3) | 0;
  i5 = i4 + 4 | 0;
  i1 = HEAP32[i5 >> 2] | 0;
  i2 = i1 - i3 | 0;
  i4 = i2 >> 3;
  if (i4) {
   _memmove(i6 | 0, i3 | 0, i2 | 0) | 0;
   i1 = HEAP32[i5 >> 2] | 0;
  }
  i2 = i6 + (i4 << 3) | 0;
  while (1) {
   if ((i1 | 0) == (i2 | 0)) break L1;
   i4 = i1 + -8 | 0;
   HEAP32[i5 >> 2] = i4;
   i1 = i4;
  }
 } while (0);
 return i6 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZNSt3__213__vector_baseIPN4wasm4CallENS_9allocatorIS3_EEED2Ev(i1 + 20 | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPKcEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_(i3, i1, i5) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 var i2 = 0, i4 = 0, i6 = 0, i7 = 0;
 i4 = i1;
 i2 = i5 - i4 | 0;
 if (i2 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i3);
 if (i2 >>> 0 < 11) HEAP8[i3 + 11 >> 0] = i2; else {
  i7 = i2 + 16 & -16;
  i6 = __Znwj(i7) | 0;
  HEAP32[i3 >> 2] = i6;
  HEAP32[i3 + 8 >> 2] = i7 | -2147483648;
  HEAP32[i3 + 4 >> 2] = i2;
  i3 = i6;
 }
 i4 = i5 - i4 | 0;
 i2 = i3;
 while (1) {
  if ((i1 | 0) == (i5 | 0)) break;
  HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
  i1 = i1 + 1 | 0;
  i2 = i2 + 1 | 0;
 }
 HEAP8[i3 + i4 >> 0] = 0;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPcEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_(i3, i1, i5) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 var i2 = 0, i4 = 0, i6 = 0, i7 = 0;
 i4 = i1;
 i2 = i5 - i4 | 0;
 if (i2 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i3);
 if (i2 >>> 0 < 11) HEAP8[i3 + 11 >> 0] = i2; else {
  i7 = i2 + 16 & -16;
  i6 = __Znwj(i7) | 0;
  HEAP32[i3 >> 2] = i6;
  HEAP32[i3 + 8 >> 2] = i7 | -2147483648;
  HEAP32[i3 + 4 >> 2] = i2;
  i3 = i6;
 }
 i4 = i5 - i4 | 0;
 i2 = i3;
 while (1) {
  if ((i1 | 0) == (i5 | 0)) break;
  HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
  i1 = i1 + 1 | 0;
  i2 = i2 + 1 | 0;
 }
 HEAP8[i3 + i4 >> 0] = 0;
 return;
}

function __ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i6, i8, i7) {
 i6 = i6 | 0;
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i4 = i6 + 4 | 0;
 i2 = (HEAP32[i4 >> 2] | 0) != 300;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = (HEAP32[i7 >> 2] | 0) - i1 | 0;
 i3 = i3 >>> 0 < 2147483647 ? i3 << 1 : -1;
 i3 = (i3 | 0) == 0 ? 4 : i3;
 i5 = (HEAP32[i8 >> 2] | 0) - i1 >> 2;
 i1 = _realloc(i2 ? i1 : 0, i3) | 0;
 if (!i2) {
  i2 = HEAP32[i6 >> 2] | 0;
  HEAP32[i6 >> 2] = i1;
  if (i2) {
   FUNCTION_TABLE_vi[HEAP32[i4 >> 2] & 511](i2);
   i1 = HEAP32[i6 >> 2] | 0;
  }
 } else HEAP32[i6 >> 2] = i1;
 HEAP32[i4 >> 2] = 301;
 HEAP32[i8 >> 2] = i1 + (i5 << 2);
 HEAP32[i7 >> 2] = (HEAP32[i6 >> 2] | 0) + (i3 >>> 2 << 2);
 return;
}

function __ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i6, i8, i7) {
 i6 = i6 | 0;
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i4 = i6 + 4 | 0;
 i2 = (HEAP32[i4 >> 2] | 0) != 300;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = (HEAP32[i7 >> 2] | 0) - i1 | 0;
 i3 = i3 >>> 0 < 2147483647 ? i3 << 1 : -1;
 i3 = (i3 | 0) == 0 ? 4 : i3;
 i5 = (HEAP32[i8 >> 2] | 0) - i1 >> 2;
 i1 = _realloc(i2 ? i1 : 0, i3) | 0;
 if (!i2) {
  i2 = HEAP32[i6 >> 2] | 0;
  HEAP32[i6 >> 2] = i1;
  if (i2) {
   FUNCTION_TABLE_vi[HEAP32[i4 >> 2] & 511](i2);
   i1 = HEAP32[i6 >> 2] | 0;
  }
 } else HEAP32[i6 >> 2] = i1;
 HEAP32[i4 >> 2] = 301;
 HEAP32[i8 >> 2] = i1 + (i5 << 2);
 HEAP32[i7 >> 2] = (HEAP32[i6 >> 2] | 0) + (i3 >>> 2 << 2);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSQ_SQ_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__213__fill_n_trueINS_6vectorIbNS_9allocatorIbEEEEEEvNS_14__bit_iteratorIT_Lb0EXLi0EEEENS6_9size_typeE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0;
 i1 = HEAP32[i3 + 4 >> 2] | 0;
 if (!i1) {
  i4 = i3;
  i1 = HEAP32[i3 >> 2] | 0;
 } else {
  i6 = 32 - i1 | 0;
  i4 = i6 >>> 0 > i2 >>> 0 ? i2 : i6;
  i5 = HEAP32[i3 >> 2] | 0;
  HEAP32[i5 >> 2] = HEAP32[i5 >> 2] | -1 >>> (i6 - i4 | 0) & -1 << i1;
  i1 = i5 + 4 | 0;
  HEAP32[i3 >> 2] = i1;
  i2 = i2 - i4 | 0;
  i4 = i3;
 }
 i3 = i2 >>> 5;
 _memset(i1 | 0, -1, i3 << 2 | 0) | 0;
 i1 = i3 << 5;
 if ((i1 | 0) != (i2 | 0)) {
  i6 = (HEAP32[i4 >> 2] | 0) + (i3 << 2) | 0;
  HEAP32[i4 >> 2] = i6;
  HEAP32[i6 >> 2] = HEAP32[i6 >> 2] | -1 >>> (32 - i2 + i1 | 0);
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE4findIS3_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE13__lower_boundIS3_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_SN_SN_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS7_EEENSM_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISB_PvEENS_22__tree_node_destructorINS5_ISU_EEEEEEDpOT_(i4, i5, i1, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i3 = __Znwj(72) | 0;
 HEAP32[i4 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i5 + 4;
 i5 = i4 + 8 | 0;
 HEAP8[i5 >> 0] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i3 + 16 | 0, HEAP32[i2 >> 2] | 0);
 __ZN4wasm12PassRegistry8PassInfoC2Ev(i3 + 32 | 0);
 HEAP8[i5 >> 0] = 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE5eraseENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_PvEEiEE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i1) | 0;
 if ((HEAP32[i3 >> 2] | 0) == (i1 | 0)) HEAP32[i3 >> 2] = i2;
 i4 = i3 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -1;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i3 + 4 >> 2] | 0, i1);
 __ZNSt3__213__vector_baseIN4wasm14SimplifyLocals10BlockBreakENS_9allocatorIS3_EEED2Ev(i1 + 20 | 0);
 __ZdlPv(i1);
 return i2 | 0;
}

function __ZN4wasm17WasmBinaryBuilder8visitNopEPNS_3NopE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i2;
 if (HEAP8[i3 + 12 >> 0] | 0) {
  i3 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 24612) | 0;
  i4 = __ZNKSt3__28ios_base6getlocEv(i3 + (HEAP32[(HEAP32[i3 >> 2] | 0) + -12 >> 2] | 0) | 0) | 0;
  HEAP32[i1 >> 2] = i4;
  i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 61680) | 0;
  i4 = FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 63](i4, 10) | 0;
  __ZNSt3__26localeD2Ev(i1);
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc(i3, i4) | 0;
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i3) | 0;
 }
 STACKTOP = i2;
 return;
}

function __ZN4wasm16PrintSExpression11visitExportEPNS_6ExportE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 4 | 0;
 i5 = i3;
 __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i2 >> 2] | 0, 34556, 0) | 0;
 i2 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__Z9printTextRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i2 >> 2] | 0, HEAP32[i1 >> 2] | 0) | 0, 32) | 0;
 HEAP32[i5 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i2, i4) | 0, 41) | 0;
 STACKTOP = i3;
 return;
}

function ___overflow(i8, i6) {
 i8 = i8 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i9;
 i5 = i6 & 255;
 HEAP8[i7 >> 0] = i5;
 i2 = i8 + 16 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (!i3) if (!(___towrite(i8) | 0)) {
  i3 = HEAP32[i2 >> 2] | 0;
  i4 = 4;
 } else i1 = -1; else i4 = 4;
 do if ((i4 | 0) == 4) {
  i2 = i8 + 20 | 0;
  i4 = HEAP32[i2 >> 2] | 0;
  if (i4 >>> 0 < i3 >>> 0 ? (i1 = i6 & 255, (i1 | 0) != (HEAP8[i8 + 75 >> 0] | 0)) : 0) {
   HEAP32[i2 >> 2] = i4 + 1;
   HEAP8[i4 >> 0] = i5;
   break;
  }
  if ((FUNCTION_TABLE_iiii[HEAP32[i8 + 36 >> 2] & 31](i8, i7, 1) | 0) == 1) i1 = HEAPU8[i7 >> 0] | 0; else i1 = -1;
 } while (0);
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1 + 20 | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE5clearEv(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = i4 + 12 | 0;
 if (HEAP32[i1 >> 2] | 0) {
  i2 = i4 + 8 | 0;
  __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE12__deallocateEPNS_11__hash_nodeIS9_PvEE(i4, HEAP32[i2 >> 2] | 0);
  HEAP32[i2 >> 2] = 0;
  i2 = HEAP32[i4 + 4 >> 2] | 0;
  i3 = 0;
  while (1) {
   if ((i3 | 0) == (i2 | 0)) break;
   HEAP32[(HEAP32[i4 >> 2] | 0) + (i3 << 2) >> 2] = 0;
   i3 = i3 + 1 | 0;
  }
  HEAP32[i1 >> 2] = 0;
 }
 return;
}

function __ZN6cashew12ValueBuilder7makeDotENS_3RefES1_(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i7 + 12 | 0;
 i1 = i7 + 8 | 0;
 i3 = i7 + 4 | 0;
 i4 = i7;
 if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i5, 0) | 0, 59292) | 0) {
  HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
  i6 = __ZN6cashew3RefixEj(i5, 1) | 0;
  i6 = __ZN6cashew5Value10getIStringEv(HEAP32[i6 >> 2] | 0) | 0;
  HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  i6 = __ZN6cashew12ValueBuilder7makeDotENS_3RefENS_7IStringE(i1, i2) | 0;
  STACKTOP = i7;
  return i6 | 0;
 } else ___assert_fail(32090, 48272, 1629, 32105);
 return 0;
}

function __ZN4wasm6Vacuum13visitFunctionEPNS_8FunctionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i4 = i6;
 i5 = i1 + 36 | 0;
 i3 = i1 + 4 | 0;
 i1 = __ZN4wasm6Vacuum8optimizeEPNS_10ExpressionEb(i2, HEAP32[i5 >> 2] | 0, (HEAP32[i3 >> 2] | 0) != 0) | 0;
 if (!i1) {
  i1 = HEAP32[i5 >> 2] | 0;
  HEAP32[i1 >> 2] = 19;
  HEAP32[i1 + 4 >> 2] = 0;
 } else HEAP32[i5 >> 2] = i1;
 if ((HEAP32[i3 >> 2] | 0) == 0 ? (__ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i4, i1), i3 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i4) | 0, __ZN4wasm14EffectAnalyzerD2Ev(i4), !i3) : 0) {
  i5 = HEAP32[i5 >> 2] | 0;
  HEAP32[i5 >> 2] = 19;
  HEAP32[i5 + 4 >> 2] = 0;
 }
 STACKTOP = i6;
 return;
}

function __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_(i4, i2, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i5 = 0, i6 = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i4 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i6 = _strlen(i2) | 0;
 i5 = i3 + 11 | 0;
 i1 = HEAP8[i5 >> 0] | 0;
 i1 = i1 << 24 >> 24 < 0 ? HEAP32[i3 + 4 >> 2] | 0 : i1 & 255;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcjj(i4, i2, i6, i1 + i6 | 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj(i4, (HEAP8[i5 >> 0] | 0) < 0 ? HEAP32[i3 >> 2] | 0 : i3, i1) | 0;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 7576;
 HEAP32[i1 + 32 >> 2] = 0;
 HEAP32[i1 + 36 >> 2] = 0;
 HEAP32[i1 + 40 >> 2] = 0;
 HEAP32[i1 + 52 >> 2] = 0;
 HEAP32[i1 + 56 >> 2] = 0;
 HEAP32[i1 + 48 >> 2] = i1 + 52;
 i2 = i1 + 60 | 0;
 HEAP32[i1 + 88 >> 2] = 0;
 HEAP32[i1 + 92 >> 2] = 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 + 84 >> 2] = i1 + 88;
 return;
}

function __ZNSt3__23mapIN4wasm4NameENS_6vectorINS1_14SimplifyLocals10BlockBreakENS_9allocatorIS5_EEEENS_4lessIS2_EENS6_INS_4pairIKS2_S8_EEEEEixERSC_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSL_IJEEEEEENS_4pairINS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65634, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function _fflush(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0;
 do if (i2) {
  if ((HEAP32[i2 + 76 >> 2] | 0) <= -1) {
   i1 = ___fflush_unlocked(i2) | 0;
   break;
  }
  i3 = (___lockfile(i2) | 0) == 0;
  i1 = ___fflush_unlocked(i2) | 0;
  if (!i3) ___unlockfile(i2);
 } else {
  if (!(HEAP32[2019] | 0)) i1 = 0; else i1 = _fflush(HEAP32[2019] | 0) | 0;
  ___lock(60100);
  i2 = HEAP32[15024] | 0;
  if (i2) do {
   if ((HEAP32[i2 + 76 >> 2] | 0) > -1) i3 = ___lockfile(i2) | 0; else i3 = 0;
   if ((HEAP32[i2 + 20 >> 2] | 0) >>> 0 > (HEAP32[i2 + 28 >> 2] | 0) >>> 0) i1 = ___fflush_unlocked(i2) | 0 | i1;
   if (i3 | 0) ___unlockfile(i2);
   i2 = HEAP32[i2 + 56 >> 2] | 0;
  } while ((i2 | 0) != 0);
  ___unlock(60100);
 } while (0);
 return i1 | 0;
}

function __ZN4wasm16PrintSExpression11visitSelectEPNS_6SelectE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i2 >> 2] | 0, 40) | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__Z12prepareColorRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE(HEAP32[i2 >> 2] | 0) | 0, 36082) | 0;
 __ZN4wasm16PrintSExpression9incIndentEv(i2);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i2, HEAP32[i1 + 8 >> 2] | 0);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i2, HEAP32[i1 + 12 >> 2] | 0);
 __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i2, HEAP32[i1 + 16 >> 2] | 0);
 __ZN4wasm16PrintSExpression9decIndentEv(i2);
 return;
}

function __ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_(i6, i8, i7) {
 i6 = i6 | 0;
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i4 = i6 + 4 | 0;
 i2 = (HEAP32[i4 >> 2] | 0) != 300;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = (HEAP32[i7 >> 2] | 0) - i1 | 0;
 i3 = i3 >>> 0 < 2147483647 ? i3 << 1 : -1;
 i3 = (i3 | 0) == 0 ? 1 : i3;
 i5 = (HEAP32[i8 >> 2] | 0) - i1 | 0;
 i1 = _realloc(i2 ? i1 : 0, i3) | 0;
 if (!i2) {
  i2 = HEAP32[i6 >> 2] | 0;
  HEAP32[i6 >> 2] = i1;
  if (i2) {
   FUNCTION_TABLE_vi[HEAP32[i4 >> 2] & 511](i2);
   i1 = HEAP32[i6 >> 2] | 0;
  }
 } else HEAP32[i6 >> 2] = i1;
 HEAP32[i4 >> 2] = 301;
 HEAP32[i8 >> 2] = i1 + i5;
 HEAP32[i7 >> 2] = (HEAP32[i6 >> 2] | 0) + i3;
 return;
}

function __ZN6cashew12ValueBuilder10makeReturnENS_3RefE(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i6 = 0, i7 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 8 | 0;
 i6 = i5 + 4 | 0;
 i2 = i5;
 i3 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i7 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59312) | 0;
 HEAP32[i6 >> 2] = i7;
 HEAP32[i1 >> 2] = HEAP32[i6 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 if (__ZN6cashew3RefntEv(i4) | 0) {
  i7 = __ZN6cashew12ValueBuilder8makeNullEv() | 0;
  HEAP32[i2 >> 2] = i7;
 } else HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
 i7 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 STACKTOP = i5;
 return i7 | 0;
}

function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i3;
 if (HEAP32[i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0) {
  __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC2ERS3_(i1, i2);
  if (HEAP8[i1 >> 0] | 0 ? (i4 = HEAP32[i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0, (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 24 >> 2] & 255](i4) | 0) == -1) : 0) {
   i4 = i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
   HEAP32[i4 >> 2] = HEAP32[i4 >> 2] | 1;
  }
  __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev(i1);
 }
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i3;
 if (HEAP32[i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0) {
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i1, i2);
  if (HEAP8[i1 >> 0] | 0 ? (i4 = HEAP32[i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0, (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 24 >> 2] & 255](i4) | 0) == -1) : 0) {
   i4 = i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
   HEAP32[i4 >> 2] = HEAP32[i4 >> 2] | 1;
  }
  __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i1);
 }
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSR_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISG_PvEENS_22__tree_node_destructorINSD_ISZ_EEEEEEDpOT_(i4, i5, i1, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i3 = __Znwj(32) | 0;
 HEAP32[i4 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i5 + 4;
 HEAP32[i3 + 16 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZN4wasm14EffectAnalyzerD2Ev(i1 + 24 | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function _pad(i6, i2, i5, i4, i1) {
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i3 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 256 | 0;
 i7 = i8;
 do if ((i5 | 0) > (i4 | 0) & (i1 & 73728 | 0) == 0) {
  i1 = i5 - i4 | 0;
  _memset(i7 | 0, i2 | 0, (i1 >>> 0 > 256 ? 256 : i1) | 0) | 0;
  i2 = HEAP32[i6 >> 2] | 0;
  i3 = (i2 & 32 | 0) == 0;
  if (i1 >>> 0 > 255) {
   i4 = i5 - i4 | 0;
   do {
    if (i3) {
     ___fwritex(i7, 256, i6) | 0;
     i2 = HEAP32[i6 >> 2] | 0;
    }
    i1 = i1 + -256 | 0;
    i3 = (i2 & 32 | 0) == 0;
   } while (i1 >>> 0 > 255);
   if (i3) i1 = i4 & 255; else break;
  } else if (!i3) break;
  ___fwritex(i7, i1, i6) | 0;
 } while (0);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE4findIS3_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE13__lower_boundIS3_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_SM_SM_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZN4wasm14CoalesceLocals11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEE(i6, i4) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i7;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP32[i5 + 8 >> 2] = 0;
 i1 = i6 + 112 | 0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i5, HEAP32[i1 >> 2] | 0);
 i2 = HEAP32[i5 >> 2] | 0;
 i3 = 0;
 while (1) {
  if (i3 >>> 0 >= (HEAP32[i1 >> 2] | 0) >>> 0) break;
  HEAP32[i2 + (i3 << 2) >> 2] = i3;
  i3 = i3 + 1 | 0;
 }
 __ZN4wasm14CoalesceLocals20pickIndicesFromOrderERNSt3__26vectorIjNS1_9allocatorIjEEEES6_(i6, i5, i4);
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i5);
 STACKTOP = i7;
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZNSt3__23mapIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS6_EEEENS_4lessIS2_EENS7_INS_4pairIKS2_S9_EEEEEixERSD_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS7_EEEEEENS_19__map_value_compareIS3_SB_NS_4lessIS3_EELb1EEENS8_ISB_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSM_IJEEEEEENS_4pairINS_15__tree_iteratorISB_PNS_11__tree_nodeISB_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseContinueERPcPKc(i2, i5, i1) {
 i2 = i2 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i4 + 20 | 0;
 i3 = i4;
 i2 = i4 + 16 | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i5);
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i3, HEAP32[i5 >> 2] | 0);
 if ((HEAP32[i3 + 12 >> 2] | 0) == 2) {
  HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + (HEAP32[i3 + 8 >> 2] | 0);
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 } else HEAP32[i2 >> 2] = 0;
 HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
 i5 = __ZN6cashew12ValueBuilder12makeContinueENS_7IStringE(i1) | 0;
 STACKTOP = i4;
 return i5 | 0;
}

function __ZNSt3__223mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEclEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i2 = i1 + 2496 | 0;
 i6 = HEAP32[i2 >> 2] | 0;
 i3 = ((i6 + 1 | 0) >>> 0) % 624 | 0;
 i4 = i1 + (i6 << 2) | 0;
 i5 = HEAP32[i1 + (i3 << 2) >> 2] | 0;
 HEAP32[i4 >> 2] = 0 - (i5 & 1) & -1727483681 ^ HEAP32[i1 + ((((i6 + 397 | 0) >>> 0) % 624 | 0) << 2) >> 2] ^ (i5 & 2147483646 | HEAP32[i4 >> 2] & -2147483648) >>> 1;
 i1 = HEAP32[i1 + (HEAP32[i2 >> 2] << 2) >> 2] | 0;
 i1 = i1 >>> 11 ^ i1;
 HEAP32[i2 >> 2] = i3;
 i1 = i1 << 7 & -1658038656 ^ i1;
 i1 = i1 << 15 & -272236544 ^ i1;
 return i1 >>> 18 ^ i1 | 0;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS7_PvEENS_22__tree_node_destructorINSC_ISR_EEEEEEDpOT_(i4, i5, i1, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i3 = __Znwj(40) | 0;
 HEAP32[i4 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i5 + 4;
 HEAP32[i3 + 16 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP8[i3 + 28 >> 0] = 0;
 HEAP32[i3 + 32 >> 2] = 0;
 HEAP32[i3 + 36 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 1;
 return;
}

function __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_(i4, i2, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i5 = 0, i6 = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i4 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i5 = HEAP8[i2 + 11 >> 0] | 0;
 i6 = i5 << 24 >> 24 < 0;
 i5 = i6 ? HEAP32[i2 + 4 >> 2] | 0 : i5 & 255;
 i1 = _strlen(i3) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcjj(i4, i6 ? HEAP32[i2 >> 2] | 0 : i2, i5, i5 + i1 | 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj(i4, i3, i1) | 0;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_(i6, i9, i8, i4, i3, i5, 13036, 13068) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_(i6, i9, i8, i4, i3, i5, 53715, 53723) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__210__time_put8__do_putEPwRS1_PK2tmcc(i4, i5, i6, i3, i1, i2) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 128 | 0;
 i10 = i7 + 16 | 0;
 i11 = i7 + 12 | 0;
 i8 = i7;
 i9 = i7 + 8 | 0;
 HEAP32[i11 >> 2] = i10 + 100;
 __ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc(i4, i10, i11, i3, i1, i2);
 i2 = i8;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i9 >> 2] = i10;
 i2 = (HEAP32[i6 >> 2] | 0) - i5 >> 2;
 i1 = _uselocale(HEAP32[i4 >> 2] | 0) | 0;
 i2 = _mbsrtowcs(i5, i9, i2, i8) | 0;
 if (i1 | 0) _uselocale(i1) | 0;
 HEAP32[i6 >> 2] = i5 + (i2 << 2);
 STACKTOP = i7;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i7, i2, i4, i5, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i6 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6 + 4 | 0;
 i8 = i6;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i5, i3, 4) | 0;
 if (!(HEAP32[i5 >> 2] & 4)) {
  if ((i1 | 0) < 69) i1 = i1 + 2e3 | 0; else i1 = (i1 + -69 | 0) >>> 0 < 31 ? i1 + 1900 | 0 : i1;
  HEAP32[i7 >> 2] = i1 + -1900;
 }
 STACKTOP = i6;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i7, i2, i4, i5, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i6 = 0, i8 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i6 + 4 | 0;
 i8 = i6;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i5, i3, 4) | 0;
 if (!(HEAP32[i5 >> 2] & 4)) {
  if ((i1 | 0) < 69) i1 = i1 + 2e3 | 0; else i1 = (i1 + -69 | 0) >>> 0 < 31 ? i1 + 1900 | 0 : i1;
  HEAP32[i7 >> 2] = i1 + -1900;
 }
 STACKTOP = i6;
 return;
}

function __ZN6cashew12ValueBuilder10makeDoubleEd(d1) {
 d1 = +d1;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i3 + 8 | 0;
 i6 = i3 + 4 | 0;
 i5 = i3;
 i4 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i7 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59348) | 0;
 HEAP32[i6 >> 2] = i7;
 HEAP32[i2 >> 2] = HEAP32[i6 >> 2];
 i4 = __ZN6cashew5Value9push_backENS_3RefE(i4, i2) | 0;
 i6 = __ZN6cashew5Arena5allocEv(59672) | 0;
 __ZN6cashew5Value4freeEv(i6);
 HEAP32[i6 >> 2] = 1;
 HEAPF64[i6 + 8 >> 3] = d1;
 HEAP32[i5 >> 2] = i6;
 HEAP32[i2 >> 2] = HEAP32[i5 >> 2];
 i2 = __ZN6cashew5Value9push_backENS_3RefE(i4, i2) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZZ11instantiateEN19JSExternalInterface4initERN4wasm6ModuleE(i1, i7) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i8;
 _emscripten_asm_const_ii(14, HEAP32[i7 + 60 >> 2] << 16 | 0) | 0;
 i3 = HEAP32[i7 + 72 >> 2] | 0;
 i4 = i6 + 4 | 0;
 i5 = i6 + 8 | 0;
 i2 = i6 + 4 | 0;
 i1 = HEAP32[i7 + 68 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i3 | 0)) break;
  __ZN4wasm6Memory7SegmentC2ERKS1_(i6, i1);
  i7 = HEAP32[i4 >> 2] | 0;
  _emscripten_asm_const_iiii(15, HEAP32[i6 >> 2] | 0, i7 | 0, (HEAP32[i5 >> 2] | 0) - i7 | 0) | 0;
  __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i2);
  i1 = i1 + 16 | 0;
 }
 STACKTOP = i8;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSL_SL_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10parseBreakERPcPKc(i2, i5, i1) {
 i2 = i2 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i4 + 20 | 0;
 i3 = i4;
 i2 = i4 + 16 | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i5);
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4FragC2EPc(i3, HEAP32[i5 >> 2] | 0);
 if ((HEAP32[i3 + 12 >> 2] | 0) == 2) {
  HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + (HEAP32[i3 + 8 >> 2] | 0);
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 } else HEAP32[i2 >> 2] = 0;
 HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
 i5 = __ZN6cashew12ValueBuilder9makeBreakENS_7IStringE(i1) | 0;
 STACKTOP = i4;
 return i5 | 0;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZNSt3__28functionIFPN4wasm4PassEvEEaSEOS5_(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i3 = i5 + 16 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 if ((i1 | 0) != (i5 | 0)) {
  if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 511](i1);
 } else FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 511](i1);
 HEAP32[i3 >> 2] = 0;
 i1 = i4 + 16 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) if ((i2 | 0) == (i4 | 0)) {
  HEAP32[i3 >> 2] = i5;
  i4 = HEAP32[i1 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i4 >> 2] | 0) + 12 >> 2] & 1023](i4, i5);
  break;
 } else {
  HEAP32[i3 >> 2] = i2;
  HEAP32[i1 >> 2] = 0;
  break;
 } else HEAP32[i3 >> 2] = 0; while (0);
 return i5 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN4wasm12PassRegistry8PassInfoEEENS_19__map_value_compareIS7_SB_NS_4lessIS7_EELb1EEENS5_ISB_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSL_SL_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__23mapIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __Z14finalizeModulev() {
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i5 + 8 | 0;
 i1 = i5 + 4 | 0;
 i4 = i5;
 i2 = _emscripten_asm_const_i(0) | 0;
 if (i2 & 65535 | 0) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 17352) | 0;
  _exit(1);
 }
 i6 = HEAP32[14814] | 0;
 __ZN4wasm7AddressC2Ey(i1, i2 >>> 16, 0);
 HEAP32[i6 + 60 >> 2] = HEAP32[i1 >> 2];
 i2 = HEAP32[14814] | 0;
 HEAP32[i4 >> 2] = HEAP32[14970];
 HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
 if (!(__ZN4wasm6Module11checkExportENS_4NameE(i2, i3) | 0)) i1 = HEAP32[(HEAP32[14814] | 0) + 60 >> 2] | 0; else i1 = 65535;
 HEAP32[i2 + 64 >> 2] = i1;
 STACKTOP = i5;
 return;
}

function __ZNK4wasm7Literal8copysignERKS0_(i4, i6, i5) {
 i4 = i4 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i7 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i1 = i7 + 16 | 0;
 i2 = i7;
 i3 = i6 + 8 | 0;
 if ((HEAP32[i6 >> 2] | 0) == 3) {
  i6 = HEAP32[i5 + 8 >> 2] & -2147483648 | HEAP32[i3 >> 2] & 2147483647;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i6;
  __ZN4wasm7Literal9castToF32Ev(i4, i1);
 } else {
  i6 = i3;
  i3 = HEAP32[i6 >> 2] | 0;
  i5 = HEAP32[i5 + 8 + 4 >> 2] & -2147483648 | HEAP32[i6 + 4 >> 2] & 2147483647;
  HEAP32[i2 >> 2] = 2;
  i6 = i2 + 8 | 0;
  HEAP32[i6 >> 2] = i3;
  HEAP32[i6 + 4 >> 2] = i5;
  __ZN4wasm7Literal9castToF64Ev(i4, i2);
 }
 STACKTOP = i7;
 return;
}

function __ZNSt3__214__split_bufferINS_6vectorINS1_IN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEEERNS5_IS9_Lj4096EEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  i3 = i3 + -16 | 0;
  HEAP32[i2 >> 2] = i3;
  __ZNSt3__213__vector_baseINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEED2Ev(i3);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE10deallocateEPcj(HEAP32[HEAP32[i4 + 16 >> 2] >> 2] | 0, i1, (HEAP32[i4 + 12 >> 2] | 0) - i1 | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZNSt3__213__vector_baseINS_6vectorINS1_IN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEEENS5_IS9_Lj4096EEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   i3 = i3 + -16 | 0;
   HEAP32[i2 >> 2] = i3;
   __ZNSt3__213__vector_baseINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEED2Ev(i3);
  }
  i3 = HEAP32[i4 >> 2] | 0;
  __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE10deallocateEPcj(HEAP32[i4 + 12 >> 2] | 0, i3, (HEAP32[i4 + 8 >> 2] | 0) - i3 | 0);
 }
 return;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl(i6, i1, i2, i4, i3, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i7 = 0, i8 = 0, i9 = 0, i10 = 0, i11 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i7 + 12 | 0;
 i9 = i7 + 8 | 0;
 i11 = i7 + 4 | 0;
 i10 = i7;
 HEAP32[i11 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i10 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i9 >> 2] = HEAP32[i11 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i10 >> 2];
 i6 = __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_(i6, i9, i8, i4, i3, i5) | 0;
 STACKTOP = i7;
 return i6 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE10parseWhileERPcPKc(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 12 | 0;
 i6 = i4 + 8 | 0;
 i8 = i4 + 4 | 0;
 i7 = i4;
 i9 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseParennedERPc(i3, i2) | 0;
 i3 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseMaybeBracketedERPcPKc(i3, i2, i1) | 0;
 HEAP32[i8 >> 2] = i9;
 HEAP32[i7 >> 2] = i3;
 HEAP32[i6 >> 2] = HEAP32[i8 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
 i3 = __ZN6cashew12ValueBuilder9makeWhileENS_3RefES1_(i6, i5) | 0;
 STACKTOP = i4;
 return i3 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSK_SK_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function _scalbn(d1, i3) {
 d1 = +d1;
 i3 = i3 | 0;
 var i2 = 0;
 if ((i3 | 0) > 1023) {
  d1 = d1 * 8988465674311579538646525.0e283;
  i2 = i3 + -1023 | 0;
  if ((i2 | 0) > 1023) {
   i2 = i3 + -2046 | 0;
   i2 = (i2 | 0) > 1023 ? 1023 : i2;
   d1 = d1 * 8988465674311579538646525.0e283;
  }
 } else if ((i3 | 0) < -1022) {
  d1 = d1 * 2.2250738585072014e-308;
  i2 = i3 + 1022 | 0;
  if ((i2 | 0) < -1022) {
   i2 = i3 + 2044 | 0;
   i2 = (i2 | 0) < -1022 ? -1022 : i2;
   d1 = d1 * 2.2250738585072014e-308;
  }
 } else i2 = i3;
 i2 = _bitshift64Shl(i2 + 1023 | 0, 0, 52) | 0;
 i3 = tempRet0;
 HEAP32[tempDoublePtr >> 2] = i2;
 HEAP32[tempDoublePtr + 4 >> 2] = i3;
 return +(d1 * +HEAPF64[tempDoublePtr >> 3]);
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_SK_SK_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZN4wasm6getSigEPNS_12FunctionTypeE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i4 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i4, __ZN4wasm6getSigENS_8WasmTypeE(HEAP32[i3 + 4 >> 2] | 0) | 0);
 i2 = HEAP32[i3 + 12 >> 2] | 0;
 i1 = HEAP32[i3 + 8 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i4, __ZN4wasm6getSigENS_8WasmTypeE(HEAP32[i1 >> 2] | 0) | 0);
  i1 = i1 + 4 | 0;
 }
 return;
}

function __ZN4wasm17WasmBinaryBuilder18processExpressionsEv(i7) {
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i8;
 i2 = i7 + 100 | 0;
 i3 = i7 + 104 | 0;
 i4 = i7 + 96 | 0;
 while (1) {
  i1 = __ZN4wasm17WasmBinaryBuilder14readExpressionERPNS_10ExpressionE(i7, i6) | 0;
  i5 = HEAP32[i6 >> 2] | 0;
  if (!i5) break;
  i1 = HEAP32[i2 >> 2] | 0;
  if ((i1 | 0) == (HEAP32[i3 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i4, i6); else {
   HEAP32[i1 >> 2] = i5;
   HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
  }
 }
 HEAP32[i7 + 108 >> 2] = i1;
 STACKTOP = i8;
 return;
}

function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 i2 = i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) | 0;
 if ((((HEAP32[i2 + 24 >> 2] | 0 ? (HEAP32[i2 + 16 >> 2] | 0) == 0 : 0) ? HEAP32[i2 + 4 >> 2] & 8192 | 0 : 0) ? !(__ZSt18uncaught_exceptionv() | 0) : 0) ? (i2 = HEAP32[i1 >> 2] | 0, i2 = HEAP32[i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0, (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 255](i2) | 0) == -1) : 0) {
  i2 = HEAP32[i1 >> 2] | 0;
  i2 = i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
  HEAP32[i2 >> 2] = HEAP32[i2 >> 2] | 1;
 }
 return;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 i2 = i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) | 0;
 if ((((HEAP32[i2 + 24 >> 2] | 0 ? (HEAP32[i2 + 16 >> 2] | 0) == 0 : 0) ? HEAP32[i2 + 4 >> 2] & 8192 | 0 : 0) ? !(__ZSt18uncaught_exceptionv() | 0) : 0) ? (i2 = HEAP32[i1 >> 2] | 0, i2 = HEAP32[i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 24 >> 2] | 0, (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 255](i2) | 0) == -1) : 0) {
  i2 = HEAP32[i1 >> 2] | 0;
  i2 = i2 + (HEAP32[(HEAP32[i2 >> 2] | 0) + -12 >> 2] | 0) + 16 | 0;
  HEAP32[i2 >> 2] = HEAP32[i2 >> 2] | 1;
 }
 return;
}

function __ZNSt3__225__independent_bits_engineINS_23mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEEjEC2ERS2_j(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0;
 HEAP32[i3 >> 2] = i1;
 HEAP32[i3 + 4 >> 2] = i2;
 i4 = ((i2 & 31 | 0) != 0 & 1) + (i2 >>> 5) | 0;
 HEAP32[i3 + 12 >> 2] = i4;
 i1 = (i2 >>> 0) / (i4 >>> 0) | 0;
 HEAP32[i3 + 8 >> 2] = i1;
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i3 + 16 >> 2] = i4 - ((i2 >>> 0) % (i4 >>> 0) | 0);
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = (i1 | 0) == 0 ? 0 : -1 >>> (32 - i1 | 0);
 HEAP32[i3 + 32 >> 2] = i1 >>> 0 < 31 ? -1 >>> (31 - i1 | 0) : -1;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8 + 4 | 0;
 i2 = i8;
 HEAP32[i1 >> 2] = i6;
 HEAP32[i2 >> 2] = i5;
 i3 = i7 + 12 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (i4 >>> 0 < (HEAP32[i7 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i4 >> 2] = i6;
  HEAP32[i4 + 4 >> 2] = i5;
  HEAP32[i3 >> 2] = i4 + 8;
 } else __ZNSt3__26vectorIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEE24__emplace_back_slow_pathIJRPFvPS3_PPNS1_10ExpressionEERSF_EEEvDpOT_(i7 + 8 | 0, i1, i2);
 STACKTOP = i8;
 return;
}

function __ZNSt3__23mapIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S5_EEEEEixERSA_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS7_EEEEEENS_19__map_value_compareIS3_SB_NS_4lessIS3_EELb1EEENS8_ISB_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSL_SL_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlNS_4NameEE0_clES3_(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0;
 i4 = HEAP32[i3 >> 2] | 0;
 i1 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE4findIS3_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_(i4, i2) | 0;
 if ((i1 | 0) == (i4 + 4 | 0)) __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlyE_clEy(HEAP32[i3 + 4 >> 2] | 0, HEAP32[i2 >> 2] | 0, 0); else __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(HEAP32[i3 + 8 >> 2] | 0, HEAP32[(HEAP32[i1 + 24 >> 2] | 0) + -4 >> 2] | 0);
 return;
}

function __ZN4wasm6ThreadC2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5;
 HEAP32[i4 + 104 >> 2] = 0;
 i2 = i4;
 i3 = i2 + 80 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 HEAP8[i4 + 80 >> 0] = 0;
 __ZN4wasm10ThreadPool3getEv() | 0;
 i3 = HEAP32[14940] | 0;
 if (i3 | 0 ? HEAP8[i3 + 12 >> 0] | 0 : 0) ___assert_fail(48657, 48612, 48, 48689);
 i3 = __Znwj(4) | 0;
 HEAP32[i1 >> 2] = i4;
 __ZNSt3__26threadC2IRFvPvEJPN4wasm6ThreadEEvEEOT_DpOT0_(i3, 286, i1);
 i1 = HEAP32[i4 >> 2] | 0;
 HEAP32[i4 >> 2] = i3;
 if (i1 | 0) {
  __ZNSt3__26threadD2Ev(i1);
  __ZdlPv(i1);
 }
 STACKTOP = i5;
 return;
}

function __ZN4wasm10TypeSeeker10visitBreakEPNS_5BreakE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i6;
 do if ((HEAP32[i1 + 8 >> 2] | 0) == (HEAP32[i5 + 32 >> 2] | 0)) {
  i1 = HEAP32[i1 + 12 >> 2] | 0;
  if (!i1) i1 = 0; else i1 = HEAP32[i1 + 4 >> 2] | 0;
  HEAP32[i4 >> 2] = i1;
  i2 = i5 + 40 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  if (i3 >>> 0 < (HEAP32[i5 + 44 >> 2] | 0) >>> 0) {
   HEAP32[i3 >> 2] = i1;
   HEAP32[i2 >> 2] = i3 + 4;
   break;
  } else {
   __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE21__push_back_slow_pathIS2_EEvOT_(i5 + 36 | 0, i4);
   break;
  }
 } while (0);
 STACKTOP = i6;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i4 + 4 | 0;
 i5 = i4;
 __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev(i3);
 HEAP32[i3 >> 2] = 12516;
 HEAP32[i3 + 32 >> 2] = i1;
 __ZNSt3__26localeC2ERKS0_(i6, i3 + 4 | 0);
 HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 63480) | 0;
 __ZNSt3__26localeD2Ev(i5);
 HEAP32[i3 + 36 >> 2] = i1;
 HEAP32[i3 + 40 >> 2] = i2;
 i2 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 255](i1) | 0) & 1;
 HEAP8[i3 + 44 >> 0] = i2;
 STACKTOP = i4;
 return;
}

function __ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i4 + 4 | 0;
 i5 = i4;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i3);
 HEAP32[i3 >> 2] = 12452;
 HEAP32[i3 + 32 >> 2] = i1;
 __ZNSt3__26localeC2ERKS0_(i6, i3 + 4 | 0);
 HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i5, 63472) | 0;
 __ZNSt3__26localeD2Ev(i5);
 HEAP32[i3 + 36 >> 2] = i1;
 HEAP32[i3 + 40 >> 2] = i2;
 i2 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 255](i1) | 0) & 1;
 HEAP8[i3 + 44 >> 0] = i2;
 STACKTOP = i4;
 return;
}

function __ZN4wasm17WasmBinaryBuilder11verifyInt32Ei(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i4 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i4;
 if ((__ZN4wasm17WasmBinaryBuilder8getInt32Ev(i2) | 0) == (i3 | 0)) {
  STACKTOP = i4;
  return;
 } else {
  i4 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i1 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = 0;
  HEAP32[i1 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 22985, 16);
  i3 = HEAP32[i2 + 16 >> 2] | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i4, i1);
  HEAP32[i4 + 12 >> 2] = 0;
  HEAP32[i4 + 16 >> 2] = i3;
  ___cxa_throw(i4 | 0, 64, 279);
 }
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 + -1 | 0) >>> 0 < 12 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 + -1 | 0) >>> 0 < 12 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i4 = 0;
 L1 : do switch (HEAP32[i2 + 4 >> 2] & 176 | 0) {
 case 16:
  {
   i2 = HEAP8[i1 >> 0] | 0;
   switch (i2 << 24 >> 24) {
   case 43:
   case 45:
    {
     i1 = i1 + 1 | 0;
     break L1;
    }
   default:
    {}
   }
   if ((i3 - i1 | 0) > 1 & i2 << 24 >> 24 == 48) {
    switch (HEAP8[i1 + 1 >> 0] | 0) {
    case 88:
    case 120:
     break;
    default:
     {
      i4 = 7;
      break L1;
     }
    }
    i1 = i1 + 2 | 0;
   } else i4 = 7;
   break;
  }
 case 32:
  {
   i1 = i3;
   break;
  }
 default:
  i4 = 7;
 } while (0);
 return i1 | 0;
}

function __ZN4wasm14SimplifyLocalsC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 6900;
 HEAP32[i1 + 16 >> 2] = 6928;
 HEAP32[i1 + 48 >> 2] = 0;
 HEAP32[i1 + 52 >> 2] = 0;
 HEAP32[i1 + 44 >> 2] = i1 + 48;
 HEAP32[i1 + 60 >> 2] = 0;
 HEAP32[i1 + 64 >> 2] = 0;
 HEAP32[i1 + 56 >> 2] = i1 + 60;
 HEAP32[i1 + 72 >> 2] = 0;
 HEAP32[i1 + 76 >> 2] = 0;
 HEAP32[i1 + 68 >> 2] = i1 + 72;
 HEAP32[i1 + 80 >> 2] = 0;
 HEAP32[i1 + 84 >> 2] = 0;
 HEAP32[i1 + 88 >> 2] = 0;
 i1 = i1 + 96 | 0;
 i2 = i1 + 36 | 0;
 do {
  HEAP32[i1 >> 2] = 0;
  i1 = i1 + 4 | 0;
 } while ((i1 | 0) < (i2 | 0));
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i5, i3) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i6;
 HEAP32[i4 >> 2] = i5;
 i1 = HEAP32[i3 + 40 >> 2] | 0;
 i2 = HEAP32[i3 + 36 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __ZZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i4, 0, i5, HEAP32[i2 >> 2] | 0);
  i2 = i2 + 4 | 0;
 }
 __ZN4wasm13WasmValidator11visitMemoryEPNS_6MemoryE(i5, i3 + 60 | 0);
 __ZN4wasm13WasmValidator11visitModuleEPNS_6ModuleE(i5, i3);
 STACKTOP = i6;
 return;
}

function __ZN4wasm6ThreadD2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0;
 __ZN4wasm10ThreadPool3getEv() | 0;
 i1 = HEAP32[14940] | 0;
 if (i1 | 0 ? HEAP8[i1 + 12 >> 0] | 0 : 0) ___assert_fail(48657, 48612, 53, 48722);
 i1 = i2 + 4 | 0;
 __ZNSt3__25mutex4lockEv(i1);
 HEAP8[i2 + 80 >> 0] = 1;
 i3 = i2 + 32 | 0;
 __ZNSt3__218condition_variable10notify_oneEv(i3);
 __ZNSt3__25mutex6unlockEv(i1);
 __ZNSt3__26thread4joinEv(HEAP32[i2 >> 2] | 0);
 __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i2 + 88 | 0);
 __ZNSt3__218condition_variableD2Ev(i3);
 __ZNSt3__25mutexD2Ev(i1);
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = 0;
 if (i1 | 0) {
  __ZNSt3__26threadD2Ev(i1);
  __ZdlPv(i1);
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE4findIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_SK_SK_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__23mapIPN4wasm12CallIndirectEN6cashew7IStringENS_4lessIS3_EENS_9allocatorINS_4pairIKS3_S5_EEEEEixERSA_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm12CallIndirectEN6cashew7IStringEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE25__emplace_unique_key_argsIS4_JRKNS_21piecewise_construct_tENS_5tupleIJRKS4_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEERNS_9allocatorISC_EEEC2EjjSF_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i6, i2, i4, i7, i3) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i7, i3, 2) | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 if ((i1 + -1 | 0) >>> 0 < 31 & (i2 & 4 | 0) == 0) HEAP32[i6 >> 2] = i1; else HEAP32[i7 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i6, i2, i4, i7, i3) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i7, i3, 3) | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 if ((i1 | 0) < 366 & (i2 & 4 | 0) == 0) HEAP32[i6 >> 2] = i1; else HEAP32[i7 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i6, i2, i4, i7, i3) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i7, i3, 2) | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 if ((i1 + -1 | 0) >>> 0 < 31 & (i2 & 4 | 0) == 0) HEAP32[i6 >> 2] = i1; else HEAP32[i7 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i6, i2, i4, i7, i3) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i7, i3, 3) | 0;
 i2 = HEAP32[i7 >> 2] | 0;
 if ((i1 | 0) < 366 & (i2 & 4 | 0) == 0) HEAP32[i6 >> 2] = i1; else HEAP32[i7 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEEC2EOS4_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 HEAP32[i2 >> 2] = 5404;
 HEAP32[i2 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 i4 = i2 + 8 | 0;
 i3 = i1 + 8 | 0;
 HEAP32[i4 >> 2] = 0;
 i5 = i2 + 12 | 0;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i4 >> 2] = HEAP32[i3 >> 2];
 i4 = i1 + 12 | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 i5 = i1 + 16 | 0;
 HEAP32[i2 + 16 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i5 >> 2] = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i3 >> 2] = 0;
 i3 = i1 + 20 | 0;
 i1 = HEAP32[i3 + 4 >> 2] | 0;
 i2 = i2 + 20 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = i1;
 return;
}

function __ZNSt3__23mapIN4wasm4NameENS_6vectorIS2_NS_9allocatorIS2_EEEENS_4lessIS2_EENS4_INS_4pairIKS2_S6_EEEEEixERSA_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65639, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSL_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISA_PvEENS_22__tree_node_destructorINS7_IST_EEEEEEDpOT_(i4, i5, i1, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i3 = __Znwj(32) | 0;
 HEAP32[i4 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i5 + 4;
 HEAP32[i3 + 16 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 1;
 return;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__erase_uniqueIS2_EEjRKT_(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i5 + 4 | 0;
 i3 = i5;
 i1 = __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE4findIS2_EENS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEERKT_(i4, i1) | 0;
 if ((i1 | 0) == (i4 + 4 | 0)) i1 = 0; else {
  HEAP32[i3 >> 2] = i1;
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE5eraseENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEE(i4, i2) | 0;
  i1 = 1;
 }
 STACKTOP = i5;
 return i1 | 0;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj(i5, i3, i4) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0;
 if (i4 >>> 0 > 1073741807) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i5);
 do if (i4 >>> 0 >= 2) {
  i1 = i4 + 4 & -4;
  if (i1 >>> 0 > 1073741823) ___assert_fail(55771, 55808, 1734, 55911); else {
   i2 = __Znwj(i1 << 2) | 0;
   HEAP32[i5 >> 2] = i2;
   HEAP32[i5 + 8 >> 2] = i1 | -2147483648;
   HEAP32[i5 + 4 >> 2] = i4;
   break;
  }
 } else {
  HEAP8[i5 + 8 + 3 >> 0] = i4;
  i2 = i5;
 } while (0);
 __ZNSt3__211char_traitsIwE4copyEPwPKwj(i2, i3, i4) | 0;
 HEAP32[i2 + (i4 << 2) >> 2] = 0;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 13 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1 + -1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 13 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1 + -1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZN4wasm13WasmValidator4failEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i4 + 4 | 0;
 i3 = i4;
 i1 = i1 + 20 | 0;
 if (!(HEAP32[i1 >> 2] | 0)) __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19483) | 0; else {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19445) | 0;
  HEAP32[i3 >> 2] = HEAP32[HEAP32[i1 >> 2] >> 2];
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(60976, i2) | 0;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 19480) | 0;
 }
 STACKTOP = i4;
 return 60976;
}

function _frexp(d1, i5) {
 d1 = +d1;
 i5 = i5 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 HEAPF64[tempDoublePtr >> 3] = d1;
 i2 = HEAP32[tempDoublePtr >> 2] | 0;
 i3 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 i4 = _bitshift64Lshr(i2 | 0, i3 | 0, 52) | 0;
 i4 = i4 & 2047;
 switch (i4 | 0) {
 case 0:
  {
   if (d1 != 0.0) {
    d1 = +_frexp(d1 * 18446744073709551616.0, i5);
    i2 = (HEAP32[i5 >> 2] | 0) + -64 | 0;
   } else i2 = 0;
   HEAP32[i5 >> 2] = i2;
   break;
  }
 case 2047:
  break;
 default:
  {
   HEAP32[i5 >> 2] = i4 + -1022;
   HEAP32[tempDoublePtr >> 2] = i2;
   HEAP32[tempDoublePtr + 4 >> 2] = i3 & -2146435073 | 1071644672;
   d1 = +HEAPF64[tempDoublePtr >> 3];
  }
 }
 return +d1;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEjw(i5, i3, i2) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0;
 if (i3 >>> 0 > 1073741807) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i5);
 do if (i3 >>> 0 >= 2) {
  i1 = i3 + 4 & -4;
  if (i1 >>> 0 > 1073741823) ___assert_fail(55771, 55808, 1734, 55911); else {
   i4 = __Znwj(i1 << 2) | 0;
   HEAP32[i5 >> 2] = i4;
   HEAP32[i5 + 8 >> 2] = i1 | -2147483648;
   HEAP32[i5 + 4 >> 2] = i3;
   break;
  }
 } else {
  HEAP8[i5 + 8 + 3 >> 0] = i3;
  i4 = i5;
 } while (0);
 __ZNSt3__211char_traitsIwE6assignEPwjw(i4, i3, i2) | 0;
 HEAP32[i4 + (i3 << 2) >> 2] = 0;
 return;
}

function __ZN6cashew12ValueBuilder10makeStringENS_7IStringE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i2 + 8 | 0;
 i6 = i2 + 4 | 0;
 i5 = i2;
 i4 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i7 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59368) | 0;
 HEAP32[i6 >> 2] = i7;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 i4 = __ZN6cashew5Value9push_backENS_3RefE(i4, i3) | 0;
 i1 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i1) | 0;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i4, i3) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_S6_(i4, i2, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0, i5 = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i4 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i1 = HEAP8[i2 + 11 >> 0] | 0;
 i5 = i1 << 24 >> 24 < 0;
 i1 = i5 ? HEAP32[i2 + 4 >> 2] | 0 : i1 & 255;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcjj(i4, i5 ? HEAP32[i2 >> 2] | 0 : i2, i1, i1 + 1 | 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc(i4, i3);
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 1) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 7 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 61 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 60 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 1) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 7 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 61 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 60 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZN4wasm7Element4listEv(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i3;
 if (!(HEAP8[i2 >> 0] | 0)) {
  i3 = ___cxa_allocate_exception(20) | 0;
  HEAP32[i1 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = 0;
  HEAP32[i1 + 8 >> 2] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 21515, 13);
  i4 = HEAP32[i2 + 28 >> 2] | 0;
  i2 = HEAP32[i2 + 32 >> 2] | 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i3, i1);
  HEAP32[i3 + 12 >> 2] = i4;
  HEAP32[i3 + 16 >> 2] = i2;
  ___cxa_throw(i3 | 0, 64, 279);
 } else {
  STACKTOP = i3;
  return i2 + 4 | 0;
 }
 return 0;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm12CallIndirectEN6cashew7IStringEEENS_19__map_value_compareIS4_S7_NS_4lessIS4_EELb1EEENS_9allocatorIS7_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__23mapIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS4_EEEENS_4lessIjEENS5_INS_4pairIKjS7_EEEEEixERSB_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE25__emplace_unique_key_argsIjJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSK_IJEEEEEENS_4pairINS_15__tree_iteratorIS9_PNS_11__tree_nodeIS9_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65639, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZN6cashew12ValueBuilder8makeNameENS_7IStringE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i2 + 8 | 0;
 i6 = i2 + 4 | 0;
 i5 = i2;
 i4 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i7 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59292) | 0;
 HEAP32[i6 >> 2] = i7;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 i4 = __ZN6cashew5Value9push_backENS_3RefE(i4, i3) | 0;
 i1 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i1) | 0;
 HEAP32[i5 >> 2] = i1;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i4, i3) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZN4wasm3LEBIjhE4readENSt3__28functionIFhvEEE(i6, i4) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 HEAP32[i6 >> 2] = 0;
 i5 = 0;
 while (1) {
  i1 = (__ZNKSt3__28functionIFhvEEclEv(i4) | 0) & 255;
  i3 = i1 & 127;
  if (!i5) i2 = -1; else i2 = (1 << 32 - i5) + -1 | 0;
  if ((i2 & i3 | 0) != (i3 | 0)) {
   i1 = 5;
   break;
  }
  HEAP32[i6 >> 2] = HEAP32[i6 >> 2] | i3 << i5;
  if (!(i1 & 128)) {
   i1 = 9;
   break;
  }
  i5 = i5 + 7 | 0;
  if (i5 >>> 0 >= 32) {
   i1 = 8;
   break;
  }
 }
 if ((i1 | 0) == 5) ___assert_fail(23085, 22948, 99, 22966); else if ((i1 | 0) == 8) ___assert_fail(23162, 22948, 104, 22966); else if ((i1 | 0) == 9) return;
}

function __ZN4wasm22SExpressionWasmBuilder14makeThenOrElseERNS_7ElementE(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i5 + 4 >> 2] | 0) | 0;
 i3 = __ZN4wasm7ElementixEj(i4, 1) | 0;
 i2 = i1 + 12 | 0;
 i3 = (HEAP8[i3 >> 0] | 0) == 0 ? 2 : 1;
 while (1) {
  i6 = (__ZN4wasm7Element4listEv(i4) | 0) + 8 | 0;
  if (i3 >>> 0 >= (HEAP32[i6 >> 2] | 0) >>> 0) break;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i5, __ZN4wasm7ElementixEj(i4, i3) | 0) | 0);
  i3 = i3 + 1 | 0;
 }
 __ZN4wasm5Block8finalizeEv(i1);
 return i1 | 0;
}

function __ZN4wasm12FunctionTypeeqERS0_(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0;
 L1 : do if (((HEAP32[i3 >> 2] | 0) == (HEAP32[i2 >> 2] | 0) ? (HEAP32[i3 + 4 >> 2] | 0) == (HEAP32[i2 + 4 >> 2] | 0) : 0) ? (i5 = HEAP32[i3 + 8 >> 2] | 0, i1 = (HEAP32[i3 + 12 >> 2] | 0) - i5 | 0, i3 = HEAP32[i2 + 8 >> 2] | 0, i4 = i3, i5, (i1 | 0) == ((HEAP32[i2 + 12 >> 2] | 0) - i3 | 0)) : 0) {
  i1 = i1 >> 2;
  i2 = 0;
  while (1) {
   if (i2 >>> 0 >= i1 >>> 0) {
    i1 = 1;
    break L1;
   }
   if ((HEAP32[i5 + (i2 << 2) >> 2] | 0) == (HEAP32[i4 + (i2 << 2) >> 2] | 0)) i2 = i2 + 1 | 0; else {
    i1 = 0;
    break;
   }
  }
 } else i1 = 0; while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 24 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 2) | 0;
 i2 = HEAP32[i6 >> 2] | 0;
 if ((i1 | 0) < 24 & (i2 & 4 | 0) == 0) HEAP32[i7 >> 2] = i1; else HEAP32[i6 >> 2] = i2 | 4;
 STACKTOP = i5;
 return;
}

function __ZN4wasm10TypeSeekerC2EPNS_10ExpressionENS_4NameE(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4;
 i6 = i3 + 4 | 0;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i6 + 4 >> 2] = 0;
 HEAP32[i6 + 8 >> 2] = 0;
 HEAP32[i6 + 12 >> 2] = 0;
 HEAP32[i6 + 16 >> 2] = 0;
 HEAP32[i6 + 20 >> 2] = 0;
 HEAP32[i3 >> 2] = 7828;
 HEAP32[i3 + 28 >> 2] = i1;
 HEAP32[i3 + 32 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i3 + 36 >> 2] = 0;
 HEAP32[i3 + 40 >> 2] = 0;
 HEAP32[i3 + 44 >> 2] = 0;
 HEAP32[i5 >> 2] = i1;
 __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i3, i5);
 STACKTOP = i4;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSJ_SJ_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__23mapIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEENS_4lessIS2_EENS4_INS_4pairIKS2_S6_EEEEEixERSA_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_4pairINS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65639, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_6vectorIPN4wasm10CallImportENS_9allocatorIS7_EEEEEENS_19__map_value_compareIS3_SB_NS_4lessIS3_EELb1EEENS8_ISB_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSM_IJEEEEEENS_10unique_ptrINS_11__tree_nodeISB_PvEENS_22__tree_node_destructorINS8_ISU_EEEEEEDpOT_(i4, i5, i1, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i3 = __Znwj(32) | 0;
 HEAP32[i4 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i5 + 4;
 HEAP32[i3 + 16 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 1;
 return;
}

function _ungetc(i1, i5) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 do if ((i1 | 0) != -1) {
  if ((HEAP32[i5 + 76 >> 2] | 0) > -1) i4 = ___lockfile(i5) | 0; else i4 = 0;
  if (!((HEAP32[i5 + 8 >> 2] | 0) == 0 ? (___toread(i5) | 0) != 0 : 0)) i6 = 6;
  if ((i6 | 0) == 6 ? (i2 = i5 + 4 | 0, i3 = HEAP32[i2 >> 2] | 0, i3 >>> 0 > ((HEAP32[i5 + 44 >> 2] | 0) + -8 | 0) >>> 0) : 0) {
   i6 = i3 + -1 | 0;
   HEAP32[i2 >> 2] = i6;
   HEAP8[i6 >> 0] = i1;
   HEAP32[i5 >> 2] = HEAP32[i5 >> 2] & -17;
   if (!i4) break;
   ___unlockfile(i5);
   break;
  }
  if (i4) {
   ___unlockfile(i5);
   i1 = -1;
  } else i1 = -1;
 } else i1 = -1; while (0);
 return i1 | 0;
}

function __ZN4wasm13WasmValidator13visitFunctionEPNS_8FunctionE(i6, i1) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i5 = i1 + 4 | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 if (i3) {
  i4 = i1 + 36 | 0;
  i1 = HEAP32[i4 >> 2] | 0;
  i2 = HEAP32[i1 + 4 >> 2] | 0;
  if ((i2 | 0) != 5) __ZN4wasm13WasmValidator13shouldBeEqualIPNS_10ExpressionENS_8WasmTypeEEEbT0_S5_T_PKc(i6, i3, i2, i1, 20498) | 0;
  i1 = i6 + 44 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  if ((i2 | 0) != 5) __ZN4wasm13WasmValidator13shouldBeEqualIPNS_10ExpressionENS_8WasmTypeEEEbT0_S5_T_PKc(i6, HEAP32[i5 >> 2] | 0, i2, HEAP32[i4 >> 2] | 0, 20549) | 0;
 } else i1 = i6 + 44 | 0;
 HEAP32[i1 >> 2] = 5;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSG_SG_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSI_SI_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSJ_SJ_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__23mapIN4wasm4NameEPNS1_12FunctionTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSH_SH_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE4findIS3_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_SK_SK_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE13parseParennedERPc(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i3);
 i1 = HEAP32[i3 >> 2] | 0;
 if ((HEAP8[i1 >> 0] | 0) != 40) ___assert_fail(31317, 31173, 899, 31525);
 HEAP32[i3 >> 2] = i1 + 1;
 i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i2, i3, 56966) | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i3);
 i2 = HEAP32[i3 >> 2] | 0;
 if ((HEAP8[i2 >> 0] | 0) == 41) {
  HEAP32[i3 >> 2] = i2 + 1;
  return i1 | 0;
 } else ___assert_fail(31539, 31173, 903, 31525);
 return 0;
}

function __ZN4wasm12PassRegistry8PassInfoaSEOS1_(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i3 + 11 | 0;
 if ((HEAP8[i1 >> 0] | 0) < 0) {
  HEAP8[HEAP32[i3 >> 2] >> 0] = 0;
  HEAP32[i3 + 4 >> 2] = 0;
 } else {
  HEAP8[i3 >> 0] = 0;
  HEAP8[i1 >> 0] = 0;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj(i3, 0);
 HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i3 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
 HEAP32[i3 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 __ZNSt3__28functionIFPN4wasm4PassEvEEaSEOS5_(i3 + 16 | 0, i2 + 16 | 0) | 0;
 return i3 | 0;
}

function __ZNSt3__23mapIjNS_6vectorIPN4wasm4CallENS_9allocatorIS4_EEEENS_4lessIjEENS5_INS_4pairIKjS7_EEEEEixERSB_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE25__emplace_unique_key_argsIjJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSK_IJEEEEEENS_4pairINS_15__tree_iteratorIS9_PNS_11__tree_nodeIS9_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSH_SH_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function _atol(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 while (1) {
  i2 = i1 + 1 | 0;
  if (!(_isspace(HEAP8[i1 >> 0] | 0) | 0)) break; else i1 = i2;
 }
 i3 = HEAP8[i1 >> 0] | 0;
 switch (i3 << 24 >> 24 | 0) {
 case 45:
  {
   i4 = 1;
   i5 = 5;
   break;
  }
 case 43:
  {
   i4 = 0;
   i5 = 5;
   break;
  }
 default:
  i4 = 0;
 }
 if ((i5 | 0) == 5) {
  i1 = i2;
  i3 = HEAP8[i2 >> 0] | 0;
 }
 i2 = (i3 << 24 >> 24) + -48 | 0;
 if (i2 >>> 0 < 10) {
  i3 = i1;
  i1 = 0;
  do {
   i3 = i3 + 1 | 0;
   i1 = (i1 * 10 | 0) - i2 | 0;
   i2 = (HEAP8[i3 >> 0] | 0) + -48 | 0;
  } while (i2 >>> 0 < 10);
 } else i1 = 0;
 return (i4 | 0 ? i1 : 0 - i1 | 0) | 0;
}

function _atoi(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 while (1) {
  i2 = i1 + 1 | 0;
  if (!(_isspace(HEAP8[i1 >> 0] | 0) | 0)) break; else i1 = i2;
 }
 i3 = HEAP8[i1 >> 0] | 0;
 switch (i3 << 24 >> 24 | 0) {
 case 45:
  {
   i4 = 1;
   i5 = 5;
   break;
  }
 case 43:
  {
   i4 = 0;
   i5 = 5;
   break;
  }
 default:
  i4 = 0;
 }
 if ((i5 | 0) == 5) {
  i1 = i2;
  i3 = HEAP8[i2 >> 0] | 0;
 }
 i2 = (i3 << 24 >> 24) + -48 | 0;
 if (i2 >>> 0 < 10) {
  i3 = i1;
  i1 = 0;
  do {
   i3 = i3 + 1 | 0;
   i1 = (i1 * 10 | 0) - i2 | 0;
   i2 = (HEAP8[i3 >> 0] | 0) + -48 | 0;
  } while (i2 >>> 0 < 10);
 } else i1 = 0;
 return (i4 | 0 ? i1 : 0 - i1 | 0) | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5eraseENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i1) | 0;
 if ((HEAP32[i3 >> 2] | 0) == (i1 | 0)) HEAP32[i3 >> 2] = i2;
 i4 = i3 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -1;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i3 + 4 >> 2] | 0, i1);
 __ZN4wasm14EffectAnalyzerD2Ev(i1 + 24 | 0);
 __ZdlPv(i1);
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSG_SG_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEEC2EjjSD_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEEC2EjjSD_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSH_SH_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSH_SH_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__214__split_bufferINS_6vectorIN6cashew6ParserINS2_3RefENS2_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS7_EEEERNS8_ISA_EEEC2EjjSC_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 357913941) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 * 12 | 0) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 * 12 | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 * 12 | 0);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE4findIS3_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_SK_SK_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__214__split_bufferINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEERNS8_ISD_EEEC2EjjSF_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 214748364) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 * 20 | 0) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 * 20 | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 * 20 | 0);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__23mapIN4wasm4NameEPNS1_8FunctionENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  i3 = i3 + -16 | 0;
  HEAP32[i2 >> 2] = i3;
  __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i3);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE10deallocateEPcj(HEAP32[HEAP32[i4 + 16 >> 2] >> 2] | 0, i1, (HEAP32[i4 + 12 >> 2] | 0) - i1 | 0);
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doWalkModuleEPNS_6ModuleE(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i6;
 i4 = i1 + -16 | 0;
 HEAP32[i5 >> 2] = i1;
 i2 = HEAP32[i3 + 40 >> 2] | 0;
 i1 = HEAP32[i3 + 36 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  __ZZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doWalkModuleEPNS_6ModuleEENKUlS9_PS4_S3_E_clES9_SA_S3_(i5, 0, i4, HEAP32[i1 >> 2] | 0);
  i1 = i1 + 4 | 0;
 }
 STACKTOP = i6;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doWalkModuleEPNS_6ModuleE(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i6;
 i4 = i1 + -16 | 0;
 HEAP32[i5 >> 2] = i1;
 i2 = HEAP32[i3 + 40 >> 2] | 0;
 i1 = HEAP32[i3 + 36 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  __ZZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doWalkModuleEPNS_6ModuleEENKUlS9_PS4_S3_E_clES9_SA_S3_(i5, 0, i4, HEAP32[i1 >> 2] | 0);
  i1 = i1 + 4 | 0;
 }
 STACKTOP = i6;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixEOS2_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJOS3_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEEC2EjjSD_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__23mapIN4wasm4NameEPNS1_6ImportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__23mapIN4wasm4NameEPNS1_6ExportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}
function __ZNSt3__213__vector_baseINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEENS_9allocatorISC_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 >> 2] | 0;
 if (i2 | 0) {
  i3 = i4 + 4 | 0;
  while (1) {
   i1 = HEAP32[i3 >> 2] | 0;
   if ((i1 | 0) == (i2 | 0)) break;
   i5 = i1 + -4 | 0;
   HEAP32[i3 >> 2] = i5;
   i1 = HEAP32[i5 >> 2] | 0;
   HEAP32[i5 >> 2] = 0;
   if (!i1) continue;
   __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE10BasicBlockD2Ev(i1);
   __ZdlPv(i1);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function ___divdi3(i1, i2, i3, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i5 = 0, i6 = 0, i7 = 0, i8 = 0, i9 = 0, i10 = 0;
 i10 = i2 >> 31 | ((i2 | 0) < 0 ? -1 : 0) << 1;
 i9 = ((i2 | 0) < 0 ? -1 : 0) >> 31 | ((i2 | 0) < 0 ? -1 : 0) << 1;
 i6 = i4 >> 31 | ((i4 | 0) < 0 ? -1 : 0) << 1;
 i5 = ((i4 | 0) < 0 ? -1 : 0) >> 31 | ((i4 | 0) < 0 ? -1 : 0) << 1;
 i8 = _i64Subtract(i10 ^ i1 | 0, i9 ^ i2 | 0, i10 | 0, i9 | 0) | 0;
 i7 = tempRet0;
 i1 = i6 ^ i10;
 i2 = i5 ^ i9;
 return _i64Subtract((___udivmoddi4(i8, i7, _i64Subtract(i6 ^ i3 | 0, i5 ^ i4 | 0, i6 | 0, i5 | 0) | 0, tempRet0, 0) | 0) ^ i1 | 0, tempRet0 ^ i2 | 0, i1 | 0, i2 | 0) | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSG_SG_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSF_SF_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__23mapIN4wasm4NameEPNS1_6ExportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixEOS2_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJOS3_EEENSI_IJEEEEEENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE16unlinkDeadBlocksENSt3__213unordered_setIPNS5_10BasicBlockENS6_4hashIS9_EENS6_8equal_toIS9_EENS6_9allocatorIS9_EEEEENKUlS9_E0_clES9_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3;
 HEAP32[i4 >> 2] = i1;
 i2 = (__ZNKSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE4findIS9_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEERKT_(HEAP32[i2 >> 2] | 0, i4) | 0) == 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockENS_14default_deleteIS9_EEEERNS_9allocatorISC_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 + 4 >> 2] | 0;
 i3 = i4 + 8 | 0;
 while (1) {
  i1 = HEAP32[i3 >> 2] | 0;
  if ((i1 | 0) == (i2 | 0)) break;
  i5 = i1 + -4 | 0;
  HEAP32[i3 >> 2] = i5;
  i1 = HEAP32[i5 >> 2] | 0;
  HEAP32[i5 >> 2] = 0;
  if (!i1) continue;
  __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE10BasicBlockD2Ev(i1);
  __ZdlPv(i1);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__213__vector_baseINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   i3 = i3 + -16 | 0;
   HEAP32[i2 >> 2] = i3;
   __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i3);
  }
  i3 = HEAP32[i4 >> 2] | 0;
  __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE10deallocateEPcj(HEAP32[i4 + 12 >> 2] | 0, i3, (HEAP32[i4 + 8 >> 2] | 0) - i3 | 0);
 }
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj5EEERAT__Kc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP8[i2 + 11 >> 0] = 4;
 i1 = HEAPU8[i1 >> 0] | HEAPU8[i1 + 1 >> 0] << 8 | HEAPU8[i1 + 2 >> 0] << 16 | HEAPU8[i1 + 3 >> 0] << 24;
 HEAP8[i2 >> 0] = i1;
 HEAP8[i2 + 1 >> 0] = i1 >> 8;
 HEAP8[i2 + 2 >> 0] = i1 >> 16;
 HEAP8[i2 + 3 >> 0] = i1 >> 24;
 HEAP8[i2 + 4 >> 0] = 0;
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE16unlinkDeadBlocksENSt3__213unordered_setIPNS5_10BasicBlockENS6_4hashIS9_EENS6_8equal_toIS9_EENS6_9allocatorIS9_EEEEENKUlS9_E_clES9_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3;
 HEAP32[i4 >> 2] = i1;
 i2 = (__ZNKSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE4findIS9_EENS_21__hash_const_iteratorIPNS_11__hash_nodeIS9_PvEEEERKT_(HEAP32[i2 >> 2] | 0, i4) | 0) == 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSG_SG_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNKSt3__27codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_j(i1, i10, i2, i8, i9) {
 i1 = i1 | 0;
 i10 = i10 | 0;
 i2 = i2 | 0;
 i8 = i8 | 0;
 i9 = i9 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i7 = i8;
 i6 = i1 + 8 | 0;
 i1 = 0;
 i5 = 0;
 L1 : while (1) {
  if ((i2 | 0) == (i8 | 0) | i5 >>> 0 >= i9 >>> 0) break;
  i4 = _uselocale(HEAP32[i6 >> 2] | 0) | 0;
  i3 = _mbrlen(i2, i7 - i2 | 0, i10) | 0;
  if (i4 | 0) _uselocale(i4) | 0;
  switch (i3 | 0) {
  case -2:
  case -1:
   break L1;
  case 0:
   {
    i2 = i2 + 1 | 0;
    i3 = 1;
    break;
   }
  default:
   i2 = i2 + i3 | 0;
  }
  i1 = i3 + i1 | 0;
  i5 = i5 + 1 | 0;
 }
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj6EEERAT__Kc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP8[i2 + 11 >> 0] = 5;
 HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
 HEAP8[i2 + 1 >> 0] = HEAP8[i1 + 1 >> 0] | 0;
 HEAP8[i2 + 2 >> 0] = HEAP8[i1 + 2 >> 0] | 0;
 HEAP8[i2 + 3 >> 0] = HEAP8[i1 + 3 >> 0] | 0;
 HEAP8[i2 + 4 >> 0] = HEAP8[i1 + 4 >> 0] | 0;
 HEAP8[i2 + 5 >> 0] = 0;
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSF_SF_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS8_PvEENS_22__tree_node_destructorINS5_ISR_EEEEEEDpOT_(i4, i5, i1, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i3 = __Znwj(32) | 0;
 HEAP32[i4 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i5 + 4;
 HEAP32[i3 + 16 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 1;
 return;
}

function __ZN4wasm10PassRunner3addINS_7PrinterENSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEEEvRT0_(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i6;
 i4 = __Znwj(20) | 0;
 __ZN4wasm4PassC2Ev(i4);
 HEAP32[i4 >> 2] = 5456;
 HEAP32[i4 + 16 >> 2] = i1;
 HEAP32[i3 >> 2] = i4;
 i1 = i5 + 12 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if (i2 >>> 0 < (HEAP32[i5 + 16 >> 2] | 0) >>> 0) {
  HEAP32[i2 >> 2] = i4;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
 } else __ZNSt3__26vectorIPN4wasm4PassENS_9allocatorIS3_EEE21__push_back_slow_pathIS3_EEvOT_(i5 + 8 | 0, i3);
 STACKTOP = i6;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSF_SF_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__214__split_bufferINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEERNS7_ISC_EEEC2EjjSE_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 357913941) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 * 12 | 0) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 * 12 | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 * 12 | 0);
 return;
}

function __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE13shrink_to_fitEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i4;
 i5 = HEAP32[i3 >> 2] | 0;
 i1 = (HEAP32[i3 + 4 >> 2] | 0) - i5 | 0;
 if (((HEAP32[i3 + 8 >> 2] | 0) - i5 | 0) >>> 0 > i1 >>> 0) {
  i5 = i1 >> 2;
  __ZNSt3__214__split_bufferIN6cashew3RefERNS_9allocatorIS2_EEEC2EjjS5_(i2, i5, i5, i3 + 8 | 0);
  __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i3, i2);
  __ZNSt3__214__split_bufferIN6cashew3RefERNS_9allocatorIS2_EEED2Ev(i2);
 }
 STACKTOP = i4;
 return;
}

function __ZNSt3__24stoiERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPji(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP32[i5 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i5, 55920, 4);
 i3 = __ZNSt3__212_GLOBAL__N_117as_integer_helperIlNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFlPKcPPciEEET_RKS7_RKT0_PjiT1_(i5, i3, i2, i1) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5);
 STACKTOP = i4;
 return i3 | 0;
}

function ___fflush_unlocked(i7) {
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i1 = i7 + 20 | 0;
 i5 = i7 + 28 | 0;
 if ((HEAP32[i1 >> 2] | 0) >>> 0 > (HEAP32[i5 >> 2] | 0) >>> 0 ? (FUNCTION_TABLE_iiii[HEAP32[i7 + 36 >> 2] & 31](i7, 0, 0) | 0, (HEAP32[i1 >> 2] | 0) == 0) : 0) i1 = -1; else {
  i6 = i7 + 4 | 0;
  i2 = HEAP32[i6 >> 2] | 0;
  i3 = i7 + 8 | 0;
  i4 = HEAP32[i3 >> 2] | 0;
  if (i2 >>> 0 < i4 >>> 0) FUNCTION_TABLE_iiii[HEAP32[i7 + 40 >> 2] & 31](i7, i2 - i4 | 0, 1) | 0;
  HEAP32[i7 + 16 >> 2] = 0;
  HEAP32[i5 >> 2] = 0;
  HEAP32[i1 >> 2] = 0;
  HEAP32[i3 >> 2] = 0;
  HEAP32[i6 >> 2] = 0;
  i1 = 0;
 }
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSK_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS9_PvEENS_22__tree_node_destructorINS6_ISS_EEEEEEDpOT_(i4, i5, i1, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i3 = __Znwj(32) | 0;
 HEAP32[i4 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i5 + 4;
 HEAP32[i3 + 16 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSJ_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS8_PvEENS_22__tree_node_destructorINS5_ISR_EEEEEEDpOT_(i4, i5, i1, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i3 = __Znwj(32) | 0;
 HEAP32[i4 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i5 + 4;
 HEAP32[i3 + 16 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 1;
 return;
}

function __ZN4wasm16PrintSExpression13visitGetLocalEPNS_8GetLocalE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 4 | 0;
 i6 = i3;
 i5 = __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i2 >> 2] | 0, 34742, 0) | 0;
 i2 = __ZN4wasm16PrintSExpression14printableLocalEj(i2, HEAP32[i1 + 8 >> 2] | 0) | 0;
 HEAP32[i6 >> 2] = i2;
 HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i5, i4) | 0, 41) | 0;
 STACKTOP = i3;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE4findIS3_EENS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEERKT_SI_SI_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__215__num_get_floatIfEET_PKcS3_Rj(i2, i5, i6) {
 i2 = i2 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var d1 = 0.0, i3 = 0, i4 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i8;
 if ((i2 | 0) == (i5 | 0)) {
  HEAP32[i6 >> 2] = 4;
  d1 = 0.0;
 } else {
  i3 = ___errno_location() | 0;
  i4 = HEAP32[i3 >> 2] | 0;
  HEAP32[i3 >> 2] = 0;
  d1 = +_strtold_l(i2, i7, __ZNSt3__26__clocEv() | 0);
  i2 = HEAP32[i3 >> 2] | 0;
  if (!i2) HEAP32[i3 >> 2] = i4;
  if ((HEAP32[i7 >> 2] | 0) == (i5 | 0)) {
   if ((i2 | 0) == 34) HEAP32[i6 >> 2] = 4;
  } else {
   HEAP32[i6 >> 2] = 4;
   d1 = 0.0;
  }
 }
 STACKTOP = i8;
 return +d1;
}

function __ZNSt3__215__num_get_floatIeEET_PKcS3_Rj(i2, i5, i6) {
 i2 = i2 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var d1 = 0.0, i3 = 0, i4 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i8;
 if ((i2 | 0) == (i5 | 0)) {
  HEAP32[i6 >> 2] = 4;
  d1 = 0.0;
 } else {
  i3 = ___errno_location() | 0;
  i4 = HEAP32[i3 >> 2] | 0;
  HEAP32[i3 >> 2] = 0;
  d1 = +_strtold_l(i2, i7, __ZNSt3__26__clocEv() | 0);
  i2 = HEAP32[i3 >> 2] | 0;
  if (!i2) HEAP32[i3 >> 2] = i4;
  if ((HEAP32[i7 >> 2] | 0) == (i5 | 0)) {
   if ((i2 | 0) == 34) HEAP32[i6 >> 2] = 4;
  } else {
   HEAP32[i6 >> 2] = 4;
   d1 = 0.0;
  }
 }
 STACKTOP = i8;
 return +d1;
}

function __ZNSt3__215__num_get_floatIdEET_PKcS3_Rj(i2, i5, i6) {
 i2 = i2 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 var d1 = 0.0, i3 = 0, i4 = 0, i7 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i8;
 if ((i2 | 0) == (i5 | 0)) {
  HEAP32[i6 >> 2] = 4;
  d1 = 0.0;
 } else {
  i3 = ___errno_location() | 0;
  i4 = HEAP32[i3 >> 2] | 0;
  HEAP32[i3 >> 2] = 0;
  d1 = +_strtold_l(i2, i7, __ZNSt3__26__clocEv() | 0);
  i2 = HEAP32[i3 >> 2] | 0;
  if (!i2) HEAP32[i3 >> 2] = i4;
  if ((HEAP32[i7 >> 2] | 0) == (i5 | 0)) {
   if ((i2 | 0) == 34) HEAP32[i6 >> 2] = 4;
  } else {
   HEAP32[i6 >> 2] = 4;
   d1 = 0.0;
  }
 }
 STACKTOP = i8;
 return +d1;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE16__construct_nodeIJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSK_IJEEEEEENS_10unique_ptrINS_11__tree_nodeIS9_PvEENS_22__tree_node_destructorINS6_ISS_EEEEEEDpOT_(i4, i5, i1, i2, i3) {
 i4 = i4 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i3 = __Znwj(32) | 0;
 HEAP32[i4 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i5 + 4;
 HEAP32[i3 + 16 >> 2] = HEAP32[HEAP32[i2 >> 2] >> 2];
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i3 + 24 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 1;
 return;
}

function __ZN4wasm6Binary8finalizeEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 switch (HEAP32[i1 + 8 >> 2] | 0) {
 case 62:
 case 61:
 case 60:
 case 59:
 case 58:
 case 57:
 case 49:
 case 48:
 case 47:
 case 46:
 case 45:
 case 44:
 case 43:
 case 42:
 case 41:
 case 40:
 case 24:
 case 23:
 case 22:
 case 21:
 case 20:
 case 19:
 case 18:
 case 17:
 case 16:
 case 15:
 case 75:
 case 74:
 case 73:
 case 72:
 case 71:
 case 70:
  {
   HEAP32[i1 + 4 >> 2] = 1;
   break;
  }
 default:
  {
   i2 = HEAP32[(HEAP32[i1 + 12 >> 2] | 0) + 4 >> 2] | 0;
   HEAP32[i1 + 4 >> 2] = (i2 | 0) != 5 ? i2 : HEAP32[(HEAP32[i1 + 16 >> 2] | 0) + 4 >> 2] | 0;
  }
 }
 return;
}

function _strtox_17(i7, i6, i1) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 var d2 = 0.0, i3 = 0, i4 = 0, i5 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i5 = i8;
 i3 = i5;
 i4 = i3 + 112 | 0;
 do {
  HEAP32[i3 >> 2] = 0;
  i3 = i3 + 4 | 0;
 } while ((i3 | 0) < (i4 | 0));
 i3 = i5 + 4 | 0;
 HEAP32[i3 >> 2] = i7;
 i4 = i5 + 8 | 0;
 HEAP32[i4 >> 2] = -1;
 HEAP32[i5 + 44 >> 2] = i7;
 HEAP32[i5 + 76 >> 2] = -1;
 ___shlim(i5, 0);
 d2 = +___floatscan(i5, i1, 1);
 i1 = (HEAP32[i3 >> 2] | 0) - (HEAP32[i4 >> 2] | 0) + (HEAP32[i5 + 108 >> 2] | 0) | 0;
 if (i6 | 0) HEAP32[i6 >> 2] = i1 | 0 ? i7 + i1 | 0 : i7;
 STACKTOP = i8;
 return +d2;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__214__split_bufferIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockERNS_9allocatorIS9_EEEC2EjjSC_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEERNS8_ISD_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  i3 = i3 + -20 | 0;
  HEAP32[i2 >> 2] = i3;
  __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i3);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN6cashew12ValueBuilder7makeVarEb(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i2 + 8 | 0;
 i5 = i2 + 4 | 0;
 i4 = i2;
 i3 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i6 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59296) | 0;
 HEAP32[i5 >> 2] = i6;
 HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
 HEAP32[i4 >> 2] = i5;
 HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder12makeSetLocalERNS_7ElementE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i3 = __ZN10MixedArena5allocIN4wasm8SetLocalEEEPT_v(HEAP32[i2 + 4 >> 2] | 0) | 0;
 i5 = __ZN4wasm22SExpressionWasmBuilder13getLocalIndexERNS_7ElementE(i2, __ZN4wasm7ElementixEj(i1, 1) | 0) | 0;
 i4 = i3 + 8 | 0;
 HEAP32[i4 >> 2] = i5;
 i1 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i2, __ZN4wasm7ElementixEj(i1, 2) | 0) | 0;
 HEAP32[i3 + 12 >> 2] = i1;
 i2 = __ZN4wasm8Function12getLocalTypeEj(HEAP32[i2 + 40 >> 2] | 0, HEAP32[i4 >> 2] | 0) | 0;
 HEAP32[i3 + 4 >> 2] = i2;
 return i3 | 0;
}

function __ZNSt3__23mapIN6cashew7IStringEiNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_iEEEEEixERS7_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSG_IJEEEEEENS_4pairINS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__213__vector_baseINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   i3 = i3 + -20 | 0;
   HEAP32[i2 >> 2] = i3;
   __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i3);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function __ZNSt3__23mapIPN4wasm8FunctionEjNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_jEEEEEixEOS3_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS4_JRKNS_21piecewise_construct_tENS_5tupleIJOS4_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65639, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZN6cashew12ValueBuilder12makeToplevelEv() {
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i2 + 8 | 0;
 i5 = i2 + 4 | 0;
 i4 = i2;
 i3 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i6 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59272) | 0;
 HEAP32[i5 >> 2] = i6;
 HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
 HEAP32[i4 >> 2] = i5;
 HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZN4wasm8LocalSet5eraseEj(i5, i2) {
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i4 = 0, i6 = 0;
 i4 = HEAP32[i5 >> 2] | 0;
 i3 = (HEAP32[i5 + 4 >> 2] | 0) - i4 >> 2;
 i1 = 0;
 while (1) {
  if (i1 >>> 0 >= i3 >>> 0) {
   i1 = 0;
   break;
  }
  if ((HEAP32[i4 + (i1 << 2) >> 2] | 0) == (i2 | 0)) {
   i2 = i1;
   i6 = 4;
   break;
  }
  i1 = i1 + 1 | 0;
 }
 if ((i6 | 0) == 4) {
  while (1) {
   i1 = i2 + 1 | 0;
   if (i1 >>> 0 >= i3 >>> 0) break;
   HEAP32[i4 + (i2 << 2) >> 2] = HEAP32[i4 + (i1 << 2) >> 2];
   i2 = i1;
   i6 = 4;
  }
  __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i5, i3 + -1 | 0);
  i1 = 1;
 }
 return i1 | 0;
}

function __ZN4wasm14GeneticLearnerIZNS_26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS2_9allocatorIjEEEEE5OrderdZNS1_11pickIndicesES7_E9GeneratorE4sortEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i2;
 i5 = HEAP32[i1 + 4 >> 2] | 0;
 i4 = HEAP32[i1 + 8 >> 2] | 0;
 HEAP32[i3 >> 2] = i1;
 __ZNSt3__26__sortIRZN4wasm14GeneticLearnerIZNS1_26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderdZNS3_11pickIndicesES8_E9GeneratorE4sortEvEUlRKNS_10unique_ptrIS9_NS_14default_deleteIS9_EEEESH_E_PSF_EEvT0_SL_T_(i5, i4, i3);
 STACKTOP = i2;
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE4dumpEPKcPc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i6;
 i5 = HEAP32[1961] | 0;
 HEAP32[i3 >> 2] = i2;
 _fprintf(i5, 31253, i3) | 0;
 i3 = 200;
 i2 = 2;
 L1 : while (1) {
  i4 = HEAP8[i1 >> 0] | 0;
  switch (i4 << 24 >> 24) {
  case 0:
   break L1;
  case 10:
   {
    i2 = i2 + -1 | 0;
    if (!i2) break L1;
    break;
   }
  default:
   {}
  }
  i3 = i3 + -1 | 0;
  if (!i3) break;
  _fputc(i4 << 24 >> 24, i5) | 0;
  i1 = i1 + 1 | 0;
 }
 _fwrite(31269, 2, 1, i5) | 0;
 STACKTOP = i6;
 return;
}

function __ZN6cashew12ValueBuilder10makeObjectEv() {
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i2 + 8 | 0;
 i5 = i2 + 4 | 0;
 i4 = i2;
 i3 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i6 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59604) | 0;
 HEAP32[i5 >> 2] = i6;
 HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
 HEAP32[i4 >> 2] = i5;
 HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__23mapIPN4wasm6ExportEjNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_jEEEEEixERS8_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE25__emplace_unique_key_argsIS4_JRKNS_21piecewise_construct_tENS_5tupleIJRKS4_EEENSH_IJEEEEEENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZNSt3__23mapIN4wasm4NameES2_NS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S2_EEEEEixERS7_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSG_IJEEEEEENS_4pairINS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65639, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSD_SD_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZN6cashew12ValueBuilder9makeBlockEv() {
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i2 + 8 | 0;
 i5 = i2 + 4 | 0;
 i4 = i2;
 i3 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i6 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59280) | 0;
 HEAP32[i5 >> 2] = i6;
 HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
 HEAP32[i4 >> 2] = i5;
 HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZN6cashew12ValueBuilder9makeArrayEv() {
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i2 + 8 | 0;
 i5 = i2 + 4 | 0;
 i4 = i2;
 i3 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i6 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59600) | 0;
 HEAP32[i5 >> 2] = i6;
 HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
 i3 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 i5 = __ZN6cashew12ValueBuilder12makeRawArrayEi(0) | 0;
 HEAP32[i4 >> 2] = i5;
 HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE7reserveEj(i4, i2) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i5;
 i1 = HEAP32[i4 >> 2] | 0;
 if ((HEAP32[i4 + 8 >> 2] | 0) - i1 >> 4 >>> 0 < i2 >>> 0) {
  __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEEC2EjjS5_(i3, i2, (HEAP32[i4 + 4 >> 2] | 0) - i1 >> 4, i4 + 8 | 0);
  __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i4, i3);
  __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEED2Ev(i3);
 }
 STACKTOP = i5;
 return;
}

function __ZN4wasm14EffectAnalyzerC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 5392;
 HEAP8[i1 + 28 >> 0] = 0;
 HEAP8[i1 + 29 >> 0] = 0;
 HEAP32[i1 + 36 >> 2] = 0;
 HEAP32[i1 + 40 >> 2] = 0;
 HEAP32[i1 + 32 >> 2] = i1 + 36;
 HEAP32[i1 + 48 >> 2] = 0;
 HEAP32[i1 + 52 >> 2] = 0;
 HEAP32[i1 + 44 >> 2] = i1 + 48;
 HEAP8[i1 + 56 >> 0] = 0;
 HEAP8[i1 + 57 >> 0] = 0;
 HEAP32[i1 + 64 >> 2] = 0;
 HEAP32[i1 + 68 >> 2] = 0;
 HEAP32[i1 + 60 >> 2] = i1 + 64;
 return;
}

function __ZZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder18parseFunctionNamesERNS_7ElementERNS_4NameES4_(i1, i5, i4, i3) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i2 = 0, i6 = 0;
 i1 = 1;
 while (1) {
  i2 = (__ZN4wasm7Element4listEv(i5) | 0) + 8 | 0;
  if (i1 >>> 0 >= (HEAP32[i2 >> 2] | 0) >>> 0) break;
  i2 = __ZN4wasm7ElementixEj(i5, i1) | 0;
  if (HEAP8[i2 >> 0] | 0) break;
  i6 = (__ZN4wasm7ElementixEj(i5, i1) | 0) + 24 | 0;
  i6 = (HEAP8[i6 >> 0] | 0) == 0;
  i2 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i5, i1) | 0) | 0;
  if (i6) HEAP32[i3 >> 2] = i2; else HEAP32[i4 >> 2] = i2;
  i1 = i1 + 1 | 0;
 }
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pair9move_fullEv(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0, i5 = 0;
 i5 = i1 + 12 | 0;
 i2 = HEAP8[i5 + 11 >> 0] | 0;
 i4 = i2 << 24 >> 24 < 0;
 i2 = __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i1, i4 ? HEAP32[i5 >> 2] | 0 : i5, i4 ? HEAP32[i1 + 16 >> 2] | 0 : i2 & 255) | 0;
 HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i3 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
 HEAP32[i3 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__23mapIN4wasm4NameEjNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_jEEEEEixERS7_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE25__emplace_unique_key_argsIS3_JRKNS_21piecewise_construct_tENS_5tupleIJRKS3_EEENSG_IJEEEEEENS_4pairINS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 63613, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_SH_SH_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZN6cashew12ValueBuilder24appendArgumentToFunctionENS_3RefENS_7IStringE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i2 = i5;
 if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i4, 0) | 0, 59276) | 0) {
  i4 = __ZN6cashew3RefixEj(i4, 2) | 0;
  i4 = HEAP32[i4 >> 2] | 0;
  i3 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i3) | 0;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN6cashew5Value9push_backENS_3RefE(i4, i1) | 0;
  STACKTOP = i5;
  return;
 } else ___assert_fail(31347, 48272, 1509, 31364);
}

function __ZZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__214__split_bufferIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementERNS_9allocatorIS6_EEEC2EjjS9_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function _vasprintf(i7, i6, i5) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i8 = 0;
 i8 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i8;
 i2 = _malloc(240) | 0;
 do if (i2) {
  HEAP32[i1 >> 2] = HEAP32[i5 >> 2];
  i1 = _vsnprintf(i2, 240, i6, i1) | 0;
  if (i1 >>> 0 < 240) {
   i6 = _realloc(i2, i1 + 1 | 0) | 0;
   HEAP32[i7 >> 2] = i6 | 0 ? i6 : i2;
   break;
  }
  _free(i2);
  if ((i1 | 0) >= 0 ? (i4 = i1 + 1 | 0, i3 = _malloc(i4) | 0, HEAP32[i7 >> 2] = i3, (i3 | 0) != 0) : 0) i1 = _vsnprintf(i3, i4, i6, i5) | 0; else i1 = -1;
 } else i1 = -1; while (0);
 STACKTOP = i8;
 return i1 | 0;
}

function _getc(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 if ((HEAP32[i4 + 76 >> 2] | 0) >= 0 ? (___lockfile(i4) | 0) != 0 : 0) {
  i1 = i4 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  if (i2 >>> 0 < (HEAP32[i4 + 8 >> 2] | 0) >>> 0) {
   HEAP32[i1 >> 2] = i2 + 1;
   i1 = HEAPU8[i2 >> 0] | 0;
  } else i1 = ___uflow(i4) | 0;
  ___unlockfile(i4);
 } else i3 = 3;
 do if ((i3 | 0) == 3) {
  i1 = i4 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  if (i2 >>> 0 < (HEAP32[i4 + 8 >> 2] | 0) >>> 0) {
   HEAP32[i1 >> 2] = i2 + 1;
   i1 = HEAPU8[i2 >> 0] | 0;
   break;
  } else {
   i1 = ___uflow(i4) | 0;
   break;
  }
 } while (0);
 return i1 | 0;
}

function __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE7reserveEj(i4, i2) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i3 = i5;
 i1 = HEAP32[i4 >> 2] | 0;
 if ((HEAP32[i4 + 8 >> 2] | 0) - i1 >> 2 >>> 0 < i2 >>> 0) {
  __ZNSt3__214__split_bufferIN6cashew3RefERNS_9allocatorIS2_EEEC2EjjS5_(i3, i2, (HEAP32[i4 + 4 >> 2] | 0) - i1 >> 2, i4 + 8 | 0);
  __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE(i4, i3);
  __ZNSt3__214__split_bufferIN6cashew3RefERNS_9allocatorIS2_EEED2Ev(i3);
 }
 STACKTOP = i5;
 return;
}

function __ZZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function _realloc(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0;
 if (!i3) {
  i3 = _malloc(i2) | 0;
  return i3 | 0;
 }
 if (i2 >>> 0 > 4294967231) {
  i3 = ___errno_location() | 0;
  HEAP32[i3 >> 2] = 12;
  i3 = 0;
  return i3 | 0;
 }
 i1 = _try_realloc_chunk(i3 + -8 | 0, i2 >>> 0 < 11 ? 16 : i2 + 11 & -8) | 0;
 if (i1 | 0) {
  i3 = i1 + 8 | 0;
  return i3 | 0;
 }
 i1 = _malloc(i2) | 0;
 if (!i1) {
  i3 = 0;
  return i3 | 0;
 }
 i4 = HEAP32[i3 + -4 >> 2] | 0;
 i4 = (i4 & -8) - ((i4 & 3 | 0) == 0 ? 8 : 4) | 0;
 _memcpy(i1 | 0, i3 | 0, (i4 >>> 0 < i2 >>> 0 ? i4 : i2) | 0) | 0;
 _free(i3);
 i3 = i1;
 return i3 | 0;
}

function __ZZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZZN4wasm6WalkerINS_14FunctionHasherENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_14FunctionHasherENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_SH_SH_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZNSt3__23mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS3_EEEEE2atERS8_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = __ZNKSt3__23mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS3_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS8_(i2, i3, i1) | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 if (!i1) {
  i3 = ___cxa_allocate_exception(8) | 0;
  __ZNSt11logic_errorC2EPKc(i3, 45399);
  HEAP32[i3 >> 2] = 15472;
  ___cxa_throw(i3 | 0, 4160, 275);
 } else {
  STACKTOP = i3;
  return i1 + 20 | 0;
 }
 return 0;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function _memcpy(i1, i4, i2) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 if ((i2 | 0) >= 4096) return _emscripten_memcpy_big(i1 | 0, i4 | 0, i2 | 0) | 0;
 i3 = i1 | 0;
 if ((i1 & 3) == (i4 & 3)) {
  while (i1 & 3) {
   if (!i2) return i3 | 0;
   HEAP8[i1 >> 0] = HEAP8[i4 >> 0] | 0;
   i1 = i1 + 1 | 0;
   i4 = i4 + 1 | 0;
   i2 = i2 - 1 | 0;
  }
  while ((i2 | 0) >= 4) {
   HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
   i1 = i1 + 4 | 0;
   i4 = i4 + 4 | 0;
   i2 = i2 - 4 | 0;
  }
 }
 while ((i2 | 0) > 0) {
  HEAP8[i1 >> 0] = HEAP8[i4 >> 0] | 0;
  i1 = i1 + 1 | 0;
  i4 = i4 + 1 | 0;
  i2 = i2 - 1 | 0;
 }
 return i3 | 0;
}

function __ZZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE12__deallocateEPNS_11__hash_nodeIS6_PvEE(i2, HEAP32[i2 + 8 >> 2] | 0);
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZN7AsmData8addParamEN6cashew7IStringE7AsmType(i4, i3, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZNSt3__213unordered_mapIN6cashew7IStringEN7AsmData5LocalENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERSB_(i4, i3) | 0;
 HEAP32[i2 >> 2] = i1;
 HEAP8[i2 + 4 >> 0] = 1;
 i1 = i4 + 24 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[i4 + 28 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4 + 20 | 0, i3); else {
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE4findIjEENS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEERKT_(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0;
 i4 = i1 + 4 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 i1 = i4;
 i2 = i4;
 L1 : while (1) {
  while (1) {
   i2 = HEAP32[i2 >> 2] | 0;
   if (!i2) break L1;
   if ((HEAP32[i2 + 16 >> 2] | 0) >>> 0 >= i3 >>> 0) break;
   i2 = i2 + 4 | 0;
  }
  i1 = i2;
 }
 if (!((i1 | 0) != (i4 | 0) ? i3 >>> 0 >= (HEAP32[i1 + 16 >> 2] | 0) >>> 0 : 0)) i1 = i4;
 return i1 | 0;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZN7AsmData6addVarEN6cashew7IStringE7AsmType(i4, i3, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZNSt3__213unordered_mapIN6cashew7IStringEN7AsmData5LocalENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERSB_(i4, i3) | 0;
 HEAP32[i2 >> 2] = i1;
 HEAP8[i2 + 4 >> 0] = 0;
 i1 = i4 + 36 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[i4 + 40 >> 2] | 0)) __ZNSt3__26vectorIN6cashew7IStringENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i4 + 32 | 0, i3); else {
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
 }
 return;
}

function __ZZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPci(i7, i1, i6) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i4 = i7 + 12 | 0;
 i5 = i7 + 16 | 0;
 i3 = i1;
 i1 = 0;
 while (1) {
  if ((i1 | 0) >= (i6 | 0)) break;
  i2 = HEAP32[i4 >> 2] | 0;
  if (i2 >>> 0 < (HEAP32[i5 >> 2] | 0) >>> 0) {
   HEAP32[i4 >> 2] = i2 + 1;
   i2 = HEAP8[i2 >> 0] | 0;
  } else {
   i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i7 >> 2] | 0) + 40 >> 2] & 255](i7) | 0;
   if ((i2 | 0) == -1) break;
   i2 = i2 & 255;
  }
  HEAP8[i3 >> 0] = i2;
  i3 = i3 + 1 | 0;
  i1 = i1 + 1 | 0;
 }
 return i1 | 0;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZN4wasm19DeadCodeElimination17doAfterIfElseTrueEPS0_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0) + 16 | 0;
 if (!(HEAP32[i1 >> 2] | 0)) ___assert_fail(33165, 33179, 150, 33214); else {
  i3 = i2 + 72 | 0;
  i4 = i2 + 76 | 0;
  i5 = (HEAP32[i4 >> 2] | 0) + -1 | 0;
  i1 = (1 << (i5 & 31) & HEAP32[(HEAP32[i3 >> 2] | 0) + (i5 >>> 5 << 2) >> 2] | 0) != 0;
  HEAP32[i4 >> 2] = i5;
  i2 = i2 + 44 | 0;
  __ZNSt3__26vectorIbNS_9allocatorIbEEE9push_backERKb(i3, i2);
  HEAP8[i2 >> 0] = i1 & 1;
  return;
 }
}

function __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEEC2ERKS6_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 HEAP32[i7 >> 2] = 0;
 i1 = i7 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i7 + 8 >> 2] = 0;
 i3 = i6 + 4 | 0;
 i4 = (HEAP32[i3 >> 2] | 0) - (HEAP32[i6 >> 2] | 0) >> 2;
 if (i4 | 0 ? (__ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE8allocateEj(i7, i4), i5 = HEAP32[i6 >> 2] | 0, i2 = (HEAP32[i3 >> 2] | 0) - i5 | 0, (i2 | 0) > 0) : 0) {
  _memcpy(HEAP32[i1 >> 2] | 0, i5 | 0, i2 | 0) | 0;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + (i2 >> 2 << 2);
 }
 return;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 4) | 0;
 if (!(HEAP32[i6 >> 2] & 4)) HEAP32[i7 >> 2] = i1 + -1900;
 STACKTOP = i5;
 return;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE(i1, i7, i2, i4, i6, i3) {
 i1 = i1 | 0;
 i7 = i7 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i3 = i3 | 0;
 var i5 = 0, i8 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i8 = i5;
 HEAP32[i8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 >> 2] = HEAP32[i8 >> 2];
 i1 = __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi(i2, i1, i6, i3, 4) | 0;
 if (!(HEAP32[i6 >> 2] & 4)) HEAP32[i7 >> 2] = i1 + -1900;
 STACKTOP = i5;
 return;
}

function __ZN4wasm4Loop8finalizeEv(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 64 | 0;
 i1 = i6 + 56 | 0;
 i4 = i6 + 8 | 0;
 i2 = i6;
 i3 = HEAP32[i5 + 8 >> 2] | 0;
 if (!i3) HEAP32[i5 + 4 >> 2] = HEAP32[(HEAP32[i5 + 16 >> 2] | 0) + 4 >> 2]; else {
  HEAP32[i2 >> 2] = i3;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN4wasm10TypeSeekerC2EPNS_10ExpressionENS_4NameE(i4, i5, i1);
  i3 = __ZN4wasmL10mergeTypesERNSt3__26vectorINS_8WasmTypeENS0_9allocatorIS2_EEEE(i4 + 36 | 0) | 0;
  HEAP32[i5 + 4 >> 2] = i3;
  __ZN4wasm10TypeSeekerD2Ev(i4);
 }
 STACKTOP = i6;
 return;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ImportENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ExportENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEEC2EjjS9_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i1, i2, i3) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i4 = 0, i5 = 0;
 if (i3 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i1);
 if (i3 >>> 0 < 11) {
  HEAP8[i1 + 11 >> 0] = i3;
  if (i3) i4 = 6;
 } else {
  i5 = i3 + 16 & -16;
  i4 = _malloc(i5) | 0;
  HEAP32[i1 >> 2] = i4;
  HEAP32[i1 + 8 >> 2] = i5 | -2147483648;
  HEAP32[i1 + 4 >> 2] = i3;
  i1 = i4;
  i4 = 6;
 }
 if ((i4 | 0) == 6) _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
 HEAP8[i1 + i3 >> 0] = 0;
 return;
}

function __ZN6cashew12ValueBuilder7makeNewENS_3RefE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i2 + 8 | 0;
 i6 = i2 + 4 | 0;
 i5 = i2;
 i4 = __ZN6cashew12ValueBuilder12makeRawArrayEi(2) | 0;
 i7 = __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(59596) | 0;
 HEAP32[i6 >> 2] = i7;
 HEAP32[i3 >> 2] = HEAP32[i6 >> 2];
 i4 = __ZN6cashew5Value9push_backENS_3RefE(i4, i3) | 0;
 HEAP32[i5 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 i1 = __ZN6cashew5Value9push_backENS_3RefE(i4, i3) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__213__vector_baseINS_10unique_ptrIZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNS_6vectorIjNS_9allocatorIjEEEEE5OrderNS_14default_deleteIS9_EEEENS5_ISC_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 >> 2] | 0;
 if (i2 | 0) {
  i3 = i4 + 4 | 0;
  while (1) {
   i1 = HEAP32[i3 >> 2] | 0;
   if ((i1 | 0) == (i2 | 0)) break;
   i5 = i1 + -4 | 0;
   HEAP32[i3 >> 2] = i5;
   i1 = HEAP32[i5 >> 2] | 0;
   HEAP32[i5 >> 2] = 0;
   if (!i1) continue;
   __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1);
   __ZdlPv(i1);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function __ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc(i9, i5, i6, i7, i3, i4) {
 i9 = i9 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i8 = 0, i10 = 0;
 i10 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i8 = i10;
 HEAP8[i8 >> 0] = 37;
 i1 = i8 + 1 | 0;
 HEAP8[i1 >> 0] = i3;
 i2 = i8 + 2 | 0;
 HEAP8[i2 >> 0] = i4;
 HEAP8[i8 + 3 >> 0] = 0;
 if (i4 << 24 >> 24) {
  HEAP8[i1 >> 0] = i4;
  HEAP8[i2 >> 0] = i3;
 }
 i9 = i5 + (_strftime_l(i5 | 0, (HEAP32[i6 >> 2] | 0) - i5 | 0, i8 | 0, i7 | 0, HEAP32[i9 >> 2] | 0) | 0) | 0;
 HEAP32[i6 >> 2] = i9;
 STACKTOP = i10;
 return;
}

function __ZNSt3__214__split_bufferINS_6vectorIPPN4wasm10ExpressionENS_9allocatorIS5_EEEERNS6_IS8_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 357913941) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 * 12 | 0) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 * 12 | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 * 12 | 0);
 return;
}

function __ZN4wasm16PrintSExpression11visitReturnEPNS_6ReturnE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i2 >> 2] | 0, 47643, 0) | 0;
 i1 = i1 + 8 | 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if ((i3 | 0) != 0 ? (HEAP32[i3 >> 2] | 0) != 19 : 0) {
  __ZN4wasm16PrintSExpression9incIndentEv(i2);
  __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i2, HEAP32[i1 >> 2] | 0);
  __ZN4wasm16PrintSExpression9decIndentEv(i2);
 } else __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, 56966) | 0;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE5eraseENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i1) | 0;
 if ((HEAP32[i3 >> 2] | 0) == (i1 | 0)) HEAP32[i3 >> 2] = i2;
 i4 = i3 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -1;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i3 + 4 >> 2] | 0, i1);
 __ZdlPv(i1);
 return i2 | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc(i6, i5, i4) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i2 = i6 + 11 | 0;
 i1 = HEAP8[i2 >> 0] | 0;
 i3 = i1 << 24 >> 24 < 0;
 if (i3) i1 = HEAP32[i6 + 4 >> 2] | 0; else i1 = i1 & 255;
 do if (i1 >>> 0 >= i5 >>> 0) if (i3) {
  HEAP8[(HEAP32[i6 >> 2] | 0) + i5 >> 0] = 0;
  HEAP32[i6 + 4 >> 2] = i5;
  break;
 } else {
  HEAP8[i6 + i5 >> 0] = 0;
  HEAP8[i2 >> 0] = i5;
  break;
 } else __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEjc(i6, i5 - i1 | 0, i4) | 0; while (0);
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2EOS1_(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i3 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i3 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 i2 = i3 + 12 | 0;
 i1 = i1 + 12 | 0;
 HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE5eraseENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i1) | 0;
 if ((HEAP32[i3 >> 2] | 0) == (i1 | 0)) HEAP32[i3 >> 2] = i2;
 i4 = i3 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -1;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i3 + 4 >> 2] | 0, i1);
 __ZdlPv(i1);
 return i2 | 0;
}

function __ZNSt3__214__split_bufferINS_8functionIFN4wasm15ThreadWorkStateEvEEERNS_9allocatorIS5_EEEC2EjjS8_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 178956970) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 * 24 | 0) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 * 24 | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 * 24 | 0);
 return;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEEC2ERKS5_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 HEAP32[i7 >> 2] = 0;
 i1 = i7 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i7 + 8 >> 2] = 0;
 i3 = i6 + 4 | 0;
 i4 = (HEAP32[i3 >> 2] | 0) - (HEAP32[i6 >> 2] | 0) >> 2;
 if (i4 | 0 ? (__ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE8allocateEj(i7, i4), i5 = HEAP32[i6 >> 2] | 0, i2 = (HEAP32[i3 >> 2] | 0) - i5 | 0, (i2 | 0) > 0) : 0) {
  _memcpy(HEAP32[i1 >> 2] | 0, i5 | 0, i2 | 0) | 0;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + (i2 >> 2 << 2);
 }
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE5eraseEjj(i7) {
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i5 = i7 + 11 | 0;
 i1 = HEAP8[i5 >> 0] | 0;
 if (i1 << 24 >> 24 < 0) {
  i6 = HEAP32[i7 >> 2] | 0;
  i2 = HEAP32[i7 + 4 >> 2] | 0;
 } else {
  i6 = i7;
  i2 = i1 & 255;
 }
 i3 = (i2 | 0) != 0 & 1;
 i4 = i2 - i3 | 0;
 if ((i2 | 0) != (i3 | 0)) {
  _memmove(i6 | 0, i6 + i3 | 0, i4 | 0) | 0;
  i1 = HEAP8[i5 >> 0] | 0;
 }
 if (i1 << 24 >> 24 < 0) HEAP32[i7 + 4 >> 2] = i4; else HEAP8[i5 >> 0] = i4;
 HEAP8[i6 + i4 >> 0] = 0;
 return;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringENS2_3RefEEENS_22__unordered_map_hasherIS3_S5_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S5_NS_8equal_toIS3_EELb1EEENS_9allocatorIS5_EEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringENS2_3RefEEENS_22__unordered_map_hasherIS3_S5_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S5_NS_8equal_toIS3_EELb1EEENS_9allocatorIS5_EEE12__deallocateEPNS_11__hash_nodeIS5_PvEE(i2, HEAP32[i2 + 8 >> 2] | 0);
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm13ReorderLocals13visitSetLocalEPNS_8SetLocalE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 8 | 0;
 i2 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i3 + 44 | 0, i1) | 0;
 HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 1;
 i2 = i3 + 56 | 0;
 if (!(__ZNKSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE14__count_uniqueIjEEjRKT_(i2, i1) | 0)) {
  i4 = HEAP32[i3 + 64 >> 2] | 0;
  i3 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i2, i1) | 0;
  HEAP32[i3 >> 2] = i4;
 }
 return;
}

function __ZN4wasm13ReorderLocals13visitGetLocalEPNS_8GetLocalE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i1 = i1 + 8 | 0;
 i2 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i3 + 44 | 0, i1) | 0;
 HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 1;
 i2 = i3 + 56 | 0;
 if (!(__ZNKSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE14__count_uniqueIjEEjRKT_(i2, i1) | 0)) {
  i4 = HEAP32[i3 + 64 >> 2] | 0;
  i3 = __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i2, i1) | 0;
  HEAP32[i3 >> 2] = i4;
 }
 return;
}

function __ZZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = i1 + 1;
 i2 = i3 + 4 | 0;
 if (i1 >>> 0 < (HEAP32[i2 >> 2] | 0) >>> 0) {
  i4 = HEAP32[HEAP32[i3 + 8 >> 2] >> 2] | 0;
  __ZZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i3 + 12 | 0, i4, 0, HEAP32[(HEAP32[i4 + 36 >> 2] | 0) + (i1 << 2) >> 2] | 0);
  i1 = (i1 + 1 | 0) == (HEAP32[i2 >> 2] | 0) & 1;
 } else i1 = 1;
 return i1 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS0_12malloc_allocIcEEEE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i3 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
 HEAP32[i3 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 i1 = i3 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function ___toread(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = i3 + 74 | 0;
 i2 = HEAP8[i1 >> 0] | 0;
 HEAP8[i1 >> 0] = i2 + 255 | i2;
 i1 = i3 + 20 | 0;
 i2 = i3 + 44 | 0;
 if ((HEAP32[i1 >> 2] | 0) >>> 0 > (HEAP32[i2 >> 2] | 0) >>> 0) FUNCTION_TABLE_iiii[HEAP32[i3 + 36 >> 2] & 31](i3, 0, 0) | 0;
 HEAP32[i3 + 16 >> 2] = 0;
 HEAP32[i3 + 28 >> 2] = 0;
 HEAP32[i1 >> 2] = 0;
 i1 = HEAP32[i3 >> 2] | 0;
 if (i1 & 20) if (!(i1 & 4)) i1 = -1; else {
  HEAP32[i3 >> 2] = i1 | 32;
  i1 = -1;
 } else {
  i1 = HEAP32[i2 >> 2] | 0;
  HEAP32[i3 + 8 >> 2] = i1;
  HEAP32[i3 + 4 >> 2] = i1;
  i1 = 0;
 }
 return i1 | 0;
}

function __ZN4wasm11MergeBlocks17visitCallIndirectEPNS_12CallIndirectE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i6 = i4;
 i5 = i2 + 28 | 0;
 i1 = __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i3, i2, i5, 0, 0, 0) | 0;
 __ZN4wasm14EffectAnalyzerC2EPNS_10ExpressionE(i6, HEAP32[i5 >> 2] | 0);
 i5 = __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i6) | 0;
 __ZN4wasm14EffectAnalyzerD2Ev(i6);
 if (!i5) __ZN4wasm11MergeBlocks10handleCallINS_12CallIndirectEEEvPT_PNS_5BlockE(i3, i2, i1);
 STACKTOP = i4;
 return;
}

function __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i4, i5) {
 i2 = i2 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 var i1 = 0, i3 = 0;
 __ZNSt3__214__shared_count12__add_sharedEv(i4);
 i3 = i2 + 8 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 if ((HEAP32[i2 + 12 >> 2] | 0) - i1 >> 2 >>> 0 > i5 >>> 0) i2 = i3; else {
  __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE6resizeEj(i3, i5 + 1 | 0);
  i2 = i3;
  i1 = HEAP32[i3 >> 2] | 0;
 }
 i1 = HEAP32[i1 + (i5 << 2) >> 2] | 0;
 if (i1 | 0) __ZNSt3__214__shared_count16__release_sharedEv(i1) | 0;
 HEAP32[(HEAP32[i2 >> 2] | 0) + (i5 << 2) >> 2] = i4;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE13__lower_boundIS3_EENS_15__tree_iteratorISG_PNS_11__tree_nodeISG_PvEEiEERKT_SS_SS_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwi(i7, i1, i6) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i4 = i7 + 12 | 0;
 i5 = i7 + 16 | 0;
 i3 = i1;
 i1 = 0;
 while (1) {
  if ((i1 | 0) >= (i6 | 0)) break;
  i2 = HEAP32[i4 >> 2] | 0;
  if (i2 >>> 0 >= (HEAP32[i5 >> 2] | 0) >>> 0) {
   i2 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i7 >> 2] | 0) + 40 >> 2] & 255](i7) | 0;
   if ((i2 | 0) == -1) break;
  } else {
   HEAP32[i4 >> 2] = i2 + 4;
   i2 = HEAP32[i2 >> 2] | 0;
  }
  HEAP32[i3 >> 2] = i2;
  i3 = i3 + 4 | 0;
  i1 = i1 + 1 | 0;
 }
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder10makeBinaryERNS_7ElementENS_8BinaryOpENS_8WasmTypeE(i3, i2, i1, i4) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i4 = __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(HEAP32[i3 + 4 >> 2] | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i1;
 i1 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i3, __ZN4wasm7ElementixEj(i2, 1) | 0) | 0;
 HEAP32[i4 + 12 >> 2] = i1;
 i3 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i3, __ZN4wasm7ElementixEj(i2, 2) | 0) | 0;
 HEAP32[i4 + 16 >> 2] = i3;
 __ZN4wasm6Binary8finalizeEv(i4);
 return i4 | 0;
}

function __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEEC2ERKS5_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 HEAP32[i7 >> 2] = 0;
 i1 = i7 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i7 + 8 >> 2] = 0;
 i3 = i6 + 4 | 0;
 i4 = (HEAP32[i3 >> 2] | 0) - (HEAP32[i6 >> 2] | 0) >> 2;
 if (i4 | 0 ? (__ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE8allocateEj(i7, i4), i5 = HEAP32[i6 >> 2] | 0, i2 = (HEAP32[i3 >> 2] | 0) - i5 | 0, (i2 | 0) > 0) : 0) {
  _memcpy(HEAP32[i1 >> 2] | 0, i5 | 0, i2 | 0) | 0;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + (i2 >> 2 << 2);
 }
 return;
}

function __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(i1, i4, i3, i5) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i2 = 0;
 i1 = i4 + 16 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) {
  if ((i2 | 0) != (i3 | 0)) {
   i5 = i4 + 36 | 0;
   HEAP32[i5 >> 2] = (HEAP32[i5 >> 2] | 0) + 1;
   HEAP32[i4 + 24 >> 2] = 2;
   HEAP8[i4 + 54 >> 0] = 1;
   break;
  }
  i1 = i4 + 24 | 0;
  if ((HEAP32[i1 >> 2] | 0) == 2) HEAP32[i1 >> 2] = i5;
 } else {
  HEAP32[i1 >> 2] = i3;
  HEAP32[i4 + 24 >> 2] = i5;
  HEAP32[i4 + 36 >> 2] = 1;
 } while (0);
 return;
}

function __ZN4wasm19DeadCodeElimination10visitBreakEPNS_5BreakE(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0, i7 = 0, i8 = 0;
 i7 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i7 + 4 | 0;
 i2 = i7;
 i8 = HEAP32[i4 + 12 >> 2] | 0;
 i3 = i8;
 if ((i8 | 0) != 0 ? (HEAP32[i8 >> 2] | 0) == 20 : 0) HEAP32[i5 + 20 >> 2] = i3; else i6 = 4;
 if ((i6 | 0) == 4 ? (HEAP32[i2 >> 2] = HEAP32[i4 + 8 >> 2], HEAP32[i1 >> 2] = HEAP32[i2 >> 2], __ZN4wasm19DeadCodeElimination8addBreakENS_4NameE(i5, i1), (HEAP32[i4 + 16 >> 2] | 0) == 0) : 0) HEAP8[i5 + 44 >> 0] = 0;
 STACKTOP = i7;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj11EEERAT__Kc(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = 0;
 HEAP8[i3 + 11 >> 0] = 10;
 i4 = i3;
 i2 = i4 + 10 | 0;
 do {
  HEAP8[i4 >> 0] = HEAP8[i1 >> 0] | 0;
  i4 = i4 + 1 | 0;
  i1 = i1 + 1 | 0;
 } while ((i4 | 0) < (i2 | 0));
 HEAP8[i3 + 10 >> 0] = 0;
 i1 = i3 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZNSt3__210__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i4 + 4 | 0;
 i5 = i4;
 __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev(i3);
 HEAP32[i3 >> 2] = 12388;
 HEAP32[i3 + 32 >> 2] = i1;
 HEAP32[i3 + 40 >> 2] = i2;
 HEAP32[i3 + 48 >> 2] = -1;
 HEAP8[i3 + 52 >> 0] = 0;
 __ZNSt3__26localeC2ERKS0_(i6, i3 + 4 | 0);
 HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
 __ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE(i3, i5);
 __ZNSt3__26localeD2Ev(i5);
 STACKTOP = i4;
 return;
}

function __ZNSt3__210__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i4 + 4 | 0;
 i5 = i4;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i3);
 HEAP32[i3 >> 2] = 12324;
 HEAP32[i3 + 32 >> 2] = i1;
 HEAP32[i3 + 40 >> 2] = i2;
 HEAP32[i3 + 48 >> 2] = -1;
 HEAP8[i3 + 52 >> 0] = 0;
 __ZNSt3__26localeC2ERKS0_(i6, i3 + 4 | 0);
 HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
 __ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE(i3, i5);
 __ZNSt3__26localeD2Ev(i5);
 STACKTOP = i4;
 return;
}

function _strtox(i8, i7, i3, i1, i2) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i9 = 0;
 i9 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i6 = i9;
 HEAP32[i6 >> 2] = 0;
 i4 = i6 + 4 | 0;
 HEAP32[i4 >> 2] = i8;
 HEAP32[i6 + 44 >> 2] = i8;
 i5 = i6 + 8 | 0;
 HEAP32[i5 >> 2] = (i8 | 0) < 0 ? -1 : i8 + 2147483647 | 0;
 HEAP32[i6 + 76 >> 2] = -1;
 ___shlim(i6, 0);
 i1 = ___intscan(i6, i3, 1, i1, i2) | 0;
 if (i7 | 0) HEAP32[i7 >> 2] = i8 + ((HEAP32[i4 >> 2] | 0) + (HEAP32[i6 + 108 >> 2] | 0) - (HEAP32[i5 >> 2] | 0));
 STACKTOP = i9;
 return i1 | 0;
}

function __ZNSt3__23mapIjjNS_4lessIjEENS_9allocatorINS_4pairIKjjEEEEEixERS5_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 8 | 0;
 i3 = i4;
 HEAP32[i5 >> 2] = i1;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE25__emplace_unique_key_argsIjJRKNS_21piecewise_construct_tENS_5tupleIJRKjEEENSE_IJEEEEEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i3, i2, i1, 65636, i5, i4 + 12 | 0);
 STACKTOP = i4;
 return (HEAP32[i3 >> 2] | 0) + 20 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj10EEERAT__Kc(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = 0;
 HEAP8[i3 + 11 >> 0] = 9;
 i4 = i3;
 i2 = i4 + 9 | 0;
 do {
  HEAP8[i4 >> 0] = HEAP8[i1 >> 0] | 0;
  i4 = i4 + 1 | 0;
  i1 = i1 + 1 | 0;
 } while ((i4 | 0) < (i2 | 0));
 HEAP8[i3 + 9 >> 0] = 0;
 i1 = i3 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZNSt3__214__split_bufferINS_4pairIPN4wasm7ElementEPNS2_5BlockEEERNS_9allocatorIS7_EEEC2EjjSA_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZN4wasm22SExpressionWasmBuilder8makeCallERNS_7ElementE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i3 = __ZN10MixedArena5allocIN4wasm4CallEEEPT_v(HEAP32[i2 + 4 >> 2] | 0) | 0;
 i4 = i3 + 24 | 0;
 i5 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 1) | 0) | 0;
 HEAP32[i4 >> 2] = i5;
 i4 = __ZNSt3__23mapIN4wasm4NameENS1_8WasmTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_(i2 + 28 | 0, i4) | 0;
 HEAP32[i3 + 4 >> 2] = HEAP32[i4 >> 2];
 __ZN4wasm22SExpressionWasmBuilder17parseCallOperandsINS_4CallEEEvRNS_7ElementEjPT_(i2, i1, 2, i3);
 return i3 | 0;
}

function __ZNSt3__214__split_bufferIPNS_6vectorIN6cashew3RefENS_9allocatorIS3_EEEERNS4_IS7_EEEC2EjjS9_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZN4wasm14CoalesceLocals26scanLivenessThroughActionsERNSt3__26vectorINS_6ActionENS1_9allocatorIS3_EEEERNS_8LocalSetE(i1, i3, i4) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i2 = 0, i5 = 0;
 i1 = (HEAP32[i3 + 4 >> 2] | 0) - (HEAP32[i3 >> 2] | 0) >> 4;
 while (1) {
  i2 = i1 + -1 | 0;
  if ((i1 | 0) <= 0) break;
  i5 = HEAP32[i3 >> 2] | 0;
  i1 = HEAP32[i5 + (i2 << 4) + 4 >> 2] | 0;
  if (!(HEAP32[i5 + (i2 << 4) >> 2] | 0)) {
   __ZN4wasm8LocalSet6insertEj(i4, i1);
   i1 = i2;
   continue;
  } else {
   __ZN4wasm8LocalSet5eraseEj(i4, i1) | 0;
   i1 = i2;
   continue;
  }
 }
 return;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE16__insert_node_atEPNS_16__tree_node_baseIPvEERSB_SB_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEEC2EjjS5_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 107374182) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 * 40 | 0) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 * 40 | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 * 40 | 0);
 return;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEE12__deallocateEPNS_11__hash_nodeIS4_PvEE(i2, HEAP32[i2 + 8 >> 2] | 0);
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm14SimplifyLocals10BlockBreakERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 268435455) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 4) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 4) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 4);
 return;
}

function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i1 - i3 >> 2;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 << 2) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -4 | 0;
    HEAP32[i6 >> 2] = i5;
    i1 = i5;
   }
  }
 } else __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function _trunc(d1) {
 d1 = +d1;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 HEAPF64[tempDoublePtr >> 3] = d1;
 i2 = HEAP32[tempDoublePtr >> 2] | 0;
 i3 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 i6 = _bitshift64Lshr(i2 | 0, i3 | 0, 52) | 0;
 i6 = (i6 & 2047) + -1011 | 0;
 if ((i6 | 0) <= 63 ? (i5 = (i6 | 0) < 12, i4 = _bitshift64Lshr(-1, -1, i6 | 0) | 0, i4 = i5 ? -1 : i4, i5 = i5 ? 2147483647 : tempRet0, !((i4 & i2 | 0) == 0 & (i5 & i3 | 0) == 0)) : 0) {
  HEAP32[tempDoublePtr >> 2] = i2 & ~i4;
  HEAP32[tempDoublePtr + 4 >> 2] = i3 & ~i5;
  d1 = +HEAPF64[tempDoublePtr >> 3];
 }
 return +d1;
}

function __ZNSt3__26vectorIcNS_9allocatorIcEEEC2ERKS3_(i8, i7) {
 i8 = i8 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 HEAP32[i8 >> 2] = 0;
 i1 = i8 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i8 + 8 >> 2] = 0;
 i3 = i7 + 4 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 i5 = HEAP32[i7 >> 2] | 0;
 if ((i4 | 0) != (i5 | 0) ? (__ZNSt3__26vectorIcNS_9allocatorIcEEE8allocateEj(i8, i4 - i5 | 0), i6 = HEAP32[i7 >> 2] | 0, i2 = (HEAP32[i3 >> 2] | 0) - i6 | 0, (i2 | 0) > 0) : 0) {
  _memcpy(HEAP32[i1 >> 2] | 0, i6 | 0, i2 | 0) | 0;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + i2;
 }
 return;
}

function __ZNSt3__23mapIPN4wasm8FunctionEjNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_jEEEEE2atERS8_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = __ZNKSt3__23mapIPN4wasm8FunctionEjNS_4lessIS3_EENS_9allocatorINS_4pairIKS3_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS8_(i2, i3, i1) | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 if (!i1) {
  i3 = ___cxa_allocate_exception(8) | 0;
  __ZNSt11logic_errorC2EPKc(i3, 45399);
  HEAP32[i3 >> 2] = 15472;
  ___cxa_throw(i3 | 0, 4160, 275);
 } else {
  STACKTOP = i3;
  return i1 + 20 | 0;
 }
 return 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_119parse_cv_qualifiersEPKcS2_Rj(i1, i2, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i3 = 0;
 HEAP32[i4 >> 2] = 0;
 if ((i1 | 0) != (i2 | 0)) {
  i2 = HEAP8[i1 >> 0] | 0;
  if (i2 << 24 >> 24 == 114) {
   HEAP32[i4 >> 2] = 4;
   i2 = i1 + 1 | 0;
   i1 = i2;
   i2 = HEAP8[i2 >> 0] | 0;
   i3 = 4;
  } else i3 = 0;
  if (i2 << 24 >> 24 == 86) {
   i3 = i3 | 2;
   HEAP32[i4 >> 2] = i3;
   i2 = i1 + 1 | 0;
   i1 = i2;
   i2 = HEAP8[i2 >> 0] | 0;
  }
  if (i2 << 24 >> 24 == 75) {
   HEAP32[i4 >> 2] = i3 | 1;
   i1 = i1 + 1 | 0;
  }
 }
 return i1 | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, i2, i3) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i4 = 0, i5 = 0;
 if (i3 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i1);
 if (i3 >>> 0 < 11) {
  HEAP8[i1 + 11 >> 0] = i3;
  if (i3) i4 = 6;
 } else {
  i5 = i3 + 16 & -16;
  i4 = __Znwj(i5) | 0;
  HEAP32[i1 >> 2] = i4;
  HEAP32[i1 + 8 >> 2] = i5 | -2147483648;
  HEAP32[i1 + 4 >> 2] = i3;
  i1 = i4;
  i4 = 6;
 }
 if ((i4 | 0) == 6) _memcpy(i1 | 0, i2 | 0, i3 | 0) | 0;
 HEAP8[i1 + i3 >> 0] = 0;
 return;
}

function _fmt_u(i2, i3, i1) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i4 = 0;
 if (i3 >>> 0 > 0 | (i3 | 0) == 0 & i2 >>> 0 > 4294967295) while (1) {
  i4 = ___uremdi3(i2 | 0, i3 | 0, 10, 0) | 0;
  i1 = i1 + -1 | 0;
  HEAP8[i1 >> 0] = i4 | 48;
  i4 = ___udivdi3(i2 | 0, i3 | 0, 10, 0) | 0;
  if (i3 >>> 0 > 9 | (i3 | 0) == 9 & i2 >>> 0 > 4294967295) {
   i2 = i4;
   i3 = tempRet0;
  } else {
   i2 = i4;
   break;
  }
 }
 if (i2) while (1) {
  i1 = i1 + -1 | 0;
  HEAP8[i1 >> 0] = (i2 >>> 0) % 10 | 0 | 48;
  if (i2 >>> 0 < 10) break; else i2 = (i2 >>> 0) / 10 | 0;
 }
 return i1 | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEjc(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0;
 if (i3 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i1);
 if (i3 >>> 0 < 11) {
  HEAP8[i1 + 11 >> 0] = i3;
  if (i3) i4 = 6;
 } else {
  i5 = i3 + 16 & -16;
  i4 = __Znwj(i5) | 0;
  HEAP32[i1 >> 2] = i4;
  HEAP32[i1 + 8 >> 2] = i5 | -2147483648;
  HEAP32[i1 + 4 >> 2] = i3;
  i1 = i4;
  i4 = 6;
 }
 if ((i4 | 0) == 6) _memset(i1 | 0, i2 | 0, i3 | 0) | 0;
 HEAP8[i1 + i3 >> 0] = 0;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcjj(i1, i3, i4, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i5 = 0;
 if (i2 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i1);
 if (i2 >>> 0 < 11) HEAP8[i1 + 11 >> 0] = i4; else {
  i5 = i2 + 16 & -16;
  i2 = _malloc(i5) | 0;
  HEAP32[i1 >> 2] = i2;
  HEAP32[i1 + 8 >> 2] = i5 | -2147483648;
  HEAP32[i1 + 4 >> 2] = i4;
  i1 = i2;
 }
 if (i4 | 0) _memcpy(i1 | 0, i3 | 0, i4 | 0) | 0;
 HEAP8[i1 + i4 >> 0] = 0;
 return;
}

function __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEEC2EjjS6_(i5, i3, i4, i1) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 HEAP32[i5 + 12 >> 2] = 0;
 HEAP32[i5 + 16 >> 2] = i1;
 do if (i3) {
  i2 = i1 + 112 | 0;
  if (i3 >>> 0 < 29 & (HEAP8[i2 >> 0] | 0) == 0) {
   HEAP8[i2 >> 0] = 1;
   break;
  } else {
   i1 = __Znwj(i3 << 2) | 0;
   break;
  }
 } else i1 = 0; while (0);
 HEAP32[i5 >> 2] = i1;
 i4 = i1 + (i4 << 2) | 0;
 HEAP32[i5 + 8 >> 2] = i4;
 HEAP32[i5 + 4 >> 2] = i4;
 HEAP32[i5 + 12 >> 2] = i1 + (i3 << 2);
 return;
}

function __ZN4wasm6Module18updateFunctionsMapEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i2 = i1 + 152 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE5clearEv(i2);
 i3 = HEAP32[i1 + 40 >> 2] | 0;
 i1 = HEAP32[i1 + 36 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i3 | 0)) break;
  i5 = HEAP32[i1 >> 2] | 0;
  i4 = __ZNSt3__23mapIN4wasm4NameEPNS1_8FunctionENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i2, i5) | 0;
  HEAP32[i4 >> 2] = i5;
  i1 = i1 + 4 | 0;
 }
 return;
}

function __ZZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__1clES2_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 4 | 0;
 i5 = i3;
 i2 = __ZN10MixedArena5allocIN4wasm8GetLocalEEEPT_v(HEAP32[(HEAP32[i1 >> 2] | 0) + 4 >> 2] | 0) | 0;
 i1 = HEAP32[HEAP32[i1 + 4 >> 2] >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[14968];
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 i1 = __ZN4wasm8Function13getLocalIndexENS_4NameE(i1, i4) | 0;
 HEAP32[i2 + 8 >> 2] = i1;
 HEAP32[i2 + 4 >> 2] = 1;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNKSt3__27collateIcE10do_compareEPKcS3_S3_S3_(i3, i1, i6, i2, i5) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i4 = 0, i7 = 0;
 while (1) {
  if ((i2 | 0) == (i5 | 0)) {
   i7 = 7;
   break;
  }
  if ((i1 | 0) == (i6 | 0)) {
   i1 = -1;
   break;
  }
  i3 = HEAP8[i1 >> 0] | 0;
  i4 = HEAP8[i2 >> 0] | 0;
  if (i3 << 24 >> 24 < i4 << 24 >> 24) {
   i1 = -1;
   break;
  }
  if (i4 << 24 >> 24 < i3 << 24 >> 24) {
   i1 = 1;
   break;
  }
  i2 = i2 + 1 | 0;
  i1 = i1 + 1 | 0;
 }
 if ((i7 | 0) == 7) i1 = (i1 | 0) != (i6 | 0) & 1;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i6;
 i4 = i1 + -16 | 0;
 HEAP32[i5 >> 2] = i1;
 i2 = HEAP32[i3 + 40 >> 2] | 0;
 i1 = HEAP32[i3 + 36 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  __ZZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i5, 0, i4, HEAP32[i1 >> 2] | 0);
  i1 = i1 + 4 | 0;
 }
 STACKTOP = i6;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i6;
 i4 = i1 + -16 | 0;
 HEAP32[i5 >> 2] = i1;
 i2 = HEAP32[i3 + 40 >> 2] | 0;
 i1 = HEAP32[i3 + 36 >> 2] | 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  __ZZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlS6_PS1_PNS_8FunctionEE_clES6_S7_S9_(i5, 0, i4, HEAP32[i1 >> 2] | 0);
  i1 = i1 + 4 | 0;
 }
 STACKTOP = i6;
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm12FunctionTypeERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __Z9parseHeapPKc(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0;
 if ((((HEAP8[i2 >> 0] | 0) == 72 ? (HEAP8[i2 + 1 >> 0] | 0) == 69 : 0) ? (HEAP8[i2 + 2 >> 0] | 0) == 65 : 0) ? (HEAP8[i2 + 3 >> 0] | 0) == 80 : 0) {
  HEAP8[i1 >> 0] = 1;
  i3 = HEAP8[i2 + 4 >> 0] | 0;
  i4 = i3 << 24 >> 24 == 85;
  HEAP8[i1 + 1 >> 0] = i4 & 1;
  i3 = i3 << 24 >> 24 == 70;
  HEAP8[i1 + 2 >> 0] = i3 & 1;
  i2 = __Z8parseIntPKc(i2 + (i4 | i3 ? 5 : 4) | 0) | 0;
  HEAP32[i1 + 4 >> 2] = i2;
  HEAP32[i1 + 8 >> 2] = i3 ? ((i2 | 0) == 64 ? 1 : 2) : 0;
 } else HEAP8[i1 >> 0] = 0;
 return;
}

function __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE16__insert_node_atEPNS_16__tree_node_baseIPvEERS9_S9_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = i2;
 HEAP32[i3 >> 2] = i1;
 i2 = HEAP32[i4 >> 2] | 0;
 if (HEAP32[i2 >> 2] | 0) {
  HEAP32[i4 >> 2] = HEAP32[i2 >> 2];
  i1 = HEAP32[i3 >> 2] | 0;
 }
 __ZNSt3__227__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i4 + 4 >> 2] | 0, i1);
 i4 = i4 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEEC2EOSC_(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 HEAP32[i5 + 4 >> 2] = i1;
 i2 = i4 + 8 | 0;
 i6 = HEAP32[i2 >> 2] | 0;
 HEAP32[i5 + 8 >> 2] = i6;
 i3 = i5 + 4 | 0;
 if (!i6) HEAP32[i5 >> 2] = i3; else {
  HEAP32[i1 + 8 >> 2] = i3;
  i6 = i4 + 4 | 0;
  HEAP32[i4 >> 2] = i6;
  HEAP32[i6 >> 2] = 0;
  HEAP32[i2 >> 2] = 0;
 }
 return;
}

function __ZNSt3__214__split_bufferIPPN4wasm10ExpressionERNS_9allocatorIS4_EEEC2EjjS7_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6Memory7SegmentERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 268435455) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 4) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 4) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 4);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNSt3__214__split_bufferIPN4wasm10ExpressionERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm10CallImportERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 + 4 >> 2] | 0;
 i3 = i4 + 8 | 0;
 while (1) {
  i1 = HEAP32[i3 >> 2] | 0;
  if ((i1 | 0) == (i2 | 0)) break;
  i5 = i1 + -4 | 0;
  HEAP32[i3 >> 2] = i5;
  i1 = HEAP32[i5 >> 2] | 0;
  HEAP32[i5 >> 2] = 0;
  if (!i1) continue;
  __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i1 + 8 | 0);
  __ZdlPv(i1);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__26locale5__impD2Ev(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0;
 HEAP32[i5 >> 2] = 14916;
 i2 = i5 + 8 | 0;
 i3 = i5 + 12 | 0;
 i4 = 0;
 while (1) {
  i1 = HEAP32[i2 >> 2] | 0;
  if (i4 >>> 0 >= (HEAP32[i3 >> 2] | 0) - i1 >> 2 >>> 0) break;
  i1 = HEAP32[i1 + (i4 << 2) >> 2] | 0;
  if (i1 | 0) __ZNSt3__214__shared_count16__release_sharedEv(i1) | 0;
  i4 = i4 + 1 | 0;
 }
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i5 + 144 | 0);
 __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev(i2);
 return;
}

function __ZNSt3__214__split_bufferINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEERNS7_ISC_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  i3 = i3 + -12 | 0;
  HEAP32[i2 >> 2] = i3;
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEED2Ev(i3);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm11WasmPrinter11printModuleEPNS_6ModuleERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 HEAP32[i4 >> 2] = i1;
 HEAP32[i4 + 4 >> 2] = i1 + 88;
 HEAP32[i4 + 8 >> 2] = 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = 0;
 HEAP8[i4 + 24 >> 0] = 0;
 __ZN4wasm10PassRunner3addINS_7PrinterENSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEEEvRT0_(i4, i2);
 __ZN4wasm10PassRunner3runEv(i4);
 __ZN4wasm10PassRunnerD2Ev(i4);
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEEC2ERKS3_(i7, i6) {
 i7 = i7 | 0;
 i6 = i6 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 HEAP32[i7 >> 2] = 0;
 i1 = i7 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i7 + 8 >> 2] = 0;
 i3 = i6 + 4 | 0;
 i4 = (HEAP32[i3 >> 2] | 0) - (HEAP32[i6 >> 2] | 0) >> 2;
 if (i4 | 0 ? (__ZNSt3__26vectorIjNS_9allocatorIjEEE8allocateEj(i7, i4), i5 = HEAP32[i6 >> 2] | 0, i2 = (HEAP32[i3 >> 2] | 0) - i5 | 0, (i2 | 0) > 0) : 0) {
  _memcpy(HEAP32[i1 >> 2] | 0, i5 | 0, i2 | 0) | 0;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + (i2 >> 2 << 2);
 }
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm8FunctionERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIN6cashew7IStringERNS_9allocatorIS2_EEEC2EjjS5_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  i3 = i3 + -24 | 0;
  HEAP32[i2 >> 2] = i3;
  __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i3);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE10deallocateEPcj(HEAP32[HEAP32[i4 + 16 >> 2] >> 2] | 0, i1, (HEAP32[i4 + 12 >> 2] | 0) - i1 | 0);
 return;
}

function __ZNSt3__213__vector_baseINS_3mapIjN4wasm14SimplifyLocals12SinkableInfoENS_4lessIjEENS_9allocatorINS_4pairIKjS4_EEEEEENS7_ISC_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   i3 = i3 + -12 | 0;
   HEAP32[i2 >> 2] = i3;
   __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEED2Ev(i3);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function __ZNSt3__214__split_bufferIPN6cashew5ValueERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm7ElementERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEEC2EjjS5_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i1 - i3 >> 2;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 << 2) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -4 | 0;
    HEAP32[i6 >> 2] = i5;
    i1 = i5;
   }
  }
 } else __ZNSt3__26vectorIPPN4wasm10ExpressionENS_9allocatorIS4_EEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm8NameTypeERNS_9allocatorIS2_EEEC2EjjS5_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 536870911) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 3) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 3) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 3);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9underflowEv(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = i4 + 44 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 i3 = HEAP32[i4 + 24 >> 2] | 0;
 if (i2 >>> 0 < i3 >>> 0) {
  HEAP32[i1 >> 2] = i3;
  i1 = i3;
 } else i1 = i2;
 if (HEAP32[i4 + 48 >> 2] & 8) {
  i3 = i4 + 16 | 0;
  i2 = HEAP32[i3 >> 2] | 0;
  if (i2 >>> 0 < i1 >>> 0) {
   HEAP32[i3 >> 2] = i1;
   i2 = i1;
  }
  i1 = HEAP32[i4 + 12 >> 2] | 0;
  if (i1 >>> 0 < i2 >>> 0) i1 = HEAPU8[i1 >> 0] | 0; else i1 = -1;
 } else i1 = -1;
 return i1 | 0;
}

function __ZNSt3__214__split_bufferIPN4wasm5BlockERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEEC2EjjS5_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 268435455) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 4) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 4) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 4);
 return;
}

function __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i1 - i3 >> 2;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 << 2) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -4 | 0;
    HEAP32[i6 >> 2] = i5;
    i1 = i5;
   }
  }
 } else __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm4PassERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm4CallERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIN6cashew3RefERNS_9allocatorIS2_EEEC2EjjS5_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6ActionERNS_9allocatorIS2_EEEC2EjjS5_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 268435455) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 4) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 4) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 4);
 return;
}

function __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   i3 = i3 + -24 | 0;
   HEAP32[i2 >> 2] = i3;
   __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i3);
  }
  i3 = HEAP32[i4 >> 2] | 0;
  __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE10deallocateEPcj(HEAP32[i4 + 12 >> 2] | 0, i3, (HEAP32[i4 + 8 >> 2] | 0) - i3 | 0);
 }
 return;
}

function __ZN4wasm11WasmPrinter15printExpressionEPNS_10ExpressionERNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEEb(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i5 = i4;
 HEAP32[i5 >> 2] = i3;
 HEAP32[i5 + 4 >> 2] = 0;
 HEAP8[i5 + 20 >> 0] = 0;
 HEAP32[i5 + 24 >> 2] = 0;
 HEAP8[i5 + 8 >> 0] = i2 & 1;
 HEAP32[i5 + 12 >> 2] = i2 ? 67717 : 58055;
 HEAP32[i5 + 16 >> 2] = i2 ? 67717 : 34477;
 __ZN4wasm7VisitorINS_16PrintSExpressionEvE5visitEPNS_10ExpressionE(i5, i1);
 STACKTOP = i4;
 return i3 | 0;
}

function __ZNSt3__214__split_bufferIN4wasm4NameERNS_9allocatorIS2_EEEC2EjjS5_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZN4wasm13WasmValidator10visitBreakEPNS_5BreakE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 4 | 0;
 i6 = i4;
 HEAP32[i6 >> 2] = HEAP32[i2 + 8 >> 2];
 i1 = HEAP32[i2 + 12 >> 2] | 0;
 HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
 __ZN4wasm13WasmValidator9noteBreakENS_4NameEPNS_10ExpressionE(i3, i5, i1);
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 if (i1 | 0) __ZN4wasm13WasmValidator12shouldBeTrueIPNS_5BreakEEEbbT_PKc(i3, (HEAP32[i1 + 4 >> 2] | 4 | 0) == 5, i2, 19619) | 0;
 STACKTOP = i4;
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm2IfERNS_9allocatorIS3_EEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZN4wasm14CoalesceLocals22calculateInterferencesERNS_8LocalSetE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0, i7 = 0;
 i1 = (HEAP32[i5 + 4 >> 2] | 0) - (HEAP32[i5 >> 2] | 0) >> 2;
 i3 = 0;
 L1 : while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i2 = i3 + 1 | 0;
  i4 = i2;
  while (1) {
   if ((i4 | 0) == (i1 | 0)) {
    i3 = i2;
    continue L1;
   }
   i7 = HEAP32[i5 >> 2] | 0;
   __ZN4wasm14CoalesceLocals16interfereLowHighEjj(i6, HEAP32[i7 + (i3 << 2) >> 2] | 0, HEAP32[i7 + (i4 << 2) >> 2] | 0);
   i4 = i4 + 1 | 0;
  }
 }
 return;
}

function __ZNKSt3__27codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_(i5, i1, i2, i3, i4, i6, i7, i8) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 var i9 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i9 = i5 + 4 | 0;
 i1 = i5;
 HEAP32[i9 >> 2] = i2;
 HEAP32[i1 >> 2] = i6;
 i7 = __ZNSt3__2L13utf16_to_utf8EPKtS1_RS1_PhS3_RS3_mNS_12codecvt_modeE(i2, i3, i9, i6, i7, i1, 1114111, 0) | 0;
 HEAP32[i4 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
 STACKTOP = i5;
 return i7 | 0;
}

function __ZN4wasm11BreakSeeker11visitSwitchEPNS_6SwitchE(i1, i6) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0;
 i3 = i6 + 8 | 0;
 i4 = HEAP32[i6 + 16 >> 2] | 0;
 i5 = i1 + 28 | 0;
 i1 = i1 + 32 | 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == (i4 | 0)) break;
  i7 = __ZNK11ArenaVectorIN4wasm4NameEEixEj(i3, i2) | 0;
  if ((HEAP32[i7 >> 2] | 0) == (HEAP32[i5 >> 2] | 0)) HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 1;
  i2 = i2 + 1 | 0;
 }
 if ((HEAP32[i6 + 24 >> 2] | 0) == (HEAP32[i5 >> 2] | 0)) HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 1;
 return;
}

function __ZNKSt3__27codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_(i5, i1, i2, i3, i4, i6, i7, i8) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 var i9 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i9 = i5 + 4 | 0;
 i1 = i5;
 HEAP32[i9 >> 2] = i2;
 HEAP32[i1 >> 2] = i6;
 i7 = __ZNSt3__2L13utf8_to_utf16EPKhS1_RS1_PtS3_RS3_mNS_12codecvt_modeE(i2, i3, i9, i6, i7, i1, 1114111, 0) | 0;
 HEAP32[i4 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
 STACKTOP = i5;
 return i7 | 0;
}

function __ZNKSt3__27codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_(i5, i1, i2, i3, i4, i6, i7, i8) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 var i9 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i9 = i5 + 4 | 0;
 i1 = i5;
 HEAP32[i9 >> 2] = i2;
 HEAP32[i1 >> 2] = i6;
 i7 = __ZNSt3__2L12ucs4_to_utf8EPKjS1_RS1_PhS3_RS3_mNS_12codecvt_modeE(i2, i3, i9, i6, i7, i1, 1114111, 0) | 0;
 HEAP32[i4 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
 STACKTOP = i5;
 return i7 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringENS_10unique_ptrIN4wasm12FunctionTypeENS_14default_deleteIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS_9allocatorISA_EEE13__lower_boundIS3_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_SN_SN_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNKSt3__27codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_(i5, i1, i2, i3, i4, i6, i7, i8) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 var i9 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i9 = i5 + 4 | 0;
 i1 = i5;
 HEAP32[i9 >> 2] = i2;
 HEAP32[i1 >> 2] = i6;
 i7 = __ZNSt3__2L12utf8_to_ucs4EPKhS1_RS1_PjS3_RS3_mNS_12codecvt_modeE(i2, i3, i9, i6, i7, i1, 1114111, 0) | 0;
 HEAP32[i4 >> 2] = HEAP32[i9 >> 2];
 HEAP32[i8 >> 2] = HEAP32[i1 >> 2];
 STACKTOP = i5;
 return i7 | 0;
}

function __ZN4wasm13WasmValidator9visitLoopEPNS_4LoopE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i2 + 12 | 0;
 if (HEAP32[i1 >> 2] | 0) __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE14__erase_uniqueIS3_EEjRKT_(i3 + 32 | 0, i1) | 0;
 i1 = i2 + 8 | 0;
 if (HEAP32[i1 >> 2] | 0) __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE14__erase_uniqueIS3_EEjRKT_(i3 + 32 | 0, i1) | 0;
 return;
}

function __ZNSt3__214__split_bufferINS_6vectorINS1_IN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEEERNS5_IS9_Lj4096EEEEC2EjjSB_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 if (!i2) i1 = 0; else i1 = __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE8allocateEj(HEAP32[i1 >> 2] | 0, i2 << 4) | 0;
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 4) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 4);
 return;
}

function __ZN6cashew10IStringSetC2EOS0_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEEC2EOS9_(i2, i1);
 i4 = i2 + 20 | 0;
 i3 = i1 + 20 | 0;
 HEAP32[i4 >> 2] = 0;
 i5 = i2 + 24 | 0;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i2 + 28 >> 2] = 0;
 HEAP32[i4 >> 2] = HEAP32[i3 >> 2];
 i4 = i1 + 24 | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 i1 = i1 + 28 | 0;
 HEAP32[i2 + 28 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i1 >> 2] = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i3 >> 2] = 0;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE16__construct_nodeIJNS_4pairIjS4_EEEEENS_10unique_ptrINS_11__tree_nodeIS5_PvEENS_22__tree_node_destructorINSA_ISJ_EEEEEEDpOT_(i2, i3, i1) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i4 = 0;
 i4 = __Znwj(96) | 0;
 HEAP32[i2 >> 2] = i4;
 HEAP32[i2 + 4 >> 2] = i3 + 4;
 HEAP32[i4 + 16 >> 2] = HEAP32[i1 >> 2];
 __ZN4wasm14SimplifyLocals12SinkableInfoC2EOS1_(i4 + 20 | 0, i1 + 4 | 0);
 HEAP8[i2 + 8 >> 0] = 1;
 return;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i1 - i3 >> 2;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 << 2) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -4 | 0;
    HEAP32[i6 >> 2] = i5;
    i1 = i5;
   }
  }
 } else __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZNSt3__214__split_bufferINS_6vectorIN6cashew6ParserINS2_3RefENS2_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS7_EEEERNS8_ISA_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  i3 = i3 + -12 | 0;
  HEAP32[i2 >> 2] = i3;
  __ZNSt3__213__vector_baseIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEED2Ev(i3);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm7Literal11setQuietNaNEd(d1) {
 d1 = +d1;
 var i2 = 0, d3 = 0.0;
 d3 = +Math_abs(+d1);
 HEAPF64[tempDoublePtr >> 3] = d3;
 i2 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 if (i2 >>> 0 > 2146435072 | (i2 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0) {
  HEAPF64[tempDoublePtr >> 3] = d1;
  i2 = HEAP32[tempDoublePtr + 4 >> 2] | 524288;
  HEAP32[tempDoublePtr >> 2] = HEAP32[tempDoublePtr >> 2];
  HEAP32[tempDoublePtr + 4 >> 2] = i2;
  return +(+HEAPF64[tempDoublePtr >> 3]);
 } else ___assert_fail(29144, 19526, 298, 29178);
 return +(0.0);
}

function __ZN11ArenaVectorIPN4wasm10ExpressionEE3setINSt3__26vectorIS2_NS5_9allocatorIS2_EEEEEEvRT_(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = (HEAP32[i4 + 4 >> 2] | 0) - (HEAP32[i4 >> 2] | 0) >> 2;
 if ((HEAP32[i5 + 12 >> 2] | 0) >>> 0 < i1 >>> 0) __ZN11ArenaVectorIPN4wasm10ExpressionEE8allocateEj(i5, i1);
 i2 = i5 + 4 | 0;
 i3 = 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  HEAP32[(HEAP32[i2 >> 2] | 0) + (i3 << 2) >> 2] = HEAP32[(HEAP32[i4 >> 2] | 0) + (i3 << 2) >> 2];
  i3 = i3 + 1 | 0;
 }
 HEAP32[i5 + 8 >> 2] = i1;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj4EEERAT__Kc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP8[i2 + 11 >> 0] = 3;
 HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
 HEAP8[i2 + 1 >> 0] = HEAP8[i1 + 1 >> 0] | 0;
 HEAP8[i2 + 2 >> 0] = HEAP8[i1 + 2 >> 0] | 0;
 HEAP8[i2 + 3 >> 0] = 0;
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function _strlen(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = i1;
 L1 : do if (!(i4 & 3)) i3 = 4; else {
  i2 = i1;
  i1 = i4;
  while (1) {
   if (!(HEAP8[i2 >> 0] | 0)) break L1;
   i2 = i2 + 1 | 0;
   i1 = i2;
   if (!(i1 & 3)) {
    i1 = i2;
    i3 = 4;
    break;
   }
  }
 } while (0);
 if ((i3 | 0) == 4) {
  while (1) {
   i2 = HEAP32[i1 >> 2] | 0;
   if (!((i2 & -2139062144 ^ -2139062144) & i2 + -16843009)) i1 = i1 + 4 | 0; else break;
  }
  if ((i2 & 255) << 24 >> 24) do i1 = i1 + 1 | 0; while ((HEAP8[i1 >> 0] | 0) != 0);
 }
 return i1 - i4 | 0;
}

function __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i1 - i3 >> 4;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 << 4) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -16 | 0;
    HEAP32[i6 >> 2] = i5;
    i1 = i5;
   }
  }
 } else __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZNSt3__213__vector_baseINS_6vectorIN6cashew6ParserINS2_3RefENS2_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS7_EEEENS8_ISA_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   i3 = i3 + -12 | 0;
   HEAP32[i2 >> 2] = i3;
   __ZNSt3__213__vector_baseIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEED2Ev(i3);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function __ZNSt3__214__split_bufferIPcRNS_9allocatorIS1_EEEC2EjjS4_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNKSt3__27collateIwE10do_compareEPKwS3_S3_S3_(i3, i1, i6, i2, i5) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i6 = i6 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 var i4 = 0, i7 = 0;
 while (1) {
  if ((i2 | 0) == (i5 | 0)) {
   i7 = 7;
   break;
  }
  if ((i1 | 0) == (i6 | 0)) {
   i1 = -1;
   break;
  }
  i3 = HEAP32[i1 >> 2] | 0;
  i4 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) < (i4 | 0)) {
   i1 = -1;
   break;
  }
  if ((i4 | 0) < (i3 | 0)) {
   i1 = 1;
   break;
  }
  i2 = i2 + 4 | 0;
  i1 = i1 + 4 | 0;
 }
 if ((i7 | 0) == 7) i1 = (i1 | 0) != (i6 | 0) & 1;
 return i1 | 0;
}

function ___fpclassify(d3) {
 d3 = +d3;
 var i1 = 0, i2 = 0, i4 = 0;
 HEAPF64[tempDoublePtr >> 3] = d3;
 i1 = HEAP32[tempDoublePtr >> 2] | 0;
 i2 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 i4 = _bitshift64Lshr(i1 | 0, i2 | 0, 52) | 0;
 switch (i4 & 2047 | 0) {
 case 0:
  {
   d3 = +Math_abs(+d3);
   HEAPF64[tempDoublePtr >> 3] = d3;
   i1 = (HEAP32[tempDoublePtr >> 2] | 0) != 0 | (HEAP32[tempDoublePtr + 4 >> 2] | 0) != 0 ? 3 : 2;
   break;
  }
 case 2047:
  {
   i1 = (i1 | 0) == 0 & (i2 & 1048575 | 0) == 0 & 1;
   break;
  }
 default:
  i1 = 4;
 }
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIPNS2_9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS6_vEENS2_8LivenessEE10BasicBlockENS_9allocatorISC_EEEEEENS_19__map_value_compareIS3_SG_NS_4lessIS3_EELb1EEENSD_ISG_EEE7destroyEPNS_11__tree_nodeISG_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE5clearEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE(i1, HEAP32[i2 >> 2] | 0);
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 >> 2] = i2;
 HEAP32[i2 >> 2] = 0;
 return;
}

function __ZNSt3__214__thread_proxyINS_5tupleIJNS_10unique_ptrINS_15__thread_structENS_14default_deleteIS3_EEEEPFvPvEPN4wasm6ThreadEEEEEES7_S7_(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i3 = __ZNSt3__219__thread_local_dataEv() | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 HEAP32[i1 >> 2] = 0;
 __ZNSt3__221__thread_specific_ptrINS_15__thread_structEE5resetEPS1_(i3, i2);
 FUNCTION_TABLE_vi[HEAP32[i1 + 4 >> 2] & 511](HEAP32[i1 + 8 >> 2] | 0);
 __ZNSt3__212__tuple_leafILj0ENS_10unique_ptrINS_15__thread_structENS_14default_deleteIS2_EEEELb0EED2Ev(i1);
 __ZdlPv(i1);
 return 0;
}

function __ZNSt3__214__split_bufferIjRNS_9allocatorIjEEEC2EjjS3_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__214__split_bufferIiRNS_9allocatorIiEEEC2EjjS3_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 do if (i2) if (i2 >>> 0 > 1073741823) {
  i4 = ___cxa_allocate_exception(4) | 0;
  __ZNSt9bad_allocC2Ev(i4);
  ___cxa_throw(i4 | 0, 4128, 273);
 } else {
  i1 = __Znwj(i2 << 2) | 0;
  break;
 } else i1 = 0; while (0);
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 2) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i1 - i3 >> 2;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 << 2) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -4 | 0;
    HEAP32[i6 >> 2] = i5;
    i1 = i5;
   }
  }
 } else __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcjj(i1, i3, i4, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i5 = 0;
 if (i2 >>> 0 > 4294967279) __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i1);
 if (i2 >>> 0 < 11) HEAP8[i1 + 11 >> 0] = i4; else {
  i5 = i2 + 16 & -16;
  i2 = __Znwj(i5) | 0;
  HEAP32[i1 >> 2] = i2;
  HEAP32[i1 + 8 >> 2] = i5 | -2147483648;
  HEAP32[i1 + 4 >> 2] = i4;
  i1 = i2;
 }
 if (i4 | 0) _memcpy(i1 | 0, i3 | 0, i4 | 0) | 0;
 HEAP8[i1 + i4 >> 0] = 0;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE13__lower_boundIS3_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_SM_SM_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEC2ERKS7_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 if ((HEAP8[i1 + 11 >> 0] | 0) < 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i2, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0); else {
  HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i2 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i2 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 }
 return;
}

function __ZN6cashew5Value8setArrayERNSt3__26vectorINS_3RefENS1_9allocatorIS3_EEEE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 __ZN6cashew5Value4freeEv(i3);
 HEAP32[i3 >> 2] = 2;
 i1 = __ZN6cashew5Arena10allocArrayEv(59672) | 0;
 HEAP32[i3 + 8 >> 2] = i1;
 if ((i1 | 0) != (i2 | 0)) __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_(i1, HEAP32[i2 >> 2] | 0, HEAP32[i2 + 4 >> 2] | 0);
 return i3 | 0;
}

function __ZN10__cxxabiv112_GLOBAL__N_112parse_numberEPKcS2_(i3, i4) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0;
 L1 : do if ((i3 | 0) != (i4 | 0) ? (i1 = (HEAP8[i3 >> 0] | 0) == 110 ? i3 + 1 | 0 : i3, (i1 | 0) != (i4 | 0)) : 0) {
  i2 = HEAP8[i1 >> 0] | 0;
  if (i2 << 24 >> 24 == 48) {
   i1 = i1 + 1 | 0;
   break;
  }
  if ((i2 + -49 & 255) < 9) do {
   i1 = i1 + 1 | 0;
   if ((i1 | 0) == (i4 | 0)) {
    i1 = i4;
    break L1;
   }
  } while (((HEAP8[i1 >> 0] | 0) + -48 | 0) >>> 0 < 10); else i1 = i3;
 } else i1 = i3; while (0);
 return i1 | 0;
}

function __ZZN4wasm18ExpressionAnalyzer5equalEPNS_10ExpressionES2_ENKUlNS_4NameES3_E0_clES3_S3_(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i4 = 0;
 i4 = HEAP32[i2 >> 2] | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE4findIS3_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_(i4, i1) | 0;
 if ((i2 | 0) != (i4 + 4 | 0)) i1 = (HEAP32[i2 + 24 >> 2] | 0) + -4 | 0;
 return (HEAP32[i1 >> 2] | 0) == (HEAP32[i3 >> 2] | 0) | 0;
}

function __ZN6cashew12ValueBuilder13appendToBlockENS_3RefES1_(i3, i4) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i2 = i5;
 if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i3, 0) | 0, 59280) | 0) {
  i3 = __ZN6cashew3RefixEj(i3, 1) | 0;
  i3 = HEAP32[i3 >> 2] | 0;
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
  STACKTOP = i5;
  return;
 } else ___assert_fail(32278, 48272, 1362, 32296);
}

function __ZN6cashew12ValueBuilder13appendToArrayENS_3RefES1_(i3, i4) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i2 = i5;
 if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i3, 0) | 0, 59600) | 0) {
  i3 = __ZN6cashew3RefixEj(i3, 1) | 0;
  i3 = HEAP32[i3 >> 2] | 0;
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
  STACKTOP = i5;
  return;
 } else ___assert_fail(32153, 48272, 1644, 32171);
}

function __ZN4wasm6Module17checkFunctionTypeENS_4NameE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i3 + 116 | 0;
 if ((__ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_(i1, i2) | 0) == (i3 + 120 | 0)) i1 = 0; else {
  i1 = __ZNSt3__23mapIN4wasm4NameEPNS1_12FunctionTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
  i1 = HEAP32[i1 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZN6cashew12ValueBuilder12appendToCallENS_3RefES1_(i3, i4) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i2 = i5;
 if (__ZN6cashew3RefeqERKNS_7IStringE(__ZN6cashew3RefixEj(i3, 0) | 0, 59344) | 0) {
  i3 = __ZN6cashew3RefixEj(i3, 2) | 0;
  i3 = HEAP32[i3 >> 2] | 0;
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  __ZN6cashew5Value9push_backENS_3RefE(i3, i1) | 0;
  STACKTOP = i5;
  return;
 } else ___assert_fail(31857, 48272, 1447, 31873);
}

function __ZN4wasm14EffectAnalyzerC2EOS0_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEEC2EOS4_(i2, i1);
 HEAP32[i2 >> 2] = 5392;
 HEAP16[i2 + 28 >> 1] = HEAP16[i1 + 28 >> 1] | 0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEEC2EOS5_(i2 + 32 | 0, i1 + 32 | 0);
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEEC2EOS5_(i2 + 44 | 0, i1 + 44 | 0);
 HEAP16[i2 + 56 >> 1] = HEAP16[i1 + 56 >> 1] | 0;
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEEC2EOS7_(i2 + 60 | 0, i1 + 60 | 0);
 return;
}

function __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew3RefE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__2lsIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_13basic_ostreamIT_T0_EES9_RKNS_12basic_stringIS6_S7_T1_EE(60976, i2) | 0, 32) | 0;
 __ZN6cashew5Value9stringifyERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEb(HEAP32[i1 >> 2] | 0, 60976, 0);
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(60976, 10) | 0;
 _abort();
}

function __ZN4wasm20OptimizeInstructions7visitIfEPNS_2IfE(i1, i6) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i7 = 0;
 i1 = i6 + 16 | 0;
 i7 = HEAP32[i1 >> 2] | 0;
 i2 = i7;
 if (((i7 | 0 ? (i4 = i6 + 8 | 0, i5 = HEAP32[i4 >> 2] | 0, !((i5 | 0) == 0 | (HEAP32[i5 >> 2] | 0) != 14)) : 0) ? (HEAP32[i5 + 8 >> 2] | 0) == 20 : 0) ? (i3 = HEAP32[i5 + 12 >> 2] | 0, (HEAP32[i3 + 4 >> 2] | 0) == 1) : 0) {
  HEAP32[i4 >> 2] = i3;
  i6 = i6 + 12 | 0;
  i7 = HEAP32[i6 >> 2] | 0;
  HEAP32[i6 >> 2] = i2;
  HEAP32[i1 >> 2] = i7;
 }
 return;
}

function _memset(i2, i6, i1) {
 i2 = i2 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i7 = 0;
 i3 = i2 + i1 | 0;
 if ((i1 | 0) >= 20) {
  i6 = i6 & 255;
  i5 = i2 & 3;
  i7 = i6 | i6 << 8 | i6 << 16 | i6 << 24;
  i4 = i3 & ~3;
  if (i5) {
   i5 = i2 + 4 - i5 | 0;
   while ((i2 | 0) < (i5 | 0)) {
    HEAP8[i2 >> 0] = i6;
    i2 = i2 + 1 | 0;
   }
  }
  while ((i2 | 0) < (i4 | 0)) {
   HEAP32[i2 >> 2] = i7;
   i2 = i2 + 4 | 0;
  }
 }
 while ((i2 | 0) < (i3 | 0)) {
  HEAP8[i2 >> 0] = i6;
  i2 = i2 + 1 | 0;
 }
 return i2 - i1 | 0;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE5eraseENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i1) | 0;
 if ((HEAP32[i3 >> 2] | 0) == (i1 | 0)) HEAP32[i3 >> 2] = i2;
 i4 = i3 + 8 | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + -1;
 __ZNSt3__213__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_(HEAP32[i3 + 4 >> 2] | 0, i1);
 __ZdlPv(i1);
 return i2 | 0;
}

function __ZNSt3__214__split_bufferINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEERNS5_IS7_Lj4096EEEEC2EjjS9_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 if (!i2) i1 = 0; else i1 = __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE8allocateEj(HEAP32[i1 >> 2] | 0, i2 << 4) | 0;
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 << 4) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 << 4);
 return;
}

function __ZN4wasm13WasmValidator10visitStoreEPNS_5StoreE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator17validateAlignmentEj(i2, HEAP32[i1 + 16 >> 2] | 0);
 __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_5StoreENS_8WasmTypeEEEbT0_S5_T_PKc(i2, HEAP32[(HEAP32[i1 + 20 >> 2] | 0) + 4 >> 2] | 0, 1, i1, 19875) | 0;
 __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_5StoreENS_8WasmTypeEEEbT0_S5_T_PKc(i2, HEAP32[(HEAP32[i1 + 24 >> 2] | 0) + 4 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0, i1, 19906) | 0;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder12MappedGlobalEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_SK_SK_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZN4wasm6Module13checkFunctionENS_4NameE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i3 + 152 | 0;
 if ((__ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_(i1, i2) | 0) == (i3 + 156 | 0)) i1 = 0; else {
  i1 = __ZNSt3__23mapIN4wasm4NameEPNS1_8FunctionENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
  i1 = HEAP32[i1 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZN11ArenaVectorIPN4wasm10ExpressionEE3setIS3_EEvRT_(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i1 = HEAP32[i4 + 8 >> 2] | 0;
 if ((HEAP32[i5 + 12 >> 2] | 0) >>> 0 < i1 >>> 0) __ZN11ArenaVectorIPN4wasm10ExpressionEE8allocateEj(i5, i1);
 i2 = i5 + 4 | 0;
 i3 = 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i6 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i4, i3) | 0;
  HEAP32[(HEAP32[i2 >> 2] | 0) + (i3 << 2) >> 2] = HEAP32[i6 >> 2];
  i3 = i3 + 1 | 0;
 }
 HEAP32[i5 + 8 >> 2] = i1;
 return;
}

function __ZN4wasmL8abort_onENSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEN6cashew7IStringE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i2 = __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__2lsIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_13basic_ostreamIT_T0_EES9_RKNS_12basic_stringIS6_S7_T1_EE(60976, i2) | 0, 32) | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i2, HEAP32[i1 >> 2] | 0) | 0, 10) | 0;
 _abort();
}

function __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i2 = HEAP32[i4 >> 2] | 0;
 do if (i2 | 0) {
  i1 = HEAP32[i4 + 16 >> 2] | 0;
  if ((i1 | 0) == (i2 | 0)) {
   HEAP8[i1 + 112 >> 0] = 0;
   break;
  } else {
   __ZdlPv(i2);
   break;
  }
 } while (0);
 return;
}

function __ZNSt3__211__call_onceERVmPvPFvS2_E(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 _pthread_mutex_lock(63520) | 0;
 while (1) {
  if ((HEAP32[i2 >> 2] | 0) != 1) break;
  _pthread_cond_wait(63548, 63520) | 0;
 }
 if (!(HEAP32[i2 >> 2] | 0)) {
  HEAP32[i2 >> 2] = 1;
  _pthread_mutex_unlock(63520) | 0;
  FUNCTION_TABLE_vi[i3 & 511](i1);
  _pthread_mutex_lock(63520) | 0;
  HEAP32[i2 >> 2] = -1;
  _pthread_mutex_unlock(63520) | 0;
  _pthread_cond_broadcast(63548) | 0;
 } else _pthread_mutex_unlock(63520) | 0;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEN4wasm15Asm2WasmBuilder4ViewEEENS_19__map_value_compareIS3_S7_NS_4lessIS3_EELb1EEENS_9allocatorIS7_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS7_PNS_11__tree_nodeIS7_PvEEiEERKT_SK_SK_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZN4wasm6Module11checkImportENS_4NameE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i3 + 128 | 0;
 if ((__ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_(i1, i2) | 0) == (i3 + 132 | 0)) i1 = 0; else {
  i1 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ImportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
  i1 = HEAP32[i1 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZN4wasm6Module11checkExportENS_4NameE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i3 + 140 | 0;
 if ((__ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_(i1, i2) | 0) == (i3 + 144 | 0)) i1 = 0; else {
  i1 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ExportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
  i1 = HEAP32[i1 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder13getLocalIndexERNS_7ElementE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i5 + 4 | 0;
 i2 = i5;
 if (!(HEAP8[i3 + 24 >> 0] | 0)) i1 = _atoi(__ZN4wasm7Element5c_strEv(i3) | 0) | 0; else {
  i4 = HEAP32[i4 + 40 >> 2] | 0;
  i3 = __ZN4wasm7Element3strEv(i3) | 0;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  i1 = __ZN4wasm8Function13getLocalIndexENS_4NameE(i4, i1) | 0;
 }
 STACKTOP = i5;
 return i1 | 0;
}

function __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2ERKS4_(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = i3 + 16 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) if ((i2 | 0) == (i3 | 0)) {
  HEAP32[i4 + 16 >> 2] = i4;
  i3 = HEAP32[i1 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i3 >> 2] | 0) + 12 >> 2] & 1023](i3, i4);
  break;
 } else {
  i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 8 >> 2] & 255](i2) | 0;
  HEAP32[i4 + 16 >> 2] = i3;
  break;
 } else HEAP32[i4 + 16 >> 2] = 0; while (0);
 return;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i1 - i3 >> 2;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 << 2) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -4 | 0;
    HEAP32[i6 >> 2] = i5;
    i1 = i5;
   }
  }
 } else __ZNSt3__26vectorIjNS_9allocatorIjEEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZNSt3__26vectorIiNS_9allocatorIiEEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i1 - i3 >> 2;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + (i4 << 2) | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -4 | 0;
    HEAP32[i6 >> 2] = i5;
    i1 = i5;
   }
  }
 } else __ZNSt3__26vectorIiNS_9allocatorIiEEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEEC2Ej(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 HEAP32[i2 >> 2] = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP8[i2 + 128 >> 0] = 0;
 if (i1 | 0) {
  __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8allocateEj(i2, i1);
  i2 = HEAP32[i3 >> 2] | 0;
  do {
   HEAP32[i2 >> 2] = 0;
   i2 = (HEAP32[i3 >> 2] | 0) + 4 | 0;
   HEAP32[i3 >> 2] = i2;
   i1 = i1 + -1 | 0;
  } while ((i1 | 0) != 0);
 }
 return;
}

function __ZN4wasm19DeadCodeElimination7visitIfEPNS_2IfE(i6, i5) {
 i6 = i6 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0;
 i1 = i6 + 44 | 0;
 i3 = i6 + 76 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 if (!(HEAP8[i1 >> 0] | 0)) {
  i2 = i4 + -1 | 0;
  i2 = (1 << (i2 & 31) & HEAP32[(HEAP32[i6 + 72 >> 2] | 0) + (i2 >>> 5 << 2) >> 2] | 0) != 0 & 1;
 } else i2 = 1;
 HEAP8[i1 >> 0] = i2;
 HEAP32[i3 >> 2] = i4 + -1;
 i5 = HEAP32[i5 + 8 >> 2] | 0;
 i1 = i5;
 if (i5 | 0 ? (HEAP32[i5 >> 2] | 0) == 20 : 0) HEAP32[i6 + 20 >> 2] = i1;
 return;
}

function __ZN4wasm12FunctionTypeaSERKS0_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i5 = i1;
 i4 = HEAP32[i5 + 4 >> 2] | 0;
 i3 = i2;
 HEAP32[i3 >> 2] = HEAP32[i5 >> 2];
 HEAP32[i3 + 4 >> 2] = i4;
 if ((i2 | 0) != (i1 | 0)) __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_(i2 + 8 | 0, HEAP32[i1 + 8 >> 2] | 0, HEAP32[i1 + 12 >> 2] | 0);
 return i2 | 0;
}

function _strerror(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = 0;
 while (1) {
  if ((HEAPU8[50445 + i2 >> 0] | 0) == (i1 | 0)) {
   i3 = 2;
   break;
  }
  i2 = i2 + 1 | 0;
  if ((i2 | 0) == 87) {
   i2 = 87;
   i1 = 50533;
   i3 = 5;
   break;
  }
 }
 if ((i3 | 0) == 2) if (!i2) i1 = 50533; else {
  i1 = 50533;
  i3 = 5;
 }
 if ((i3 | 0) == 5) while (1) {
  i3 = i1;
  while (1) {
   i1 = i3 + 1 | 0;
   if (!(HEAP8[i3 >> 0] | 0)) break; else i3 = i1;
  }
  i2 = i2 + -1 | 0;
  if (!i2) break; else i3 = 5;
 }
 return i1 | 0;
}

function __ZN6cashew19DotZeroValueBuilder10makeDoubleEd(d1) {
 d1 = +d1;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i3 + 12 | 0;
 i4 = i3 + 8 | 0;
 i6 = i3 + 4 | 0;
 i5 = i3;
 HEAP32[i6 >> 2] = HEAP32[14857];
 i7 = __ZN6cashew12ValueBuilder10makeDoubleEd(d1) | 0;
 HEAP32[i5 >> 2] = i7;
 HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
 HEAP32[i2 >> 2] = HEAP32[i5 >> 2];
 i2 = __ZN6cashew12ValueBuilder10makePrefixENS_7IStringENS_3RefE(i4, i2) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_SK_SK_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__214__split_bufferIN4wasm14SimplifyLocals10BlockBreakERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  HEAP32[i2 >> 2] = i3 + -16;
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEED2Ev(i3 + -12 | 0);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN10__cxxabiv112_GLOBAL__N_111string_pairERNS2_11short_allocIS3_Lj4096EEEEC2EjjS6_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 if (!i2) i1 = 0; else i1 = __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE8allocateEj(HEAP32[i1 >> 2] | 0, i2 * 24 | 0) | 0;
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + (i3 * 24 | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + (i2 * 24 | 0);
 return;
}

function __ZNSt3__26vectorINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEE18__construct_at_endEj(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 i3 = i1 + 4 | 0;
 i1 = i2;
 i2 = HEAP32[i3 >> 2] | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  HEAP32[i2 + 4 >> 2] = 0;
  HEAP32[i2 + 8 >> 2] = 0;
  HEAP32[i2 + 12 >> 2] = 0;
  HEAPF32[i2 + 16 >> 2] = 1.0;
  i2 = (HEAP32[i3 >> 2] | 0) + 20 | 0;
  HEAP32[i3 >> 2] = i2;
  i1 = i1 + -1 | 0;
 } while ((i1 | 0) != 0);
 return;
}

function __ZNSt3__26vectorIcNS_9allocatorIcEEE6resizeEj(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 i6 = i5 + 4 | 0;
 i1 = HEAP32[i6 >> 2] | 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i2 = i1 - i3 | 0;
 L1 : do if (i2 >>> 0 >= i4 >>> 0) {
  if (i2 >>> 0 > i4 >>> 0) {
   i2 = i3 + i4 | 0;
   while (1) {
    if ((i1 | 0) == (i2 | 0)) break L1;
    i5 = i1 + -1 | 0;
    HEAP32[i6 >> 2] = i5;
    i1 = i5;
   }
  }
 } else __ZNSt3__26vectorIcNS_9allocatorIcEEE8__appendEj(i5, i4 - i2 | 0); while (0);
 return;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm8FunctionENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 + 4 >> 2] | 0;
 i3 = i4 + 8 | 0;
 while (1) {
  i1 = HEAP32[i3 >> 2] | 0;
  if ((i1 | 0) == (i2 | 0)) break;
  i5 = i1 + -4 | 0;
  HEAP32[i3 >> 2] = i5;
  i1 = HEAP32[i5 >> 2] | 0;
  HEAP32[i5 >> 2] = 0;
  if (!i1) continue;
  __ZN4wasm8FunctionD2Ev(i1);
  __ZdlPv(i1);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__213__vector_baseIN4wasm14SimplifyLocals10BlockBreakENS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   HEAP32[i2 >> 2] = i3 + -16;
   __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEED2Ev(i3 + -12 | 0);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE12__deallocateEPNS_11__hash_nodeIS9_PvEE(i2, HEAP32[i2 + 8 >> 2] | 0);
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__213__vector_baseINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 >> 2] | 0;
 if (i2 | 0) {
  i3 = i4 + 4 | 0;
  while (1) {
   i1 = HEAP32[i3 >> 2] | 0;
   if ((i1 | 0) == (i2 | 0)) break;
   i5 = i1 + -4 | 0;
   HEAP32[i3 >> 2] = i5;
   i1 = HEAP32[i5 >> 2] | 0;
   HEAP32[i5 >> 2] = 0;
   if (!i1) continue;
   __ZN4wasm6ThreadD2Ev(i1);
   __ZdlPv(i1);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function __ZSt9terminatev() {
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 8 | 0;
 i1 = ___cxa_get_globals_fast() | 0;
 if ((i1 | 0 ? (i2 = HEAP32[i1 >> 2] | 0, i2 | 0) : 0) ? (i1 = i2 + 48 | 0, (HEAP32[i1 >> 2] & -256 | 0) == 1126902528 ? (HEAP32[i1 + 4 >> 2] | 0) == 1129074247 : 0) : 0) {
  FUNCTION_TABLE_v[HEAP32[i2 + 12 >> 2] & 3]();
  _abort_message(56390, i3);
 }
 i3 = HEAP32[3834] | 0;
 HEAP32[3834] = i3 + 0;
 FUNCTION_TABLE_v[i3 & 3]();
 _abort_message(56390, i4);
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_SK_SK_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder8makeHostERNS_7ElementENS_6HostOpE(i4, i3, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = __ZN10MixedArena5allocIN4wasm4HostEEEPT_v(HEAP32[i4 + 4 >> 2] | 0) | 0;
 HEAP32[i1 + 8 >> 2] = i2;
 if ((i2 | 0) == 3) {
  i4 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i3, 1) | 0) | 0;
  HEAP32[i1 + 12 >> 2] = i4;
 } else __ZN4wasm22SExpressionWasmBuilder17parseCallOperandsINS_4HostEEEvRNS_7ElementEjPT_(i4, i3, 1, i1);
 __ZN4wasm4Host8finalizeEv(i1);
 return i1 | 0;
}

function __ZNSt3__28functionIFPN4wasm4PassEvEEC2ERKS5_(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = i3 + 16 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) if ((i2 | 0) == (i3 | 0)) {
  HEAP32[i4 + 16 >> 2] = i4;
  i3 = HEAP32[i1 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i3 >> 2] | 0) + 12 >> 2] & 1023](i3, i4);
  break;
 } else {
  i3 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 8 >> 2] & 255](i2) | 0;
  HEAP32[i4 + 16 >> 2] = i3;
  break;
 } else HEAP32[i4 + 16 >> 2] = 0; while (0);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_12FunctionTypeEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 + 4 >> 2] | 0;
 i3 = i4 + 8 | 0;
 while (1) {
  i1 = HEAP32[i3 >> 2] | 0;
  if ((i1 | 0) == (i2 | 0)) break;
  i5 = i1 + -4 | 0;
  HEAP32[i3 >> 2] = i5;
  i1 = HEAP32[i5 >> 2] | 0;
  HEAP32[i5 >> 2] = 0;
  if (!i1) continue;
  __ZN4wasm6ThreadD2Ev(i1);
  __ZdlPv(i1);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib(i5, i3, i2, i1, i4, i6) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 if ((i5 | 0) == (HEAP32[i3 + 8 >> 2] | 0)) __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0, i3, i2, i1, i4); else {
  i5 = HEAP32[i5 + 8 >> 2] | 0;
  FUNCTION_TABLE_viiiiii[HEAP32[(HEAP32[i5 >> 2] | 0) + 20 >> 2] & 15](i5, i3, i2, i1, i4, i6);
 }
 return;
}

function __ZN4wasm22SExpressionWasmBuilder17parseCallOperandsINS_12CallIndirectEEEvRNS_7ElementEjPT_(i4, i3, i1, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i5 = 0;
 i2 = i2 + 8 | 0;
 while (1) {
  i5 = (__ZN4wasm7Element4listEv(i3) | 0) + 8 | 0;
  if (i1 >>> 0 >= (HEAP32[i5 >> 2] | 0) >>> 0) break;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i4, __ZN4wasm7ElementixEj(i3, i1) | 0) | 0);
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEEclES5_j(i2, i4, i1) {
 i2 = i2 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i5;
 HEAP32[i3 >> 2] = i1;
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 if (!i1) {
  i5 = ___cxa_allocate_exception(4) | 0;
  HEAP32[i5 >> 2] = 4480;
  ___cxa_throw(i5 | 0, 160, 11);
 } else {
  i4 = FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 24 >> 2] & 31](i1, i4, i3) | 0;
  STACKTOP = i5;
  return i4 | 0;
 }
 return 0;
}

function __ZN4wasm22SExpressionWasmBuilder17parseCallOperandsINS_10CallImportEEEvRNS_7ElementEjPT_(i4, i3, i1, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i5 = 0;
 i2 = i2 + 8 | 0;
 while (1) {
  i5 = (__ZN4wasm7Element4listEv(i3) | 0) + 8 | 0;
  if (i1 >>> 0 >= (HEAP32[i5 >> 2] | 0) >>> 0) break;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i4, __ZN4wasm7ElementixEj(i3, i1) | 0) | 0);
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNK4wasm7Literal19countTrailingZeroesEv(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i2 + 8 | 0;
 if ((HEAP32[i2 >> 2] | 0) == 1) {
  i1 = __ZN4wasm19CountTrailingZeroesIjEEiT_(HEAP32[i1 >> 2] | 0) | 0;
  HEAP32[i3 + 8 >> 2] = i1;
  i1 = 1;
 } else {
  i2 = i1;
  i2 = __ZN4wasm19CountTrailingZeroesIyEEiT_(HEAP32[i2 >> 2] | 0, HEAP32[i2 + 4 >> 2] | 0) | 0;
  i1 = i3 + 8 | 0;
  HEAP32[i1 >> 2] = i2;
  HEAP32[i1 + 4 >> 2] = ((i2 | 0) < 0) << 31 >> 31;
  i1 = 2;
 }
 HEAP32[i3 >> 2] = i1;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEERKT_SI_SI_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ImportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNK4wasm7Literal18countLeadingZeroesEv(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i2 + 8 | 0;
 if ((HEAP32[i2 >> 2] | 0) == 1) {
  i1 = __ZN4wasm18CountLeadingZeroesIjEEiT_(HEAP32[i1 >> 2] | 0) | 0;
  HEAP32[i3 + 8 >> 2] = i1;
  i1 = 1;
 } else {
  i2 = i1;
  i2 = __ZN4wasm18CountLeadingZeroesIyEEiT_(HEAP32[i2 >> 2] | 0, HEAP32[i2 + 4 >> 2] | 0) | 0;
  i1 = i3 + 8 | 0;
  HEAP32[i1 >> 2] = i2;
  HEAP32[i1 + 4 >> 2] = ((i2 | 0) < 0) << 31 >> 31;
  i1 = 2;
 }
 HEAP32[i3 >> 2] = i1;
 return;
}

function __ZNKSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE14__count_uniqueIjEEjRKT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 i1 = i2 + 4 | 0;
 while (1) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (!i1) {
   i1 = 0;
   break;
  }
  i2 = HEAP32[i1 + 16 >> 2] | 0;
  if (i3 >>> 0 < i2 >>> 0) continue;
  if (i2 >>> 0 >= i3 >>> 0) {
   i1 = 1;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder17parseCallOperandsINS_4HostEEEvRNS_7ElementEjPT_(i4, i3, i1, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i5 = 0;
 i2 = i2 + 16 | 0;
 while (1) {
  i5 = (__ZN4wasm7Element4listEv(i3) | 0) + 8 | 0;
  if (i1 >>> 0 >= (HEAP32[i5 >> 2] | 0) >>> 0) break;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i4, __ZN4wasm7ElementixEj(i3, i1) | 0) | 0);
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZN4wasm15Asm2WasmBuilder8blockifyEPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if ((HEAP32[i1 >> 2] | 0) == 1 ? (i3 = (__ZN4wasm10Expression4castINS_5BlockEEEPT_v(i1) | 0) + 8 | 0, (HEAP32[i3 >> 2] | 0) == 0) : 0) i1 = (HEAP32[i1 >> 2] | 0) == 1 ? i1 : 0; else {
  i3 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i2 + 4 >> 2] | 0) | 0;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i3 + 12 | 0, i1);
  __ZN4wasm5Block8finalizeEv(i3);
  i1 = i3;
 }
 return i1 | 0;
}

function __ZNSt3__26threadC2IRFvPvEJPN4wasm6ThreadEEvEEOT_DpOT0_(i4, i3, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i5 = 0;
 i5 = __Znwj(4) | 0;
 __ZNSt3__215__thread_structC2Ev(i5);
 i1 = __Znwj(12) | 0;
 i2 = HEAP32[i2 >> 2] | 0;
 HEAP32[i1 >> 2] = i5;
 HEAP32[i1 + 4 >> 2] = i3;
 HEAP32[i1 + 8 >> 2] = i2;
 if (_pthread_create(i4 | 0, 0, 185, i1 | 0) | 0) {
  __ZNSt3__212__tuple_leafILj0ENS_10unique_ptrINS_15__thread_structENS_14default_deleteIS2_EEEELb0EED2Ev(i1);
  __ZdlPv(i1);
 }
 return;
}

function __ZN4wasm22SExpressionWasmBuilder17parseCallOperandsINS_4CallEEEvRNS_7ElementEjPT_(i4, i3, i1, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i5 = 0;
 i2 = i2 + 8 | 0;
 while (1) {
  i5 = (__ZN4wasm7Element4listEv(i3) | 0) + 8 | 0;
  if (i1 >>> 0 >= (HEAP32[i5 >> 2] | 0) >>> 0) break;
  __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i2, __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i4, __ZN4wasm7ElementixEj(i3, i1) | 0) | 0);
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE14__count_uniqueIS3_EEjRKT_(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0;
 i1 = i1 + 4 | 0;
 while (1) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (!i1) {
   i1 = 0;
   break;
  }
  i2 = i1 + 16 | 0;
  if (__ZNK6cashew7IStringltERKS0_(i3, i2) | 0) continue;
  if (!(__ZNK6cashew7IStringltERKS0_(i2, i3) | 0)) {
   i1 = 1;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 return i1 | 0;
}

function __ZNKSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE14__count_uniqueIS3_EEjRKT_(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0;
 i1 = i1 + 4 | 0;
 while (1) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (!i1) {
   i1 = 0;
   break;
  }
  i2 = i1 + 16 | 0;
  if (__ZNK6cashew7IStringltERKS0_(i3, i2) | 0) continue;
  if (!(__ZNK6cashew7IStringltERKS0_(i2, i3) | 0)) {
   i1 = 1;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 return i1 | 0;
}

function __ZN6cashew5Value9push_backENS_3RefE(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 if ((HEAP32[i5 >> 2] | 0) != 2) ___assert_fail(48262, 48272, 479, 31142);
 i1 = HEAP32[i5 + 8 >> 2] | 0;
 i2 = i1 + 4 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if ((i3 | 0) == (HEAP32[i1 + 8 >> 2] | 0)) __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(i1, i4); else {
  HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 4;
 }
 return i5 | 0;
}

function __ZN4wasm13WasmValidator9visitHostEPNS_4HostE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if ((HEAP32[i1 + 8 >> 2] | 0) == 2) {
  __ZN4wasm13WasmValidator13shouldBeEqualIPNS_4HostEjEEbT0_S4_T_PKc(i2, HEAP32[i1 + 24 >> 2] | 0, 1, i1, 20432) | 0;
  i3 = __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i1 + 16 | 0, 0) | 0;
  __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_4HostENS_8WasmTypeEEEbT0_S5_T_PKc(i2, HEAP32[(HEAP32[i3 >> 2] | 0) + 4 >> 2] | 0, 1, i1, 20464) | 0;
 }
 return;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE4findIS2_EENS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEERKT_(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i1 = i2 + 4 | 0;
 i2 = __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE13__lower_boundIS2_EENS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEERKT_SD_SD_(i2, i3, HEAP32[i1 >> 2] | 0, i1) | 0;
 if ((i2 | 0) != (i1 | 0) ? !(__ZNK6cashew7IStringltERKS0_(i3, i2 + 16 | 0) | 0) : 0) i1 = i2;
 return i1 | 0;
}

function __ZN4wasm15Asm2WasmBuilder18isUnsignedCoercionEN6cashew3RefE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 12 | 0;
 i5 = i3 + 8 | 0;
 i7 = i3 + 4 | 0;
 i6 = i3;
 HEAP32[i7 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i6 >> 2] = HEAP32[i2 + 80 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i7 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i6 >> 2];
 i2 = (__Z10detectSignN6cashew3RefENS_7IStringE(i5, i4) | 0) == 2;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN6cashew7IStringEiEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_SH_SH_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZN4wasm19DeadCodeEliminationC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 5212;
 HEAP32[i1 + 16 >> 2] = 5240;
 HEAP8[i1 + 44 >> 0] = 1;
 HEAP32[i1 + 52 >> 2] = 0;
 HEAP32[i1 + 56 >> 2] = 0;
 HEAP32[i1 + 48 >> 2] = i1 + 52;
 i1 = i1 + 60 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 HEAP32[i1 + 20 >> 2] = 0;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj18EEERAT__Kc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i2, i1, 17);
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj15EEERAT__Kc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i2, i1, 14);
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj14EEERAT__Kc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i2, i1, 13);
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj13EEERAT__Kc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i2, i1, 12);
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairC2ILj12EEERAT__Kc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6__initEPKcj(i2, i1, 11);
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE13__lower_boundIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_SH_SH_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEEC2EOS7_(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 HEAP32[i5 + 4 >> 2] = i1;
 i2 = i4 + 8 | 0;
 i6 = HEAP32[i2 >> 2] | 0;
 HEAP32[i5 + 8 >> 2] = i6;
 i3 = i5 + 4 | 0;
 if (!i6) HEAP32[i5 >> 2] = i3; else {
  HEAP32[i1 + 8 >> 2] = i3;
  i6 = i4 + 4 | 0;
  HEAP32[i4 >> 2] = i6;
  HEAP32[i6 >> 2] = 0;
  HEAP32[i2 >> 2] = 0;
 }
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_12DbD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213__vector_baseINS_6vectorINS1_IN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEEENS5_IS9_Lj4096EEEED2Ev(i1 + 32 | 0);
 __ZNSt3__213__vector_baseINS_6vectorIN10__cxxabiv112_GLOBAL__N_111string_pairENS3_11short_allocIS4_Lj4096EEEEENS5_IS7_Lj4096EEEED2Ev(i1 + 16 | 0);
 __ZNSt3__213__vector_baseIN10__cxxabiv112_GLOBAL__N_111string_pairENS2_11short_allocIS3_Lj4096EEEED2Ev(i1);
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 if ((HEAP8[i1 + 11 >> 0] | 0) < 0) __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i2, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0); else {
  HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
  HEAP32[i2 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
  HEAP32[i2 + 8 >> 2] = HEAP32[i1 + 8 >> 2];
 }
 return;
}

function __ZNKSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE14__count_uniqueIS3_EEjRKT_(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0;
 i1 = i1 + 4 | 0;
 while (1) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (!i1) {
   i1 = 0;
   break;
  }
  i2 = i1 + 16 | 0;
  if (__ZNK6cashew7IStringltERKS0_(i3, i2) | 0) continue;
  if (!(__ZNK6cashew7IStringltERKS0_(i2, i3) | 0)) {
   i1 = 1;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 5768;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEjEENS_19__map_value_compareISA_SB_NS_4lessISA_EELb1EEENS_9allocatorISB_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm9CFGWalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEENS2_8LivenessEE10BasicBlockEjEENS_19__map_value_compareISA_SB_NS_4lessISA_EELb1EEENS_9allocatorISB_EEE7destroyEPNS_11__tree_nodeISB_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 5168;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib(i7, i5, i4, i3, i6, i8) {
 i7 = i7 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i6 = i6 | 0;
 i8 = i8 | 0;
 var i1 = 0, i2 = 0;
 i2 = HEAP32[i7 + 4 >> 2] | 0;
 i1 = i2 >> 8;
 if (i2 & 1) i1 = HEAP32[(HEAP32[i3 >> 2] | 0) + i1 >> 2] | 0;
 i7 = HEAP32[i7 >> 2] | 0;
 FUNCTION_TABLE_viiiiii[HEAP32[(HEAP32[i7 >> 2] | 0) + 20 >> 2] & 15](i7, i5, i4, i3 + i1 | 0, i2 & 2 | 0 ? i6 : 2, i8);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function ___stdio_seek(i1, i2, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i3 = 0, i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i6 = i5;
 i3 = i5 + 20 | 0;
 HEAP32[i6 >> 2] = HEAP32[i1 + 60 >> 2];
 HEAP32[i6 + 4 >> 2] = 0;
 HEAP32[i6 + 8 >> 2] = i2;
 HEAP32[i6 + 12 >> 2] = i3;
 HEAP32[i6 + 16 >> 2] = i4;
 if ((___syscall_ret(___syscall140(140, i6 | 0) | 0) | 0) < 0) {
  HEAP32[i3 >> 2] = -1;
  i1 = -1;
 } else i1 = HEAP32[i3 >> 2] | 0;
 STACKTOP = i5;
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 5768;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 5168;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 6312;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZNSt3__219__tree_right_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i5) {
 i5 = i5 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i5 >> 2] | 0;
 i4 = i3 + 4 | 0;
 i1 = HEAP32[i4 >> 2] | 0;
 HEAP32[i5 >> 2] = i1;
 if (i1 | 0) HEAP32[i1 + 8 >> 2] = i5;
 i1 = i5 + 8 | 0;
 HEAP32[i3 + 8 >> 2] = HEAP32[i1 >> 2];
 i2 = HEAP32[i1 >> 2] | 0;
 if ((HEAP32[i2 >> 2] | 0) == (i5 | 0)) HEAP32[i2 >> 2] = i3; else HEAP32[i2 + 4 >> 2] = i3;
 HEAP32[i4 >> 2] = i5;
 HEAP32[i1 >> 2] = i3;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 7476;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5clearEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i1, HEAP32[i2 >> 2] | 0);
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 >> 2] = i2;
 HEAP32[i2 >> 2] = 0;
 return;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ImportENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 + 4 >> 2] | 0;
 i3 = i4 + 8 | 0;
 while (1) {
  i1 = HEAP32[i3 >> 2] | 0;
  if ((i1 | 0) == (i2 | 0)) break;
  i5 = i1 + -4 | 0;
  HEAP32[i3 >> 2] = i5;
  i1 = HEAP32[i5 >> 2] | 0;
  HEAP32[i5 >> 2] = 0;
  if (!i1) continue;
  __ZdlPv(i1);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferINS_10unique_ptrIN4wasm6ExportENS_14default_deleteIS3_EEEERNS_9allocatorIS6_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i2 = HEAP32[i4 + 4 >> 2] | 0;
 i3 = i4 + 8 | 0;
 while (1) {
  i1 = HEAP32[i3 >> 2] | 0;
  if ((i1 | 0) == (i2 | 0)) break;
  i5 = i1 + -4 | 0;
  HEAP32[i3 >> 2] = i5;
  i1 = HEAP32[i5 >> 2] | 0;
  HEAP32[i5 >> 2] = 0;
  if (!i1) continue;
  __ZdlPv(i1);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 6312;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 5948;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 7476;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 6672;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 6492;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 7408;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 7600;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EEclEOS5_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 4 | 0;
 i5 = i3;
 HEAP32[i5 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i4 >> 2] = HEAP32[i5 >> 2];
 i2 = __ZZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEENK3__1clES2_(i2 + 4 | 0, i4) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 5948;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 7036;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZNSt3__212_GLOBAL__N_130throw_from_string_out_of_rangeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i3;
 i3 = i3 + 4 | 0;
 __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_(i3, i1, 55925);
 i1 = HEAP32[1961] | 0;
 HEAP32[i2 >> 2] = (HEAP8[i3 + 11 >> 0] | 0) < 0 ? HEAP32[i3 >> 2] | 0 : i3;
 _fprintf(i1, 55940, i2) | 0;
 _abort();
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 6672;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 6492;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 7408;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 7600;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseMaybeBracketedERPcPKc(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE9skipSpaceERPc(i2);
 if ((HEAP8[HEAP32[i2 >> 2] >> 0] | 0) == 123) i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE19parseBracketedBlockERPc(i3, i2) | 0; else i1 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE23parseElementOrStatementERPcPKc(i3, i2, i1) | 0;
 return i1 | 0;
}

function __ZN4wasm6Module15getFunctionTypeENS_4NameE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 i1 = i1 + 116 | 0;
 i3 = __ZNSt3__23mapIN4wasm4NameEPNS1_12FunctionTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
 if (!(HEAP32[i3 >> 2] | 0)) ___assert_fail(21713, 19526, 1453, 21736); else {
  i3 = __ZNSt3__23mapIN4wasm4NameEPNS1_12FunctionTypeENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
  return HEAP32[i3 >> 2] | 0;
 }
 return 0;
}

function __ZN4wasm6Memory7SegmentC2EOS1_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0, i5 = 0;
 HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
 i4 = i2 + 4 | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i4 >> 2] = 0;
 i5 = i2 + 8 | 0;
 HEAP32[i5 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i4 >> 2] = HEAP32[i3 >> 2];
 i4 = i1 + 8 | 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 i1 = i1 + 12 | 0;
 HEAP32[i2 + 12 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i1 >> 2] = 0;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i3 >> 2] = 0;
 return;
}

function __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE18__construct_at_endEj(i1, i5) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = i1 + 4 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = i5;
 i4 = i2;
 while (1) {
  HEAP32[i4 >> 2] = 0;
  HEAP32[i4 + 4 >> 2] = 0;
  HEAP32[i4 + 8 >> 2] = 0;
  i1 = i1 + -1 | 0;
  if (!i1) break; else i4 = i4 + 12 | 0;
 }
 HEAP32[i3 >> 2] = i2 + (i5 * 12 | 0);
 return;
}

function __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEEC2EOS5_(i5, i4) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i6 = 0;
 HEAP32[i5 >> 2] = HEAP32[i4 >> 2];
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 HEAP32[i5 + 4 >> 2] = i1;
 i2 = i4 + 8 | 0;
 i6 = HEAP32[i2 >> 2] | 0;
 HEAP32[i5 + 8 >> 2] = i6;
 i3 = i5 + 4 | 0;
 if (!i6) HEAP32[i5 >> 2] = i3; else {
  HEAP32[i1 + 8 >> 2] = i3;
  i6 = i4 + 4 | 0;
  HEAP32[i4 >> 2] = i6;
  HEAP32[i6 >> 2] = 0;
  HEAP32[i2 >> 2] = 0;
 }
 return;
}

function __ZNSt3__212_GLOBAL__N_129throw_from_string_invalid_argERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i3;
 i3 = i3 + 4 | 0;
 __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_(i3, i1, 55944);
 i1 = HEAP32[1961] | 0;
 HEAP32[i2 >> 2] = (HEAP8[i3 + 11 >> 0] | 0) < 0 ? HEAP32[i3 >> 2] | 0 : i3;
 _fprintf(i1, 55940, i2) | 0;
 _abort();
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 7036;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 5348;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZN4wasm15MinifiedPrinter3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i2;
 HEAP32[i4 >> 2] = HEAP32[i3 + 16 >> 2];
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP8[i4 + 20 >> 0] = 0;
 HEAP32[i4 + 24 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 1;
 HEAP32[i4 + 12 >> 2] = 67717;
 HEAP32[i4 + 16 >> 2] = 67717;
 __ZN4wasm16PrintSExpression11visitModuleEPNS_6ModuleE(i4, i1);
 STACKTOP = i2;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 5348;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZN4wasm19DeadCodeElimination10doPreBlockEPS0_PPNS_10ExpressionE(i5, i1) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i4;
 HEAP32[i1 >> 2] = 0;
 i2 = i5 + 64 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 if (i3 >>> 0 < (HEAP32[i5 + 68 >> 2] | 0) >>> 0) {
  HEAP32[i3 >> 2] = 0;
  HEAP32[i2 >> 2] = i3 + 4;
 } else __ZNSt3__26vectorIjNS_9allocatorIjEEE21__push_back_slow_pathIjEEvOT_(i5 + 60 | 0, i1);
 STACKTOP = i4;
 return;
}

function __ZNSt3__218__tree_left_rotateIPNS_16__tree_node_baseIPvEEEEvT_(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i2 = i4 + 4 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 HEAP32[i2 >> 2] = i1;
 if (i1 | 0) HEAP32[i1 + 8 >> 2] = i4;
 i1 = i4 + 8 | 0;
 HEAP32[i3 + 8 >> 2] = HEAP32[i1 >> 2];
 i2 = HEAP32[i1 >> 2] | 0;
 if ((HEAP32[i2 >> 2] | 0) == (i4 | 0)) HEAP32[i2 >> 2] = i3; else HEAP32[i2 + 4 >> 2] = i3;
 HEAP32[i3 >> 2] = i4;
 HEAP32[i1 >> 2] = i3;
 return;
}

function __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 do if (i1 | 0) {
  i2 = i4 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  while (1) {
   if ((i3 | 0) == (i1 | 0)) break;
   i5 = i3 + -4 | 0;
   HEAP32[i2 >> 2] = i5;
   i3 = i5;
  }
  if ((i4 + 16 | 0) == (i1 | 0)) {
   HEAP8[i4 + 128 >> 0] = 0;
   break;
  } else {
   __ZdlPv(i1);
   break;
  }
 } while (0);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZNSt3__211__stdoutbufIwE6xsputnEPKwi(i4, i1, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0;
 L1 : do if (!(HEAP8[i4 + 44 >> 0] | 0)) {
  i2 = i1;
  i1 = 0;
  while (1) {
   if ((i1 | 0) >= (i3 | 0)) break L1;
   if ((FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 52 >> 2] & 63](i4, HEAP32[i2 >> 2] | 0) | 0) == -1) break L1;
   i2 = i2 + 4 | 0;
   i1 = i1 + 1 | 0;
  }
 } else i1 = _fwrite(i1, 4, i3, HEAP32[i4 + 32 >> 2] | 0) | 0; while (0);
 return i1 | 0;
}

function __ZNSt3__211__stdoutbufIcE6xsputnEPKci(i4, i1, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0;
 L1 : do if (!(HEAP8[i4 + 44 >> 0] | 0)) {
  i2 = i1;
  i1 = 0;
  while (1) {
   if ((i1 | 0) >= (i3 | 0)) break L1;
   if ((FUNCTION_TABLE_iii[HEAP32[(HEAP32[i4 >> 2] | 0) + 52 >> 2] & 63](i4, HEAPU8[i2 >> 0] | 0) | 0) == -1) break L1;
   i2 = i2 + 1 | 0;
   i1 = i1 + 1 | 0;
  }
 } else i1 = _fwrite(i1, 1, i3, HEAP32[i4 + 32 >> 2] | 0) | 0; while (0);
 return i1 | 0;
}

function __ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 63480) | 0;
 i3 = i2 + 36 | 0;
 HEAP32[i3 >> 2] = i4;
 i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 24 >> 2] & 255](i4) | 0;
 i1 = i2 + 44 | 0;
 HEAP32[i1 >> 2] = i4;
 i3 = HEAP32[i3 >> 2] | 0;
 i3 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 255](i3) | 0) & 1;
 HEAP8[i2 + 53 >> 0] = i3;
 return;
}

function __ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i4 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 63472) | 0;
 i3 = i2 + 36 | 0;
 HEAP32[i3 >> 2] = i4;
 i4 = FUNCTION_TABLE_ii[HEAP32[(HEAP32[i4 >> 2] | 0) + 24 >> 2] & 255](i4) | 0;
 i1 = i2 + 44 | 0;
 HEAP32[i1 >> 2] = i4;
 i3 = HEAP32[i3 >> 2] | 0;
 i3 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i3 >> 2] | 0) + 28 >> 2] & 255](i3) | 0) & 1;
 HEAP8[i2 + 53 >> 0] = i3;
 return;
}

function __ZN4wasm7Literal10NaNPayloadEd(d1) {
 d1 = +d1;
 var i2 = 0, d3 = 0.0;
 d3 = +Math_abs(+d1);
 HEAPF64[tempDoublePtr >> 3] = d3;
 i2 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 if (i2 >>> 0 > 2146435072 | (i2 | 0) == 2146435072 & (HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 0) {
  HEAPF64[tempDoublePtr >> 3] = d1;
  i2 = HEAP32[tempDoublePtr >> 2] | 0;
  tempRet0 = HEAP32[tempDoublePtr + 4 >> 2] & 1048575;
  return i2 | 0;
 } else ___assert_fail(29144, 19526, 285, 29429);
 return 0;
}

function __ZN4wasm11FullPrinter3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i2;
 HEAP32[i4 >> 2] = HEAP32[i3 + 16 >> 2];
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP32[i4 + 24 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 0;
 HEAP32[i4 + 12 >> 2] = 58055;
 HEAP32[i4 + 16 >> 2] = 34477;
 HEAP8[i4 + 20 >> 0] = 1;
 __ZN4wasm16PrintSExpression11visitModuleEPNS_6ModuleE(i4, i1);
 STACKTOP = i2;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(20) | 0;
 i3 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 7240;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i1 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i1 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return i2 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZNKSt3__25ctypeIwE5do_isEPKwS3_Pt(i1, i6, i5, i2) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i7 = 0;
 i4 = (i5 - i6 | 0) >>> 2;
 i3 = i6;
 while (1) {
  if ((i3 | 0) == (i5 | 0)) break;
  i1 = HEAP32[i3 >> 2] | 0;
  if (i1 >>> 0 < 128) {
   i7 = ___ctype_b_loc() | 0;
   i1 = HEAPU16[(HEAP32[i7 >> 2] | 0) + (i1 << 1) >> 1] | 0;
  } else i1 = 0;
  HEAP16[i2 >> 1] = i1;
  i2 = i2 + 2 | 0;
  i3 = i3 + 4 | 0;
 }
 return i6 + (i4 << 2) | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE8parseNewERPcPKc(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 4 | 0;
 i6 = i4;
 i3 = __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE12parseElementERPcPKc(i3, i2, i1) | 0;
 HEAP32[i6 >> 2] = i3;
 HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
 i3 = __ZN6cashew12ValueBuilder7makeNewENS_3RefE(i5) | 0;
 STACKTOP = i4;
 return i3 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = 7240;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 HEAP32[i2 + 8 >> 2] = HEAP32[i3 + 8 >> 2];
 HEAP32[i2 + 12 >> 2] = HEAP32[i3 + 12 >> 2];
 return;
}

function __ZNK4wasm7Literal8popCountEv(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i2 + 8 | 0;
 if ((HEAP32[i2 >> 2] | 0) == 1) {
  i1 = __ZN4wasm8PopCountIjEEiT_(HEAP32[i1 >> 2] | 0) | 0;
  HEAP32[i3 + 8 >> 2] = i1;
  i1 = 1;
 } else {
  i2 = i1;
  i2 = __ZN4wasm8PopCountIyEEiT_(HEAP32[i2 >> 2] | 0, HEAP32[i2 + 4 >> 2] | 0) | 0;
  i1 = i3 + 8 | 0;
  HEAP32[i1 >> 2] = i2;
  HEAP32[i1 + 4 >> 2] = ((i2 | 0) < 0) << 31 >> 31;
  i1 = 2;
 }
 HEAP32[i3 >> 2] = i1;
 return;
}

function __ZN4wasm19DeadCodeElimination19doAfterBlockElementEPS0_PPNS_10ExpressionE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i1 = __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 i4 = (HEAP32[i3 + 64 >> 2] | 0) + -4 | 0;
 i2 = (HEAP32[i4 >> 2] | 0) + 1 | 0;
 HEAP32[i4 >> 2] = i2;
 if ((HEAP8[i3 + 44 >> 0] | 0) == 0 ? (HEAP32[i1 + 20 >> 2] | 0) >>> 0 > i2 >>> 0 : 0) __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i1 + 12 | 0, i2);
 return;
}

function _wmemmove(i4, i3, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 i2 = (i1 | 0) == 0;
 if (i4 - i3 >> 2 >>> 0 < i1 >>> 0) {
  if (!i2) do {
   i1 = i1 + -1 | 0;
   HEAP32[i4 + (i1 << 2) >> 2] = HEAP32[i3 + (i1 << 2) >> 2];
  } while ((i1 | 0) != 0);
 } else if (!i2) {
  i2 = i3;
  i3 = i4;
  while (1) {
   i1 = i1 + -1 | 0;
   HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
   if (!i1) break; else {
    i2 = i2 + 4 | 0;
    i3 = i3 + 4 | 0;
   }
  }
 }
 return i4 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE5clearEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_8FunctionEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE(i1, HEAP32[i2 >> 2] | 0);
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 >> 2] = i2;
 HEAP32[i2 >> 2] = 0;
 return;
}

function __ZN4wasm7Printer3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i2;
 HEAP32[i4 >> 2] = HEAP32[i3 + 16 >> 2];
 HEAP32[i4 + 4 >> 2] = 0;
 HEAP8[i4 + 20 >> 0] = 0;
 HEAP32[i4 + 24 >> 2] = 0;
 HEAP8[i4 + 8 >> 0] = 0;
 HEAP32[i4 + 12 >> 2] = 58055;
 HEAP32[i4 + 16 >> 2] = 34477;
 __ZN4wasm16PrintSExpression11visitModuleEPNS_6ModuleE(i4, i1);
 STACKTOP = i2;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8allocateEj(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 if (i2 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i3);
 i1 = i3 + 128 | 0;
 if (i2 >>> 0 < 29 & (HEAP8[i1 >> 0] | 0) == 0) {
  HEAP8[i1 >> 0] = 1;
  i1 = i3 + 16 | 0;
 } else i1 = __Znwj(i2 << 2) | 0;
 HEAP32[i3 + 4 >> 2] = i1;
 HEAP32[i3 >> 2] = i1;
 HEAP32[i3 + 8 >> 2] = i1 + (i2 << 2);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE5clearEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i1, HEAP32[i2 >> 2] | 0);
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 >> 2] = i2;
 HEAP32[i2 >> 2] = 0;
 return;
}

function __ZNKSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE14__count_uniqueIjEEjRKT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 i1 = i2 + 4 | 0;
 while (1) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (!i1) {
   i1 = 0;
   break;
  }
  i2 = HEAP32[i1 + 16 >> 2] | 0;
  if (i3 >>> 0 < i2 >>> 0) continue;
  if (i2 >>> 0 >= i3 >>> 0) {
   i1 = 1;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 return i1 | 0;
}

function __ZN4wasm6Module11getFunctionENS_4NameE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 i1 = i1 + 152 | 0;
 i3 = __ZNSt3__23mapIN4wasm4NameEPNS1_8FunctionENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
 if (!(HEAP32[i3 >> 2] | 0)) ___assert_fail(29365, 19526, 1456, 29384); else {
  i3 = __ZNSt3__23mapIN4wasm4NameEPNS1_8FunctionENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
  return HEAP32[i3 >> 2] | 0;
 }
 return 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 6124;
 __ZNSt3__213__vector_baseIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 6032;
 __ZNSt3__213__vector_baseIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2EOS4_(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = i3 + 16 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 do if (i2) if ((i2 | 0) == (i3 | 0)) {
  HEAP32[i4 + 16 >> 2] = i4;
  i3 = HEAP32[i1 >> 2] | 0;
  FUNCTION_TABLE_vii[HEAP32[(HEAP32[i3 >> 2] | 0) + 12 >> 2] & 1023](i3, i4);
  break;
 } else {
  HEAP32[i4 + 16 >> 2] = i2;
  HEAP32[i1 >> 2] = 0;
  break;
 } else HEAP32[i4 + 16 >> 2] = 0; while (0);
 return;
}

function __ZN4wasm8Function13getLocalIndexENS_4NameE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i1 = i1 + 52 | 0;
 if (!(__ZNKSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE14__count_uniqueIS3_EEjRKT_(i1, i2) | 0)) ___assert_fail(22555, 19526, 1363, 22584); else {
  i2 = __ZNSt3__23mapIN4wasm4NameEjNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_jEEEEEixERS7_(i1, i2) | 0;
  return HEAP32[i2 >> 2] | 0;
 }
 return 0;
}

function __ZN4wasm14GeneticLearnerIZNS_26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS2_9allocatorIjEEEEE5OrderdZNS1_11pickIndicesES7_E9GeneratorE11randomIndexEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZNSt3__223mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EEclEv(i1 + 16 | 0) | 0;
 return (i2 >>> 0) % ((HEAP32[i1 + 8 >> 2] | 0) - (HEAP32[i1 + 4 >> 2] | 0) >> 2 >>> 0) | 0 | 0;
}

function __ZN4wasm12toUInteger64Ed(d2) {
 d2 = +d2;
 var i1 = 0, i3 = 0;
 HEAPF64[tempDoublePtr >> 3] = d2;
 if ((HEAP32[tempDoublePtr + 4 >> 2] | 0) >= 0) if (d2 < 18446744073709551616.0) {
  i3 = +Math_abs(d2) >= 1.0 ? (d2 > 0.0 ? ~~+Math_min(+Math_floor(d2 / 4294967296.0), 4294967295.0) >>> 0 : ~~+Math_ceil((d2 - +(~~d2 >>> 0)) / 4294967296.0) >>> 0) : 0;
  i1 = ~~d2 >>> 0;
 } else {
  i3 = -1;
  i1 = -1;
 } else {
  i3 = 0;
  i1 = 0;
 }
 tempRet0 = i3;
 return i1 | 0;
}

function __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(i2, i3, i1) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i2, 40) | 0;
 if (i1) __Z17prepareMajorColorRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE(i2) | 0; else __Z12prepareColorRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE(i2) | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i2, i3) | 0;
 return i2 | 0;
}

function __ZN4wasm12RegisterPassINS_28DuplicateFunctionEliminationEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 7324;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasm19DeadCodeElimination8addBreakENS_4NameE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 if (!(HEAP8[i2 + 44 >> 0] | 0)) ___assert_fail(33232, 33179, 46, 33242); else {
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i3, i2 + 48 | 0, i1, i1);
  STACKTOP = i3;
  return;
 }
}

function __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib(i6, i4, i3, i5, i7) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 i7 = i7 | 0;
 var i1 = 0, i2 = 0;
 i2 = HEAP32[i6 + 4 >> 2] | 0;
 i1 = i2 >> 8;
 if (i2 & 1) i1 = HEAP32[(HEAP32[i3 >> 2] | 0) + i1 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 FUNCTION_TABLE_viiiii[HEAP32[(HEAP32[i6 >> 2] | 0) + 24 >> 2] & 3](i6, i4, i3 + i1 | 0, i2 & 2 | 0 ? i5 : 2, i7);
 return;
}

function __ZN4wasm12RegisterPassINS_26CoalesceLocalsWithLearningEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 7776;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasm6Module9getImportENS_4NameE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 i1 = i1 + 128 | 0;
 i3 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ImportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
 if (!(HEAP32[i3 >> 2] | 0)) ___assert_fail(19735, 19526, 1454, 19752); else {
  i3 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ImportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
  return HEAP32[i3 >> 2] | 0;
 }
 return 0;
}

function __ZN4wasm6Module9getExportENS_4NameE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 i1 = i1 + 140 | 0;
 i3 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ExportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
 if (!(HEAP32[i3 >> 2] | 0)) ___assert_fail(29338, 19526, 1455, 29355); else {
  i3 = __ZNSt3__23mapIN4wasm4NameEPNS1_6ExportENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_(i1, i2) | 0;
  return HEAP32[i3 >> 2] | 0;
 }
 return 0;
}

function __ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi(i4, i2, i1, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 if ((i4 | 0) == (HEAP32[i2 + 8 >> 2] | 0)) __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0, i2, i1, i3); else {
  i4 = HEAP32[i4 + 8 >> 2] | 0;
  FUNCTION_TABLE_viiii[HEAP32[(HEAP32[i4 >> 2] | 0) + 28 >> 2] & 15](i4, i2, i1, i3);
 }
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 8 >> 2] & 31](i3, i2, i1);
 HEAP32[i3 + 40 >> 2] = i1;
 __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i3 + 16 + -16 + 16 | 0, i1);
 FUNCTION_TABLE_viii[HEAP32[(HEAP32[i3 >> 2] | 0) + 16 >> 2] & 31](i3, i2, i1);
 return;
}

function __ZN4wasm14CoalesceLocalsC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 7532;
 HEAP32[i1 + 16 >> 2] = 7564;
 i2 = i1 + 116 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i2 + 24 >> 2] = 0;
 HEAPF32[i1 + 144 >> 2] = 1.0;
 return;
}

function __ZNSt3__214__split_bufferINS_6vectorIPPN4wasm10ExpressionENS_9allocatorIS5_EEEERNS6_IS8_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  i3 = i3 + -12 | 0;
  HEAP32[i2 >> 2] = i3;
  __ZNSt3__213__vector_baseIPPN4wasm10ExpressionENS_9allocatorIS4_EEED2Ev(i3);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__213__vector_baseINS_6vectorIPPN4wasm10ExpressionENS_9allocatorIS5_EEEENS6_IS8_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   i3 = i3 + -12 | 0;
   HEAP32[i2 >> 2] = i3;
   __ZNSt3__213__vector_baseIPPN4wasm10ExpressionENS_9allocatorIS4_EEED2Ev(i3);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function __ZN4wasm12RegisterPassINS_20OptimizeInstructionsEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 5672;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZNSt3__26locale2id5__getEv(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i2 = i5 + 16 | 0;
 i3 = i5 + 12 | 0;
 i1 = i5;
 HEAP32[i1 >> 2] = i4;
 HEAP32[i1 + 4 >> 2] = 290;
 HEAP32[i1 + 8 >> 2] = 0;
 if ((HEAP32[i4 >> 2] | 0) != -1) {
  HEAP32[i2 >> 2] = i1;
  HEAP32[i3 >> 2] = i2;
  __ZNSt3__211__call_onceERVmPvPFvS2_E(i4, i3, 291);
 }
 STACKTOP = i5;
 return (HEAP32[i4 + 4 >> 2] | 0) + -1 | 0;
}

function __ZN4wasm12RegisterPassINS_19DeadCodeEliminationEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 5072;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function ___towrite(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0;
 i1 = i2 + 74 | 0;
 i3 = HEAP8[i1 >> 0] | 0;
 HEAP8[i1 >> 0] = i3 + 255 | i3;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!(i1 & 8)) {
  HEAP32[i2 + 8 >> 2] = 0;
  HEAP32[i2 + 4 >> 2] = 0;
  i1 = HEAP32[i2 + 44 >> 2] | 0;
  HEAP32[i2 + 28 >> 2] = i1;
  HEAP32[i2 + 20 >> 2] = i1;
  HEAP32[i2 + 16 >> 2] = i1 + (HEAP32[i2 + 48 >> 2] | 0);
  i1 = 0;
 } else {
  HEAP32[i2 >> 2] = i1 | 32;
  i1 = -1;
 }
 return i1 | 0;
}

function __ZN4wasm15Asm2WasmBuilder14detectWasmTypeEN6cashew3RefEP7AsmData(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 4 | 0;
 i6 = i4;
 HEAP32[i6 >> 2] = HEAP32[i1 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
 i3 = __ZN4wasm13asmToWasmTypeE7AsmType(__ZN4wasm15Asm2WasmBuilder13detectAsmTypeEN6cashew3RefEP7AsmData(i3, i5, i2) | 0) | 0;
 STACKTOP = i4;
 return i3 | 0;
}

function __ZN4wasm14EffectAnalyzerD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 5392;
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEED2Ev(i1 + 60 | 0);
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEED2Ev(i1 + 44 | 0);
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEED2Ev(i1 + 32 | 0);
 HEAP32[i1 >> 2] = 5404;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 8 | 0);
 return;
}

function __ZN4wasm14CoalesceLocalsD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7532;
 HEAP32[i1 + 16 >> 2] = 7564;
 __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEED2Ev(i1 + 128 | 0);
 __ZNSt3__26vectorIbNS_9allocatorIbEEED2Ev(i1 + 116 | 0);
 __ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEED2Ev(i1);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE5clearEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i1, HEAP32[i2 >> 2] | 0);
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 >> 2] = i2;
 HEAP32[i2 >> 2] = 0;
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskERNS_9allocatorISA_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm13ReorderLocalsD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7104;
 HEAP32[i1 + 16 >> 2] = 7132;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEED2Ev(i1 + 56 | 0);
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEED2Ev(i1 + 44 | 0);
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEED2Ev(i1);
 return;
}

function __ZN4wasm12RegisterPassINS_17RemoveUnusedNamesEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 6216;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasmL10mergeTypesERNSt3__26vectorINS_8WasmTypeENS0_9allocatorIS2_EEEE(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = HEAP32[i1 + 4 >> 2] | 0;
 i3 = HEAP32[i1 >> 2] | 0;
 i1 = 5;
 while (1) {
  if ((i3 | 0) == (i4 | 0)) break;
  i2 = HEAP32[i3 >> 2] | 0;
  if (!((i1 | 0) == 0 | (i2 | 0) == 0)) {
   if ((i2 | 0) != 5) if ((i1 | 0) == 5) i1 = i2; else i1 = (i1 | 0) == (i2 | 0) ? i1 : 0;
  } else i1 = 0;
  i3 = i3 + 4 | 0;
 }
 return i1 | 0;
}

function __ZN4wasm11MergeBlocks11visitSelectEPNS_6SelectE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = i1 + 12 | 0;
 i4 = i1 + 8 | 0;
 __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i1 + 16 | 0, __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i3, __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i4, 0, 0, 0) | 0, i4, 0) | 0, i4, i3) | 0;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorINS2_14SimplifyLocals10BlockBreakENS_9allocatorIS6_EEEEEENS_19__map_value_compareIS3_SA_NS_4lessIS3_EELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__223mersenne_twister_engineIjLj32ELj624ELj397ELj31ELj2567483615ELj11ELj4294967295ELj7ELj2636928640ELj15ELj4022730752ELj18ELj1812433253EE4seedEj(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 HEAP32[i3 >> 2] = i1;
 i2 = 1;
 while (1) {
  if ((i2 | 0) == 624) break;
  i4 = (Math_imul(i1 >>> 30 ^ i1, 1812433253) | 0) + i2 | 0;
  HEAP32[i3 + (i2 << 2) >> 2] = i4;
  i1 = i4;
  i2 = i2 + 1 | 0;
 }
 HEAP32[i3 + 2496 >> 2] = 0;
 return;
}

function __ZN4wasm12RegisterPassINS_15RemoveUnusedBrsEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 5852;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasm12RegisterPassINS_15MinifiedPrinterEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 5528;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasm22SExpressionWasmBuilder12makeGetLocalERNS_7ElementE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = __ZN10MixedArena5allocIN4wasm8GetLocalEEEPT_v(HEAP32[i2 + 4 >> 2] | 0) | 0;
 i1 = __ZN4wasm22SExpressionWasmBuilder13getLocalIndexERNS_7ElementE(i2, __ZN4wasm7ElementixEj(i1, 1) | 0) | 0;
 HEAP32[i3 + 8 >> 2] = i1;
 i2 = __ZN4wasm8Function12getLocalTypeEj(HEAP32[i2 + 40 >> 2] | 0, i1) | 0;
 HEAP32[i3 + 4 >> 2] = i2;
 return i3 | 0;
}

function __ZN4wasm14SimplifyLocals21doNoteIfElseConditionEPS0_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i1 = (__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0) + 16 | 0;
 if (!(HEAP32[i1 >> 2] | 0)) ___assert_fail(42111, 41949, 137, 42158); else {
  __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE5clearEv(i2 + 44 | 0);
  return;
 }
}

function __ZN4wasm12RegisterPassINS_14SimplifyLocalsEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 6576;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasm12RegisterPassINS_14PostEmscriptenEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 6396;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasm12RegisterPassINS_14CoalesceLocalsEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 7732;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi(i6, i4, i3, i5) {
 i6 = i6 | 0;
 i4 = i4 | 0;
 i3 = i3 | 0;
 i5 = i5 | 0;
 var i1 = 0, i2 = 0;
 i2 = HEAP32[i6 + 4 >> 2] | 0;
 i1 = i2 >> 8;
 if (i2 & 1) i1 = HEAP32[(HEAP32[i3 >> 2] | 0) + i1 >> 2] | 0;
 i6 = HEAP32[i6 >> 2] | 0;
 FUNCTION_TABLE_viiii[HEAP32[(HEAP32[i6 >> 2] | 0) + 28 >> 2] & 15](i6, i4, i3 + i1 | 0, i2 & 2 | 0 ? i5 : 2);
 return;
}

function __ZN4wasm12RegisterPassINS_13ReorderLocalsEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 6940;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE10BasicBlockD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213__vector_baseIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEED2Ev(i1 + 48 | 0);
 __ZNSt3__213__vector_baseIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEED2Ev(i1 + 36 | 0);
 __ZN4wasm8LivenessD2Ev(i1);
 return;
}

function __ZN4wasm22SExpressionWasmBuilder10makeReturnERNS_7ElementE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0, i4 = 0;
 i1 = __ZN10MixedArena5allocIN4wasm6ReturnEEEPT_v(HEAP32[i3 + 4 >> 2] | 0) | 0;
 i4 = (__ZN4wasm7Element4listEv(i2) | 0) + 8 | 0;
 if ((HEAP32[i4 >> 2] | 0) >>> 0 > 1) {
  i4 = __ZN4wasm22SExpressionWasmBuilder15parseExpressionERNS_7ElementE(i3, __ZN4wasm7ElementixEj(i2, 1) | 0) | 0;
  HEAP32[i1 + 8 >> 2] = i4;
 }
 return i1 | 0;
}

function __ZN4wasm12RegisterPassINS_11MergeBlocksEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 5252;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasm12RegisterPassINS_11FullPrinterEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 5600;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZN4wasm16PrintSExpression13printFullLineEPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!(HEAP8[i2 + 8 >> 0] | 0)) __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i2 >> 2] | 0, HEAP32[i2 + 4 >> 2] | 0) | 0;
 __ZN4wasm7VisitorINS_16PrintSExpressionEvE5visitEPNS_10ExpressionE(i2, i1);
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(HEAP32[i2 >> 2] | 0, HEAP32[i2 + 16 >> 2] | 0) | 0;
 return;
}

function _memcmp(i2, i3, i1) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 L1 : do if (!i1) i1 = 0; else {
  i5 = i1;
  i4 = i2;
  while (1) {
   i2 = HEAP8[i4 >> 0] | 0;
   i1 = HEAP8[i3 >> 0] | 0;
   if (i2 << 24 >> 24 != i1 << 24 >> 24) break;
   i5 = i5 + -1 | 0;
   if (!i5) {
    i1 = 0;
    break L1;
   } else {
    i4 = i4 + 1 | 0;
    i3 = i3 + 1 | 0;
   }
  }
  i1 = (i2 & 255) - (i1 & 255) | 0;
 } while (0);
 return i1 | 0;
}

function ___stdout_write(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i4 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 80 | 0;
 i4 = i5;
 HEAP32[i2 + 36 >> 2] = 6;
 if ((HEAP32[i2 >> 2] & 64 | 0) == 0 ? (HEAP32[i4 >> 2] = HEAP32[i2 + 60 >> 2], HEAP32[i4 + 4 >> 2] = 21505, HEAP32[i4 + 8 >> 2] = i5 + 12, ___syscall54(54, i4 | 0) | 0) : 0) HEAP8[i2 + 75 >> 0] = -1;
 i4 = ___stdio_write(i2, i1, i3) | 0;
 STACKTOP = i5;
 return i4 | 0;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function _vsscanf(i4, i3, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i5 = 0, i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 112 | 0;
 i2 = i6;
 i5 = i2;
 i7 = i5 + 112 | 0;
 do {
  HEAP32[i5 >> 2] = 0;
  i5 = i5 + 4 | 0;
 } while ((i5 | 0) < (i7 | 0));
 HEAP32[i2 + 32 >> 2] = 28;
 HEAP32[i2 + 44 >> 2] = i4;
 HEAP32[i2 + 76 >> 2] = -1;
 HEAP32[i2 + 84 >> 2] = i4;
 i7 = _vfscanf(i2, i3, i1) | 0;
 STACKTOP = i6;
 return i7 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE5clearEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(i1, HEAP32[i2 >> 2] | 0);
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 >> 2] = i2;
 HEAP32[i2 >> 2] = 0;
 return;
}

function __ZN7AsmData7getTypeERKN6cashew7IStringE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i1 = __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE4findIS3_EENS_15__hash_iteratorIPNS_11__hash_nodeIS6_PvEEEERKT_(i2, i1) | 0;
 if (!i1) i1 = 8; else i1 = HEAP32[i1 + 12 >> 2] | 0;
 return i1 | 0;
}

function __ZN4wasm7Builder8makeHostENS_6HostOpENS_4NameEONSt3__26vectorIPNS_10ExpressionENS3_9allocatorIS6_EEEE(i4, i2, i1, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i4 = __ZN10MixedArena5allocIN4wasm4HostEEEPT_v(HEAP32[i4 >> 2] | 0) | 0;
 HEAP32[i4 + 8 >> 2] = i2;
 HEAP32[i4 + 12 >> 2] = HEAP32[i1 >> 2];
 __ZN11ArenaVectorIPN4wasm10ExpressionEE3setINSt3__26vectorIS2_NS5_9allocatorIS2_EEEEEEvRT_(i4 + 16 | 0, i3);
 return i4 | 0;
}

function __ZN4wasm12RegisterPassINS_7PrinterEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 5484;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEEaSERKS7_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 if ((i2 | 0) != (i1 | 0)) {
  i3 = HEAP8[i1 + 11 >> 0] | 0;
  i4 = i3 << 24 >> 24 < 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6assignEPKcj(i2, i4 ? HEAP32[i1 >> 2] | 0 : i1, i4 ? HEAP32[i1 + 4 >> 2] | 0 : i3 & 255);
 }
 return;
}

function __ZN4wasm12RegisterPassINS_6VacuumEEC2EPKcS4_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0, i5 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 i5 = __ZN4wasm12PassRegistry3getEv() | 0;
 HEAP32[i4 >> 2] = 7144;
 HEAP32[i4 + 16 >> 2] = i4;
 __ZN4wasm12PassRegistry12registerPassEPKcS2_NSt3__28functionIFPNS_4PassEvEEE(i5, i2, i1, i4);
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i4);
 STACKTOP = i3;
 return;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEE13__move_assignERS3_NS_17integral_constantIbLb1EEE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i4 = 0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE10deallocateEv(i3);
 HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
 i1 = i2 + 4 | 0;
 HEAP32[i3 + 4 >> 2] = HEAP32[i1 >> 2];
 i4 = i2 + 8 | 0;
 HEAP32[i3 + 8 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i4 >> 2] = 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i2 >> 2] = 0;
 return;
}

function __ZNK4wasm7Literal2leERKS0_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var d4 = 0.0;
 if ((HEAP32[i3 >> 2] | 0) == 3) {
  d4 = +__ZNK4wasm7Literal6getf32Ev(i3);
  i3 = d4 <= +__ZNK4wasm7Literal6getf32Ev(i2) & 1;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i3;
 } else {
  d4 = +__ZNK4wasm7Literal6getf64Ev(i3);
  i3 = d4 <= +__ZNK4wasm7Literal6getf64Ev(i2) & 1;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i3;
 }
 return;
}

function __ZNK4wasm7Literal2geERKS0_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var d4 = 0.0;
 if ((HEAP32[i3 >> 2] | 0) == 3) {
  d4 = +__ZNK4wasm7Literal6getf32Ev(i3);
  i3 = d4 >= +__ZNK4wasm7Literal6getf32Ev(i2) & 1;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i3;
 } else {
  d4 = +__ZNK4wasm7Literal6getf64Ev(i3);
  i3 = d4 >= +__ZNK4wasm7Literal6getf64Ev(i2) & 1;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i3;
 }
 return;
}

function __ZN4wasm16FunctionReplacer9visitCallEPNS_4CallE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = HEAP32[i2 + 28 >> 2] | 0;
 i1 = i1 + 24 | 0;
 i2 = __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_(i3, i1) | 0;
 if ((i2 | 0) != (i3 + 4 | 0)) HEAP32[i1 >> 2] = HEAP32[i2 + 20 >> 2];
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockERNS_9allocatorIS9_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNK4wasm7Literal2ltERKS0_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var d4 = 0.0;
 if ((HEAP32[i3 >> 2] | 0) == 3) {
  d4 = +__ZNK4wasm7Literal6getf32Ev(i3);
  i3 = d4 < +__ZNK4wasm7Literal6getf32Ev(i2) & 1;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i3;
 } else {
  d4 = +__ZNK4wasm7Literal6getf64Ev(i3);
  i3 = d4 < +__ZNK4wasm7Literal6getf64Ev(i2) & 1;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i3;
 }
 return;
}

function __ZNK4wasm7Literal2gtERKS0_(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var d4 = 0.0;
 if ((HEAP32[i3 >> 2] | 0) == 3) {
  d4 = +__ZNK4wasm7Literal6getf32Ev(i3);
  i3 = d4 > +__ZNK4wasm7Literal6getf32Ev(i2) & 1;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i3;
 } else {
  d4 = +__ZNK4wasm7Literal6getf64Ev(i3);
  i3 = d4 > +__ZNK4wasm7Literal6getf64Ev(i2) & 1;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i3;
 }
 return;
}

function __ZN11ArenaVectorIPN4wasm10ExpressionEE6resizeEj(i1, i4) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 if ((HEAP32[i1 + 12 >> 2] | 0) >>> 0 < i4 >>> 0) __ZN11ArenaVectorIPN4wasm10ExpressionEE10reallocateEj(i1, i4);
 i3 = i1 + 8 | 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if (i2 >>> 0 >= i4 >>> 0) break;
  HEAP32[(HEAP32[i1 >> 2] | 0) + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 HEAP32[i3 >> 2] = i4;
 return;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE13__lower_boundIS2_EENS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEERKT_SD_SD_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 L1 : while (1) {
  while (1) {
   if (!i2) break L1;
   if (!(__ZNK6cashew7IStringltERKS0_(i2 + 16 | 0, i4) | 0)) break;
   i2 = HEAP32[i2 + 4 >> 2] | 0;
  }
  i1 = i2;
  i2 = HEAP32[i2 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__214__split_bufferINS_8functionIFN4wasm15ThreadWorkStateEvEEERNS_9allocatorIS5_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  i3 = i3 + -24 | 0;
  HEAP32[i2 >> 2] = i3;
  __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i3);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__213__vector_baseINS_8functionIFN4wasm15ThreadWorkStateEvEEENS_9allocatorIS5_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   i3 = i3 + -24 | 0;
   HEAP32[i2 >> 2] = i3;
   __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i3);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function __ZN7AsmDataD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213__vector_baseIN6cashew7IStringENS_9allocatorIS2_EEED2Ev(i1 + 32 | 0);
 __ZNSt3__213__vector_baseIN6cashew7IStringENS_9allocatorIS2_EEED2Ev(i1 + 20 | 0);
 __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEED2Ev(i1);
 return;
}

function ___string_read(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i4 = 0, i5 = 0, i6 = 0, i7 = 0;
 i4 = i2 + 84 | 0;
 i6 = HEAP32[i4 >> 2] | 0;
 i7 = i3 + 256 | 0;
 i5 = _memchr(i6, 0, i7) | 0;
 i5 = (i5 | 0) == 0 ? i7 : i5 - i6 | 0;
 i3 = i5 >>> 0 < i3 >>> 0 ? i5 : i3;
 _memcpy(i1 | 0, i6 | 0, i3 | 0) | 0;
 HEAP32[i2 + 4 >> 2] = i6 + i3;
 i1 = i6 + i5 | 0;
 HEAP32[i2 + 8 >> 2] = i1;
 HEAP32[i4 >> 2] = i1;
 return i3 | 0;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11TypeUpdaterNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerIZNS1_15RemoveUnusedBrs14doWalkFunctionEPNS1_8FunctionEE11SelectifierNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(i1, i3) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i2 = 0;
 i1 = i1 + 4 | 0;
 while (1) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (!i1) {
   i1 = 0;
   break;
  }
  i2 = i1 + 16 | 0;
  if (__ZNK6cashew7IStringltERKS0_(i3, i2) | 0) continue;
  if (!(__ZNK6cashew7IStringltERKS0_(i2, i3) | 0)) {
   i1 = 1;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 return i1 | 0;
}

function __ZNKSt3__25ctypeIwE10do_toupperEPwPKw(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i6 = 0;
 i3 = (i4 - i5 | 0) >>> 2;
 i2 = i5;
 while (1) {
  if ((i2 | 0) == (i4 | 0)) break;
  i1 = HEAP32[i2 >> 2] | 0;
  if (i1 >>> 0 < 128) {
   i6 = ___ctype_toupper_loc() | 0;
   i1 = HEAP32[(HEAP32[i6 >> 2] | 0) + (i1 << 2) >> 2] | 0;
  }
  HEAP32[i2 >> 2] = i1;
  i2 = i2 + 4 | 0;
 }
 return i5 + (i3 << 2) | 0;
}

function __ZNKSt3__25ctypeIwE10do_tolowerEPwPKw(i1, i5, i4) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0, i6 = 0;
 i3 = (i4 - i5 | 0) >>> 2;
 i2 = i5;
 while (1) {
  if ((i2 | 0) == (i4 | 0)) break;
  i1 = HEAP32[i2 >> 2] | 0;
  if (i1 >>> 0 < 128) {
   i6 = ___ctype_tolower_loc() | 0;
   i1 = HEAP32[(HEAP32[i6 >> 2] | 0) + (i1 << 2) >> 2] | 0;
  }
  HEAP32[i2 >> 2] = i1;
  i2 = i2 + 4 | 0;
 }
 return i5 + (i3 << 2) | 0;
}

function __ZN4wasm8FunctionD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i1 + 52 | 0);
 __ZNSt3__213__vector_baseIN4wasm4NameENS_9allocatorIS2_EEED2Ev(i1 + 40 | 0);
 __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i1 + 20 | 0);
 __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i1 + 8 | 0);
 return;
}

function __ZNSt3__28ios_base4initEPv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 HEAP32[i2 + 24 >> 2] = i1;
 HEAP32[i2 + 16 >> 2] = (i1 | 0) == 0 & 1;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 4098;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 6;
 i3 = i2 + 28 | 0;
 i1 = i2 + 32 | 0;
 i2 = i1 + 40 | 0;
 do {
  HEAP32[i1 >> 2] = 0;
  i1 = i1 + 4 | 0;
 } while ((i1 | 0) < (i2 | 0));
 __ZNSt3__26localeC2Ev(i3);
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerIZNS1_13ReorderLocals13visitFunctionEPNS1_8FunctionEE9ReIndexerNS1_7VisitorIS6_vEEE4TaskENS_9allocatorISA_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm15Asm2WasmBuilder10getLiteralEN6cashew3RefE(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0, i6 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4 + 4 | 0;
 i6 = i4;
 HEAP32[i6 >> 2] = HEAP32[i2 >> 2];
 HEAP32[i5 >> 2] = HEAP32[i6 >> 2];
 __ZN4wasm15Asm2WasmBuilder12checkLiteralEN6cashew3RefE(i1, i3, i5);
 if (!(HEAP32[i1 >> 2] | 0)) _abort(); else {
  STACKTOP = i4;
  return;
 }
}

function _strcmp(i4, i2) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i1 = 0, i3 = 0;
 i3 = HEAP8[i4 >> 0] | 0;
 i1 = HEAP8[i2 >> 0] | 0;
 if (i3 << 24 >> 24 == 0 ? 1 : i3 << 24 >> 24 != i1 << 24 >> 24) i2 = i3; else {
  do {
   i4 = i4 + 1 | 0;
   i2 = i2 + 1 | 0;
   i3 = HEAP8[i4 >> 0] | 0;
   i1 = HEAP8[i2 >> 0] | 0;
  } while (!(i3 << 24 >> 24 == 0 ? 1 : i3 << 24 >> 24 != i1 << 24 >> 24));
  i2 = i3;
 }
 return (i2 & 255) - (i1 & 255) | 0;
}

function __ZNSt3__26vectorIN4wasm7LiteralENS_9allocatorIS2_EEE18__construct_at_endEj(i1, i5) {
 i1 = i1 | 0;
 i5 = i5 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i6 = 0;
 i3 = i1 + 4 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 i1 = i5;
 i4 = i2;
 while (1) {
  HEAP32[i4 >> 2] = 0;
  i6 = i4 + 8 | 0;
  HEAP32[i6 >> 2] = 0;
  HEAP32[i6 + 4 >> 2] = 0;
  i1 = i1 + -1 | 0;
  if (!i1) break; else i4 = i4 + 16 | 0;
 }
 HEAP32[i3 >> 2] = i2 + (i5 << 4);
 return;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE10deallocateEv(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  while (1) {
   if ((i3 | 0) == (i1 | 0)) break;
   i5 = i3 + -4 | 0;
   HEAP32[i2 >> 2] = i5;
   i3 = i5;
  }
  __ZdlPv(i1);
  HEAP32[i4 + 8 >> 2] = 0;
  HEAP32[i2 >> 2] = 0;
  HEAP32[i4 >> 2] = 0;
 }
 return;
}

function __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE10deallocateEv(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  while (1) {
   if ((i3 | 0) == (i1 | 0)) break;
   i5 = i3 + -8 | 0;
   HEAP32[i2 >> 2] = i5;
   i3 = i5;
  }
  __ZdlPv(i1);
  HEAP32[i4 + 8 >> 2] = 0;
  HEAP32[i2 >> 2] = 0;
  HEAP32[i4 >> 2] = 0;
 }
 return;
}

function __ZNSt3__214__split_bufferIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementERNS_9allocatorIS6_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN6cashew5Value10getIntegerEv(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = __ZN6cashew5Value9getNumberEv(i2) | 0;
 if (!(+_fmod(+HEAPF64[i1 >> 3], 1.0) == 0.0)) ___assert_fail(30540, 48272, 229, 30566);
 i1 = __ZN6cashew5Value9getNumberEv(i2) | 0;
 i1 = ~~+HEAPF64[i1 >> 3];
 i2 = __ZN6cashew5Value9getNumberEv(i2) | 0;
 if (+(i1 | 0) == +HEAPF64[i2 >> 3]) return i1 | 0; else ___assert_fail(30577, 48272, 231, 30566);
 return 0;
}

function __ZN4wasm17WasmBinaryBuilder13popExpressionEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0, i5 = 0;
 i5 = i1 + 100 | 0;
 i4 = HEAP32[i5 >> 2] | 0;
 i2 = i4;
 if ((i4 | 0) == (HEAP32[i1 + 96 >> 2] | 0)) ___assert_fail(25192, 22948, 1569, 25219);
 i3 = i2 + -4 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 i1 = i2;
 while (1) {
  if ((i1 | 0) == (i3 | 0)) break;
  i2 = i1 + -4 | 0;
  HEAP32[i5 >> 2] = i2;
  i1 = i2;
 }
 return i4 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 6084;
 HEAP32[i1 + 16 >> 2] = 6112;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 5992;
 HEAP32[i1 + 16 >> 2] = 6020;
 return;
}

function __ZN11ArenaVectorIN4wasm4NameEE9push_backES1_(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i2 = i4 + 8 | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if ((i1 | 0) == (HEAP32[i4 + 12 >> 2] | 0)) {
  __ZN11ArenaVectorIN4wasm4NameEE10reallocateEj(i4, (i1 << 1) + 2 | 0);
  i1 = HEAP32[i2 >> 2] | 0;
 }
 HEAP32[(HEAP32[i4 + 4 >> 2] | 0) + (i1 << 2) >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 1;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = __Znwj(64) | 0;
 HEAP32[i3 >> 2] = 4940;
 i4 = i3 + 4 | 0;
 i1 = i1 + 4 | 0;
 i2 = i4 + 60 | 0;
 do {
  HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
  i4 = i4 + 4 | 0;
  i1 = i1 + 4 | 0;
 } while ((i4 | 0) < (i2 | 0));
 return i3 | 0;
}

function __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE10deallocateEv(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  while (1) {
   if ((i3 | 0) == (i1 | 0)) break;
   i5 = i3 + -4 | 0;
   HEAP32[i2 >> 2] = i5;
   i3 = i5;
  }
  __ZdlPv(i1);
  HEAP32[i4 + 8 >> 2] = 0;
  HEAP32[i2 >> 2] = 0;
  HEAP32[i4 >> 2] = 0;
 }
 return;
}

function __ZN4wasm14EffectAnalyzer9visitLoopEPNS_4LoopE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i2 + 12 | 0;
 if (HEAP32[i1 >> 2] | 0) __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__erase_uniqueIS2_EEjRKT_(i3 + 60 | 0, i1) | 0;
 i1 = i2 + 8 | 0;
 if (HEAP32[i1 >> 2] | 0) __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__erase_uniqueIS2_EEjRKT_(i3 + 60 | 0, i1) | 0;
 return;
}

function __ZN11ArenaVectorIN4wasm4NameEE6resizeEj(i1, i4) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i2 = 0, i3 = 0;
 if ((HEAP32[i1 + 12 >> 2] | 0) >>> 0 < i4 >>> 0) __ZN11ArenaVectorIN4wasm4NameEE10reallocateEj(i1, i4);
 i3 = i1 + 8 | 0;
 i1 = i1 + 4 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if (i2 >>> 0 >= i4 >>> 0) break;
  HEAP32[(HEAP32[i1 >> 2] | 0) + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 HEAP32[i3 >> 2] = i4;
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm19DeadCodeEliminationD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 5212;
 HEAP32[i1 + 16 >> 2] = 5240;
 __ZNSt3__26vectorIbNS_9allocatorIbEEED2Ev(i1 + 72 | 0);
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1 + 60 | 0);
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEED2Ev(i1 + 48 | 0);
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEED2Ev(i1);
 return;
}

function __ZN4wasm6Vacuum4scanEPS0_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 16 | 0;
 __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i3, 426, i1);
 __ZN4wasm10PostWalkerINS_6VacuumENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE(i2, i1);
 __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE8pushTaskEPFvPS1_PPNS_10ExpressionEES8_(i3, 427, i1);
 return;
}

function __ZN4wasm6Memory7SegmentC2ENS_7AddressEPKcS2_(i4, i1, i5, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i2 = 0;
 HEAP32[i4 >> 2] = HEAP32[i1 >> 2];
 i2 = i4 + 4 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i4 + 8 >> 2] = 0;
 HEAP32[i4 + 12 >> 2] = 0;
 i1 = HEAP32[i3 >> 2] | 0;
 __ZNSt3__26vectorIcNS_9allocatorIcEEE6resizeEj(i2, i1);
 if (i1 | 0) _memmove(HEAP32[i2 >> 2] | 0, i5 | 0, i1 | 0) | 0;
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN11ArenaVectorIPN4wasm10ExpressionEE10reallocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = i2 + 4 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 __ZN11ArenaVectorIPN4wasm10ExpressionEE8allocateEj(i2, i1);
 i1 = HEAP32[i2 + 8 >> 2] | 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  HEAP32[(HEAP32[i3 >> 2] | 0) + (i2 << 2) >> 2] = HEAP32[i4 + (i2 << 2) >> 2];
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZNSt3__2lsIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_13basic_ostreamIT_T0_EES9_RKNS_12basic_stringIS6_S7_T1_EE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0;
 i3 = HEAP8[i2 + 11 >> 0] | 0;
 i4 = i3 << 24 >> 24 < 0;
 return __ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j(i1, i4 ? HEAP32[i2 >> 2] | 0 : i2, i4 ? HEAP32[i2 + 4 >> 2] | 0 : i3 & 255) | 0;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN10MixedArena5clearEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0;
 i4 = i3 + 4 | 0;
 i1 = HEAP32[i4 >> 2] | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  __ZdaPv(HEAP32[i2 >> 2] | 0);
  i2 = i2 + 4 | 0;
 }
 i1 = HEAP32[i3 >> 2] | 0;
 i2 = HEAP32[i4 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  i3 = i2 + -4 | 0;
  HEAP32[i4 >> 2] = i3;
  i2 = i3;
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE5clearEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i1, HEAP32[i2 >> 2] | 0);
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 >> 2] = i2;
 HEAP32[i2 >> 2] = 0;
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE7__cloneEPNS0_6__baseISB_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 HEAP32[i1 >> 2] = 4940;
 i3 = i1 + 4 | 0;
 i1 = i2 + 4 | 0;
 i2 = i3 + 60 | 0;
 do {
  HEAP32[i3 >> 2] = HEAP32[i1 >> 2];
  i3 = i3 + 4 | 0;
  i1 = i1 + 4 | 0;
 } while ((i3 | 0) < (i2 | 0));
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__213__vector_baseIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_9allocatorIS9_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNKSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE14__count_uniqueIjEEjRKT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 i1 = i2 + 4 | 0;
 while (1) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (!i1) {
   i1 = 0;
   break;
  }
  i2 = HEAP32[i1 + 16 >> 2] | 0;
  if (i3 >>> 0 < i2 >>> 0) continue;
  if (i2 >>> 0 >= i3 >>> 0) {
   i1 = 1;
   break;
  }
  i1 = i1 + 4 | 0;
 }
 return i1 | 0;
}

function __ZN4wasm6Vacuum8visitPreEPS0_PPNS_10ExpressionE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = i4 + 48 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) == (HEAP32[i4 + 52 >> 2] | 0)) __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE21__push_back_slow_pathIRKS3_EEvOT_(i4 + 44 | 0, i3); else {
  HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 4;
 }
 return;
}

function __ZNKSt3__27codecvtIwc11__mbstate_tE11do_encodingEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = i1 + 8 | 0;
 i2 = _uselocale(HEAP32[i1 >> 2] | 0) | 0;
 i3 = _mbtowc(0, 0, 4) | 0;
 if (i2 | 0) _uselocale(i2) | 0;
 if (!i3) {
  i1 = HEAP32[i1 >> 2] | 0;
  if (i1) {
   i1 = _uselocale(i1) | 0;
   if (!i1) i1 = 0; else {
    _uselocale(i1) | 0;
    i1 = 0;
   }
  } else i1 = 1;
 } else i1 = -1;
 return i1 | 0;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm10PassRunnerD2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i4 = i1 + 8 | 0;
 i1 = HEAP32[i1 + 12 >> 2] | 0;
 i3 = HEAP32[i4 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i2 = HEAP32[i3 >> 2] | 0;
  if (i2 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i2 >> 2] | 0) + 4 >> 2] & 511](i2);
  i3 = i3 + 4 | 0;
 }
 __ZNSt3__213__vector_baseIPN4wasm4PassENS_9allocatorIS3_EEED2Ev(i4);
 return;
}

function __ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEEN9ReIndexer13visitSetLocalEPNS_8SetLocalE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i4 = HEAP32[i3 + 28 >> 2] | 0;
 i1 = i1 + 8 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((HEAP32[i4 + 12 >> 2] | 0) - (HEAP32[i4 + 8 >> 2] | 0) >> 2 >>> 0 <= i2 >>> 0) HEAP32[i1 >> 2] = HEAP32[(HEAP32[HEAP32[i3 + 32 >> 2] >> 2] | 0) + (i2 << 2) >> 2];
 return;
}

function __ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEEN9ReIndexer13visitGetLocalEPNS_8GetLocalE(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0, i4 = 0;
 i4 = HEAP32[i3 + 28 >> 2] | 0;
 i1 = i1 + 8 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((HEAP32[i4 + 12 >> 2] | 0) - (HEAP32[i4 + 8 >> 2] | 0) >> 2 >>> 0 <= i2 >>> 0) HEAP32[i1 >> 2] = HEAP32[(HEAP32[HEAP32[i3 + 32 >> 2] >> 2] | 0) + (i2 << 2) >> 2];
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6Memory7SegmentERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  HEAP32[i2 >> 2] = i3 + -16;
  __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i3 + -12 | 0);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm4Name7fromIntEj(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i2 + 12 | 0;
 i3 = i2;
 __ZNSt3__29to_stringEj(i3, i1);
 __ZN6cashew7IStringC2EPKcb(i4, (HEAP8[i3 + 11 >> 0] | 0) < 0 ? HEAP32[i3 >> 2] | 0 : i3, 0);
 i1 = HEAP32[i4 >> 2] | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i3);
 STACKTOP = i2;
 return i1 | 0;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEE10deallocateEv(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  i3 = HEAP32[i2 >> 2] | 0;
  while (1) {
   if ((i3 | 0) == (i1 | 0)) break;
   i5 = i3 + -4 | 0;
   HEAP32[i2 >> 2] = i5;
   i3 = i5;
  }
  __ZdlPv(i1);
  HEAP32[i4 + 8 >> 2] = 0;
  HEAP32[i2 >> 2] = 0;
  HEAP32[i4 >> 2] = 0;
 }
 return;
}

function __ZN11ArenaVectorIPN4wasm7ElementEE10reallocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = i2 + 4 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 __ZN11ArenaVectorIPN4wasm7ElementEE8allocateEj(i2, i1);
 i1 = HEAP32[i2 + 8 >> 2] | 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == (i1 | 0)) break;
  HEAP32[(HEAP32[i3 >> 2] | 0) + (i2 << 2) >> 2] = HEAP32[i4 + (i2 << 2) >> 2];
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i2 = i4 + 8 | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if ((i1 | 0) == (HEAP32[i4 + 12 >> 2] | 0)) {
  __ZN11ArenaVectorIPN4wasm10ExpressionEE10reallocateEj(i4, (i1 << 1) + 2 | 0);
  i1 = HEAP32[i2 >> 2] | 0;
 }
 HEAP32[(HEAP32[i4 + 4 >> 2] | 0) + (i1 << 2) >> 2] = i3;
 HEAP32[i2 >> 2] = i1 + 1;
 return;
}

function __ZN11ArenaVectorIN4wasm4NameEE10reallocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = i2 + 4 | 0;
 i4 = HEAP32[i3 >> 2] | 0;
 __ZN11ArenaVectorIN4wasm4NameEE8allocateEj(i2, i1);
 i1 = i2 + 8 | 0;
 i2 = 0;
 while (1) {
  if (i2 >>> 0 >= (HEAP32[i1 >> 2] | 0) >>> 0) break;
  HEAP32[(HEAP32[i3 >> 2] | 0) + (i2 << 2) >> 2] = HEAP32[i4 + (i2 << 2) >> 2];
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNKSt3__25ctypeIwE11do_scan_notEtPKwS3_(i2, i4, i1, i3) {
 i2 = i2 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i5 = 0;
 while (1) {
  if ((i1 | 0) == (i3 | 0)) {
   i1 = i3;
   break;
  }
  i2 = HEAP32[i1 >> 2] | 0;
  if (i2 >>> 0 >= 128) break;
  i5 = ___ctype_b_loc() | 0;
  if (!((HEAP16[(HEAP32[i5 >> 2] | 0) + (i2 << 1) >> 1] & i4) << 16 >> 16)) break;
  i1 = i1 + 4 | 0;
 }
 return i1 | 0;
}

function __ZNSt3__28ios_base16__call_callbacksENS0_5eventE(i5, i3) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0, i4 = 0, i6 = 0;
 i1 = i5 + 32 | 0;
 i2 = i5 + 36 | 0;
 i4 = HEAP32[i5 + 40 >> 2] | 0;
 while (1) {
  if (!i4) break;
  i6 = i4 + -1 | 0;
  FUNCTION_TABLE_viii[HEAP32[(HEAP32[i1 >> 2] | 0) + (i6 << 2) >> 2] & 31](i3, i5, HEAP32[(HEAP32[i2 >> 2] | 0) + (i6 << 2) >> 2] | 0);
  i4 = i6;
 }
 return;
}

function __ZN4wasm13WasmValidator11visitReturnEPNS_6ReturnE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i1 = HEAP32[i1 + 8 >> 2] | 0;
 i2 = i2 + 44 | 0;
 do if (i1) {
  i3 = HEAP32[i2 >> 2] | 0;
  i1 = HEAP32[i1 + 4 >> 2] | 0;
  if ((i3 | 0) == 5) {
   HEAP32[i2 >> 2] = i1;
   break;
  }
  if (!((i1 | 0) == 5 | (i3 | 0) == (i1 | 0))) HEAP32[i2 >> 2] = 0;
 } else HEAP32[i2 >> 2] = 0; while (0);
 return;
}

function __ZN4wasm15RemoveUnusedBrsD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 6176;
 HEAP32[i1 + 16 >> 2] = 6204;
 __ZNSt3__213__vector_baseINS_6vectorIPPN4wasm10ExpressionENS_9allocatorIS5_EEEENS6_IS8_EEED2Ev(i1 + 60 | 0);
 __ZNSt3__213__vector_baseIPPN4wasm10ExpressionENS_9allocatorIS4_EEED2Ev(i1 + 48 | 0);
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEED2Ev(i1);
 return;
}

function __ZN11ArenaVectorIPN4wasm7ElementEE9push_backES2_(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i2 = i4 + 8 | 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if ((i1 | 0) == (HEAP32[i4 + 12 >> 2] | 0)) {
  __ZN11ArenaVectorIPN4wasm7ElementEE10reallocateEj(i4, (i1 << 1) + 2 | 0);
  i1 = HEAP32[i2 >> 2] | 0;
 }
 HEAP32[(HEAP32[i4 + 4 >> 2] | 0) + (i1 << 2) >> 2] = i3;
 HEAP32[i2 >> 2] = i1 + 1;
 return;
}

function __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEaSERKS4_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 32 | 0;
 i4 = i3;
 __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEC2ERKS4_(i4, i1);
 __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEE4swapERS4_(i4, i2);
 __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i4);
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__26chrono12steady_clock3nowEv() {
 var i1 = 0, i2 = 0, i3 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i2;
 _clock_gettime(1, i1 | 0) | 0;
 i3 = HEAP32[i1 >> 2] | 0;
 i1 = HEAP32[i1 + 4 >> 2] | 0;
 i3 = ___muldi3(i3 | 0, ((i3 | 0) < 0) << 31 >> 31 | 0, 1e9, 0) | 0;
 i1 = _i64Add(i3 | 0, tempRet0 | 0, i1 | 0, ((i1 | 0) < 0) << 31 >> 31 | 0) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZNSt3__213__vector_baseIN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm17RemoveUnusedNames10visitBreakEPNS_5BreakE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i1 + 8 | 0;
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i3, i2 + 44 | 0, i1, i1);
 STACKTOP = i3;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 if ((i2 | 0) != (i1 | 0)) {
  i3 = HEAP8[i1 + 11 >> 0] | 0;
  i4 = i3 << 24 >> 24 < 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj(i2, i4 ? HEAP32[i1 >> 2] | 0 : i1, i4 ? HEAP32[i1 + 4 >> 2] | 0 : i3 & 255) | 0;
 }
 return i2 | 0;
}

function ___muldsi3(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0, i5 = 0, i6 = 0;
 i6 = i1 & 65535;
 i5 = i2 & 65535;
 i3 = Math_imul(i5, i6) | 0;
 i4 = i1 >>> 16;
 i1 = (i3 >>> 16) + (Math_imul(i5, i4) | 0) | 0;
 i5 = i2 >>> 16;
 i2 = Math_imul(i5, i6) | 0;
 return (tempRet0 = (i1 >>> 16) + (Math_imul(i5, i4) | 0) + (((i1 & 65535) + i2 | 0) >>> 16) | 0, i1 + i2 << 16 | i3 & 65535 | 0) | 0;
}

function __ZN4wasm16PrintSExpression9decIndentEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 if (!(HEAP8[i1 + 8 >> 0] | 0)) {
  i3 = i1 + 4 | 0;
  i2 = (HEAP32[i3 >> 2] | 0) + -1 | 0;
  HEAP32[i3 >> 2] = i2;
  __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(HEAP32[i1 >> 2] | 0, i2) | 0;
 }
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i1 >> 2] | 0, 41) | 0;
 return;
}

function __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i1) return; else {
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE(i2, HEAP32[i1 >> 2] | 0);
  __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE(i2, HEAP32[i1 + 4 >> 2] | 0);
  __ZdlPv(i1);
  return;
 }
}

function __ZNKSt3__25ctypeIwE9do_narrowEPKwS3_cPc(i1, i6, i5, i4, i2) {
 i1 = i1 | 0;
 i6 = i6 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i3 = 0, i7 = 0;
 i3 = (i5 - i6 | 0) >>> 2;
 i1 = i2;
 i2 = i6;
 while (1) {
  if ((i2 | 0) == (i5 | 0)) break;
  i7 = HEAP32[i2 >> 2] | 0;
  HEAP8[i1 >> 0] = i7 >>> 0 < 128 ? i7 & 255 : i4;
  i1 = i1 + 1 | 0;
  i2 = i2 + 4 | 0;
 }
 return i6 + (i3 << 2) | 0;
}

function __ZNKSt3__25ctypeIcE10do_toupperEPcPKc(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i4 = 0;
 i2 = i1;
 while (1) {
  if ((i2 | 0) == (i3 | 0)) break;
  i1 = HEAP8[i2 >> 0] | 0;
  if (i1 << 24 >> 24 > -1) {
   i4 = ___ctype_toupper_loc() | 0;
   i1 = HEAP32[(HEAP32[i4 >> 2] | 0) + (i1 << 24 >> 24 << 2) >> 2] & 255;
  }
  HEAP8[i2 >> 0] = i1;
  i2 = i2 + 1 | 0;
 }
 return i3 | 0;
}

function __ZNKSt3__25ctypeIcE10do_tolowerEPcPKc(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i4 = 0;
 i2 = i1;
 while (1) {
  if ((i2 | 0) == (i3 | 0)) break;
  i1 = HEAP8[i2 >> 0] | 0;
  if (i1 << 24 >> 24 > -1) {
   i4 = ___ctype_tolower_loc() | 0;
   i1 = HEAP32[(HEAP32[i4 >> 2] | 0) + (i1 << 24 >> 24 << 2) >> 2] & 255;
  }
  HEAP8[i2 >> 0] = i1;
  i2 = i2 + 1 | 0;
 }
 return i3 | 0;
}

function __ZN4wasm14EffectAnalyzer10visitBreakEPNS_5BreakE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i1 + 8 | 0;
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE25__emplace_unique_key_argsIS2_JRKS2_EEENS_4pairINS_15__tree_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEbEERKT_DpOT0_(i3, i2 + 60 | 0, i1, i1);
 STACKTOP = i3;
 return;
}

function __ZNSt3__214__split_bufferIN6cashew13OperatorClassERNS_9allocatorIS2_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 while (1) {
  i3 = HEAP32[i2 >> 2] | 0;
  if ((i3 | 0) == (i1 | 0)) break;
  i3 = i3 + -40 | 0;
  HEAP32[i2 >> 2] = i3;
  __ZN6cashew10IStringSetD2Ev(i3);
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function ___fpclassifyf(d2) {
 d2 = +d2;
 var i1 = 0;
 i1 = (HEAPF32[tempDoublePtr >> 2] = d2, HEAP32[tempDoublePtr >> 2] | 0);
 switch (i1 >>> 23 & 255 | 0) {
 case 0:
  {
   d2 = +Math_abs(+d2);
   i1 = (HEAPF32[tempDoublePtr >> 2] = d2, HEAP32[tempDoublePtr >> 2] | 0) | 0 ? 3 : 2;
   break;
  }
 case 255:
  {
   i1 = (i1 & 8388607 | 0) == 0 & 1;
   break;
  }
 default:
  i1 = 4;
 }
 return i1 | 0;
}

function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC2ERS3_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP8[i2 >> 0] = 0;
 HEAP32[i2 + 4 >> 2] = i1;
 i1 = i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0;
 if (!(HEAP32[i1 + 16 >> 2] | 0)) {
  i1 = HEAP32[i1 + 72 >> 2] | 0;
  if (i1 | 0) __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv(i1) | 0;
  HEAP8[i2 >> 0] = 1;
 }
 return;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP8[i2 >> 0] = 0;
 HEAP32[i2 + 4 >> 2] = i1;
 i1 = i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0;
 if (!(HEAP32[i1 + 16 >> 2] | 0)) {
  i1 = HEAP32[i1 + 72 >> 2] | 0;
  if (i1 | 0) __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(i1) | 0;
  HEAP8[i2 >> 0] = 1;
 }
 return;
}

function __ZNSt3__213__vector_baseIN6cashew13OperatorClassENS_9allocatorIS2_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0;
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) {
  i2 = i4 + 4 | 0;
  while (1) {
   i3 = HEAP32[i2 >> 2] | 0;
   if ((i3 | 0) == (i1 | 0)) break;
   i3 = i3 + -40 | 0;
   HEAP32[i2 >> 2] = i3;
   __ZN6cashew10IStringSetD2Ev(i3);
  }
  __ZdlPv(HEAP32[i4 >> 2] | 0);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIS3_NS_9allocatorIS3_EEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function _rint(d1) {
 d1 = +d1;
 var i2 = 0, i3 = 0;
 HEAPF64[tempDoublePtr >> 3] = d1;
 i2 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 i3 = i2 & 2146435072;
 if (!(i3 >>> 0 > 1126170624 | (i3 | 0) == 1126170624 & 0 > 0)) {
  i2 = (i2 | 0) < 0;
  d1 = i2 ? d1 + -4503599627370496.0 + 4503599627370496.0 : d1 + 4503599627370496.0 + -4503599627370496.0;
  if (d1 == 0.0) d1 = i2 ? -0.0 : 0.0;
 }
 return +d1;
}

function __ZNSt3__214__split_bufferINS_4pairIPN4wasm7ElementEPNS2_5BlockEEERNS_9allocatorIS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNKSt3__25ctypeIwE10do_scan_isEtPKwS3_(i2, i4, i1, i3) {
 i2 = i2 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i5 = 0;
 while (1) {
  if ((i1 | 0) == (i3 | 0)) {
   i1 = i3;
   break;
  }
  i2 = HEAP32[i1 >> 2] | 0;
  if (i2 >>> 0 < 128 ? (i5 = ___ctype_b_loc() | 0, (HEAP16[(HEAP32[i5 >> 2] | 0) + (i2 << 1) >> 1] & i4) << 16 >> 16) : 0) break;
  i1 = i1 + 4 | 0;
 }
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm8FunctionENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm15RemoveUnusedBrs7visitIfEPNS_2IfE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 if (((HEAP32[i3 + 16 >> 2] | 0) == 0 ? (i1 = HEAP32[i3 + 12 >> 2] | 0, !((i1 | 0) == 0 | (HEAP32[i1 >> 2] | 0) != 4)) : 0) ? (i2 = i1 + 16 | 0, (HEAP32[i2 >> 2] | 0) == 0) : 0) {
  HEAP32[i2 >> 2] = HEAP32[i3 + 8 >> 2];
  HEAP32[i4 + 20 >> 2] = i1;
  HEAP8[i4 + 44 >> 0] = 1;
 }
 return;
}

function __ZN10MixedArena5allocIN4wasm6SwitchEEEPT_v(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZN10MixedArena10allocSpaceEj(i1, 36) | 0;
 HEAP32[i2 >> 2] = 5;
 HEAP32[i2 + 8 >> 2] = i1;
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 HEAP32[i1 + 20 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 5;
 return i2 | 0;
}

function __ZNSt3__214__split_bufferIPNS_6vectorIN6cashew3RefENS_9allocatorIS3_EEEERNS4_IS7_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_16FunctionReplacerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 6620;
 HEAP32[i1 + 16 >> 2] = 6648;
 return;
}

function _fwrite(i2, i5, i1, i3) {
 i2 = i2 | 0;
 i5 = i5 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i4 = 0, i6 = 0;
 i4 = Math_imul(i1, i5) | 0;
 if ((HEAP32[i3 + 76 >> 2] | 0) > -1) {
  i6 = (___lockfile(i3) | 0) == 0;
  i2 = ___fwritex(i2, i4, i3) | 0;
  if (!i6) ___unlockfile(i3);
 } else i2 = ___fwritex(i2, i4, i3) | 0;
 if ((i2 | 0) != (i4 | 0)) i1 = (i2 >>> 0) / (i5 >>> 0) | 0;
 return i1 | 0;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEN7AsmData5LocalEEENS_22__unordered_map_hasherIS3_S6_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S6_NS_8equal_toIS3_EELb1EEENS_9allocatorIS6_EEE12__deallocateEPNS_11__hash_nodeIS6_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 while (1) {
  if (!i1) break;
  i2 = HEAP32[i1 >> 2] | 0;
  __ZdlPv(i1);
  i1 = i2;
 }
 return;
}

function __ZN4wasm14CoalesceLocals9interfereEjj(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0;
 if ((i1 | 0) != (i2 | 0)) {
  i4 = Math_imul(HEAP32[i3 + 112 >> 2] | 0, i2 >>> 0 < i1 >>> 0 ? i2 : i1) | 0;
  i2 = i4 + (i1 >>> 0 < i2 >>> 0 ? i2 : i1) | 0;
  i3 = (HEAP32[i3 + 116 >> 2] | 0) + (i2 >>> 5 << 2) | 0;
  HEAP32[i3 >> 2] = 1 << (i2 & 31) | HEAP32[i3 >> 2];
 }
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 5756;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_20OptimizeInstructionsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14FunctionHasherENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14EffectAnalyzerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 6660;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14SimplifyLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 i3 = HEAP32[i2 >> 2] | 0;
 HEAP32[i1 >> 2] = i3;
 HEAP32[i1 + (HEAP32[i3 + -12 >> 2] | 0) >> 2] = HEAP32[i2 + 32 >> 2];
 HEAP32[i1 + 8 >> 2] = HEAP32[i2 + 36 >> 2];
 __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 12 | 0);
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i2 = __Znwj(12) | 0;
 HEAP32[i2 >> 2] = 5028;
 i4 = i1 + 4 | 0;
 i3 = HEAP32[i4 + 4 >> 2] | 0;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 + 4 >> 2] = i3;
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i2 = __Znwj(12) | 0;
 HEAP32[i2 >> 2] = 4984;
 i4 = i1 + 4 | 0;
 i3 = HEAP32[i4 + 4 >> 2] | 0;
 i1 = i2 + 4 | 0;
 HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i1 + 4 >> 2] = i3;
 return i2 | 0;
}

function __ZN4wasm13WasmValidatorD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4272;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEED2Ev(i1 + 32 | 0);
 HEAP32[i1 >> 2] = 4284;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_13WasmValidatorENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 8 | 0);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 5156;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_19DeadCodeEliminationENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__28numpunctIwEC2Ej(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 + 4 >> 2] = i1 + -1;
 HEAP32[i2 >> 2] = 15028;
 HEAP32[i2 + 8 >> 2] = 46;
 HEAP32[i2 + 12 >> 2] = 44;
 i1 = i2 + 16 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function _newlocale(i2, i3, i1) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i4 = 0;
 if (((HEAP8[i3 >> 0] | 0) != 0 ? (_strcmp(i3, 53279) | 0) != 0 : 0) ? (_strcmp(i3, 52379) | 0) != 0 : 0) i1 = 0; else i4 = 4;
 do if ((i4 | 0) == 4) if (!i1) if (!(HEAP32[15030] | 0)) {
  HEAP32[15030] = 1;
  i1 = 60124;
  break;
 } else {
  i1 = _calloc(1, 4) | 0;
  break;
 } while (0);
 return i1 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS_6vectorIjNS_9allocatorIjEEEEEENS_19__map_value_compareIS3_S8_NS_4lessIS3_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_11BreakSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7__cloneEPNS0_6__baseISB_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 HEAP32[i1 >> 2] = 5028;
 i4 = i2 + 4 | 0;
 i3 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i2 + 4 >> 2] = i3;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7__cloneEPNS0_6__baseISB_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 HEAP32[i1 >> 2] = 4984;
 i4 = i2 + 4 | 0;
 i3 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
 HEAP32[i2 + 4 >> 2] = i3;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 5716;
 HEAP32[i1 + 16 >> 2] = 5744;
 return;
}

function __ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm14FunctionHasher6createEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(36) | 0;
 i3 = i2 + 4 | 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = 0;
 HEAP32[i3 + 12 >> 2] = 0;
 HEAP32[i3 + 16 >> 2] = 0;
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i2 >> 2] = 7396;
 HEAP32[i2 + 32 >> 2] = 0;
 HEAP32[i2 + 28 >> 2] = HEAP32[i1 + 28 >> 2];
 return i2 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 5116;
 HEAP32[i1 + 16 >> 2] = 5144;
 return;
}

function __ZNSt3__28numpunctIcEC2Ej(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 + 4 >> 2] = i1 + -1;
 HEAP32[i2 >> 2] = 14988;
 HEAP8[i2 + 8 >> 0] = 46;
 HEAP8[i2 + 9 >> 0] = 44;
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIjNS_6vectorIPN4wasm4CallENS_9allocatorIS5_EEEEEENS_19__map_value_compareIjS9_NS_4lessIjEELb1EEENS6_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 6300;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_17RemoveUnusedNamesENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function _copysign(d1, d2) {
 d1 = +d1;
 d2 = +d2;
 var i3 = 0;
 HEAPF64[tempDoublePtr >> 3] = d2;
 i3 = HEAP32[tempDoublePtr + 4 >> 2] | 0;
 d2 = +Math_abs(+d1);
 HEAPF64[tempDoublePtr >> 3] = d2;
 i3 = i3 & -2147483648 | HEAP32[tempDoublePtr + 4 >> 2];
 HEAP32[tempDoublePtr >> 2] = HEAP32[tempDoublePtr >> 2];
 HEAP32[tempDoublePtr + 4 >> 2] = i3;
 return +(+HEAPF64[tempDoublePtr >> 3]);
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringENS2_3RefEEENS_22__unordered_map_hasherIS3_S5_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S5_NS_8equal_toIS3_EELb1EEENS_9allocatorIS5_EEE12__deallocateEPNS_11__hash_nodeIS5_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 while (1) {
  if (!i1) break;
  i2 = HEAP32[i1 >> 2] | 0;
  __ZdlPv(i1);
  i1 = i2;
 }
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 6260;
 HEAP32[i1 + 16 >> 2] = 6288;
 return;
}

function __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE12__deallocateEPNS_11__hash_nodeIS2_PvEE(i2, HEAP32[i2 + 8 >> 2] | 0);
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm7Literal7getBitsEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 switch (HEAP32[i3 >> 2] | 0) {
 case 3:
 case 1:
  {
   i2 = HEAP32[i3 + 8 >> 2] | 0;
   i1 = ((i2 | 0) < 0) << 31 >> 31;
   break;
  }
 case 4:
 case 2:
  {
   i2 = i3 + 8 | 0;
   i1 = HEAP32[i2 + 4 >> 2] | 0;
   i2 = HEAP32[i2 >> 2] | 0;
   break;
  }
 default:
  _abort();
 }
 tempRet0 = i1;
 return i2 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 6808;
 HEAP32[i1 + 16 >> 2] = 6836;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 5896;
 HEAP32[i1 + 16 >> 2] = 5924;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 6716;
 HEAP32[i1 + 16 >> 2] = 6744;
 return;
}

function __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEaSEDn(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 i1 = i3 + 16 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) != (i3 | 0)) {
  if (i2 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i2 >> 2] | 0) + 20 >> 2] & 511](i2);
 } else FUNCTION_TABLE_vi[HEAP32[(HEAP32[i2 >> 2] | 0) + 16 >> 2] & 511](i2);
 HEAP32[i1 >> 2] = 0;
 return i3 | 0;
}

function __ZNSt3__219__libcpp_snprintf_lEPcjP15__locale_structPKcz(i5, i4, i1, i3, i2) {
 i5 = i5 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i6 = 0, i7 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i7 = i6;
 HEAP32[i7 >> 2] = i2;
 i2 = _uselocale(i1) | 0;
 i1 = _vsnprintf(i5, i4, i3, i7) | 0;
 if (i2 | 0) _uselocale(i2) | 0;
 STACKTOP = i6;
 return i1 | 0;
}

function __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNKSt3__220__time_get_c_storageIwE3__xEv(i1) {
 i1 = i1 | 0;
 if ((HEAP8[58704] | 0) == 0 ? ___cxa_guard_acquire(58704) | 0 : 0) {
  HEAP32[15836] = 0;
  HEAP32[15837] = 0;
  HEAP32[15838] = 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj(63344, 14244, _wcslen(14244) | 0);
  ___cxa_atexit(299, 63344, ___dso_handle | 0) | 0;
 }
 return 63344;
}

function __ZNKSt3__220__time_get_c_storageIwE3__rEv(i1) {
 i1 = i1 | 0;
 if ((HEAP8[58696] | 0) == 0 ? ___cxa_guard_acquire(58696) | 0 : 0) {
  HEAP32[15833] = 0;
  HEAP32[15834] = 0;
  HEAP32[15835] = 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj(63332, 14196, _wcslen(14196) | 0);
  ___cxa_atexit(299, 63332, ___dso_handle | 0) | 0;
 }
 return 63332;
}

function __ZNKSt3__220__time_get_c_storageIwE3__cEv(i1) {
 i1 = i1 | 0;
 if ((HEAP8[58688] | 0) == 0 ? ___cxa_guard_acquire(58688) | 0 : 0) {
  HEAP32[15830] = 0;
  HEAP32[15831] = 0;
  HEAP32[15832] = 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj(63320, 14112, _wcslen(14112) | 0);
  ___cxa_atexit(299, 63320, ___dso_handle | 0) | 0;
 }
 return 63320;
}

function __ZNKSt3__220__time_get_c_storageIwE3__XEv(i1) {
 i1 = i1 | 0;
 if ((HEAP8[58712] | 0) == 0 ? ___cxa_guard_acquire(58712) | 0 : 0) {
  HEAP32[15839] = 0;
  HEAP32[15840] = 0;
  HEAP32[15841] = 0;
  __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj(63356, 14280, _wcslen(14280) | 0);
  ___cxa_atexit(299, 63356, ___dso_handle | 0) | 0;
 }
 return 63356;
}

function __ZN4wasm15RemoveUnusedBrsC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 6176;
 HEAP32[i1 + 16 >> 2] = 6204;
 i1 = i1 + 48 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 HEAP32[i1 + 20 >> 2] = 0;
 return;
}

function __ZN4wasm14EffectAnalyzer13visitSetLocalEPNS_8SetLocalE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i1 + 8 | 0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE25__emplace_unique_key_argsIjJRKjEEENS_4pairINS_15__tree_iteratorIjPNS_11__tree_nodeIjPvEEiEEbEERKT_DpOT0_(i3, i2 + 44 | 0, i1, i1);
 STACKTOP = i3;
 return;
}

function __ZN4wasm14EffectAnalyzer13visitGetLocalEPNS_8GetLocalE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i1 + 8 | 0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE25__emplace_unique_key_argsIjJRKjEEENS_4pairINS_15__tree_iteratorIjPNS_11__tree_nodeIjPvEEiEEbEERKT_DpOT0_(i3, i2 + 32 | 0, i1, i1);
 STACKTOP = i3;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 6848;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_15SetLocalRemoverENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 5936;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_15RemoveUnusedBrsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 6756;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_15GetLocalCounterENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 6440;
 HEAP32[i1 + 16 >> 2] = 6468;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 6984;
 HEAP32[i1 + 16 >> 2] = 7012;
 return;
}

function __ZN4wasm13WasmValidator11visitBinaryEPNS_6BinaryE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = HEAP32[(HEAP32[i3 + 12 >> 2] | 0) + 4 >> 2] | 0;
 if ((i1 | 0) != 5 ? (i2 = HEAP32[(HEAP32[i3 + 16 >> 2] | 0) + 4 >> 2] | 0, (i2 | 0) != 5) : 0) __ZN4wasm13WasmValidator13shouldBeEqualIPNS_6BinaryENS_8WasmTypeEEEbT0_S5_T_PKc(i4, i1, i2, i3, 20399) | 0;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 6480;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_14PostEmscriptenENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZN4wasm13printWasmTypeENS_8WasmTypeE(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 switch (i2 | 0) {
 case 0:
  {
   i1 = 22034;
   break;
  }
 case 1:
  {
   i1 = 22039;
   break;
  }
 case 2:
  {
   i1 = 22043;
   break;
  }
 case 3:
  {
   i1 = 22047;
   break;
  }
 case 4:
  {
   i1 = 22051;
   break;
  }
 case 5:
  {
   i1 = 36141;
   break;
  }
 default:
  {}
 }
 return i1 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 5296;
 HEAP32[i1 + 16 >> 2] = 5324;
 return;
}

function __ZNSt3__217__call_once_proxyINS_5tupleIJONS_12_GLOBAL__N_111__fake_bindEEEEEEvPv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = HEAP32[HEAP32[i1 >> 2] >> 2] | 0;
 i1 = HEAP32[i2 + 4 >> 2] | 0;
 i3 = HEAP32[i2 + 8 >> 2] | 0;
 i2 = (HEAP32[i2 >> 2] | 0) + (i3 >> 1) | 0;
 if (i3 & 1) i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + i1 >> 2] | 0;
 FUNCTION_TABLE_vi[i1 & 511](i2);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm12FunctionTypeERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm13ReorderLocalsC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 7104;
 HEAP32[i1 + 16 >> 2] = 7132;
 HEAP32[i1 + 48 >> 2] = 0;
 HEAP32[i1 + 52 >> 2] = 0;
 HEAP32[i1 + 44 >> 2] = i1 + 48;
 HEAP32[i1 + 60 >> 2] = 0;
 HEAP32[i1 + 64 >> 2] = 0;
 HEAP32[i1 + 56 >> 2] = i1 + 60;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 7024;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_13ReorderLocalsENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__214__split_bufferIPPN4wasm10ExpressionERNS_9allocatorIS4_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__212__hash_tableINS_17__hash_value_typeIN6cashew7IStringEiEENS_22__unordered_map_hasherIS3_S4_NS_4hashIS3_EELb1EEENS_21__unordered_map_equalIS3_S4_NS_8equal_toIS3_EELb1EEENS_9allocatorIS4_EEE12__deallocateEPNS_11__hash_nodeIS4_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 while (1) {
  if (!i1) break;
  i2 = HEAP32[i1 >> 2] | 0;
  __ZdlPv(i1);
  i1 = i2;
 }
 return;
}

function __ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib(i5, i3, i2, i1, i4, i6) {
 i5 = i5 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i6 = i6 | 0;
 if ((i5 | 0) == (HEAP32[i3 + 8 >> 2] | 0)) __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0, i3, i2, i1, i4);
 return;
}

function _interpreter_stack_trace() {
 var i1 = 0, i2 = 0, i3 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i2;
 __ZN4wasm14ModuleInstance18printFunctionStackEv(i3, HEAP32[14813] | 0);
 i1 = ___strdup((HEAP8[i3 + 11 >> 0] | 0) < 0 ? HEAP32[i3 >> 2] | 0 : i3) | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i3);
 STACKTOP = i2;
 return i1 | 0;
}

function __ZNSt3__214__split_bufferIPN4wasm10ExpressionERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm10CallImportERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function _memmove(i1, i4, i2) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 if ((i4 | 0) < (i1 | 0) & (i1 | 0) < (i4 + i2 | 0)) {
  i3 = i1;
  i4 = i4 + i2 | 0;
  i1 = i1 + i2 | 0;
  while ((i2 | 0) > 0) {
   i1 = i1 - 1 | 0;
   i4 = i4 - 1 | 0;
   i2 = i2 - 1 | 0;
   HEAP8[i1 >> 0] = HEAP8[i4 >> 0] | 0;
  }
  i1 = i3;
 } else _memcpy(i1, i4, i2) | 0;
 return i1 | 0;
}

function __ZZN4wasm12RegisterPassINS_28DuplicateFunctionEliminationEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(28) | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 HEAP32[i1 + 20 >> 2] = 0;
 HEAP32[i1 + 24 >> 2] = 0;
 __ZN4wasm28DuplicateFunctionEliminationC2Ev(i1);
 return i1 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 5336;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_11MergeBlocksENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm8FunctionERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN6cashew7IStringERNS_9allocatorIS2_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__211__stdoutbufIwE5imbueERKNS_6localeE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 255](i2) | 0;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 63480) | 0;
 HEAP32[i2 + 36 >> 2] = i1;
 i1 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 255](i1) | 0) & 1;
 HEAP8[i2 + 44 >> 0] = i1;
 return;
}

function __ZNSt3__211__stdoutbufIcE5imbueERKNS_6localeE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_ii[HEAP32[(HEAP32[i2 >> 2] | 0) + 24 >> 2] & 255](i2) | 0;
 i1 = __ZNKSt3__26locale9use_facetERNS0_2idE(i1, 63472) | 0;
 HEAP32[i2 + 36 >> 2] = i1;
 i1 = (FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 28 >> 2] & 255](i1) | 0) & 1;
 HEAP8[i2 + 44 >> 0] = i1;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 20 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = 7188;
 HEAP32[i1 + 16 >> 2] = 7216;
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameENS2_8WasmTypeEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__214__split_bufferIPN6cashew5ValueERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm7ElementERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm8WasmTypeERNS_9allocatorIS2_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm8NameTypeERNS_9allocatorIS2_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -8 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN4wasm7LiteralERNS_9allocatorIS2_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -16 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm17SExpressionParserC2EPc(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 HEAP32[i3 >> 2] = i1;
 __ZN10MixedArenaC2Ev(i3 + 12 | 0);
 i2 = i3 + 40 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = i1;
 i1 = 0;
 while (1) {
  if (i1 | 0) break;
  i1 = __ZN4wasm17SExpressionParser5parseEv(i3) | 0;
  HEAP32[i2 >> 2] = i1;
 }
 return;
}

function __ZNSt3__214__split_bufferIN4wasm6ActionERNS_9allocatorIS2_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -16 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEPNS2_6ExportEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm5BlockERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIcRNS_9allocatorIcEEEC2EjjS3_(i4, i2, i3, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 12 >> 2] = 0;
 HEAP32[i4 + 16 >> 2] = i1;
 if (!i2) i1 = 0; else i1 = __Znwj(i2) | 0;
 HEAP32[i4 >> 2] = i1;
 i3 = i1 + i3 | 0;
 HEAP32[i4 + 8 >> 2] = i3;
 HEAP32[i4 + 4 >> 2] = i3;
 HEAP32[i4 + 12 >> 2] = i1 + i2;
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm4PassERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIPN4wasm4CallERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIN6cashew3RefERNS_9allocatorIS2_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__213__vector_baseINS_4pairIPN4wasm7ElementEPNS2_5BlockEEENS_9allocatorIS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm7Literal10getIntegerEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 switch (HEAP32[i3 >> 2] | 0) {
 case 1:
  {
   i2 = HEAP32[i3 + 8 >> 2] | 0;
   i1 = ((i2 | 0) < 0) << 31 >> 31;
   break;
  }
 case 2:
  {
   i2 = i3 + 8 | 0;
   i1 = HEAP32[i2 + 4 >> 2] | 0;
   i2 = HEAP32[i2 >> 2] | 0;
   break;
  }
 default:
  _abort();
 }
 tempRet0 = i1;
 return i2 | 0;
}

function __ZN4wasm14CoalesceLocals16interfereLowHighEjj(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (i2 >>> 0 < i1 >>> 0) {
  i2 = (Math_imul(HEAP32[i3 + 112 >> 2] | 0, i2) | 0) + i1 | 0;
  i3 = (HEAP32[i3 + 116 >> 2] | 0) + (i2 >>> 5 << 2) | 0;
  HEAP32[i3 >> 2] = 1 << (i2 & 31) | HEAP32[i3 >> 2];
  return;
 } else ___assert_fail(46755, 46670, 211, 46766);
}

function __ZN10MixedArena5allocIN4wasm7ElementEEEPT_v(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZN10MixedArena10allocSpaceEj(i1, 36) | 0;
 HEAP8[i2 >> 0] = 1;
 HEAP32[i2 + 4 >> 2] = i1;
 i1 = i2 + 8 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i2 + 28 >> 2] = -1;
 HEAP32[i2 + 32 >> 2] = -1;
 return i2 | 0;
}

function __ZNSt3__214__split_bufferIN4wasm4NameERNS_9allocatorIS2_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm7Builder8blockifyEPNS_10ExpressionES2_(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 if (!((i1 | 0) != 0 ? (HEAP32[i1 >> 2] | 0) == 1 : 0)) i1 = __ZN4wasm7Builder9makeBlockEPNS_10ExpressionE(i2, i1) | 0;
 if (i3 | 0) {
  __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i1 + 12 | 0, i3);
  __ZN4wasm5Block8finalizeEv(i1);
 }
 return i1 | 0;
}

function __ZNSt3__214__split_bufferIPN4wasm2IfERNS_9allocatorIS3_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__213__vector_baseIPNS_6vectorIN6cashew3RefENS_9allocatorIS3_EEEENS4_IS7_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNKSt3__220__time_get_c_storageIcE3__rEv(i1) {
 i1 = i1 | 0;
 if ((HEAP8[58616] | 0) == 0 ? ___cxa_guard_acquire(58616) | 0 : 0) {
  HEAP32[15630] = 0;
  HEAP32[15631] = 0;
  HEAP32[15632] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(62520, 54005, 11);
  ___cxa_atexit(295, 62520, ___dso_handle | 0) | 0;
 }
 return 62520;
}

function __ZNKSt3__220__time_get_c_storageIcE3__cEv(i1) {
 i1 = i1 | 0;
 if ((HEAP8[58608] | 0) == 0 ? ___cxa_guard_acquire(58608) | 0 : 0) {
  HEAP32[15627] = 0;
  HEAP32[15628] = 0;
  HEAP32[15629] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(62508, 53984, 20);
  ___cxa_atexit(295, 62508, ___dso_handle | 0) | 0;
 }
 return 62508;
}

function __ZN4wasm19DeadCodeElimination17visitCallIndirectEPNS_12CallIndirectE(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = HEAP32[i3 + 28 >> 2] | 0;
 i2 = i1;
 if ((i1 | 0) != 0 ? (HEAP32[i1 >> 2] | 0) == 20 : 0) HEAP32[i4 + 20 >> 2] = i2; else __ZN4wasm19DeadCodeElimination10handleCallINS_12CallIndirectEEEvPT_PNS_10ExpressionE(i4, i3, i1);
 return;
}

function __ZNKSt3__220__time_get_c_storageIcE3__xEv(i1) {
 i1 = i1 | 0;
 if ((HEAP8[58624] | 0) == 0 ? ___cxa_guard_acquire(58624) | 0 : 0) {
  HEAP32[15633] = 0;
  HEAP32[15634] = 0;
  HEAP32[15635] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(62532, 54017, 8);
  ___cxa_atexit(295, 62532, ___dso_handle | 0) | 0;
 }
 return 62532;
}

function __ZNKSt3__220__time_get_c_storageIcE3__XEv(i1) {
 i1 = i1 | 0;
 if ((HEAP8[58632] | 0) == 0 ? ___cxa_guard_acquire(58632) | 0 : 0) {
  HEAP32[15636] = 0;
  HEAP32[15637] = 0;
  HEAP32[15638] = 0;
  __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(62544, 54026, 8);
  ___cxa_atexit(295, 62544, ___dso_handle | 0) | 0;
 }
 return 62544;
}

function __ZN4wasmlsERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEENS_4NameE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 if (!i1) ___assert_fail(19517, 19526, 82, 57330); else return __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(__ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i2, 36) | 0, i1) | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = (__ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0) + 12 | 0;
 i3 = HEAP32[i3 >> 2] | 0;
 i1 = i3;
 if (i3 | 0 ? (HEAP32[i3 >> 2] | 0) == 20 : 0) HEAP32[i2 + 20 >> 2] = i1;
 return;
}

function __ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEEC2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 __ZNSt3__26vectorINS0_IN6cashew6ParserINS1_3RefENS1_19DotZeroValueBuilderEE17ExpressionElementENS_9allocatorIS6_EEEENS7_IS9_EEE6resizeEj(i1, 1);
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE15doVisitSetLocalEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEEN9ReIndexer13visitSetLocalEPNS_8SetLocalE(i2, __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE15doVisitGetLocalEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZZN4wasm13ReorderLocals13visitFunctionEPNS_8FunctionEEN9ReIndexer13visitGetLocalEPNS_8GetLocalE(i2, __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function _llvm_cttz_i32(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP8[cttz_i8 + (i2 & 255) >> 0] | 0;
 if ((i1 | 0) < 8) return i1 | 0;
 i1 = HEAP8[cttz_i8 + (i2 >> 8 & 255) >> 0] | 0;
 if ((i1 | 0) < 8) return i1 + 8 | 0;
 i1 = HEAP8[cttz_i8 + (i2 >> 16 & 255) >> 0] | 0;
 if ((i1 | 0) < 8) return i1 + 16 | 0;
 return (HEAP8[cttz_i8 + (i2 >>> 24) >> 0] | 0) + 24 | 0;
}

function __ZN4wasm16FunctionReplacer6createEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = __Znwj(32) | 0;
 i3 = i2 + 4 | 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = 0;
 HEAP32[i3 + 12 >> 2] = 0;
 HEAP32[i3 + 16 >> 2] = 0;
 HEAP32[i3 + 20 >> 2] = 0;
 HEAP32[i2 >> 2] = 7464;
 HEAP32[i2 + 28 >> 2] = HEAP32[i1 + 28 >> 2];
 return i2 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 + 16 >> 2] = 7228;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_6VacuumENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 24 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNKSt3__27collateIwE12do_transformEPKwS3_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPKwEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_(i3, i2, i1);
 return;
}

function __ZNKSt3__27collateIcE12do_transformEPKcS3_(i3, i4, i2, i1) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i3 >> 2] = 0;
 HEAP32[i3 + 4 >> 2] = 0;
 HEAP32[i3 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPKcEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_(i3, i2, i1);
 return;
}

function __ZNSt3__26vectorIPN4wasm10ExpressionENS_9allocatorIS3_EEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if (i1 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2); else {
  i3 = __Znwj(i1 << 2) | 0;
  HEAP32[i2 + 4 >> 2] = i3;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 8 >> 2] = i3 + (i1 << 2);
  return;
 }
}

function __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz(i4, i1, i3, i2) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i5;
 HEAP32[i6 >> 2] = i2;
 i2 = _uselocale(i1) | 0;
 i1 = _vasprintf(i4, i3, i6) | 0;
 if (i2 | 0) _uselocale(i2) | 0;
 STACKTOP = i5;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = (__ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0) + 12 | 0;
 i3 = HEAP32[i3 >> 2] | 0;
 i1 = i3;
 if (i3 | 0 ? (HEAP32[i3 >> 2] | 0) == 20 : 0) HEAP32[i2 + 20 >> 2] = i1;
 return;
}

function ___cxa_can_catch(i1, i2, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 var i3 = 0, i5 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i5;
 HEAP32[i3 >> 2] = HEAP32[i4 >> 2];
 i1 = FUNCTION_TABLE_iiii[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 31](i1, i2, i3) | 0;
 if (i1) HEAP32[i4 >> 2] = HEAP32[i3 >> 2];
 STACKTOP = i5;
 return i1 & 1 | 0;
}

function __ZNSt3__214__split_bufferIPcRNS_9allocatorIS1_EEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function _calloc(i3, i1) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 if (i3) {
  i2 = Math_imul(i1, i3) | 0;
  if ((i1 | i3) >>> 0 > 65535) i2 = ((i2 >>> 0) / (i3 >>> 0) | 0 | 0) == (i1 | 0) ? i2 : -1;
 } else i2 = 0;
 i1 = _malloc(i2) | 0;
 if (!i1) return i1 | 0;
 if (!(HEAP32[i1 + -4 >> 2] & 3)) return i1 | 0;
 _memset(i1 | 0, 0, i2 | 0) | 0;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = (__ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0) + 20 | 0;
 i3 = HEAP32[i3 >> 2] | 0;
 i1 = i3;
 if (i3 | 0 ? (HEAP32[i3 >> 2] | 0) == 20 : 0) HEAP32[i2 + 20 >> 2] = i1;
 return;
}

function __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_h(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3;
 HEAP8[i4 >> 0] = i1;
 i2 = __ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j(i2, i4, 1) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3;
 HEAP8[i4 >> 0] = i1;
 i2 = __ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j(i2, i4, 1) | 0;
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__26vectorIN4wasm8WasmTypeENS_9allocatorIS2_EEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if (i1 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2); else {
  i3 = __Znwj(i1 << 2) | 0;
  HEAP32[i2 + 4 >> 2] = i3;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 8 >> 2] = i3 + (i1 << 2);
  return;
 }
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z(i4, i1, i3, i2) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i5;
 HEAP32[i6 >> 2] = i2;
 i2 = _uselocale(i1) | 0;
 i1 = _vsscanf(i4, i3, i6) | 0;
 if (i2 | 0) _uselocale(i2) | 0;
 STACKTOP = i5;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i1 = (__ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0) + 8 | 0;
 if ((HEAP32[i1 >> 2] | 0) == (HEAP32[i2 + 28 >> 2] | 0)) {
  i2 = i2 + 32 | 0;
  HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 1;
 }
 return;
}

function __ZNSt3__26vectorIbNS_9allocatorIbEEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if ((i1 | 0) < 0) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2); else {
  i1 = ((i1 + -1 | 0) >>> 5) + 1 | 0;
  i3 = __Znwj(i1 << 2) | 0;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 4 >> 2] = 0;
  HEAP32[i2 + 8 >> 2] = i1;
  return;
 }
}

function __ZNSt3__26vectorIN4wasm8NameTypeENS_9allocatorIS2_EEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if (i1 >>> 0 > 536870911) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2); else {
  i3 = __Znwj(i1 << 3) | 0;
  HEAP32[i2 + 4 >> 2] = i3;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 8 >> 2] = i3 + (i1 << 3);
  return;
 }
}

function __ZNSt3__214__split_bufferIjRNS_9allocatorIjEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZNSt3__214__split_bufferIiRNS_9allocatorIiEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -4 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 i1 = HEAP32[i4 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __ZN4wasm28DuplicateFunctionEliminationD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7368;
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm8FunctionEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEED2Ev(i1 + 16 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNK4wasm7Literal5floorEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var d3 = 0.0;
 if ((HEAP32[i1 >> 2] | 0) == 3) {
  d3 = +Math_floor(+(+__ZNK4wasm7Literal6getf32Ev(i1)));
  HEAPF32[i2 + 8 >> 2] = d3;
  i1 = 3;
 } else {
  d3 = +Math_floor(+(+__ZNK4wasm7Literal6getf64Ev(i1)));
  HEAPF64[i2 + 8 >> 3] = d3;
  i1 = 4;
 }
 HEAP32[i2 >> 2] = i1;
 return;
}

function __GLOBAL__sub_I_simple_ast_cpp() {
 HEAP32[14918] = 0;
 HEAP32[14919] = 0;
 HEAP32[14920] = 0;
 HEAP32[14921] = 0;
 HEAP32[14922] = 0;
 HEAP32[14923] = 0;
 HEAP32[14924] = 0;
 HEAP32[14925] = 0;
 ___cxa_atexit(284, 59672, ___dso_handle | 0) | 0;
 __ZN6cashew10IStringSetC2EPKc(59704, 48173);
 ___cxa_atexit(281, 59704, ___dso_handle | 0) | 0;
 return;
}

function __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if (i1 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2); else {
  i3 = __Znwj(i1 << 2) | 0;
  HEAP32[i2 + 4 >> 2] = i3;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 8 >> 2] = i3 + (i1 << 2);
  return;
 }
}

function __ZNK4wasm7Literal9nearbyintEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var d3 = 0.0;
 if ((HEAP32[i1 >> 2] | 0) == 3) {
  d3 = +_nearbyintf(+__ZNK4wasm7Literal6getf32Ev(i1));
  HEAPF32[i2 + 8 >> 2] = d3;
  i1 = 3;
 } else {
  d3 = +_nearbyint(+__ZNK4wasm7Literal6getf64Ev(i1));
  HEAPF64[i2 + 8 >> 3] = d3;
  i1 = 4;
 }
 HEAP32[i2 >> 2] = i1;
 return;
}

function __ZNSt3__26vectorIN4wasm4NameENS_9allocatorIS2_EEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if (i1 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2); else {
  i3 = __Znwj(i1 << 2) | 0;
  HEAP32[i2 + 4 >> 2] = i3;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 8 >> 2] = i3 + (i1 << 2);
  return;
 }
}

function __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIPN4wasm6ExportEjEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__213__vector_baseIPN4wasm12FunctionTypeENS_9allocatorIS3_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNKSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEEclES5_(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i1 = HEAP32[i1 + 16 >> 2] | 0;
 if (!i1) {
  i2 = ___cxa_allocate_exception(4) | 0;
  HEAP32[i2 >> 2] = 4480;
  ___cxa_throw(i2 | 0, 160, 11);
 } else return FUNCTION_TABLE_iii[HEAP32[(HEAP32[i1 >> 2] | 0) + 24 >> 2] & 63](i1, i2) | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i1 = __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 i2 = (HEAP32[HEAP32[i2 + 44 >> 2] >> 2] | 0) + (HEAP32[i1 + 8 >> 2] << 2) | 0;
 HEAP32[i2 >> 2] = (HEAP32[i2 >> 2] | 0) + 1;
 return;
}

function __ZNSt3__213__vector_baseIPPN4wasm10ExpressionENS_9allocatorIS4_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNK4wasm7Literal4sqrtEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var d3 = 0.0;
 if ((HEAP32[i1 >> 2] | 0) == 3) {
  d3 = +Math_sqrt(+(+__ZNK4wasm7Literal6getf32Ev(i1)));
  HEAPF32[i2 + 8 >> 2] = d3;
  i1 = 3;
 } else {
  d3 = +Math_sqrt(+(+__ZNK4wasm7Literal6getf64Ev(i1)));
  HEAPF64[i2 + 8 >> 3] = d3;
  i1 = 4;
 }
 HEAP32[i2 >> 2] = i1;
 return;
}

function __ZNK4wasm7Literal4ceilEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var d3 = 0.0;
 if ((HEAP32[i1 >> 2] | 0) == 3) {
  d3 = +Math_ceil(+(+__ZNK4wasm7Literal6getf32Ev(i1)));
  HEAPF32[i2 + 8 >> 2] = d3;
  i1 = 3;
 } else {
  d3 = +Math_ceil(+(+__ZNK4wasm7Literal6getf64Ev(i1)));
  HEAPF64[i2 + 8 >> 3] = d3;
  i1 = 4;
 }
 HEAP32[i2 >> 2] = i1;
 return;
}

function __ZZN4wasm28DuplicateFunctionElimination3runEPNS_10PassRunnerEPNS_6ModuleEENKUlRKNSt3__210unique_ptrINS_8FunctionENS5_14default_deleteIS7_EEEEE_clESC_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return (__ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(HEAP32[i2 >> 2] | 0, HEAP32[i1 >> 2] | 0) | 0) != 0 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameES3_EENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __Z9printTextRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i1, 34) | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i1, i2) | 0;
 return __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i1, 34) | 0;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE9doVisitIfEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11Selectifier7visitIfEPNS_2IfE(i2, __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6Thread4workENSt3__28functionIFNS_15ThreadWorkStateEvEEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 4 | 0;
 __ZNSt3__25mutex4lockEv(i3);
 __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEEaSERKS4_(i2 + 88 | 0, i1) | 0;
 __ZNSt3__218condition_variable10notify_oneEv(i2 + 32 | 0);
 __ZNSt3__25mutex6unlockEv(i3);
 return;
}

function __ZN4wasm14EffectAnalyzer11hasAnythingEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = HEAP16[i1 + 28 >> 1] | 0;
 if ((i2 & 255) << 24 >> 24 == 0 & (i2 & 65535) < 256 ? (HEAP32[i1 + 40 >> 2] | 0) == (0 - (HEAP32[i1 + 52 >> 2] | 0) | 0) : 0) {
  i2 = HEAP16[i1 + 56 >> 1] | 0;
  return (i2 & 65535) > 255 | (i2 & 255) << 24 >> 24 != 0 | 0;
 }
 return 1;
}

function _truncf(d1) {
 d1 = +d1;
 var i2 = 0, i3 = 0, i4 = 0;
 i2 = (HEAPF32[tempDoublePtr >> 2] = d1, HEAP32[tempDoublePtr >> 2] | 0);
 i3 = (i2 >>> 23 & 255) + -118 | 0;
 if ((i3 | 0) <= 31 ? (i4 = (i3 | 0) < 9 ? 2147483647 : -1 >>> i3, (i4 & i2 | 0) != 0) : 0) d1 = (HEAP32[tempDoublePtr >> 2] = i2 & ~i4, +HEAPF32[tempDoublePtr >> 2]);
 return +d1;
}

function __ZNSt3__213__vector_baseIPN4wasm8FunctionENS_9allocatorIS3_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN6cashew7IStringENS_9allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIN4wasm4NameEjEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__213__vector_baseIPN6cashew5ValueENS_9allocatorIS3_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIPN4wasm7ElementENS_9allocatorIS3_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm8NameTypeENS_9allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -8 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN4wasm7LiteralENS_9allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -16 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 i3 = HEAP32[i2 >> 2] | 0;
 HEAP32[i1 >> 2] = i3;
 HEAP32[i1 + (HEAP32[i3 + -12 >> 2] | 0) >> 2] = HEAP32[i2 + 12 >> 2];
 __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 8 | 0);
 return;
}

function __ZNSt3__213__vector_baseIN4wasm6ActionENS_9allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -16 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm8LocalSetaSERKS0_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if ((i2 | 0) != (i1 | 0)) __ZNSt3__26vectorIjNS_9allocatorIjEEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_(i2, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0);
 return i2 | 0;
}

function __ZN10MixedArena5allocIN4wasm10CallImportEEEPT_v(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZN10MixedArena10allocSpaceEj(i1, 28) | 0;
 HEAP32[i2 >> 2] = 7;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = i1;
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 return i2 | 0;
}

function __ZNSt3__213__vector_baseIPN4wasm5BlockENS_9allocatorIS3_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm7Literal9castToI64Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0;
 if ((HEAP32[i2 >> 2] | 0) == 4) {
  i4 = i2 + 8 | 0;
  i3 = HEAP32[i4 + 4 >> 2] | 0;
  i2 = i1 + 8 | 0;
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i2 + 4 >> 2] = i3;
  HEAP32[i1 >> 2] = 2;
  return;
 } else ___assert_fail(28667, 19526, 219, 28795);
}

function __ZN4wasm7Literal9castToF64Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0;
 if ((HEAP32[i2 >> 2] | 0) == 2) {
  i4 = i2 + 8 | 0;
  i3 = HEAP32[i4 + 4 >> 2] | 0;
  i2 = i1 + 8 | 0;
  HEAP32[i2 >> 2] = HEAP32[i4 >> 2];
  HEAP32[i2 + 4 >> 2] = i3;
  HEAP32[i1 >> 2] = 4;
  return;
 } else ___assert_fail(22338, 19526, 207, 22360);
}

function __ZN4wasm13WasmValidator9visitLoadEPNS_4LoadE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator17validateAlignmentEj(i2, HEAP32[i1 + 16 >> 2] | 0);
 __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_4LoadENS_8WasmTypeEEEbT0_S5_T_PKc(i2, HEAP32[(HEAP32[i1 + 20 >> 2] | 0) + 4 >> 2] | 0, 1, i1, 19829) | 0;
 return;
}

function __ZN4wasm12PassRegistry8PassInfoC2ENSt3__212basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEENS2_8functionIFPNS_4PassEvEEE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i3, i2);
 __ZNSt3__28functionIFPN4wasm4PassEvEEC2ERKS5_(i3 + 16 | 0, i1);
 return;
}

function __ZNSt3__213__vector_baseIPN4wasm4PassENS_9allocatorIS3_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIPN4wasm4CallENS_9allocatorIS3_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIN6cashew3RefENS_9allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm14AstStackHelperC2EN6cashew3RefE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i1 = HEAP32[14805] | 0;
 if ((i1 | 0) == (HEAP32[14806] | 0)) __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_(59216, i2); else {
  HEAP32[i1 >> 2] = HEAP32[i2 >> 2];
  HEAP32[14805] = (HEAP32[14805] | 0) + 4;
 }
 return;
}

function __ZN4wasm13WasmValidator13visitSetLocalEPNS_8SetLocalE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[(HEAP32[i2 + 12 >> 2] | 0) + 4 >> 2] | 0;
 if ((i1 | 0) != 5) __ZN4wasm13WasmValidator33shouldBeEqualOrFirstIsUnreachableIPNS_8SetLocalENS_8WasmTypeEEEbT0_S5_T_PKc(i3, i1, HEAP32[i2 + 4 >> 2] | 0, i2, 19798) | 0;
 return;
}

function __ZNSt3__213__vector_baseIN4wasm4NameENS_9allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm17WasmBinaryBuilder16readMemoryAccessERNS_7AddressEjS2_(i4, i1, i2, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 __ZN4wasm7AddressaSEy(i1, __ZN4wasm4Pow2Ej(__ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i4) | 0) | 0, 0) | 0;
 __ZN4wasm7AddressaSEy(i3, __ZN4wasm17WasmBinaryBuilder9getU32LEBEv(i4) | 0, 0) | 0;
 return;
}

function __ZNSt3__213__vector_baseIPN4wasm2IfENS_9allocatorIS3_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__212__hash_tableIPN4wasm9CFGWalkerINS1_14CoalesceLocalsENS1_7VisitorIS3_vEENS1_8LivenessEE10BasicBlockENS_4hashIS9_EENS_8equal_toIS9_EENS_9allocatorIS9_EEE12__deallocateEPNS_11__hash_nodeIS9_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 while (1) {
  if (!i1) break;
  i2 = HEAP32[i1 >> 2] | 0;
  __ZdlPv(i1);
  i1 = i2;
 }
 return;
}

function __ZNK4wasm7Literal5truncEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var d3 = 0.0;
 if ((HEAP32[i1 >> 2] | 0) == 3) {
  d3 = +_truncf(+__ZNK4wasm7Literal6getf32Ev(i1));
  HEAPF32[i2 + 8 >> 2] = d3;
  i1 = 3;
 } else {
  d3 = +_trunc(+__ZNK4wasm7Literal6getf64Ev(i1));
  HEAPF64[i2 + 8 >> 3] = d3;
  i1 = 4;
 }
 HEAP32[i2 >> 2] = i1;
 return;
}

function __ZNSt3__28ios_base4InitD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(60808) | 0;
 __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv(60892) | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv(61144) | 0;
 __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv(61228) | 0;
 return;
}

function __ZNSt3__211__tree_prevIPNS_16__tree_node_baseIPvEEEET_S5_(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 >> 2] | 0;
 if (!i1) while (1) {
  i1 = HEAP32[i2 + 8 >> 2] | 0;
  if ((HEAP32[i1 >> 2] | 0) == (i2 | 0)) i2 = i1; else break;
 } else while (1) {
  i2 = HEAP32[i1 + 4 >> 2] | 0;
  if (!i2) break; else i1 = i2;
 }
 return i1 | 0;
}

function __ZNSt3__211__tree_nextIPNS_16__tree_node_baseIPvEEEET_S5_(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 + 4 >> 2] | 0;
 if (!i1) while (1) {
  i1 = HEAP32[i2 + 8 >> 2] | 0;
  if ((HEAP32[i1 >> 2] | 0) == (i2 | 0)) break; else i2 = i1;
 } else while (1) {
  i2 = HEAP32[i1 >> 2] | 0;
  if (!i2) break; else i1 = i2;
 }
 return i1 | 0;
}

function __ZNSt3__26vectorIjNS_9allocatorIjEEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if (i1 >>> 0 > 1073741823) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2); else {
  i3 = __Znwj(i1 << 2) | 0;
  HEAP32[i2 + 4 >> 2] = i3;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 8 >> 2] = i3 + (i1 << 2);
  return;
 }
}

function __ZN4wasm14CoalesceLocals10interferesEjj(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i4 = 0;
 i4 = Math_imul(HEAP32[i3 + 112 >> 2] | 0, i2 >>> 0 < i1 >>> 0 ? i2 : i1) | 0;
 i2 = i4 + (i1 >>> 0 < i2 >>> 0 ? i2 : i1) | 0;
 return (1 << (i2 & 31) & HEAP32[(HEAP32[i3 + 116 >> 2] | 0) + (i2 >>> 5 << 2) >> 2] | 0) != 0 | 0;
}

function __ZN10MixedArena5allocIN4wasm4CallEEEPT_v(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZN10MixedArena10allocSpaceEj(i1, 28) | 0;
 HEAP32[i2 >> 2] = 6;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = i1;
 i1 = i2 + 12 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 return i2 | 0;
}

function ___uflow(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i1 = i3;
 if ((HEAP32[i2 + 8 >> 2] | 0) == 0 ? (___toread(i2) | 0) != 0 : 0) i1 = -1; else if ((FUNCTION_TABLE_iiii[HEAP32[i2 + 32 >> 2] & 31](i2, i1, 1) | 0) == 1) i1 = HEAPU8[i1 >> 0] | 0; else i1 = -1;
 STACKTOP = i3;
 return i1 | 0;
}

function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekposENS_4fposI11__mbstate_tEEj(i3, i4, i1, i2) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i1 = i1 + 8 | 0;
 FUNCTION_TABLE_viiiiii[HEAP32[(HEAP32[i4 >> 2] | 0) + 16 >> 2] & 15](i3, i4, HEAP32[i1 >> 2] | 0, HEAP32[i1 + 4 >> 2] | 0, 0, i2);
 return;
}

function __ZN4wasm4Pow2Ej(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 switch (i2 | 0) {
 case 0:
  {
   i1 = 1;
   break;
  }
 case 1:
  {
   i1 = 2;
   break;
  }
 case 2:
  {
   i1 = 4;
   break;
  }
 case 3:
  {
   i1 = 8;
   break;
  }
 case 4:
  {
   i1 = 16;
   break;
  }
 case 5:
  {
   i1 = 32;
   break;
  }
 default:
  {}
 }
 return i1 | 0;
}

function ___shlim(i3, i4) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i5 = 0;
 HEAP32[i3 + 104 >> 2] = i4;
 i1 = HEAP32[i3 + 8 >> 2] | 0;
 i2 = HEAP32[i3 + 4 >> 2] | 0;
 i5 = i1 - i2 | 0;
 HEAP32[i3 + 108 >> 2] = i5;
 if ((i4 | 0) != 0 & (i5 | 0) > (i4 | 0)) HEAP32[i3 + 100 >> 2] = i2 + i4; else HEAP32[i3 + 100 >> 2] = i1;
 return;
}

function __ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi(i4, i2, i1, i3) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 if ((i4 | 0) == (HEAP32[i2 + 8 >> 2] | 0)) __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0, i2, i1, i3);
 return;
}

function __ZN4wasm13sigToWasmTypeEc(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 switch (i2 << 24 >> 24 | 0) {
 case 105:
  {
   i1 = 1;
   break;
  }
 case 106:
  {
   i1 = 2;
   break;
  }
 case 102:
  {
   i1 = 3;
   break;
  }
 case 100:
  {
   i1 = 4;
   break;
  }
 case 118:
  {
   i1 = 0;
   break;
  }
 default:
  _abort();
 }
 return i1 | 0;
}

function __ZN4wasm11MergeBlocks11visitSwitchEPNS_6SwitchE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i1 + 32 | 0;
 __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i1 + 28 | 0, __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i3, 0, 0, 0) | 0, i3, 0) | 0;
 return;
}

function __ZN4wasm11MergeBlocks11visitBinaryEPNS_6BinaryE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i1 + 12 | 0;
 __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i1 + 16 | 0, __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i3, 0, 0, 0) | 0, i3, 0) | 0;
 return;
}

function __ZNSt3__214__split_bufferIcRNS_9allocatorIcEEED2Ev(i4) {
 i4 = i4 | 0;
 var i1 = 0, i2 = 0, i3 = 0, i5 = 0;
 i1 = HEAP32[i4 + 4 >> 2] | 0;
 i2 = i4 + 8 | 0;
 i3 = HEAP32[i2 >> 2] | 0;
 while (1) {
  if ((i3 | 0) == (i1 | 0)) break;
  i5 = i3 + -1 | 0;
  HEAP32[i2 >> 2] = i5;
  i3 = i5;
 }
 __ZdlPv(HEAP32[i4 >> 2] | 0);
 return;
}

function __ZNK4wasm7Literal12extendToSI64Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 if ((HEAP32[i2 >> 2] | 0) == 1) {
  i3 = HEAP32[i2 + 8 >> 2] | 0;
  HEAP32[i1 >> 2] = 2;
  i2 = i1 + 8 | 0;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 4 >> 2] = ((i3 | 0) < 0) << 31 >> 31;
  return;
 } else ___assert_fail(22306, 19526, 375, 28521);
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE5clearEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = i1 + 4 | 0;
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i1, HEAP32[i2 >> 2] | 0);
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 >> 2] = i2;
 HEAP32[i2 >> 2] = 0;
 return;
}

function __ZNSt3__213__vector_baseIPcNS_9allocatorIS1_EEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZN4wasm11MergeBlocks10visitStoreEPNS_5StoreE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i1 + 20 | 0;
 __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i1 + 24 | 0, __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i3, 0, 0, 0) | 0, i3, 0) | 0;
 return;
}

function __ZN4wasm11MergeBlocks10visitBreakEPNS_5BreakE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i1 + 12 | 0;
 __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i1 + 16 | 0, __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i3, 0, 0, 0) | 0, i3, 0) | 0;
 return;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj(i5, i6, i1, i2, i3, i4) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i6 = i5;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i6 + 4 >> 2] = 0;
 i6 = i5 + 8 | 0;
 HEAP32[i6 >> 2] = -1;
 HEAP32[i6 + 4 >> 2] = -1;
 return;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj(i5, i6, i1, i2, i3, i4) {
 i5 = i5 | 0;
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i6 = i5;
 HEAP32[i6 >> 2] = 0;
 HEAP32[i6 + 4 >> 2] = 0;
 i6 = i5 + 8 | 0;
 HEAP32[i6 >> 2] = -1;
 HEAP32[i6 + 4 >> 2] = -1;
 return;
}

function __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEjEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 if ((i1 | 0) != (i2 | 0)) {
  if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 511](i1);
 } else FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 511](i1);
 return;
}

function __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIiNS_9allocatorIiEEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -4 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0, i4 = 0;
 i3 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) {
  i1 = i1 + 4 | 0;
  i2 = HEAP32[i1 >> 2] | 0;
  while (1) {
   if ((i2 | 0) == (i3 | 0)) break;
   i4 = i2 + -1 | 0;
   HEAP32[i1 >> 2] = i4;
   i2 = i4;
  }
  __ZdlPv(i3);
 }
 return;
}

function __ZNSt3__28functionIFPN4wasm10ExpressionEN6cashew3RefEEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 if ((i1 | 0) != (i2 | 0)) {
  if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 511](i1);
 } else FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 511](i1);
 return;
}

function __ZN10MixedArena5allocIN4wasm4HostEEEPT_v(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZN10MixedArena10allocSpaceEj(i1, 32) | 0;
 HEAP32[i2 >> 2] = 18;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = i1;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i2 + 24 >> 2] = 0;
 HEAP32[i2 + 28 >> 2] = 0;
 return i2 | 0;
}

function __ZN4wasm7Literal10NaNPayloadEf(d1) {
 d1 = +d1;
 var d2 = 0.0;
 d2 = +Math_abs(+d1);
 if ((HEAPF32[tempDoublePtr >> 2] = d2, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 2139095040) return (HEAPF32[tempDoublePtr >> 2] = d1, HEAP32[tempDoublePtr >> 2] | 0) & 8388607 | 0; else ___assert_fail(29144, 19526, 278, 29429);
 return 0;
}

function __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZN10MixedArena10allocSpaceEj(i1, 28) | 0;
 HEAP32[i2 >> 2] = 1;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = i1;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i2 + 24 >> 2] = 0;
 return i2 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZN4wasm6getSigENS_8WasmTypeE(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 switch (i2 | 0) {
 case 1:
  {
   i1 = 105;
   break;
  }
 case 2:
  {
   i1 = 106;
   break;
  }
 case 3:
  {
   i1 = 102;
   break;
  }
 case 4:
  {
   i1 = 100;
   break;
  }
 case 0:
  {
   i1 = 118;
   break;
  }
 default:
  _abort();
 }
 return i1 | 0;
}

function __ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEED2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEED2Ev(i1 + 16 | 0);
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__25ctypeIcEC2EPKtbj(i4, i3, i2, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i4 + 4 >> 2] = i1 + -1;
 HEAP32[i4 >> 2] = 14936;
 i1 = i4 + 8 | 0;
 HEAP32[i1 >> 2] = i3;
 HEAP8[i4 + 12 >> 0] = i2 & 1;
 if (!i3) {
  i4 = ___ctype_b_loc() | 0;
  HEAP32[i1 >> 2] = HEAP32[i4 >> 2];
 }
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZN4wasm8LocalSetaSEOS0_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i4 = i3 + 1 | 0;
 HEAP8[i4 >> 0] = HEAP8[i3 >> 0] | 0;
 __ZNSt3__26vectorIjNS_9allocatorIjEEE13__move_assignERS3_NS_17integral_constantIbLb1EEE(i2, i1, i4);
 STACKTOP = i3;
 return i2 | 0;
}

function __ZNSt3__218__libcpp_refstringC2EPKc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i4 = _strlen(i1) | 0;
 i3 = __Znwj(i4 + 13 | 0) | 0;
 HEAP32[i3 >> 2] = i4;
 HEAP32[i3 + 4 >> 2] = i4;
 HEAP32[i3 + 8 >> 2] = 0;
 i3 = i3 + 12 | 0;
 _memcpy(i3 | 0, i1 | 0, i4 + 1 | 0) | 0;
 HEAP32[i2 >> 2] = i3;
 return;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 12100;
 __ZNSt3__26localeC2Ev(i1 + 4 | 0);
 i1 = i1 + 8 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 HEAP32[i1 + 20 >> 2] = 0;
 return;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 12036;
 __ZNSt3__26localeC2Ev(i1 + 4 | 0);
 i1 = i1 + 8 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 HEAP32[i1 + 20 >> 2] = 0;
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination10handleCallINS_10CallImportEEEvPT_PNS_10ExpressionE(i2, __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0, 0);
 return;
}

function __ZNSt3__28functionIFN4wasm15ThreadWorkStateEvEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 if ((i1 | 0) != (i2 | 0)) {
  if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 511](i1);
 } else FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 511](i1);
 return;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5uflowEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) i1 = -1; else {
  i2 = i1 + 12 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  HEAP32[i2 >> 2] = i1 + 4;
  i1 = HEAP32[i1 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5uflowEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if ((FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 36 >> 2] & 255](i1) | 0) == -1) i1 = -1; else {
  i2 = i1 + 12 | 0;
  i1 = HEAP32[i2 >> 2] | 0;
  HEAP32[i2 >> 2] = i1 + 1;
  i1 = HEAPU8[i1 >> 0] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNKSt3__28functionIFN4wasm15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 i1 = HEAP32[i1 + 16 >> 2] | 0;
 if (!i1) {
  i1 = ___cxa_allocate_exception(4) | 0;
  HEAP32[i1 >> 2] = 4480;
  ___cxa_throw(i1 | 0, 160, 11);
 } else return FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 24 >> 2] & 255](i1) | 0;
 return 0;
}

function __ZN4wasm17WasmBinaryBuilder12getBreakNameEi(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = HEAP32[i2 + 84 >> 2] | 0;
 i2 = (HEAP32[i2 + 88 >> 2] | 0) - i3 >> 2;
 i1 = i2 + ~i1 | 0;
 if (i1 >>> 0 < i2 >>> 0) return HEAP32[i3 + (i1 << 2) >> 2] | 0; else ___assert_fail(24207, 22948, 1778, 24258);
 return 0;
}

function __ZNSt3__26vectorIcNS_9allocatorIcEEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if ((i1 | 0) < 0) __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i2); else {
  i3 = __Znwj(i1) | 0;
  HEAP32[i2 + 4 >> 2] = i3;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 8 >> 2] = i3 + i1;
  return;
 }
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZN4wasm7Literal11setQuietNaNEf(d1) {
 d1 = +d1;
 var d2 = 0.0;
 d2 = +Math_abs(+d1);
 if ((HEAPF32[tempDoublePtr >> 2] = d2, HEAP32[tempDoublePtr >> 2] | 0) >>> 0 > 2139095040) return +(HEAPF32[tempDoublePtr >> 2] = d1, +HEAPF32[tempDoublePtr >> 2]); else ___assert_fail(29144, 19526, 292, 29178);
 return +(0.0);
}

function __ZN4wasm5unhexEc(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i2 = i3 << 24 >> 24;
 do if ((i3 + -48 & 255) >= 10) {
  if ((i3 + -97 & 255) < 6) {
   i1 = i2 + -87 | 0;
   break;
  }
  if ((i3 + -65 & 255) < 6) {
   i1 = i2 + -55 | 0;
   break;
  } else _abort();
 } else i1 = i2 + -48 | 0; while (0);
 return i1 | 0;
}

function __ZNKSt3__25ctypeIcE9do_narrowEPKcS3_cPc(i3, i1, i5, i4, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i5 = i5 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 while (1) {
  if ((i1 | 0) == (i5 | 0)) break;
  i3 = HEAP8[i1 >> 0] | 0;
  HEAP8[i2 >> 0] = i3 << 24 >> 24 > -1 ? i3 : i4;
  i2 = i2 + 1 | 0;
  i1 = i1 + 1 | 0;
 }
 return i5 | 0;
}

function __ZN4wasm13WasmValidator7visitIfEPNS_2IfE(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = (HEAP32[(HEAP32[i2 + 8 >> 2] | 0) + 4 >> 2] | 0) + -1 | 0;
 if (i1 >>> 0 < 5) i1 = (19 >>> (i1 & 31) & 1) != 0; else i1 = 0;
 __ZN4wasm13WasmValidator12shouldBeTrueIPNS_2IfEEEbbT_PKc(i3, i1, i2, 19573) | 0;
 return;
}

function _sn_write(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i4 = 0, i5 = 0;
 i4 = i1 + 20 | 0;
 i5 = HEAP32[i4 >> 2] | 0;
 i1 = (HEAP32[i1 + 16 >> 2] | 0) - i5 | 0;
 i1 = i1 >>> 0 > i2 >>> 0 ? i2 : i1;
 _memcpy(i5 | 0, i3 | 0, i1 | 0) | 0;
 HEAP32[i4 >> 2] = (HEAP32[i4 >> 2] | 0) + i1;
 return i2 | 0;
}

function __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeINS_12__value_typeIjjEENS_19__map_value_compareIjS2_NS_4lessIjEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i1 = __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 if ((HEAP32[HEAP32[i1 + 16 >> 2] >> 2] | 0) == 19) {
  HEAP32[i1 >> 2] = 19;
  HEAP32[i1 + 4 >> 2] = 0;
 }
 return;
}

function __ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEEC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 __ZN4wasm4PassC2Ev(i1);
 i2 = i1 + 16 | 0;
 __ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEEC2Ev(i2);
 HEAP32[i1 >> 2] = 7644;
 HEAP32[i2 >> 2] = 7672;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE10deallocateEPcj(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 if (i1 >>> 0 <= i3 >>> 0 & (i1 + 4096 | 0) >>> 0 >= i3 >>> 0) {
  i1 = i1 + 4096 | 0;
  if ((i3 + (i2 + 15 & -16) | 0) == (HEAP32[i1 >> 2] | 0)) HEAP32[i1 >> 2] = i3;
 } else _free(i3);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_14FunctionHasherENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNSt3__28ios_baseD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 12020;
 __ZNSt3__28ios_base16__call_callbacksENS0_5eventE(i1, 0);
 __ZNSt3__26localeD2Ev(i1 + 28 | 0);
 _free(HEAP32[i1 + 32 >> 2] | 0);
 _free(HEAP32[i1 + 36 >> 2] | 0);
 _free(HEAP32[i1 + 48 >> 2] | 0);
 _free(HEAP32[i1 + 60 >> 2] | 0);
 return;
}

function __ZN4wasm13WasmValidator14doWalkFunctionEPNS_8FunctionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1 + 36 | 0);
 __ZN4wasm13WasmValidator12shouldBeTrueIPKcEEbbT_S3_(i2, (HEAP32[i2 + 40 >> 2] | 0) == 0, 19325, 19339) | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNKSt3__27collateIwE7do_hashEPKwS3_(i1, i2, i3) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i4 = 0, i5 = 0;
 i1 = 0;
 while (1) {
  if ((i2 | 0) == (i3 | 0)) break;
  i4 = (HEAP32[i2 >> 2] | 0) + (i1 << 4) | 0;
  i5 = i4 & -268435456;
  i1 = (i5 >>> 24 | i5) ^ i4;
  i2 = i2 + 4 | 0;
 }
 return i1 | 0;
}

function __GLOBAL__sub_I_optimizer_shared_cpp() {
 HEAP32[14934] = 0;
 __ZN6cashew7IString3setEPKcb(59740, 48310, 1);
 __ZN6cashew7IString3setEPKcb(59744, 48329, 1);
 __ZN6cashew7IString3setEPKcb(59748, 48348, 1);
 __ZN6cashew7IString3setEPKcb(59752, 48367, 1);
 __ZN6cashew7IString3setEPKcb(59756, 48388, 1);
 return;
}

function _copysignf(d1, d2) {
 d1 = +d1;
 d2 = +d2;
 var i3 = 0;
 i3 = (HEAPF32[tempDoublePtr >> 2] = d2, HEAP32[tempDoublePtr >> 2] | 0);
 d2 = +Math_abs(+d1);
 return +(HEAP32[tempDoublePtr >> 2] = i3 & -2147483648 | (HEAPF32[tempDoublePtr >> 2] = d2, HEAP32[tempDoublePtr >> 2] | 0), +HEAPF32[tempDoublePtr >> 2]);
}

function __ZNSt3__221__thread_specific_ptrINS_15__thread_structEE5resetEPS1_(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = _pthread_getspecific(HEAP32[i3 >> 2] | 0) | 0;
 _pthread_setspecific(HEAP32[i3 >> 2] | 0, i2 | 0) | 0;
 if (i1 | 0) {
  __ZNSt3__215__thread_structD2Ev(i1);
  __ZdlPv(i1);
 }
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKc(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 return __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6insertEjPKcj(i3, i1, i2, _strlen(i2) | 0) | 0;
}

function __ZNKSt3__27collateIcE7do_hashEPKcS3_(i1, i2, i3) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i4 = 0, i5 = 0;
 i1 = 0;
 while (1) {
  if ((i2 | 0) == (i3 | 0)) break;
  i4 = (HEAP8[i2 >> 0] | 0) + (i1 << 4) | 0;
  i5 = i4 & -268435456;
  i1 = (i5 >>> 24 | i5) ^ i4;
  i2 = i2 + 1 | 0;
 }
 return i1 | 0;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm10TypeSeekerD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7828;
 __ZNSt3__213__vector_baseIN4wasm8WasmTypeENS_9allocatorIS2_EEED2Ev(i1 + 36 | 0);
 HEAP32[i1 >> 2] = 7840;
 __ZNSt3__213__vector_baseIN4wasm6WalkerINS1_10TypeSeekerENS1_7VisitorIS3_vEEE4TaskENS_9allocatorIS7_EEED2Ev(i1 + 8 | 0);
 return;
}

function __ZN4wasm8Function12getLocalTypeEj(i4, i3) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = HEAP32[i4 + 8 >> 2] | 0;
 i2 = (HEAP32[i4 + 12 >> 2] | 0) - i1 >> 2;
 if (i2 >>> 0 > i3 >>> 0) i1 = i1 + (i3 << 2) | 0; else i1 = (HEAP32[i4 + 20 >> 2] | 0) + (i3 - i2 << 2) | 0;
 return HEAP32[i1 >> 2] | 0;
}

function __ZN4wasm15RemoveUnusedBrs5clearEPS0_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i3 = HEAP32[i2 + 48 >> 2] | 0;
 i1 = i2 + 52 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 while (1) {
  if ((i2 | 0) == (i3 | 0)) break;
  i4 = i2 + -4 | 0;
  HEAP32[i1 >> 2] = i4;
  i2 = i4;
 }
 return;
}

function __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 if ((i1 | 0) != (i2 | 0)) {
  if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 511](i1);
 } else FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 511](i1);
 return;
}

function __ZNKSt3__28functionIFPN4wasm4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 i1 = HEAP32[i1 + 16 >> 2] | 0;
 if (!i1) {
  i1 = ___cxa_allocate_exception(4) | 0;
  HEAP32[i1 >> 2] = 4480;
  ___cxa_throw(i1 | 0, 160, 11);
 } else return FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 24 >> 2] & 255](i1) | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination17visitCallIndirectEPNS_12CallIndirectE(i2, __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE2atEj(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i3 >> 2] | 0;
 if ((HEAP32[i3 + 4 >> 2] | 0) - i1 >> 2 >>> 0 > i2 >>> 0) return i1 + (i2 << 2) | 0; else __ZNKSt3__220__vector_base_commonILb1EE20__throw_out_of_rangeEv(i3);
 return 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNK4wasm7Literal12extendToUI64Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 if ((HEAP32[i2 >> 2] | 0) == 1) {
  i3 = HEAP32[i2 + 8 >> 2] | 0;
  HEAP32[i1 >> 2] = 2;
  i2 = i1 + 8 | 0;
  HEAP32[i2 >> 2] = i3;
  HEAP32[i2 + 4 >> 2] = 0;
  return;
 } else ___assert_fail(22306, 19526, 379, 28534);
}

function __ZN4wasm15Asm2WasmBuilder12bytesToShiftEj(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 switch (i2 | 0) {
 case 1:
  {
   i1 = 0;
   break;
  }
 case 2:
  {
   i1 = 1;
   break;
  }
 case 4:
  {
   i1 = 2;
   break;
  }
 case 8:
  {
   i1 = 3;
   break;
  }
 default:
  _abort();
 }
 return i1 | 0;
}

function __ZN11ArenaVectorIPN4wasm10ExpressionEE8pop_backEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = i3 + 8 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if (!i2) ___assert_fail(34187, 34204, 206, 34290); else {
  i2 = i2 + -1 | 0;
  HEAP32[i1 >> 2] = i2;
  return (HEAP32[i3 + 4 >> 2] | 0) + (i2 << 2) | 0;
 }
 return 0;
}

function __ZN10MixedArena5allocIN4wasm12CallIndirectEEEPT_v(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZN10MixedArena10allocSpaceEj(i1, 32) | 0;
 HEAP32[i2 >> 2] = 8;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = i1;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 return i2 | 0;
}

function __ZN4wasm14SimplifyLocals10BlockBreakC2EOS1_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
 __ZNSt3__26__treeINS_12__value_typeIjN4wasm14SimplifyLocals12SinkableInfoEEENS_19__map_value_compareIjS5_NS_4lessIjEELb1EEENS_9allocatorIS5_EEEC2EOSC_(i2 + 4 | 0, i1 + 4 | 0);
 return;
}

function __ZN10MixedArena5allocIN4wasm5BreakEEEPT_v(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 20) | 0;
 HEAP32[i1 >> 2] = 4;
 i2 = i1 + 4 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 >> 2] = 5;
 return i1 | 0;
}

function _rintf(d1) {
 d1 = +d1;
 var i2 = 0;
 i2 = (HEAPF32[tempDoublePtr >> 2] = d1, HEAP32[tempDoublePtr >> 2] | 0);
 if ((i2 & 2130706432) >>> 0 <= 1249902592) {
  i2 = (i2 | 0) < 0;
  d1 = i2 ? d1 + -8388608.0 + 8388608.0 : d1 + 8388608.0 + -8388608.0;
  if (d1 == 0.0) d1 = i2 ? -0.0 : 0.0;
 }
 return +d1;
}

function __ZZN4wasm12RegisterPassINS_20OptimizeInstructionsEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __Znwj(44) | 0;
 i2 = i1;
 i3 = i2 + 44 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 __ZN4wasm20OptimizeInstructionsC2Ev(i1);
 return i1 | 0;
}

function __ZZN4wasm12RegisterPassINS_19DeadCodeEliminationEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __Znwj(84) | 0;
 i2 = i1;
 i3 = i2 + 84 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 __ZN4wasm19DeadCodeEliminationC2Ev(i1);
 return i1 | 0;
}

function __ZN4wasm22SExpressionWasmBuilder15preParseImportsERNS_7ElementE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = __ZN4wasm7Element3strEv(__ZN4wasm7ElementixEj(i1, 0) | 0) | 0;
 if ((i3 | 0) == (HEAP32[14980] | 0)) __ZN4wasm22SExpressionWasmBuilder11parseImportERNS_7ElementE(i2, i1);
 return;
}

function __ZN4wasm7Builder9makeBlockEPNS_10ExpressionE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i1 = __ZN10MixedArena5allocIN4wasm5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 if (i2 | 0) {
  __ZN11ArenaVectorIPN4wasm10ExpressionEE9push_backES2_(i1 + 12 | 0, i2);
  __ZN4wasm5Block8finalizeEv(i1);
 }
 return i1 | 0;
}

function __ZN4wasm10ThreadPool19notifyThreadIsReadyEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = i1 + 16 | 0;
 __ZNSt3__25mutex4lockEv(i2);
 i3 = i1 + 92 | 0;
 HEAP32[i3 >> 2] = (HEAP32[i3 >> 2] | 0) + 1;
 __ZNSt3__218condition_variable10notify_oneEv(i1 + 44 | 0);
 __ZNSt3__25mutex6unlockEv(i2);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 37460 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm7Builder12makeSetLocalEjPNS_10ExpressionE(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = __ZN10MixedArena5allocIN4wasm8SetLocalEEEPT_v(HEAP32[i2 >> 2] | 0) | 0;
 HEAP32[i2 + 8 >> 2] = i1;
 HEAP32[i2 + 12 >> 2] = i3;
 HEAP32[i2 + 4 >> 2] = HEAP32[i3 + 4 >> 2];
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 33279 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination10handleCallINS_4CallEEEvPT_PNS_10ExpressionE(i2, __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0, 0);
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_15arenaILj4096EE8allocateEj(i4, i1) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = i1 + 15 & -16;
 i3 = i4 + 4096 | 0;
 i1 = HEAP32[i3 >> 2] | 0;
 if ((i4 + 4096 - i1 | 0) >>> 0 < i2 >>> 0) i1 = _malloc(i2) | 0; else HEAP32[i3 >> 2] = i1 + i2;
 return i1 | 0;
}

function __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11TypeUpdaterC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 6136;
 HEAP32[i1 + 16 >> 2] = 6164;
 return;
}

function __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11SelectifierC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 6044;
 HEAP32[i1 + 16 >> 2] = 6072;
 return;
}

function __ZZN4wasm12RegisterPassINS_17RemoveUnusedNamesEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __Znwj(56) | 0;
 i2 = i1;
 i3 = i2 + 56 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 __ZN4wasm17RemoveUnusedNamesC2Ev(i1);
 return i1 | 0;
}

function __ZN6cashew5Value8setArrayEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 __ZN6cashew5Value4freeEv(i2);
 HEAP32[i2 >> 2] = 2;
 i3 = __ZN6cashew5Arena10allocArrayEv(59672) | 0;
 HEAP32[i2 + 8 >> 2] = i3;
 __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE7reserveEj(i3, i1);
 return i2 | 0;
}

function __ZN4wasm13WasmValidator8validateERNS_6ModuleE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = i2 + 28 | 0;
 HEAP8[i3 >> 0] = 1;
 HEAP32[i2 + 24 >> 2] = i1;
 __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleE(i2, i1);
 return (HEAP8[i3 >> 0] | 0) != 0 | 0;
}

function __ZN11ArenaVectorIN4wasm4NameEE8pop_backEv(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = i3 + 8 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if (!i2) ___assert_fail(34187, 34204, 206, 34290); else {
  i2 = i2 + -1 | 0;
  HEAP32[i1 >> 2] = i2;
  return (HEAP32[i3 + 4 >> 2] | 0) + (i2 << 2) | 0;
 }
 return 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 40080 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks10handleCallINS_10CallImportEEEvPT_PNS_5BlockE(i2, __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0, 0);
 return;
}

function __ZN4wasm17RemoveUnusedNamesC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 6356;
 HEAP32[i1 + 16 >> 2] = 6384;
 HEAP32[i1 + 48 >> 2] = 0;
 HEAP32[i1 + 52 >> 2] = 0;
 HEAP32[i1 + 44 >> 2] = i1 + 48;
 return;
}

function __ZNSt3__217__assoc_sub_state12__make_readyEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = i1 + 12 | 0;
 __ZNSt3__25mutex4lockEv(i2);
 i3 = i1 + 88 | 0;
 HEAP32[i3 >> 2] = HEAP32[i3 >> 2] | 4;
 __ZNSt3__218condition_variable10notify_allEv(i1 + 40 | 0);
 __ZNSt3__25mutex6unlockEv(i2);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 45863 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm18CountLeadingZeroesIjEEiT_(i1) {
 i1 = i1 | 0;
 i1 = i1 >>> 1 | i1;
 i1 = i1 >>> 2 | i1;
 i1 = i1 >>> 4 | i1;
 i1 = i1 >>> 8 | i1;
 i1 = i1 >>> 16 | i1;
 if (!i1) i1 = 32; else {
  i1 = 48543 + ((Math_imul(i1, 130329821) | 0) >>> 27) | 0;
  i1 = HEAPU8[i1 >> 0] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__28functionIFhvEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 if ((i1 | 0) != (i2 | 0)) {
  if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 511](i1);
 } else FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 511](i1);
 return;
}

function __ZNSt3__28functionIFavEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 if ((i1 | 0) != (i2 | 0)) {
  if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 20 >> 2] & 511](i1);
 } else FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 16 >> 2] & 511](i1);
 return;
}

function __ZNKSt3__28functionIFhvEEclEv(i1) {
 i1 = i1 | 0;
 i1 = HEAP32[i1 + 16 >> 2] | 0;
 if (!i1) {
  i1 = ___cxa_allocate_exception(4) | 0;
  HEAP32[i1 >> 2] = 4480;
  ___cxa_throw(i1 | 0, 160, 11);
 } else return FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 24 >> 2] & 255](i1) | 0;
 return 0;
}

function __ZNKSt3__28functionIFavEEclEv(i1) {
 i1 = i1 | 0;
 i1 = HEAP32[i1 + 16 >> 2] | 0;
 if (!i1) {
  i1 = ___cxa_allocate_exception(4) | 0;
  HEAP32[i1 >> 2] = 4480;
  ___cxa_throw(i1 | 0, 160, 11);
 } else return FUNCTION_TABLE_ii[HEAP32[(HEAP32[i1 >> 2] | 0) + 24 >> 2] & 255](i1) | 0;
 return 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 39294 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN6cashew5Value4backEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if ((HEAP32[i1 >> 2] | 0) != 2) ___assert_fail(48262, 48272, 491, 34222);
 i2 = HEAP32[i1 + 8 >> 2] | 0;
 i1 = HEAP32[i2 + 4 >> 2] | 0;
 if ((i1 | 0) == (HEAP32[i2 >> 2] | 0)) i1 = 0; else i1 = HEAP32[i1 + -4 >> 2] | 0;
 return i1 | 0;
}

function __ZN4wasm6rehashEjj(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0, i4 = 0;
 i3 = i1;
 i1 = 5381;
 while (1) {
  if (!i3) break;
  i4 = i1 * 33 ^ i3 & 255;
  i3 = i3 >>> 8;
  i1 = i4;
 }
 while (1) {
  if (!i2) break;
  i4 = i1 * 33 ^ i2 & 255;
  i2 = i2 >>> 8;
  i1 = i4;
 }
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator17visitCallIndirectEPNS_12CallIndirectE(i2, __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN10MixedArenaD2Ev(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 __ZN10MixedArena5clearEv(i3);
 i1 = i3 + 24 | 0;
 if (HEAP32[i1 >> 2] | 0 ? (i2 = HEAP32[i1 >> 2] | 0, i2 | 0) : 0) {
  __ZN10MixedArenaD2Ev(i2);
  __ZdlPv(i2);
 }
 __ZNSt3__213__vector_baseIPcNS_9allocatorIS1_EEED2Ev(i3);
 return;
}

function ___uremdi3(i1, i2, i3, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i5 = 0, i6 = 0;
 i6 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i6 | 0;
 ___udivmoddi4(i1, i2, i3, i4, i5) | 0;
 STACKTOP = i6;
 return (tempRet0 = HEAP32[i5 + 4 >> 2] | 0, HEAP32[i5 >> 2] | 0) | 0;
}

function __ZZN4wasm12RegisterPassINS_15RemoveUnusedBrsEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __Znwj(72) | 0;
 i2 = i1;
 i3 = i2 + 72 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 __ZN4wasm15RemoveUnusedBrsC2Ev(i1);
 return i1 | 0;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj(i3, i4, i1, i2) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i3;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 i4 = i3 + 8 | 0;
 HEAP32[i4 >> 2] = -1;
 HEAP32[i4 + 4 >> 2] = -1;
 return;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj(i3, i4, i1, i2) {
 i3 = i3 | 0;
 i4 = i4 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = i3;
 HEAP32[i4 >> 2] = 0;
 HEAP32[i4 + 4 >> 2] = 0;
 i4 = i3 + 8 | 0;
 HEAP32[i4 >> 2] = -1;
 HEAP32[i4 + 4 >> 2] = -1;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doWalkModuleEPNS_6ModuleEENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 42807 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 40913 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 45423 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 46824 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm17RemoveUnusedNamesD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 6356;
 HEAP32[i1 + 16 >> 2] = 6384;
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEED2Ev(i1 + 44 | 0);
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEED2Ev(i1);
 return;
}

function dynCall_iiiiiiiii(i9, i1, i2, i3, i4, i5, i6, i7, i8) {
 i9 = i9 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 return FUNCTION_TABLE_iiiiiiiii[i9 & 15](i1 | 0, i2 | 0, i3 | 0, i4 | 0, i5 | 0, i6 | 0, i7 | 0, i8 | 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 43953 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm7Builder9makeUnaryENS_7UnaryOpEPNS_10ExpressionE(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(HEAP32[i2 >> 2] | 0) | 0;
 HEAP32[i2 + 8 >> 2] = i1;
 HEAP32[i2 + 12 >> 2] = i3;
 __ZN4wasm5Unary8finalizeEv(i2);
 return i2 | 0;
}

function __ZN4wasm16PrintSExpression16visitUnreachableEPNS_11UnreachableE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__Z17printMinorOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i2 >> 2] | 0, 36141) | 0, 41) | 0;
 return;
}

function __ZZN4wasm12RegisterPassINS_14PostEmscriptenEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __Znwj(44) | 0;
 i2 = i1;
 i3 = i2 + 44 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 __ZN4wasm14PostEmscriptenC2Ev(i1);
 return i1 | 0;
}

function __ZN4wasm17RemoveUnusedNames10visitBlockEPNS_5BlockE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i1 = i1 + 8 | 0;
 if (HEAP32[i1 >> 2] | 0 ? (__ZNKSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__count_uniqueIS2_EEjRKT_(i2 + 44 | 0, i1) | 0) == 0 : 0) HEAP32[i1 >> 2] = 0;
 return;
}

function __ZN4wasm16PrintSExpression15visitCallImportEPNS_10CallImportE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i2 >> 2] | 0, 34714, 0) | 0;
 __ZN4wasm16PrintSExpression13printCallBodyINS_10CallImportEEEvPT_(i2, i1);
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_111string_pairD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i1 + 12 | 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i1);
 return;
}

function __Z8doIndentRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEj(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == (i2 | 0)) break;
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i3, 34501) | 0;
  i1 = i1 + 1 | 0;
 }
 return i3 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 34299 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks17visitCallIndirectEPNS_12CallIndirectE(i2, __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZZN4wasm12RegisterPassINS_13ReorderLocalsEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __Znwj(68) | 0;
 i2 = i1;
 i3 = i2 + 68 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 __ZN4wasm13ReorderLocalsC2Ev(i1);
 return i1 | 0;
}

function __ZNKSt3__28messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = _catopen((HEAP8[i2 + 11 >> 0] | 0) < 0 ? HEAP32[i2 >> 2] | 0 : i2, 1) | 0;
 return i3 >>> ((i3 | 0) != (-1 | 0) & 1) | 0;
}

function __ZNKSt3__28messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = _catopen((HEAP8[i2 + 11 >> 0] | 0) < 0 ? HEAP32[i2 >> 2] | 0 : i2, 1) | 0;
 return i3 >>> ((i3 | 0) != (-1 | 0) & 1) | 0;
}

function __ZN4wasm15getWasmTypeSizeENS_8WasmTypeE(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 switch (i2 | 0) {
 case 0:
  {
   _abort();
   break;
  }
 case 3:
 case 1:
  {
   i1 = 4;
   break;
  }
 case 2:
  {
   i1 = 8;
   break;
  }
 case 4:
  {
   i1 = 8;
   break;
  }
 default:
  {}
 }
 return i1 | 0;
}

function __ZN4wasm6Vacuum9visitPostEPS0_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0, i4 = 0;
 i1 = i2 + 48 | 0;
 i3 = HEAP32[i1 >> 2] | 0;
 i2 = i3 + -4 | 0;
 while (1) {
  if ((i3 | 0) == (i2 | 0)) break;
  i4 = i3 + -4 | 0;
  HEAP32[i1 >> 2] = i4;
  i3 = i4;
 }
 return;
}

function __ZN4wasm22SExpressionWasmBuilder10parseStartERNS_7ElementE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = HEAP32[i2 >> 2] | 0;
 i2 = __ZN4wasm22SExpressionWasmBuilder15getFunctionNameERNS_7ElementE(i2, __ZN4wasm7ElementixEj(i1, 1) | 0) | 0;
 HEAP32[i3 + 84 >> 2] = i2;
 return;
}

function __ZN4wasm10ThreadPool20resetThreadsAreReadyEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i3 = i1 + 92 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = 0;
 if ((i2 | 0) == ((HEAP32[i1 + 4 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) >> 2 | 0)) return; else ___assert_fail(48590, 48612, 177, 48636);
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator15visitCallImportEPNS_10CallImportE(i2, __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm12PassRegistry8PassInfoC2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 HEAP32[i2 + 32 >> 2] = 0;
 return;
}

function __ZN4wasm11getWasmTypeEjb(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 L1 : do if (i3 >>> 0 < 4) i1 = 1; else switch (i3 | 0) {
 case 4:
  {
   i1 = i2 ? 3 : 1;
   break L1;
  }
 case 8:
  {
   i1 = i2 ? 4 : 2;
   break L1;
  }
 default:
  _abort();
 } while (0);
 return i1 | 0;
}

function __Z17printMinorOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(i1, 40) | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i1, i2) | 0;
 return i1 | 0;
}

function __ZZN4wasm12RegisterPassINS_11MergeBlocksEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __Znwj(44) | 0;
 i2 = i1;
 i3 = i2 + 44 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 __ZN4wasm11MergeBlocksC2Ev(i1);
 return i1 | 0;
}

function __ZNSt3__214__shared_count16__release_sharedEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i3 = i1 + 4 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = i2 + -1;
 if (!i2) {
  FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 8 >> 2] & 511](i1);
  i1 = 1;
 } else i1 = 0;
 return i1 | 0;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitBlockEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm5Block8finalizeEv(__ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEE6appendEPKcj(i2, i1, _strlen(i1) | 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 44624 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm4PassC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 HEAP32[i1 >> 2] = 4632;
 i1 = i1 + 4 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = 0;
 while (1) {
  if ((i2 | 0) == 3) break;
  HEAP32[i1 + (i2 << 2) >> 2] = 0;
  i2 = i2 + 1 | 0;
 }
 return;
}

function __ZN4wasm11make_uniqueINS_12FunctionTypeEJEEENSt3__210unique_ptrIT_NS2_14default_deleteIS4_EEEEDpOT0_() {
 var i1 = 0;
 i1 = __Znwj(20) | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 return i1 | 0;
}

function __ZN4wasm13wasmToAsmTypeENS_8WasmTypeE(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 switch (i2 | 0) {
 case 1:
  {
   i1 = 0;
   break;
  }
 case 3:
  {
   i1 = 2;
   break;
  }
 case 4:
  {
   i1 = 1;
   break;
  }
 case 0:
  {
   i1 = 8;
   break;
  }
 default:
  _abort();
 }
 return i1 | 0;
}

function __ZN10MixedArena5allocIN4wasm5ConstEEEPT_v(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 24) | 0;
 HEAP32[i1 >> 2] = 13;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 i2 = i1 + 16 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 return i1 | 0;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE11doVisitLoopEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm4Loop8finalizeEv(__ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm16PrintSExpression14printableLocalEj(i2, i3) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i1 = 0;
 i2 = HEAP32[i2 + 24 >> 2] | 0;
 if (!((i2 | 0) != 0 ? (i1 = __ZN4wasm8Function12tryLocalNameEj(i2, i3) | 0, (i1 | 0) != 0) : 0)) i1 = __ZN4wasm4Name7fromIntEj(i3) | 0;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination11visitSwitchEPNS_6SwitchE(i2, __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination11visitSelectEPNS_6SelectE(i2, __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination11visitReturnEPNS_6ReturnE(i2, __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination11visitBinaryEPNS_6BinaryE(i2, __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm15SetLocalRemover13visitSetLocalEPNS_8SetLocalE(i2, __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZL12prepare2wasmv() {
 var i1 = 0;
 if ((HEAP32[14810] | 0) == 0 & (HEAP32[14811] | 0) == 0 & (HEAP32[14812] | 0) == 0 & (HEAP32[14813] | 0) == 0) {
  i1 = (_emscripten_asm_const_i(5) | 0) != 0 & 1;
  HEAP8[63612] = i1;
  return;
 } else ___assert_fail(21070, 18398, 48, 21182);
}

function __ZNKSt3__210moneypunctIwLb1EE16do_positive_signEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__210moneypunctIwLb0EE16do_positive_signEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__210moneypunctIcLb1EE16do_positive_signEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__210moneypunctIcLb0EE16do_positive_signEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm20OptimizeInstructions10visitUnaryEPNS_5UnaryE(i2, __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14SimplifyLocals13visitGetLocalEPNS_8GetLocalE(i2, __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14EffectAnalyzer13visitSetLocalEPNS_8SetLocalE(i2, __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14EffectAnalyzer13visitGetLocalEPNS_8GetLocalE(i2, __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm14ParseExceptionC2ENSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i2, i1);
 HEAP32[i2 + 12 >> 2] = -1;
 HEAP32[i2 + 16 >> 2] = -1;
 return;
}

function __ZN4wasm13asmToWasmTypeE7AsmType(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 switch (i2 | 0) {
 case 0:
  {
   i1 = 1;
   break;
  }
 case 1:
  {
   i1 = 4;
   break;
  }
 case 2:
  {
   i1 = 3;
   break;
  }
 case 8:
  {
   i1 = 0;
   break;
  }
 default:
  _abort();
 }
 return i1 | 0;
}

function __ZNKSt3__210moneypunctIwLb1EE14do_curr_symbolEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__210moneypunctIwLb0EE14do_curr_symbolEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__210moneypunctIcLb1EE14do_curr_symbolEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__210moneypunctIcLb0EE14do_curr_symbolEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNK4wasm7Literal13truncateToF32Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var d3 = 0.0;
 if ((HEAP32[i2 >> 2] | 0) == 4) {
  d3 = +__ZNK4wasm7Literal6getf64Ev(i2);
  HEAP32[i1 >> 2] = 3;
  HEAPF32[i1 + 8 >> 2] = d3;
  return;
 } else ___assert_fail(28667, 19526, 391, 28805);
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination10visitStoreEPNS_5StoreE(i2, __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination10visitBreakEPNS_5BreakE(i2, __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination10visitBlockEPNS_5BlockE(i2, __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm17RemoveUnusedNames11visitSwitchEPNS_6SwitchE(i2, __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator13visitSetLocalEPNS_8SetLocalE(i2, __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13ReorderLocals13visitSetLocalEPNS_8SetLocalE(i2, __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13ReorderLocals13visitGetLocalEPNS_8GetLocalE(i2, __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks10handleCallINS_4CallEEEvPT_PNS_5BlockE(i2, __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0, 0);
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE9doVisitIfEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm2If8finalizeEv(__ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm14SimplifyLocals12SinkableInfoC2EPPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = i1;
 i2 = i2 + 4 | 0;
 __ZN4wasm14EffectAnalyzerC2Ev(i2);
 __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE4walkERPNS_10ExpressionE(i2, i1);
 return;
}

function __ZNK4wasm7Literal11extendToF64Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var d3 = 0.0;
 if ((HEAP32[i2 >> 2] | 0) == 3) {
  d3 = +__ZNK4wasm7Literal6getf32Ev(i2);
  HEAP32[i1 >> 2] = 4;
  HEAPF64[i1 + 8 >> 3] = d3;
  return;
 } else ___assert_fail(28630, 19526, 383, 28783);
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14PostEmscripten13visitMemoryOpINS_5StoreEEEvPT_(i2, __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm16PrintSExpression8visitNopEPNS_3NopE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(__Z17printMinorOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKc(HEAP32[i2 >> 2] | 0, 36137) | 0, 41) | 0;
 return;
}

function __ZZN4wasm12RegisterPassINS_6VacuumEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i1 = __Znwj(56) | 0;
 i2 = i1;
 i3 = i2 + 56 | 0;
 do {
  HEAP32[i2 >> 2] = 0;
  i2 = i2 + 4 | 0;
 } while ((i2 | 0) < (i3 | 0));
 __ZN4wasm6VacuumC2Ev(i1);
 return i1 | 0;
}

function __ZNSt3__215__thread_structC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __Znwj(24) | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 HEAP32[i2 + 12 >> 2] = 0;
 HEAP32[i2 + 16 >> 2] = 0;
 HEAP32[i2 + 20 >> 2] = 0;
 HEAP32[i1 >> 2] = i2;
 return;
}

function __ZNKSt3__210moneypunctIwLb1EE11do_groupingEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__210moneypunctIwLb0EE11do_groupingEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__210moneypunctIcLb1EE11do_groupingEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function __ZNKSt3__210moneypunctIcLb0EE11do_groupingEv(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = 0;
 i1 = 0;
 while (1) {
  if ((i1 | 0) == 3) break;
  HEAP32[i2 + (i1 << 2) >> 2] = 0;
  i1 = i1 + 1 | 0;
 }
 return;
}

function _wmemcpy(i4, i2, i1) {
 i4 = i4 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 if (i1 | 0) {
  i3 = i4;
  while (1) {
   i1 = i1 + -1 | 0;
   HEAP32[i3 >> 2] = HEAP32[i2 >> 2];
   if (!i1) break; else {
    i2 = i2 + 4 | 0;
    i3 = i3 + 4 | 0;
   }
  }
 }
 return i4 | 0;
}

function ___muldi3(i1, i2, i3, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 var i5 = 0, i6 = 0;
 i5 = i1;
 i6 = i3;
 i3 = ___muldsi3(i5, i6) | 0;
 i1 = tempRet0;
 return (tempRet0 = (Math_imul(i2, i6) | 0) + (Math_imul(i4, i5) | 0) + i1 | i1 & 0, i3 | 0 | 0) | 0;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE19doVisitCallIndirectEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE19doVisitCallIndirectEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm17RemoveUnusedNames10visitBreakEPNS_5BreakE(i2, __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm17RemoveUnusedNames10visitBlockEPNS_5BlockE(i2, __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks13visitSetLocalEPNS_8SetLocalE(i2, __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm7Literal8getFloatEv(i2) {
 i2 = i2 | 0;
 var d1 = 0.0;
 switch (HEAP32[i2 >> 2] | 0) {
 case 3:
  {
   d1 = +__ZNK4wasm7Literal6getf32Ev(i2);
   break;
  }
 case 4:
  {
   d1 = +__ZNK4wasm7Literal6getf64Ev(i2);
   break;
  }
 default:
  _abort();
 }
 return +d1;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination9visitLoopEPNS_4LoopE(i2, __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14PostEmscripten13visitMemoryOpINS_4LoadEEEvPT_(i2, __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6VacuumD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7284;
 HEAP32[i1 + 16 >> 2] = 7312;
 __ZNSt3__213__vector_baseIPN4wasm10ExpressionENS_9allocatorIS3_EEED2Ev(i1 + 44 | 0);
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEED2Ev(i1);
 return;
}

function __ZN4wasm6Module15getFunctionTypeEj(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i3 >> 2] | 0;
 if ((HEAP32[i3 + 4 >> 2] | 0) - i1 >> 2 >>> 0 > i2 >>> 0) return HEAP32[i1 + (i2 << 2) >> 2] | 0; else ___assert_fail(23682, 19526, 1448, 21736);
 return 0;
}

function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4392;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 32 | 0);
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev(i1);
 return;
}

function __ZNKSt3__28numpunctIwE12do_falsenameEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj(i1, 15080, _wcslen(15080) | 0);
 return;
}

function __ZNKSt3__27codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_(i6, i1, i4, i2, i5, i7, i3, i8) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 i8 = i8 | 0;
 HEAP32[i5 >> 2] = i4;
 HEAP32[i8 >> 2] = i7;
 return 3;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE18doVisitUnreachableEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE18doVisitUnreachableEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14EffectAnalyzer11visitSwitchEPNS_6SwitchE(i2, __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm16PrintSExpression9visitCallEPNS_4CallE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __Z12printOpeningRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEEPKcb(HEAP32[i2 >> 2] | 0, 34708, 0) | 0;
 __ZN4wasm16PrintSExpression13printCallBodyINS_4CallEEEvPT_(i2, i1);
 return;
}

function __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEE12__deallocateEPNS_11__hash_nodeIS2_PvEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 while (1) {
  if (!i1) break;
  i2 = HEAP32[i1 >> 2] | 0;
  __ZdlPv(i1);
  i1 = i2;
 }
 return;
}

function __ZNKSt3__28numpunctIwE11do_truenameEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj(i1, 15060, _wcslen(15060) | 0);
 return;
}

function __ZNKSt3__27codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_(i6, i1, i4, i2, i5, i7, i3, i8) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 i7 = i7 | 0;
 i3 = i3 | 0;
 i8 = i8 | 0;
 HEAP32[i5 >> 2] = i4;
 HEAP32[i8 >> 2] = i7;
 return 3;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_28DuplicateFunctionEliminationEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE17doVisitCallImportEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE17doVisitCallImportEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator11visitSwitchEPNS_6SwitchE(i2, __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator11visitReturnEPNS_6ReturnE(i2, __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator11visitBinaryEPNS_6BinaryE(i2, __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm19DeadCodeElimination11visitReturnEPNS_6ReturnE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = HEAP32[i1 + 8 >> 2] | 0;
 i1 = i3;
 if ((i3 | 0) != 0 ? (HEAP32[i3 >> 2] | 0) == 20 : 0) HEAP32[i2 + 20 >> 2] = i1; else HEAP8[i2 + 44 >> 0] = 0;
 return;
}

function __ZN4wasm16PrintSExpression9incIndentEv(i1) {
 i1 = i1 | 0;
 if (!(HEAP8[i1 + 8 >> 0] | 0)) {
  __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(HEAP32[i1 >> 2] | 0, 10) | 0;
  i1 = i1 + 4 | 0;
  HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 1;
 }
 return;
}

function ___cxa_get_globals_fast() {
 var i1 = 0, i2 = 0;
 i1 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 if (!(_pthread_once(63600, 3) | 0)) {
  i2 = _pthread_getspecific(HEAP32[15901] | 0) | 0;
  STACKTOP = i1;
  return i2 | 0;
 } else _abort_message(56066, i1);
 return 0;
}

function __ZN6cashew13OperatorClassC2EOS0_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 __ZN6cashew10IStringSetC2EOS0_(i2, i1);
 i3 = i1 + 32 | 0;
 i1 = HEAP32[i3 + 4 >> 2] | 0;
 i2 = i2 + 32 | 0;
 HEAP32[i2 >> 2] = HEAP32[i3 >> 2];
 HEAP32[i2 + 4 >> 2] = i1;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE19doVisitCallIndirectEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14SimplifyLocals10visitBlockEPNS_5BlockE(i2, __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14EffectAnalyzer10visitBreakEPNS_5BreakE(i2, __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14EffectAnalyzer10visitBlockEPNS_5BlockE(i2, __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6VacuumC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 7284;
 HEAP32[i1 + 16 >> 2] = 7312;
 HEAP32[i1 + 44 >> 2] = 0;
 HEAP32[i1 + 48 >> 2] = 0;
 HEAP32[i1 + 52 >> 2] = 0;
 return;
}

function __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUlyE_clEy(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = HEAP32[i3 >> 2] | 0;
 i2 = __ZN4wasm6rehashEjj(__ZN4wasm6rehashEjj(HEAP32[i3 >> 2] | 0, i2) | 0, i1) | 0;
 HEAP32[i3 >> 2] = i2;
 return;
}

function __ZNSt3__212__tuple_leafILj0ENS_10unique_ptrINS_15__thread_structENS_14default_deleteIS2_EEEELb0EED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = 0;
 if (i1 | 0) {
  __ZNSt3__215__thread_structD2Ev(i1);
  __ZdlPv(i1);
 }
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 45953 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm16FunctionReplacer9visitCallEPNS_4CallE(i2, __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __Z8parseIntPKc(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = i1;
 i1 = (HEAP8[i1 >> 0] | 0) + -48 | 0;
 while (1) {
  i2 = i2 + 1 | 0;
  i3 = HEAP8[i2 >> 0] | 0;
  if (!(i3 << 24 >> 24)) break;
  i1 = (i1 * 10 | 0) + -48 + (i3 << 24 >> 24) | 0;
 }
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_26CoalesceLocalsWithLearningEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE18doVisitUnreachableEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm20OptimizeInstructions7visitIfEPNS_2IfE(i2, __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator10visitUnaryEPNS_5UnaryE(i2, __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator10visitStoreEPNS_5StoreE(i2, __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator10visitBreakEPNS_5BreakE(i2, __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator10visitBlockEPNS_5BlockE(i2, __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks11visitSwitchEPNS_6SwitchE(i2, __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks11visitSelectEPNS_6SelectE(i2, __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks11visitReturnEPNS_6ReturnE(i2, __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks11visitBinaryEPNS_6BinaryE(i2, __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11BreakSeeker11visitSwitchEPNS_6SwitchE(i2, __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function dynCall_iiiiiiii(i8, i1, i2, i3, i4, i5, i6, i7) {
 i8 = i8 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 return FUNCTION_TABLE_iiiiiiii[i8 & 7](i1 | 0, i2 | 0, i3 | 0, i4 | 0, i5 | 0, i6 | 0, i7 | 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 47487 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE15doVisitSetLocalEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE15doVisitGetLocalEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE15doVisitSetLocalEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE15doVisitGetLocalEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 31079 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 30885 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE17doVisitCallImportEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeElimination7visitIfEPNS_2IfE(i2, __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10TypeSeeker11visitSwitchEPNS_6SwitchE(i2, __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm11make_uniqueINS_6ExportEJEEENSt3__210unique_ptrIT_NS2_14default_deleteIS4_EEEEDpOT0_() {
 var i1 = 0, i2 = 0;
 i1 = __Znwj(8) | 0;
 i2 = i1;
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 4 >> 2] = 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 return i1 | 0;
}

function __GLOBAL__sub_I_Print_cpp() {
 __ZN4wasm12RegisterPassINS_7PrinterEEC2EPKcS4_(65626, 49444, 36153);
 __ZN4wasm12RegisterPassINS_15MinifiedPrinterEEC2EPKcS4_(65627, 36347, 36362);
 __ZN4wasm12RegisterPassINS_11FullPrinterEEC2EPKcS4_(65628, 36608, 36619);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 30604 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm14EffectAnalyzer9visitLoopEPNS_4LoopE(i2, __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm18isInRangeI32TruncUEx(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if (i2 >>> 0 < 1106247679 | (i2 | 0) == 1106247679 & i1 >>> 0 < 4292870145) i1 = 1; else i1 = (i2 | 0) < 0 & (i2 >>> 0 < 3220176896 | (i2 | 0) == -1074790400 & i1 >>> 0 < 0);
 return i1 | 0;
}

function __ZN4wasm18isInRangeI32TruncSEx(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if (i2 >>> 0 < 1105199103 | (i2 | 0) == 1105199103 & i1 >>> 0 < 4290772993) i1 = 1; else i1 = (i2 | 0) < 0 & (i2 >>> 0 < 3252682752 | (i2 | 0) == -1042284544 & i1 >>> 0 < 1);
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks10visitUnaryEPNS_5UnaryE(i2, __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks10visitStoreEPNS_5StoreE(i2, __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks10visitBreakEPNS_5BreakE(i2, __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks10visitBlockEPNS_5BlockE(i2, __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZNKSt3__210moneypunctIwLb1EE16do_negative_signEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEjw(i1, 1, 45);
 return;
}

function __ZNKSt3__210moneypunctIwLb0EE16do_negative_signEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEjw(i1, 1, 45);
 return;
}

function __ZNKSt3__210moneypunctIcLb1EE16do_negative_signEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEjc(i1, 1, 45);
 return;
}

function __ZNKSt3__210moneypunctIcLb0EE16do_negative_signEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEjc(i1, 1, 45);
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13doVisitSwitchEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13doVisitSelectEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13doVisitReturnEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13doVisitBinaryEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13doVisitSwitchEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13doVisitSelectEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13doVisitReturnEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13doVisitBinaryEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator9visitLoopEPNS_4LoopE(i2, __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator9visitLoadEPNS_4LoadE(i2, __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator9visitHostEPNS_4HostE(i2, __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator9visitCallEPNS_4CallE(i2, __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10TypeSeeker10visitBreakEPNS_5BreakE(i2, __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10TypeSeeker10visitBlockEPNS_5BlockE(i2, __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 37584 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitUnaryEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitStoreEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitConstEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitBreakEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitUnaryEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitStoreEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitConstEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitBreakEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitBlockEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11TypeUpdaterD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11SelectifierD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__25ctypeIcE8do_widenEPKcS3_Pc(i3, i1, i4, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 while (1) {
  if ((i1 | 0) == (i4 | 0)) break;
  HEAP8[i2 >> 0] = HEAP8[i1 >> 0] | 0;
  i2 = i2 + 1 | 0;
  i1 = i1 + 1 | 0;
 }
 return i4 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 33401 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1, 4328);
 __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev(i1 + 60 | 0);
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE11doVisitLoadEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE11doVisitHostEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE11doVisitCallEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE11doVisitLoopEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE11doVisitLoadEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE11doVisitHostEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE11doVisitCallEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 HEAP8[i2 + 44 >> 0] = 0;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks9visitLoadEPNS_4LoadE(i2, __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_19destruct_EPv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 _free(i1);
 if (!(_pthread_setspecific(HEAP32[15901] | 0, 0) | 0)) {
  STACKTOP = i2;
  return;
 } else _abort_message(55963, i2);
}

function _snprintf(i3, i2, i1, i4) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 var i5 = 0, i6 = 0;
 i5 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i6 = i5;
 HEAP32[i6 >> 2] = i4;
 i4 = _vsnprintf(i3, i2, i1, i6) | 0;
 STACKTOP = i5;
 return i4 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 40198 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm15RemoveUnusedBrs7visitIfEPNS_2IfE(i2, __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm14EffectAnalyzer10visitBlockEPNS_5BlockE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i1 = i1 + 8 | 0;
 if (HEAP32[i1 >> 2] | 0) __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE14__erase_uniqueIS2_EEjRKT_(i2 + 60 | 0, i1) | 0;
 return;
}

function __ZN4wasm10ThreadPoolD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__218condition_variableD2Ev(i1 + 44 | 0);
 __ZNSt3__25mutexD2Ev(i1 + 16 | 0);
 __ZNSt3__213__vector_baseINS_10unique_ptrIN4wasm6ThreadENS_14default_deleteIS3_EEEENS_9allocatorIS6_EEED2Ev(i1);
 return;
}

function __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1, 4744);
 __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev(i1 + 64 | 0);
 return;
}

function __ZNKSt3__28numpunctIcE12do_falsenameEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 56968, 5);
 return;
}

function __ZNKSt3__25ctypeIwE8do_widenEPKcS3_Pw(i3, i1, i4, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 while (1) {
  if ((i1 | 0) == (i4 | 0)) break;
  HEAP32[i2 >> 2] = HEAP8[i1 >> 0];
  i2 = i2 + 4 | 0;
  i1 = i1 + 1 | 0;
 }
 return i4 | 0;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE10doVisitNopEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE10doVisitNopEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13doVisitSwitchEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13doVisitSelectEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13doVisitReturnEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13doVisitBinaryEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10TypeSeeker9visitLoopEPNS_4LoopE(i2, __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __Znwj(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = (i1 | 0) == 0 ? 1 : i1;
 while (1) {
  i1 = _malloc(i2) | 0;
  if (i1 | 0) break;
  i1 = __ZSt15get_new_handlerv() | 0;
  if (!i1) {
   i1 = 0;
   break;
  }
  FUNCTION_TABLE_v[i1 & 3]();
 }
 return i1 | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKc(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 return __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEjPKcj(i3, i1, i2, _strlen(i2) | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_20OptimizeInstructionsEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNKSt3__28numpunctIcE11do_truenameEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj(i1, 56974, 4);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 39408 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 36548 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm8LivenessD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213__vector_baseIN4wasm6ActionENS_9allocatorIS2_EEED2Ev(i1 + 24 | 0);
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1 + 12 | 0);
 __ZNSt3__213__vector_baseIjNS_9allocatorIjEEED2Ev(i1);
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 HEAP8[i2 + 29 >> 0] = 1;
 return;
}

function __ZN4wasm18isInRangeI64TruncUEx(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if (i2 >>> 0 < 1139802112 | (i2 | 0) == 1139802112 & i1 >>> 0 < 0) i1 = 1; else i1 = (i2 | 0) < 0 & (i2 >>> 0 < 3220176896 | (i2 | 0) == -1074790400 & i1 >>> 0 < 0);
 return i1 | 0;
}

function __ZN4wasm18isInRangeI64TruncSEx(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if (i2 >>> 0 < 1138753536 | (i2 | 0) == 1138753536 & i1 >>> 0 < 0) i1 = 1; else i1 = (i2 | 0) < 0 & (i2 >>> 0 < 3286237184 | (i2 | 0) == -1008730112 & i1 >>> 0 < 1);
 return i1 | 0;
}

function __ZN4wasm12PassRegistry3getEv() {
 var i1 = 0;
 i1 = HEAP32[14817] | 0;
 if (!i1) {
  i1 = __Znwj(12) | 0;
  HEAP32[i1 >> 2] = 0;
  HEAP32[i1 + 4 >> 2] = 0;
  HEAP32[i1 + 8 >> 2] = 0;
  HEAP32[i1 >> 2] = i1 + 4;
  HEAP32[14817] = i1;
 }
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 42919 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 41025 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 47223 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNK4wasm7Literal13truncateToI32Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if ((HEAP32[i2 >> 2] | 0) == 2) {
  i2 = HEAP32[i2 + 8 >> 2] | 0;
  HEAP32[i1 >> 2] = 1;
  HEAP32[i1 + 8 >> 2] = i2;
  return;
 } else ___assert_fail(22338, 19526, 387, 28547);
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitUnaryEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitStoreEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitConstEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitBreakEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitBlockEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_19DeadCodeEliminationEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 44063 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 HEAP8[i2 + 28 >> 0] = 1;
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm13WasmValidator7visitIfEPNS_2IfE(i2, __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm11make_uniqueINS_6ImportEJEEENSt3__210unique_ptrIT_NS2_14default_deleteIS4_EEEEDpOT0_() {
 var i1 = 0;
 i1 = __Znwj(16) | 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 return i1 | 0;
}

function __ZL8abort_onN6cashew3RefE(i1) {
 i1 = i1 | 0;
 __ZN6cashew5Value9stringifyERNSt3__213basic_ostreamIcNS1_11char_traitsIcEEEEb(HEAP32[i1 >> 2] | 0, 60976, 0);
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c(60976, 10) | 0;
 _abort();
}

function __ZNKSt3__27codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_j(i5, i1, i2, i3, i4) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 return __ZNSt3__2L20utf8_to_utf16_lengthEPKhS1_jmNS_12codecvt_modeE(i2, i3, i4, 1114111, 0) | 0;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE11doVisitLoopEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE11doVisitLoadEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE11doVisitHostEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE11doVisitCallEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm2If8finalizeEv(i2) {
 i2 = i2 | 0;
 var i1 = 0, i3 = 0;
 i1 = HEAP32[i2 + 16 >> 2] | 0;
 if (i1 | 0) {
  i3 = HEAP32[(HEAP32[i2 + 12 >> 2] | 0) + 4 >> 2] | 0;
  HEAP32[i2 + 4 >> 2] = (i3 | 0) != 5 ? i3 : HEAP32[i1 + 4 >> 2] | 0;
 }
 return;
}

function __ZN4wasm12toSInteger32Ed(d2) {
 d2 = +d2;
 var i1 = 0;
 if (d2 > -2147483648.0 & d2 < 2147483647.0) i1 = ~~d2; else {
  HEAPF64[tempDoublePtr >> 3] = d2;
  i1 = (HEAP32[tempDoublePtr + 4 >> 2] | 0) < 0 ? -2147483648 : 2147483647;
 }
 return i1 | 0;
}

function __ZN10MixedArenaC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 HEAP32[i1 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 32768;
 i2 = _pthread_self() | 0;
 HEAP32[i1 + 20 >> 2] = i2;
 HEAP32[i1 + 24 >> 2] = 0;
 return;
}

function __ZNKSt3__27codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_j(i5, i1, i2, i3, i4) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 return __ZNSt3__2L19utf8_to_ucs4_lengthEPKhS1_jmNS_12codecvt_modeE(i2, i3, i4, 1114111, 0) | 0;
}

function __ZNKSt3__25ctypeIwE5do_isEtw(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (i1 >>> 0 < 128) {
  i3 = ___ctype_b_loc() | 0;
  i1 = (HEAP16[(HEAP32[i3 >> 2] | 0) + (i1 << 1) >> 1] & i2) << 16 >> 16 != 0;
 } else i1 = 0;
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __Znwj(8) | 0;
 HEAP32[i2 >> 2] = 4500;
 HEAP32[i2 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __Znwj(8) | 0;
 HEAP32[i2 >> 2] = 4588;
 HEAP32[i2 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7__cloneEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __Znwj(8) | 0;
 HEAP32[i2 >> 2] = 4544;
 HEAP32[i2 + 4 >> 2] = HEAP32[i1 + 4 >> 2];
 return i2 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 34405 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 36793 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN6cashew5ValueixEj(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 2) return __ZNSt3__26vectorIN6cashew3RefENS_9allocatorIS2_EEE2atEj(HEAP32[i1 + 8 >> 2] | 0, i2) | 0; else ___assert_fail(48262, 48272, 474, 57296);
 return 0;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm6Vacuum10visitBlockEPNS_5BlockE(i2, __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 HEAP8[i2 + 29 >> 0] = 1;
 return;
}

function __ZTv0_n12_NSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0);
 return;
}

function __ZTv0_n12_NSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63448) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63440) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63432) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63424) | 0);
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE10doVisitNopEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN12_GLOBAL__N_114__libcpp_nmstrD2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i3 = (HEAP32[i1 >> 2] | 0) + -4 | 0;
 i2 = HEAP32[i3 >> 2] | 0;
 HEAP32[i3 >> 2] = i2 + -1;
 if ((i2 + -1 | 0) < 0) __ZdlPv((HEAP32[i1 >> 2] | 0) + -12 | 0);
 return;
}

function __GLOBAL__sub_I_wasm_js_cpp() {
 HEAP32[14804] = 0;
 HEAP32[14805] = 0;
 HEAP32[14806] = 0;
 ___cxa_atexit(280, 59216, ___dso_handle | 0) | 0;
 __ZN6cashew7IString3setEPKcb(59228, 17268, 1);
 __ZN6cashew7IString3setEPKcb(59232, 17273, 1);
 return;
}

function __ZNSt3__26locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63384) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63376) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63368) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(62556) | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_17RemoveUnusedNamesEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZTv0_n12_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0);
 return;
}

function __ZTv0_n12_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61744) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61736) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61728) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61704) | 0);
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE9doVisitIfEPS4_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 36296 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN4wasm8Function12tryLocalNameEj(i3, i2) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i3 + 40 >> 2] | 0;
 if ((HEAP32[i3 + 44 >> 2] | 0) - i1 >> 2 >>> 0 > i2 >>> 0) return HEAP32[i1 + (i2 << 2) >> 2] | 0; else return 0;
 return 0;
}

function __ZN4wasm4Host8finalizeEv(i1) {
 i1 = i1 | 0;
 switch (HEAP32[i1 + 8 >> 2] | 0) {
 case 3:
 case 1:
 case 0:
  {
   HEAP32[i1 + 4 >> 2] = 1;
   break;
  }
 case 2:
  {
   HEAP32[i1 + 4 >> 2] = 1;
   break;
  }
 default:
  _abort();
 }
 return;
}

function __ZN4wasm15SetLocalRemover13visitSetLocalEPNS_8SetLocalE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!(HEAP32[(HEAP32[HEAP32[i2 + 44 >> 2] >> 2] | 0) + (HEAP32[i1 + 8 >> 2] << 2) >> 2] | 0)) HEAP32[i2 + 20 >> 2] = HEAP32[i1 + 12 >> 2];
 return;
}

function __ZN4wasm14EffectAnalyzer14hasSideEffectsEv(i1) {
 i1 = i1 | 0;
 if (((HEAP8[i1 + 29 >> 0] | 0) == 0 ? (HEAP32[i1 + 52 >> 2] | 0) == 0 : 0) ? (HEAP8[i1 + 57 >> 0] | 0) == 0 : 0) i1 = (HEAP8[i1 + 28 >> 0] | 0) != 0; else i1 = 1;
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_15RemoveUnusedBrsEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_15MinifiedPrinterEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE7__cloneEPNS0_6__baseIS7_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4500;
 HEAP32[i1 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7__cloneEPNS0_6__baseIS7_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4588;
 HEAP32[i1 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7__cloneEPNS0_6__baseIS7_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4544;
 HEAP32[i1 + 4 >> 2] = HEAP32[i2 + 4 >> 2];
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 44718 ? i2 + 4 | 0 : 0) | 0;
}

function __ZN6cashew5Value4sizeEv(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 2) {
  i1 = HEAP32[i1 + 8 >> 2] | 0;
  return (HEAP32[i1 + 4 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) >> 2 | 0;
 } else ___assert_fail(48262, 48272, 458, 18701);
 return 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_14SimplifyLocalsEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_14PostEmscriptenEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_14CoalesceLocalsEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function ___stdio_close(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i3 = i2;
 HEAP32[i3 >> 2] = HEAP32[i1 + 60 >> 2];
 i1 = ___syscall_ret(___syscall6(6, i3 | 0) | 0) | 0;
 STACKTOP = i2;
 return i1 | 0;
}

function __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 return __ZNSt3__224__put_character_sequenceIcNS_11char_traitsIcEEEERNS_13basic_ostreamIT_T0_EES7_PKS4_j(i1, i2, _strlen(i2) | 0) | 0;
}

function __ZNK4wasm7Literal14reinterpreti64Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 4) {
  i1 = i1 + 8 | 0;
  tempRet0 = HEAP32[i1 + 4 >> 2] | 0;
  return HEAP32[i1 >> 2] | 0;
 } else ___assert_fail(28667, 19526, 233, 28689);
 return 0;
}

function __ZNK11ArenaVectorIPN4wasm10ExpressionEEixEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if ((HEAP32[i2 + 8 >> 2] | 0) >>> 0 > i1 >>> 0) return (HEAP32[i2 + 4 >> 2] | 0) + (i1 << 2) | 0; else ___assert_fail(19130, 34204, 181, 57296);
 return 0;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 HEAP8[i2 + 28 >> 0] = 1;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_13ReorderLocalsEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNKSt3__27codecvtIwc11__mbstate_tE13do_max_lengthEv(i1) {
 i1 = i1 | 0;
 i1 = HEAP32[i1 + 8 >> 2] | 0;
 if (i1) {
  i1 = _uselocale(i1) | 0;
  if (!i1) i1 = 4; else {
   _uselocale(i1) | 0;
   i1 = 4;
  }
 } else i1 = 1;
 return i1 | 0;
}

function __ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7324;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 HEAP8[i2 + 57 >> 0] = 1;
 return;
}

function __ZN4wasm18CountLeadingZeroesIyEEiT_(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if ((i2 | 0) == 0 & 0 == 0) i1 = (__ZN4wasm18CountLeadingZeroesIjEEiT_(i1) | 0) + 32 | 0; else i1 = __ZN4wasm18CountLeadingZeroesIjEEiT_(i2) | 0;
 return i1 | 0;
}

function dynCall_iiiiiii(i7, i1, i2, i3, i4, i5, i6) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 return FUNCTION_TABLE_iiiiiii[i7 & 63](i1 | 0, i2 | 0, i3 | 0, i4 | 0, i5 | 0, i6 | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function _bitshift64Ashr(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 if ((i1 | 0) < 32) {
  tempRet0 = i2 >> i1;
  return i3 >>> i1 | (i2 & (1 << i1) - 1) << 32 - i1;
 }
 tempRet0 = (i2 | 0) < 0 ? -1 : 0;
 return i2 >> i1 - 32 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7776;
 return;
}

function __ZNK11ArenaVectorIPN4wasm7ElementEEixEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if ((HEAP32[i2 + 8 >> 2] | 0) >>> 0 > i1 >>> 0) return (HEAP32[i2 + 4 >> 2] | 0) + (i1 << 2) | 0; else ___assert_fail(19130, 34204, 181, 57296);
 return 0;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 HEAP8[i2 + 56 >> 0] = 1;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 HEAP8[i2 + 29 >> 0] = 1;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 HEAP8[i2 + 29 >> 0] = 1;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_11MergeBlocksEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_11FullPrinterEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNK11ArenaVectorIPN4wasm10ExpressionEE4backEv(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 + 8 >> 2] | 0;
 if (!i1) ___assert_fail(34187, 34204, 201, 34222); else return (HEAP32[i2 + 4 >> 2] | 0) + (i1 + -1 << 2) | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm6Vacuum7visitIfEPNS_2IfE(i2, __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__27codecvtIwc11__mbstate_tED2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 HEAP32[i1 >> 2] = 14868;
 i1 = i1 + 8 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) != (__ZNSt3__26__clocEv() | 0)) _freelocale(HEAP32[i1 >> 2] | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNK11ArenaVectorIN4wasm4NameEEixEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if ((HEAP32[i2 + 8 >> 2] | 0) >>> 0 > i1 >>> 0) return (HEAP32[i2 + 4 >> 2] | 0) + (i1 << 2) | 0; else ___assert_fail(19130, 34204, 181, 57296);
 return 0;
}

function __ZN4wasm7AddressaSEy(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 if (i2 >>> 0 < 1 | (i2 | 0) == 1 & i1 >>> 0 < 0) {
  HEAP32[i3 >> 2] = i1;
  return i3 | 0;
 } else ___assert_fail(21382, 19526, 103, 57127);
 return 0;
}

function __ZN10MixedArena5allocIN4wasm5StoreEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 28) | 0;
 HEAP32[i1 >> 2] = 12;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 return i1 | 0;
}

function _fprintf(i1, i2, i3) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 var i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4;
 HEAP32[i5 >> 2] = i3;
 i3 = _vfprintf(i1, i2, i5) | 0;
 STACKTOP = i4;
 return i3 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 7324;
 return i1 | 0;
}

function __ZNK4wasm7Literal6geti64Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 2) {
  i1 = i1 + 8 | 0;
  tempRet0 = HEAP32[i1 + 4 >> 2] | 0;
  return HEAP32[i1 >> 2] | 0;
 } else ___assert_fail(22338, 19526, 226, 27747);
 return 0;
}

function __ZN4wasm7Literal9castToI32Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if ((HEAP32[i2 >> 2] | 0) == 3) {
  HEAP32[i1 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
  HEAP32[i1 >> 2] = 1;
  return;
 } else ___assert_fail(28630, 19526, 213, 28773);
}

function __ZN4wasm7Literal9castToF32Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if ((HEAP32[i2 >> 2] | 0) == 1) {
  HEAP32[i1 + 8 >> 2] = HEAP32[i2 + 8 >> 2];
  HEAP32[i1 >> 2] = 3;
  return;
 } else ___assert_fail(22306, 19526, 201, 22328);
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN10MixedArena5allocIN4wasm4LoadEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 24) | 0;
 HEAP32[i1 >> 2] = 11;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 return i1 | 0;
}

function dynCall_iiiiiid(i7, i1, i2, i3, i4, i5, d6) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 d6 = +d6;
 return FUNCTION_TABLE_iiiiiid[i7 & 3](i1 | 0, i2 | 0, i3 | 0, i4 | 0, i5 | 0, +d6) | 0;
}

function __ZNSt3__210unique_ptrIN4wasm10ThreadPoolENS_14default_deleteIS2_EEED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 >> 2] | 0;
 HEAP32[i2 >> 2] = 0;
 if (i1 | 0) {
  __ZN4wasm10ThreadPoolD2Ev(i1);
  __ZdlPv(i1);
 }
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 5672;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function _sscanf(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 var i4 = 0, i5 = 0;
 i4 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i5 = i4;
 HEAP32[i5 >> 2] = i3;
 i3 = _vsscanf(i2, i1, i5) | 0;
 STACKTOP = i4;
 return i3 | 0;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwj(i2, i1, _wcslen(i1) | 0) | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj(i2, i1, _strlen(i1) | 0) | 0;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj(i2, i1, _strlen(i1) | 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 7776;
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 5072;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN10MixedArena5allocIN4wasm4LoopEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 20) | 0;
 HEAP32[i1 >> 2] = 3;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 12 >> 2] = 0;
 return i1 | 0;
}

function _wmemset(i4, i3, i1) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 var i2 = 0;
 if (i1 | 0) {
  i2 = i4;
  while (1) {
   i1 = i1 + -1 | 0;
   HEAP32[i2 >> 2] = i3;
   if (!i1) break; else i2 = i2 + 4 | 0;
  }
 }
 return i4 | 0;
}

function __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeIN4wasm4NameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__25ctypeIcE10do_tolowerEc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (i1 << 24 >> 24 > -1) {
  i2 = ___ctype_tolower_loc() | 0;
  i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + (i1 << 24 >> 24 << 2) >> 2] & 255;
 }
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 23369 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 25037 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE6targetERKSt9type_info(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return ((HEAP32[i1 + 4 >> 2] | 0) == 24883 ? i2 + 4 | 0 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 6216;
 return;
}

function __ZNK11ArenaVectorIN4wasm4NameEE4backEv(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = HEAP32[i2 + 8 >> 2] | 0;
 if (!i1) ___assert_fail(34187, 34204, 201, 34222); else return (HEAP32[i2 + 4 >> 2] | 0) + (i1 + -1 << 2) | 0;
 return 0;
}

function __ZN6cashew10IStringSetD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213__vector_baseIcNS_9allocatorIcEEED2Ev(i1 + 20 | 0);
 __ZNSt3__212__hash_tableIN6cashew7IStringENS_4hashIS2_EENS_8equal_toIS2_EENS_9allocatorIS2_EEED2Ev(i1);
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm14FunctionHasher6hash64Ey(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 + 32 | 0;
 i2 = __ZN4wasm6rehashEjj(__ZN4wasm6rehashEjj(HEAP32[i3 >> 2] | 0, i2) | 0, i1) | 0;
 HEAP32[i3 >> 2] = i2;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function dynCall_viiiiii(i7, i1, i2, i3, i4, i5, i6) {
 i7 = i7 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 FUNCTION_TABLE_viiiiii[i7 & 15](i1 | 0, i2 | 0, i3 | 0, i4 | 0, i5 | 0, i6 | 0);
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm12isUInteger64Ed(d1) {
 d1 = +d1;
 HEAPF64[tempDoublePtr >> 3] = d1;
 if ((HEAP32[tempDoublePtr + 4 >> 2] | 0) < 0) return 0; else return d1 <= 18446744073709551616.0 & (__ZN4wasm9isIntegerEd(d1) | 0) | 0;
 return 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_7PrinterEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 5852;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 5528;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm4NameC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN6cashew7IStringC2EPKcb(i2, (HEAP8[i1 + 11 >> 0] | 0) < 0 ? HEAP32[i1 >> 2] | 0 : i1, 0);
 return;
}

function __ZN4wasm14EffectAnalyzer9checkPostEPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm7VisitorINS_14EffectAnalyzerEvE5visitEPNS_10ExpressionE(i2, i1);
 return __ZN4wasm14EffectAnalyzer11hasAnythingEv(i2) | 0;
}

function __ZN11ArenaVectorIPN4wasm10ExpressionEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 + 12 >> 2] = i1;
 i1 = __ZN10MixedArena10allocSpaceEj(HEAP32[i2 >> 2] | 0, i1 << 2) | 0;
 HEAP32[i2 + 4 >> 2] = i1;
 return;
}

function __ZNKSt3__25ctypeIcE10do_toupperEc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (i1 << 24 >> 24 > -1) {
  i2 = ___ctype_toupper_loc() | 0;
  i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + ((i1 & 255) << 2) >> 2] & 255;
 }
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 6576;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 6396;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7732;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm14EffectAnalyzer14accessesMemoryEv(i1) {
 i1 = i1 | 0;
 if (!(HEAP8[i1 + 29 >> 0] | 0)) {
  i1 = HEAP16[i1 + 56 >> 1] | 0;
  return (i1 & 65535) > 255 | (i1 & 255) << 24 >> 24 != 0 | 0;
 } else return 1;
 return 0;
}

function __ZN4wasm14AstStackHelper9getParentEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i1 = HEAP32[14804] | 0;
 i2 = (HEAP32[14805] | 0) - i1 >> 2;
 if (i2 >>> 0 > 1) i1 = HEAP32[i1 + (i2 + -2 << 2) >> 2] | 0; else i1 = 0;
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZZN4wasm12RegisterPassINS_6VacuumEEC1EPKcS4_ENKUlvE_clEv(i1 + 4 | 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 5672;
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 6940;
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function _bitshift64Shl(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 if ((i1 | 0) < 32) {
  tempRet0 = i2 << i1 | (i3 & (1 << i1) - 1 << 32 - i1) >>> 32 - i1;
  return i3 << i1;
 }
 tempRet0 = i3 << i1 - 32;
 return 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 5072;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm19CountTrailingZeroesIyEEiT_(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if (!i1) i1 = (__ZN4wasm19CountTrailingZeroesIjEEiT_(i2) | 0) + 32 | 0; else i1 = __ZN4wasm19CountTrailingZeroesIjEEiT_(i1) | 0;
 return i1 | 0;
}

function __ZN4wasm12toUInteger32Ed(d2) {
 d2 = +d2;
 var i1 = 0;
 HEAPF64[tempDoublePtr >> 3] = d2;
 if ((HEAP32[tempDoublePtr + 4 >> 2] | 0) >= 0) if (d2 < 4294967295.0) i1 = ~~d2 >>> 0; else i1 = -1; else i1 = 0;
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 968;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 5252;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 5600;
 return;
}

function __ZNK6cashew7IStringltERKS0_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 var i3 = 0;
 i3 = HEAP32[i2 >> 2] | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 return (_strcmp((i3 | 0) == 0 ? 67717 : i3, (i2 | 0) == 0 ? 67717 : i2) | 0) < 0 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement7getNodeEv(i1) {
 i1 = i1 | 0;
 if (!(HEAP8[i1 >> 0] | 0)) ___assert_fail(32061, 31173, 322, 32068); else return HEAP32[i1 + 4 >> 2] | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN11ArenaVectorIPN4wasm7ElementEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 + 12 >> 2] = i1;
 i1 = __ZN10MixedArena10allocSpaceEj(HEAP32[i2 >> 2] | 0, i1 << 2) | 0;
 HEAP32[i2 + 4 >> 2] = i1;
 return;
}

function _abort_message(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 var i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 HEAP32[i3 >> 2] = i2;
 i2 = HEAP32[1961] | 0;
 _vfprintf(i2, i1, i3) | 0;
 _fputc(10, i2) | 0;
 _abort();
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 520;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 6216;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZZN4wasm18ExpressionAnalyzer4hashEPNS_10ExpressionEENKUljE_clEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i2 = HEAP32[i2 >> 2] | 0;
 i1 = __ZN4wasm6rehashEjj(HEAP32[i2 >> 2] | 0, i1) | 0;
 HEAP32[i2 >> 2] = i1;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 1416;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE17ExpressionElement5getOpEv(i1) {
 i1 = i1 | 0;
 if (!(HEAP8[i1 >> 0] | 0)) return HEAP32[i1 + 4 >> 2] | 0; else ___assert_fail(32076, 31173, 326, 32084);
 return 0;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function _bitshift64Lshr(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 if ((i1 | 0) < 32) {
  tempRet0 = i2 >>> i1;
  return i3 >>> i1 | (i2 & (1 << i1) - 1) << 32 - i1;
 }
 tempRet0 = 0;
 return i2 >>> i1 - 32 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__28ios_base6getlocEv(i1) {
 i1 = i1 | 0;
 var i2 = 0, i3 = 0;
 i3 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 i2 = i3;
 __ZNSt3__26localeC2ERKS0_(i2, i1 + 28 | 0);
 STACKTOP = i3;
 return HEAP32[i2 >> 2] | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2424;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 5852;
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 5528;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN10__cxxabiv112_GLOBAL__N_110construct_Ev() {
 var i1 = 0;
 i1 = STACKTOP;
 STACKTOP = STACKTOP + 16 | 0;
 if (!(_pthread_key_create(63604, 303) | 0)) {
  STACKTOP = i1;
  return;
 } else _abort_message(56016, i1);
}

function __ZZN4wasm12RegisterPassINS_26CoalesceLocalsWithLearningEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(148) | 0;
 _memset(i1 | 0, 0, 148) | 0;
 __ZN4wasm26CoalesceLocalsWithLearningC2Ev(i1);
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 1280;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 6576;
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 6396;
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 7732;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN11ArenaVectorIN4wasm4NameEE8allocateEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 + 12 >> 2] = i1;
 i1 = __ZN10MixedArena10allocSpaceEj(HEAP32[i2 >> 2] | 0, i1 << 2) | 0;
 HEAP32[i2 + 4 >> 2] = i1;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 1880;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 1552;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2344;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2560;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 5484;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 6940;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm20OptimizeInstructionsC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 5812;
 HEAP32[i1 + 16 >> 2] = 5840;
 return;
}

function __ZN4wasm12isUInteger32Ed(d1) {
 d1 = +d1;
 HEAPF64[tempDoublePtr >> 3] = d1;
 if ((HEAP32[tempDoublePtr + 4 >> 2] | 0) < 0) return 0; else return d1 <= 4294967295.0 & (__ZN4wasm9isIntegerEd(d1) | 0) | 0;
 return 0;
}

function __GLOBAL__sub_I_CoalesceLocals_cpp() {
 __ZN4wasm12RegisterPassINS_14CoalesceLocalsEEC2EPKcS4_(65641, 47052, 47068);
 __ZN4wasm12RegisterPassINS_26CoalesceLocalsWithLearningEEC2EPKcS4_(65642, 47282, 47307);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__27codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_j(i5, i1, i3, i2, i4) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 i4 = i4 | 0;
 i5 = i2 - i3 | 0;
 return (i5 >>> 0 < i4 >>> 0 ? i5 : i4) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2072;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 7144;
 return;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 5252;
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 5600;
 return i1 | 0;
}

function __ZN4wasm8PopCountIjEEiT_(i1) {
 i1 = i1 | 0;
 i1 = i1 - (i1 >>> 1 & 1431655765) | 0;
 i1 = (i1 >>> 2 & 858993459) + (i1 & 858993459) | 0;
 return (Math_imul((i1 >>> 4) + i1 & 252645135, 16843009) | 0) >>> 24 | 0;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__26locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63488) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63496) | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN6cashew3RefeqERKNS_7IStringE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 if (!(HEAP32[i1 >> 2] | 0)) i1 = (HEAP32[i1 + 8 >> 2] | 0) == (HEAP32[i2 >> 2] | 0); else i1 = 0;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__26locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63480) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63472) | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__26locale9use_facetERNS0_2idE(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 i2 = __ZNSt3__26locale2id5__getEv(i2) | 0;
 return HEAP32[(HEAP32[i1 + 8 >> 2] | 0) + (i2 << 2) >> 2] | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 712;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function runPostSets() {}
function _i64Subtract(i1, i2, i3, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i4 = i2 - i4 - (i3 >>> 0 > i1 >>> 0 | 0) >>> 0;
 return (tempRet0 = i4, i1 - i3 >>> 0 | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm28DuplicateFunctionEliminationC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm4PassC2Ev(i1);
 HEAP32[i1 >> 2] = 7368;
 HEAP32[i1 + 20 >> 2] = 0;
 HEAP32[i1 + 24 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = i1 + 20;
 return;
}

function dynCall_iiiiii(i6, i1, i2, i3, i4, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 return FUNCTION_TABLE_iiiiii[i6 & 31](i1 | 0, i2 | 0, i3 | 0, i4 | 0, i5 | 0) | 0;
}

function __ZNSt3__26locale5__imp11make_globalEv() {
 var i1 = 0;
 i1 = __ZNSt3__26locale7classicEv() | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 HEAP32[15878] = i1;
 __ZNSt3__214__shared_count12__add_sharedEv(i1);
 return 63512;
}

function __ZNKSt3__25ctypeIwE10do_toupperEw(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (i1 >>> 0 < 128) {
  i2 = ___ctype_toupper_loc() | 0;
  i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + (i1 << 2) >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNKSt3__25ctypeIwE10do_tolowerEw(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (i1 >>> 0 < 128) {
  i2 = ___ctype_tolower_loc() | 0;
  i1 = HEAP32[(HEAP32[i2 >> 2] | 0) + (i1 << 2) >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 5484;
 return i1 | 0;
}

function __ZN6cashew6ParserINS_3RefENS_19DotZeroValueBuilderEE7isSpaceEc(i1) {
 i1 = i1 | 0;
 i1 = i1 + -9 << 24 >> 24;
 if ((i1 & 255) < 24) return (8388627 >>> (i1 & 255) & 1 | 0) != 0 | 0; else return 0;
 return 0;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BlockEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(8) | 0;
 HEAP32[i1 >> 2] = 7144;
 return i1 | 0;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm11MergeBlocks13visitSetLocalEPNS_8SetLocalE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i1 + 12 | 0, 0, 0, 0) | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2208;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__26locale8__globalEv() {
 if ((HEAP8[59200] | 0) == 0 ? ___cxa_guard_acquire(59200) | 0 : 0) {
  __ZNSt3__26locale5__imp11make_globalEv() | 0;
  HEAP32[15879] = 63512;
 }
 return HEAP32[15879] | 0;
}

function __ZNSt3__26locale7classicEv() {
 if ((HEAP8[59032] | 0) == 0 ? ___cxa_guard_acquire(59032) | 0 : 0) {
  __ZNSt3__26locale5__imp12make_classicEv() | 0;
  HEAP32[15877] = 63504;
 }
 return HEAP32[15877] | 0;
}

function __ZNSt3__26locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63416) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63408) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63400) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63392) | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm7AddressC2Ey(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP32[i3 >> 2] = i1;
 if (i2 >>> 0 < 1 | (i2 | 0) == 1 & i1 >>> 0 < 0) return; else ___assert_fail(21382, 19526, 100, 21425);
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm15SetLocalRemoverC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 6860;
 HEAP32[i1 + 16 >> 2] = 6888;
 return;
}

function __ZN4wasm15GetLocalCounterC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 6768;
 HEAP32[i1 + 16 >> 2] = 6796;
 return;
}

function __ZNSt3__26localeC2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = __ZNSt3__26locale8__globalEv() | 0;
 i2 = HEAP32[i2 >> 2] | 0;
 HEAP32[i1 >> 2] = i2;
 __ZNSt3__214__shared_count12__add_sharedEv(i2);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6SelectEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN10MixedArena5allocIN4wasm6ReturnEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 12) | 0;
 HEAP32[i1 >> 2] = 17;
 HEAP32[i1 + 8 >> 2] = 0;
 HEAP32[i1 + 4 >> 2] = 5;
 return i1 | 0;
}

function __ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0);
 return;
}

function __ZNSt3__26__clocEv() {
 var i1 = 0;
 if ((HEAP8[58552] | 0) == 0 ? ___cxa_guard_acquire(58552) | 0 : 0) {
  i1 = _newlocale(2147483647, 53279, 0) | 0;
  HEAP32[15425] = i1;
 }
 return HEAP32[15425] | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm14PostEmscriptenC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 6536;
 HEAP32[i1 + 16 >> 2] = 6564;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5StoreEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5ConstEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_5BreakEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm11MergeBlocks11visitReturnEPNS_6ReturnE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i1 + 8 | 0, 0, 0, 0) | 0;
 return;
}

function dynCall_iiiiid(i6, i1, i2, i3, i4, d5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 d5 = +d5;
 return FUNCTION_TABLE_iiiiid[i6 & 7](i1 | 0, i2 | 0, i3 | 0, i4 | 0, +d5) | 0;
}

function __ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0);
 return;
}

function __ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0);
 return;
}

function __ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0);
 return;
}

function __ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm11MergeBlocks10visitUnaryEPNS_5UnaryE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i1 + 12 | 0, 0, 0, 0) | 0;
 return;
}

function __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4LoadEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4HostEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_4CallEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_2IfEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm19DeadCodeElimination18doAfterIfConditionEPS0_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26vectorIbNS_9allocatorIbEEE9push_backERKb(i2 + 72 | 0, i2 + 44 | 0);
 return;
}

function __ZN10MixedArena5allocIN4wasm2IfEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 20) | 0;
 HEAP32[i1 >> 2] = 2;
 HEAP32[i1 + 4 >> 2] = 0;
 HEAP32[i1 + 16 >> 2] = 0;
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEEclEv(i1) {
 i1 = i1 | 0;
 return __ZN4wasm17WasmBinaryBuilder7getInt8Ev(HEAP32[i1 + 4 >> 2] | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEEclEv(i1) {
 i1 = i1 | 0;
 return __ZN4wasm17WasmBinaryBuilder7getInt8Ev(HEAP32[i1 + 4 >> 2] | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEEclEv(i1) {
 i1 = i1 | 0;
 return __ZN4wasm17WasmBinaryBuilder7getInt8Ev(HEAP32[i1 + 4 >> 2] | 0) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm19CountTrailingZeroesIjEEiT_(i1) {
 i1 = i1 | 0;
 if (!i1) i1 = 32; else {
  i1 = 48511 + ((Math_imul(i1 & 0 - i1, 125613361) | 0) >>> 27) | 0;
  i1 = HEAPU8[i1 >> 0] | 0;
 }
 return i1 | 0;
}

function __ZThn8_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1 + -8 | 0);
 return;
}

function __ZThn8_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev(i1 + -8 | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_8numpunctIwEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61720) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_8numpunctIcEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61692) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_8messagesIwEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63464) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_8messagesIcEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(63456) | 0);
 return;
}

function __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm10Expression4castINS_3NopEEEPT_v(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZN4wasm11MergeBlocks9visitLoadEPNS_4LoadE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN4wasm11MergeBlocks8optimizeEPNS_10ExpressionERS2_PNS_5BlockEPS2_S6_(i2, i1, i1 + 20 | 0, 0, 0, 0) | 0;
 return;
}

function __ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__26locale5__imp7installINS_7collateIwEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61672) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_7collateIcEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61664) | 0);
 return;
}

function __ZN6cashew7IStringC2EPKcb(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!i2) ___assert_fail(18621, 18623, 63, 18658); else {
  __ZN6cashew7IString3setEPKcb(i3, i2, i1);
  return;
 }
}

function __ZN4wasm12PassRegistry8PassInfoD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28functionIFPN4wasm4PassEvEED2Ev(i1 + 16 | 0);
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1);
 return;
}

function __ZN4wasm11MergeBlocksC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEEC2Ev(i1);
 HEAP32[i1 >> 2] = 5416;
 HEAP32[i1 + 16 >> 2] = 5444;
 return;
}

function dynCall_viiiii(i6, i1, i2, i3, i4, i5) {
 i6 = i6 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 FUNCTION_TABLE_viiiii[i6 & 3](i1 | 0, i2 | 0, i3 | 0, i4 | 0, i5 | 0);
}

function __ZNSt3__26locale5__imp7installINS_5ctypeIwEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61712) | 0);
 return;
}

function __ZNSt3__26locale5__imp7installINS_5ctypeIcEEEEvPT_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZNSt3__26locale5__imp7installEPNS0_5facetEl(i2, i1, __ZNSt3__26locale2id5__getEv(61680) | 0);
 return;
}

function __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE(i1, HEAP32[i1 + 4 >> 2] | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm8Function12getNumLocalsEv(i1) {
 i1 = i1 | 0;
 return ((HEAP32[i1 + 24 >> 2] | 0) - (HEAP32[i1 + 20 >> 2] | 0) >> 2) + ((HEAP32[i1 + 12 >> 2] | 0) - (HEAP32[i1 + 8 >> 2] | 0) >> 2) | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZZN4wasm12RegisterPassINS_14SimplifyLocalsEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(132) | 0;
 _memset(i1 | 0, 0, 132) | 0;
 __ZN4wasm14SimplifyLocalsC2Ev(i1);
 return i1 | 0;
}

function __ZZN4wasm12RegisterPassINS_14CoalesceLocalsEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(148) | 0;
 _memset(i1 | 0, 0, 148) | 0;
 __ZN4wasm14CoalesceLocalsC2Ev(i1);
 return i1 | 0;
}

function __ZZ11instantiateEN19JSExternalInterface10growMemoryEN4wasm7AddressES1_(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 _emscripten_asm_const_ii(31, HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm17WasmBinaryBuilder11getWasmTypeEv(i1) {
 i1 = i1 | 0;
 i1 = __ZN4wasm17WasmBinaryBuilder7getInt8Ev(i1) | 0;
 if ((i1 & 255) < 5) return i1 << 24 >> 24 | 0; else _abort();
 return 0;
}

function __ZNKSt3__210moneypunctIwLb1EE13do_pos_formatEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP8[i1 >> 0] = 2;
 HEAP8[i1 + 1 >> 0] = 3;
 HEAP8[i1 + 2 >> 0] = 0;
 HEAP8[i1 + 3 >> 0] = 4;
 return;
}

function __ZNKSt3__210moneypunctIwLb1EE13do_neg_formatEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP8[i1 >> 0] = 2;
 HEAP8[i1 + 1 >> 0] = 3;
 HEAP8[i1 + 2 >> 0] = 0;
 HEAP8[i1 + 3 >> 0] = 4;
 return;
}

function __ZNKSt3__210moneypunctIwLb0EE13do_pos_formatEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP8[i1 >> 0] = 2;
 HEAP8[i1 + 1 >> 0] = 3;
 HEAP8[i1 + 2 >> 0] = 0;
 HEAP8[i1 + 3 >> 0] = 4;
 return;
}

function __ZNKSt3__210moneypunctIwLb0EE13do_neg_formatEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP8[i1 >> 0] = 2;
 HEAP8[i1 + 1 >> 0] = 3;
 HEAP8[i1 + 2 >> 0] = 0;
 HEAP8[i1 + 3 >> 0] = 4;
 return;
}

function __ZNKSt3__210moneypunctIcLb1EE13do_pos_formatEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP8[i1 >> 0] = 2;
 HEAP8[i1 + 1 >> 0] = 3;
 HEAP8[i1 + 2 >> 0] = 0;
 HEAP8[i1 + 3 >> 0] = 4;
 return;
}

function __ZNKSt3__210moneypunctIcLb1EE13do_neg_formatEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP8[i1 >> 0] = 2;
 HEAP8[i1 + 1 >> 0] = 3;
 HEAP8[i1 + 2 >> 0] = 0;
 HEAP8[i1 + 3 >> 0] = 4;
 return;
}

function __ZNKSt3__210moneypunctIcLb0EE13do_pos_formatEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP8[i1 >> 0] = 2;
 HEAP8[i1 + 1 >> 0] = 3;
 HEAP8[i1 + 2 >> 0] = 0;
 HEAP8[i1 + 3 >> 0] = 4;
 return;
}

function __ZNKSt3__210moneypunctIcLb0EE13do_neg_formatEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 HEAP8[i1 >> 0] = 2;
 HEAP8[i1 + 1 >> 0] = 3;
 HEAP8[i1 + 2 >> 0] = 0;
 HEAP8[i1 + 3 >> 0] = 4;
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEEN10__cxxabiv112_GLOBAL__N_112malloc_allocIcEEED2Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP8[i1 + 11 >> 0] | 0) < 0) _free(HEAP32[i1 >> 2] | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__27codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_(i3, i1, i4, i2, i5) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 HEAP32[i5 >> 2] = i4;
 return 3;
}

function __ZNKSt3__27codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_(i3, i1, i4, i2, i5) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 HEAP32[i5 >> 2] = i4;
 return 3;
}

function __ZN6cashew5Value9setStringERKNS_7IStringE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 __ZN6cashew5Value4freeEv(i2);
 HEAP32[i2 >> 2] = 0;
 HEAP32[i2 + 8 >> 2] = HEAP32[i1 >> 2];
 return i2 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__27codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_(i3, i1, i4, i2, i5) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i5 = i5 | 0;
 HEAP32[i5 >> 2] = i4;
 return 3;
}

function __ZN4wasm14SimplifyLocals12SinkableInfoC2EOS1_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
 __ZN4wasm14EffectAnalyzerC2EOS0_(i2 + 4 | 0, i1 + 4 | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2432;
}

function __ZN4wasm6Memory7SegmentC2ERKS1_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = HEAP32[i1 >> 2];
 __ZNSt3__26vectorIcNS_9allocatorIcEEEC2ERKS3_(i2 + 4 | 0, i1 + 4 | 0);
 return;
}

function __ZN4wasm19DeadCodeElimination13visitFunctionEPNS_8FunctionE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 if (!(HEAP32[i2 + 56 >> 2] | 0)) return; else ___assert_fail(33251, 33179, 344, 43601);
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2624;
}

function __ZNK4wasm7Literal14reinterpretf64Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 2) return +(+HEAPF64[i1 + 8 >> 3]); else ___assert_fail(22338, 19526, 235, 25134);
 return +(0.0);
}

function __ZNK4wasm7Literal14reinterpretf32Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 1) return +(+HEAPF32[i1 + 8 >> 2]); else ___assert_fail(22306, 19526, 234, 25095);
 return +(0.0);
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 392;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 368;
}

function __ZN10MixedArena5allocIN4wasm11UnreachableEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 8) | 0;
 HEAP32[i1 >> 2] = 20;
 HEAP32[i1 + 4 >> 2] = 5;
 return i1 | 0;
}

function ___strdup(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i2 = (_strlen(i3) | 0) + 1 | 0;
 i1 = _malloc(i2) | 0;
 if (!i1) i1 = 0; else _memcpy(i1 | 0, i3 | 0, i2 | 0) | 0;
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 336;
}

function __ZN6cashew11isIdentInitEc(i1) {
 i1 = i1 | 0;
 if ((i1 + -97 & 255) < 26) return 1; else return i1 << 24 >> 24 == 36 | (i1 << 24 >> 24 == 95 | (i1 + -65 & 255) < 26) | 0;
 return 0;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm15MinifiedPrinterD0Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN10MixedArena5allocIN4wasm8SetLocalEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 16) | 0;
 HEAP32[i1 >> 2] = 10;
 HEAP32[i1 + 4 >> 2] = 0;
 return i1 | 0;
}

function dynCall_iiiii(i5, i1, i2, i3, i4) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 return FUNCTION_TABLE_iiiii[i5 & 7](i1 | 0, i2 | 0, i3 | 0, i4 | 0) | 0;
}

function __ZZN4wasm12RegisterPassINS_15MinifiedPrinterEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(20) | 0;
 __ZN4wasm7PrinterC2Ev(i1);
 HEAP32[i1 >> 2] = 5572;
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNK4wasm7Literal14reinterpreti32Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 3) return HEAP32[i1 + 8 >> 2] | 0; else ___assert_fail(28630, 19526, 232, 28652);
 return 0;
}

function __ZN10MixedArena5allocIN4wasm8GetLocalEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 12) | 0;
 HEAP32[i1 >> 2] = 9;
 HEAP32[i1 + 4 >> 2] = 0;
 return i1 | 0;
}

function _i64Add(i1, i2, i3, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i3 = i1 + i3 >>> 0;
 return (tempRet0 = i2 + i4 + (i3 >>> 0 < i1 >>> 0 | 0) >>> 0, i3 | 0) | 0;
}

function __ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) + 12 | 0);
 return;
}

function __ZNSt3__25ctypeIcED2Ev(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 HEAP32[i2 >> 2] = 14936;
 i1 = HEAP32[i2 + 8 >> 2] | 0;
 if (i1 | 0 ? HEAP8[i2 + 12 >> 0] | 0 : 0) __ZdaPv(i1);
 return;
}

function __ZNSt3__221__thread_specific_ptrINS_15__thread_structEE16__at_thread_exitEPv(i1) {
 i1 = i1 | 0;
 if (i1 | 0) {
  __ZNSt3__215__thread_structD2Ev(i1);
  __ZdlPv(i1);
 }
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 992;
}

function __ZN4wasm7ElementixEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i2 = __ZNK11ArenaVectorIPN4wasm7ElementEEixEj(__ZN4wasm7Element4listEv(i2) | 0, i1) | 0;
 return HEAP32[i2 >> 2] | 0;
}

function __ZN10MixedArena5allocIN4wasm6SelectEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 20) | 0;
 HEAP32[i1 >> 2] = 16;
 HEAP32[i1 + 4 >> 2] = 0;
 return i1 | 0;
}

function __ZN10MixedArena5allocIN4wasm6BinaryEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 20) | 0;
 HEAP32[i1 >> 2] = 15;
 HEAP32[i1 + 4 >> 2] = 0;
 return i1 | 0;
}

function __ZNKSt3__28numpunctIwE11do_groupingEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i1, i2 + 16 | 0);
 return;
}

function __ZNKSt3__28numpunctIcE11do_groupingEv(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_(i1, i2 + 12 | 0);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 544;
}

function __ZN4wasm14FunctionHasher4hashEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i2 = i2 + 32 | 0;
 i1 = __ZN4wasm6rehashEjj(HEAP32[i2 >> 2] | 0, i1) | 0;
 HEAP32[i2 >> 2] = i1;
 return;
}

function __ZN4wasm11FullPrinterD0Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm10Expression4castINS_12CallIndirectEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 8) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_11UnreachableEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 20) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN10MixedArena5allocIN4wasm5UnaryEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 16) | 0;
 HEAP32[i1 >> 2] = 14;
 HEAP32[i1 + 4 >> 2] = 0;
 return i1 | 0;
}

function __ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0);
 return;
}

function __ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) + 4 | 0);
 return;
}

function __ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) + 8 | 0);
 return;
}

function __ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + (HEAP32[(HEAP32[i1 >> 2] | 0) + -12 >> 2] | 0) + 8 | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 1440;
}

function __ZNK4wasm7Literal6getf64Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 4) return +(+HEAPF64[i1 + 8 >> 3]); else ___assert_fail(28667, 19526, 228, 29516);
 return +(0.0);
}

function __ZNK4wasm7Literal6getf32Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 3) return +(+HEAPF32[i1 + 8 >> 2]); else ___assert_fail(28630, 19526, 227, 29509);
 return +(0.0);
}

function __ZZN4wasm12RegisterPassINS_11FullPrinterEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(20) | 0;
 __ZN4wasm7PrinterC2Ev(i1);
 HEAP32[i1 >> 2] = 5644;
 return i1 | 0;
}

function __ZNSt3__210__time_putD2Ev(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if ((i2 | 0) != (__ZNSt3__26__clocEv() | 0)) _freelocale(HEAP32[i1 >> 2] | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm10Expression4castINS_10CallImportEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 7) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 1304;
}

function __ZN4wasm20OptimizeInstructionsD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN10MixedArena5allocIN4wasm3NopEEEPT_v(i1) {
 i1 = i1 | 0;
 i1 = __ZN10MixedArena10allocSpaceEj(i1, 8) | 0;
 HEAP32[i1 >> 2] = 19;
 HEAP32[i1 + 4 >> 2] = 0;
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 816;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 1904;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 1576;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2600;
}

function __ZN6cashew12ValueBuilder13makeRawStringERKNS_7IStringE(i1) {
 i1 = i1 | 0;
 return __ZN6cashew5Value9setStringERKNS_7IStringE(__ZN6cashew5Arena5allocEv(59672) | 0, i1) | 0;
}

function __ZN4wasm10Expression4castINS_8SetLocalEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 10) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function b11(i1, i2, i3, i4, i5, i6, i7, i8) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 i8 = i8 | 0;
 abort(11);
 return 0;
}

function __ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2096;
}

function __ZN4wasm7PrinterD0Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm10Expression4castINS_8GetLocalEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 9) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZNSt3__26localeC2ERKS0_(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 HEAP32[i2 >> 2] = i1;
 __ZNSt3__214__shared_count12__add_sharedEv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN6cashew5Value8getArrayEv(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 2) return HEAP32[i1 + 8 >> 2] | 0; else ___assert_fail(48262, 48272, 220, 31152);
 return 0;
}

function __ZN4wasm10Expression4castINS_6SelectEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 16) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_6ReturnEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 17) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_6BinaryEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 15) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNK4wasm7Literal6geti32Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 1) return HEAP32[i1 + 8 >> 2] | 0; else ___assert_fail(22306, 19526, 225, 29502);
 return 0;
}

function __ZN6cashew5Value10getCStringEv(i1) {
 i1 = i1 | 0;
 if (!(HEAP32[i1 >> 2] | 0)) return HEAP32[i1 + 8 >> 2] | 0; else ___assert_fail(18599, 48272, 208, 19053);
 return 0;
}

function __ZN4wasm10Expression4castINS_6SwitchEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 5) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_5UnaryEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 14) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_5StoreEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 12) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_5ConstEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 13) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function dynCall_viiii(i5, i1, i2, i3, i4) {
 i5 = i5 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 FUNCTION_TABLE_viiii[i5 & 15](i1 | 0, i2 | 0, i3 | 0, i4 | 0);
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 736;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 856;
}

function __ZN4wasm4PassD0Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm10Expression4castINS_5BreakEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 4) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_5BlockEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 1) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_4LoadEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 11) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_4HostEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 18) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function _uselocale(i3) {
 i3 = i3 | 0;
 var i1 = 0, i2 = 0;
 i1 = (_pthread_self() | 0) + 180 | 0;
 i2 = HEAP32[i1 >> 2] | 0;
 if (i3 | 0) HEAP32[i1 >> 2] = i3;
 return i2 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm10Expression4castINS_4LoopEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 3) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_4CallEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 6) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZN4wasm10Expression4castINS_3NopEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 19) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function ___syscall_ret(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 if (i1 >>> 0 > 4294963200) {
  i2 = ___errno_location() | 0;
  HEAP32[i2 >> 2] = 0 - i1;
  i1 = -1;
 }
 return i1 | 0;
}

function __ZNSt3__218condition_variable4waitERNS_11unique_lockINS_5mutexEEE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 _pthread_cond_wait(i2 | 0, HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__211char_traitsIcE7compareEPKcS3_j(i2, i3, i1) {
 i2 = i2 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 if (!i1) i1 = 0; else i1 = _memcmp(i2, i3, i1) | 0;
 return i1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function ___errno_location() {
 var i1 = 0;
 if (!(HEAP32[15018] | 0)) i1 = 60116; else {
  i1 = (_pthread_self() | 0) + 64 | 0;
  i1 = HEAP32[i1 >> 2] | 0;
 }
 return i1 | 0;
}

function __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP8[i1 + 8 + 3 >> 0] | 0) < 0) __ZdlPv(HEAP32[i1 >> 2] | 0);
 return;
}

function __ZN6cashew12ValueBuilder8makeNullEv() {
 var i1 = 0;
 i1 = __ZN6cashew5Arena5allocEv(59672) | 0;
 __ZN6cashew5Value4freeEv(i1);
 HEAP32[i1 >> 2] = 3;
 return i1 | 0;
}

function __ZN4wasm10Expression4castINS_2IfEEEPT_v(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 2) return i1 | 0; else ___assert_fail(19537, 19526, 901, 19568);
 return 0;
}

function __ZNSt3__28numpunctIwED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 15028;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 16 | 0);
 return;
}

function __ZNSt3__28numpunctIcED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 14988;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 12 | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 776;
}

function __ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 2232;
}

function __ZN4wasm15SetLocalRemoverD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm15GetLocalCounterD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__215__thread_structD2Ev(i1) {
 i1 = i1 | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 if (i1 | 0) {
  __ZNSt3__219__thread_struct_impD2Ev(i1);
  __ZdlPv(i1);
 }
 return;
}

function __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1) {
 i1 = i1 | 0;
 if ((HEAP8[i1 + 11 >> 0] | 0) < 0) __ZdlPv(HEAP32[i1 >> 2] | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE18destroy_deallocateEv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm7Element5c_strEv(i1) {
 i1 = i1 | 0;
 if (!(HEAP8[i1 >> 0] | 0)) return HEAP32[i1 + 20 >> 2] | 0; else ___assert_fail(21582, 21446, 95, 21595);
 return 0;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm14PostEmscriptenD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm7Element3strEv(i1) {
 i1 = i1 | 0;
 if (!(HEAP8[i1 >> 0] | 0)) return HEAP32[i1 + 20 >> 2] | 0; else ___assert_fail(21582, 21446, 90, 21591);
 return 0;
}

function __ZN4wasm26CoalesceLocalsWithLearningC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm14CoalesceLocalsC2Ev(i1);
 HEAP32[i1 >> 2] = 7684;
 HEAP32[i1 + 16 >> 2] = 7720;
 return;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED0Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 12100;
 __ZNSt3__26localeD2Ev(i1 + 4 | 0);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED0Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 12036;
 __ZNSt3__26localeD2Ev(i1 + 4 | 0);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN6cashew5Value9getNumberEv(i1) {
 i1 = i1 | 0;
 if ((HEAP32[i1 >> 2] | 0) == 1) return i1 + 8 | 0; else ___assert_fail(18706, 48272, 216, 18717);
 return 0;
}

function __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__210__time_putD2Ev(i1 + 8 | 0);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__210__time_putD2Ev(i1 + 8 | 0);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm8PopCountIyEEiT_(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i1 = __ZN4wasm8PopCountIjEEiT_(i1) | 0;
 return (__ZN4wasm8PopCountIjEEiT_(i2) | 0) + i1 | 0;
}

function __ZNSt3__219__thread_local_dataEv() {
 if ((HEAP8[59208] | 0) == 0 ? ___cxa_guard_acquire(59208) | 0 : 0) _pthread_key_create(63596, 302) | 0;
 return 63596;
}

function __ZN6cashew5Value10getIStringEv(i1) {
 i1 = i1 | 0;
 if (!(HEAP32[i1 >> 2] | 0)) return i1 + 8 | 0; else ___assert_fail(18599, 48272, 212, 18610);
 return 0;
}

function __ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev(i1 + -8 | 0);
 return;
}

function __ZN4wasm11MergeBlocksD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm4PassD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 4632;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__26locale5facet16__on_zero_sharedEv(i1) {
 i1 = i1 | 0;
 if (i1 | 0) FUNCTION_TABLE_vi[HEAP32[(HEAP32[i1 >> 2] | 0) + 4 >> 2] & 511](i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt11logic_errorC2EPKc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 >> 2] = 15452;
 __ZNSt3__218__libcpp_refstringC2EPKc(i2 + 4 | 0, i1);
 return;
}

function __ZN4wasm26CoalesceLocalsWithLearning6createEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(148) | 0;
 __ZN4wasm26CoalesceLocalsWithLearningC2Ev(i1);
 return i1 | 0;
}

function __GLOBAL__sub_I_DuplicateFunctionElimination_cpp() {
 __ZN4wasm12RegisterPassINS_28DuplicateFunctionEliminationEEC2EPKcS4_(65638, 44768, 44799);
 return;
}

function dynCall_iiii(i4, i1, i2, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 return FUNCTION_TABLE_iiii[i4 & 31](i1 | 0, i2 | 0, i3 | 0) | 0;
}

function b0(i1, i2, i3, i4, i5, i6, i7) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 i7 = i7 | 0;
 abort(0);
 return 0;
}

function __ZNSt3__26locale2id6__initEv(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = HEAP32[15422] | 0;
 HEAP32[15422] = i2 + 1;
 HEAP32[i1 + 4 >> 2] = i2 + 1;
 return;
}

function __ZNSt3__211char_traitsIwE4moveEPwPKwj(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 if (i2) i1 = _wmemmove(i1, i3, i2) | 0;
 return i1 | 0;
}

function __ZN4wasm18isInRangeI64TruncUEi(i1) {
 i1 = i1 | 0;
 if (i1 >>> 0 < 1602224128) i1 = 1; else i1 = (i1 | 0) < 0 & i1 >>> 0 < 3212836864;
 return i1 | 0;
}

function __ZN4wasm18isInRangeI64TruncSEi(i1) {
 i1 = i1 | 0;
 if (i1 >>> 0 < 1593835520) i1 = 1; else i1 = (i1 | 0) < 0 & i1 >>> 0 < 3741319169;
 return i1 | 0;
}

function __ZN4wasm18isInRangeI32TruncUEi(i1) {
 i1 = i1 | 0;
 if (i1 >>> 0 < 1333788672) i1 = 1; else i1 = (i1 | 0) < 0 & i1 >>> 0 < 3212836864;
 return i1 | 0;
}

function __ZN4wasm18isInRangeI32TruncSEi(i1) {
 i1 = i1 | 0;
 if (i1 >>> 0 < 1325400064) i1 = 1; else i1 = (i1 | 0) < 0 & i1 >>> 0 < 3472883713;
 return i1 | 0;
}

function __ZN4wasm10ThreadPool9isRunningEv() {
 var i1 = 0;
 i1 = HEAP32[14940] | 0;
 if (!i1) i1 = 0; else i1 = (HEAP8[i1 + 12 >> 0] | 0) != 0;
 return i1 | 0;
}

function __ZNSt3__211char_traitsIwE6assignEPwjw(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 if (i3) i1 = _wmemset(i1, i2, i3) | 0;
 return i1 | 0;
}

function __ZNSt3__211char_traitsIwE4copyEPwPKwj(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 if (i2) i1 = _wmemcpy(i1, i3, i2) | 0;
 return i1 | 0;
}

function _strchr(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i2 = ___strchrnul(i2, i1) | 0;
 return ((HEAP8[i2 >> 0] | 0) == (i1 & 255) << 24 >> 24 ? i2 : 0) | 0;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 200;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 256;
}

function __ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE11target_typeEv(i1) {
 i1 = i1 | 0;
 return 232;
}

function __ZN6cashew11isIdentPartEc(i1) {
 i1 = i1 | 0;
 if (__ZN6cashew11isIdentInitEc(i1) | 0) return 1; else return (i1 + -48 & 255) < 10 | 0;
 return 0;
}

function __ZN4wasm10ThreadPool4sizeEv(i1) {
 i1 = i1 | 0;
 i1 = (HEAP32[i1 + 4 >> 2] | 0) - (HEAP32[i1 >> 2] | 0) >> 2;
 return (i1 >>> 0 > 1 ? i1 : 1) | 0;
}

function __ZThn16_N4wasm26CoalesceLocalsWithLearning6createEv(i1) {
 i1 = i1 | 0;
 return __ZN4wasm26CoalesceLocalsWithLearning6createEv(i1 + -16 | 0) | 0;
}

function __ZZN4wasm12RegisterPassINS_7PrinterEEC1EPKcS4_ENKUlvE_clEv(i1) {
 i1 = i1 | 0;
 i1 = __Znwj(20) | 0;
 __ZN4wasm7PrinterC2Ev(i1);
 return i1 | 0;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 12100;
 __ZNSt3__26localeD2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 12036;
 __ZNSt3__26localeD2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN6cashew12ValueBuilder12makeRawArrayEi(i1) {
 i1 = i1 | 0;
 return __ZN6cashew5Value8setArrayEj(__ZN6cashew5Arena5allocEv(59672) | 0, i1) | 0;
}

function _wcslen(i2) {
 i2 = i2 | 0;
 var i1 = 0;
 i1 = i2;
 while (1) if (!(HEAP32[i1 >> 2] | 0)) break; else i1 = i1 + 4 | 0;
 return i1 - i2 >> 2 | 0;
}

function __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__210__time_putD2Ev(i1 + 8 | 0);
 return;
}

function __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__210__time_putD2Ev(i1 + 8 | 0);
 return;
}

function __ZNSt3__28ios_base33__set_badbit_and_consider_rethrowEv(i1) {
 i1 = i1 | 0;
 i1 = i1 + 16 | 0;
 HEAP32[i1 >> 2] = HEAP32[i1 >> 2] | 1;
 return;
}

function __ZNSt3__25mutex6unlockEv(i1) {
 i1 = i1 | 0;
 if (!(_pthread_mutex_unlock(i1 | 0) | 0)) return; else ___assert_fail(55451, 55459, 48, 55561);
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function dynCall_viii(i4, i1, i2, i3) {
 i4 = i4 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 FUNCTION_TABLE_viii[i4 & 31](i1 | 0, i2 | 0, i3 | 0);
}

function __ZZ11instantiateEN19JSExternalInterface4trapEPKc(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 _emscripten_asm_const_ii(32, i2 | 0) | 0;
 return;
}
function stackAlloc(i1) {
 i1 = i1 | 0;
 var i2 = 0;
 i2 = STACKTOP;
 STACKTOP = STACKTOP + i1 | 0;
 STACKTOP = STACKTOP + 15 & -16;
 return i2 | 0;
}

function ___cxa_guard_acquire(i1) {
 i1 = i1 | 0;
 if ((HEAP8[i1 >> 0] | 0) == 1) i1 = 0; else {
  HEAP8[i1 >> 0] = 1;
  i1 = 1;
 }
 return i1 | 0;
}

function __ZN6cashew3RefntEv(i1) {
 i1 = i1 | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 if (!i1) i1 = 1; else i1 = (HEAP32[i1 >> 2] | 0) == 3;
 return i1 | 0;
}

function ___cxa_is_pointer_type(i1) {
 i1 = i1 | 0;
 if (!i1) i1 = 0; else i1 = (___dynamic_cast(i1, 4104, 4192, 0) | 0) != 0;
 return i1 & 1 | 0;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7destroyEv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm5FatalD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__2lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc(60976, 34477) | 0;
 _exit(1);
}

function __GLOBAL__sub_I_OptimizeInstructions_cpp() {
 __ZN4wasm12RegisterPassINS_20OptimizeInstructionsEEC2EPKcS4_(65629, 36849, 36871);
 return;
}

function __ZNSt3__28ios_base5clearEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 HEAP32[i2 + 16 >> 2] = (HEAP32[i2 + 24 >> 2] | 0) == 0 | i1;
 return;
}

function __ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm28DuplicateFunctionEliminationD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm28DuplicateFunctionEliminationD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 12 | 0);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__214__shared_count12__add_sharedEv(i1) {
 i1 = i1 | 0;
 i1 = i1 + 4 | 0;
 HEAP32[i1 >> 2] = (HEAP32[i1 >> 2] | 0) + 1;
 return;
}

function __ZNKSt3__25ctypeIwE9do_narrowEwc(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 return (i1 >>> 0 < 128 ? i1 & 255 : i2) | 0;
}

function __GLOBAL__sub_I_DeadCodeElimination_cpp() {
 __ZN4wasm12RegisterPassINS_19DeadCodeEliminationEEC2EPKcS4_(65624, 32485, 32489);
 return;
}

function b6(i1, i2, i3, i4, i5, i6) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 abort(6);
 return 0;
}

function _strtoull_l(i4, i3, i1, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = _strtoull(i4, i3, i1) | 0;
 return i4 | 0;
}

function __ZNSt3__211__stdoutbufIwED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__211__stdoutbufIcED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__25ctypeIcE9do_narrowEcc(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 return (i1 << 24 >> 24 > -1 ? i1 : i2) | 0;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6setbufEPwi(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 return i3 | 0;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6setbufEPci(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 return i3 | 0;
}

function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 4 | 0);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 4 | 0);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 8 | 0);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 8 | 0);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__stdinbufIwED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__stdinbufIcED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm14ParseExceptionD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev(i1);
 return;
}

function _strtoll_l(i4, i3, i1, i2) {
 i4 = i4 | 0;
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 i4 = _strtoll(i4, i3, i1) | 0;
 return i4 | 0;
}

function _isxdigit(i1) {
 i1 = i1 | 0;
 if ((i1 + -48 | 0) >>> 0 < 10) i1 = 1; else i1 = ((i1 | 32) + -97 | 0) >>> 0 < 6;
 return i1 & 1 | 0;
}

function __ZN4wasm12isSInteger32Ed(d1) {
 d1 = +d1;
 return d1 <= 2147483647.0 & (d1 >= -2147483648.0 & (__ZN4wasm9isIntegerEd(d1) | 0)) | 0;
}

function b3(i1, i2, i3, i4, i5, d6) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 d6 = +d6;
 abort(3);
 return 0;
}

function __ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + -8 + 12 | 0);
 return;
}

function __ZNSt11logic_errorD2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 15452;
 __ZN12_GLOBAL__N_114__libcpp_nmstrD2Ev(i1 + 4 | 0);
 return;
}

function __ZN4wasm7PrinterC2Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm4PassC2Ev(i1);
 HEAP32[i1 >> 2] = 5456;
 HEAP32[i1 + 16 >> 2] = 60808;
 return;
}

function __GLOBAL__sub_I_RemoveUnusedNames_cpp() {
 __ZN4wasm12RegisterPassINS_17RemoveUnusedNamesEEC2EPKcS4_(65631, 39468, 39488);
 return;
}

function ___udivdi3(i1, i2, i3, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 return ___udivmoddi4(i1, i2, i3, i4, 0) | 0;
}

function __ZNSt3__27codecvtIwc11__mbstate_tED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__27codecvtIwc11__mbstate_tED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv(i1) {
 i1 = i1 | 0;
 ___assert_fail(55721, 55597, 1194, 55750);
}

function __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv(i1) {
 i1 = i1 | 0;
 ___assert_fail(55568, 55597, 1183, 55700);
}

function _strtoll(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = _strtox(i3, i2, i1, 0, -2147483648) | 0;
 return i3 | 0;
}

function __ZN6Colors15outputColorCodeERNSt3__213basic_ostreamIcNS0_11char_traitsIcEEEEPKc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return;
}

function __GLOBAL__sub_I_RemoveUnusedBrs_cpp() {
 __ZN4wasm12RegisterPassINS_15RemoveUnusedBrsEEC2EPKcS4_(65630, 37649, 37667);
 return;
}

function _strtol(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = _strtox(i3, i2, i1, -2147483648, 0) | 0;
 return i3 | 0;
}

function __ZNKSt3__220__vector_base_commonILb1EE20__throw_out_of_rangeEv(i1) {
 i1 = i1 | 0;
 ___assert_fail(55385, 55282, 315, 55750);
}

function __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv(i1) {
 i1 = i1 | 0;
 ___assert_fail(55259, 55282, 304, 55700);
}

function b13(i1, i2, i3, i4, i5, i6) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 i6 = i6 | 0;
 abort(13);
}

function __GLOBAL__sub_I_SimplifyLocals_cpp() {
 __ZN4wasm12RegisterPassINS_14SimplifyLocalsEEC2EPKcS4_(65633, 41084, 41100);
 return;
}

function __GLOBAL__sub_I_PostEmscripten_cpp() {
 __ZN4wasm12RegisterPassINS_14PostEmscriptenEEC2EPKcS4_(65632, 40260, 40276);
 return;
}

function dynCall_iii(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 return FUNCTION_TABLE_iii[i3 & 63](i1 | 0, i2 | 0) | 0;
}

function __ZNSt3__26localeD2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__214__shared_count16__release_sharedEv(HEAP32[i1 >> 2] | 0) | 0;
 return;
}

function __ZNSt3__26vectorIbNS_9allocatorIbEEED2Ev(i1) {
 i1 = i1 | 0;
 i1 = HEAP32[i1 >> 2] | 0;
 if (i1 | 0) __ZdlPv(i1);
 return;
}

function __GLOBAL__sub_I_ReorderLocals_cpp() {
 __ZN4wasm12RegisterPassINS_13ReorderLocalsEEC2EPKcS4_(65635, 42978, 42993);
 return;
}

function __ZNSt3__26locale5__imp12make_classicEv() {
 __ZNSt3__26locale5__impC2Ej(59040, 1);
 HEAP32[15876] = 59040;
 return 63504;
}

function __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 12 | 0);
 return;
}

function _strtoull(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = _strtox(i3, i2, i1, -1, -1) | 0;
 return i3 | 0;
}

function __ZN4wasm26CoalesceLocalsWithLearningD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm14CoalesceLocalsD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__26thread4joinEv(i1) {
 i1 = i1 | 0;
 _pthread_join(HEAP32[i1 >> 2] | 0, 0) | 0;
 HEAP32[i1 >> 2] = 0;
 return;
}

function __ZNSt3__26thread20hardware_concurrencyEv() {
 var i1 = 0;
 i1 = _sysconf(84) | 0;
 return ((i1 | 0) < 0 ? 0 : i1) | 0;
}

function __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 4 | 0);
 return;
}

function __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 8 | 0);
 return;
}

function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1 + 8 | 0);
 return;
}

function __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv(i1) {
 i1 = i1 | 0;
 return 2;
}

function __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv(i1) {
 i1 = i1 | 0;
 return 2;
}

function __GLOBAL__sub_I_MergeBlocks_cpp() {
 __ZN4wasm12RegisterPassINS_11MergeBlocksEEC2EPKcS4_(65625, 33465, 33478);
 return;
}

function b15(i1, i2, i3, i4, i5) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 abort(15);
 return 0;
}

function __ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZN4wasm4Pass8finalizeEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 return;
}

function __ZN4wasm19DeadCodeEliminationD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm19DeadCodeEliminationD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function _mbrlen(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 return _mbrtowc(0, i2, i1, i3 | 0 ? i3 : 60132) | 0;
}

function __ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return;
}

function __ZN6cashew3RefixEj(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 return __ZN6cashew5ValueixEj(HEAP32[i1 >> 2] | 0, i2) | 0;
}

function __ZN4wasm4Pass7prepareEPNS_10PassRunnerEPNS_6ModuleE(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 return;
}

function __ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __GLOBAL__I_000101() {
 __ZNSt3__28ios_base4InitC2Ev(0);
 ___cxa_atexit(289, 67716, ___dso_handle | 0) | 0;
 return;
}

function dynCall_vii(i3, i1, i2) {
 i3 = i3 | 0;
 i1 = i1 | 0;
 i2 = i2 | 0;
 FUNCTION_TABLE_vii[i3 & 1023](i1 | 0, i2 | 0);
}

function __ZNSt3__210__stdinbufIwE9underflowEv(i1) {
 i1 = i1 | 0;
 return __ZNSt3__210__stdinbufIwE9__getcharEb(i1, 0) | 0;
}

function __ZNSt3__210__stdinbufIcE9underflowEv(i1) {
 i1 = i1 | 0;
 return __ZNSt3__210__stdinbufIcE9__getcharEb(i1, 0) | 0;
}

function _wctomb(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if (!i1) i1 = 0; else i1 = _wcrtomb(i1, i2, 0) | 0;
 return i1 | 0;
}

function __ZN4wasm17RemoveUnusedNamesD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm17RemoveUnusedNamesD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function b7(i1, i2, i3, i4, d5) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 d5 = +d5;
 abort(7);
 return 0;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return -1;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return -1;
}

function __ZNSt3__218condition_variable10notify_allEv(i1) {
 i1 = i1 | 0;
 _pthread_cond_broadcast(i1 | 0) | 0;
 return;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8overflowEj(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return -1;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8overflowEi(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return -1;
}

function __ZNSt3__210__stdinbufIwE5uflowEv(i1) {
 i1 = i1 | 0;
 return __ZNSt3__210__stdinbufIwE9__getcharEb(i1, 1) | 0;
}

function __ZNSt3__210__stdinbufIcE5uflowEv(i1) {
 i1 = i1 | 0;
 return __ZNSt3__210__stdinbufIcE9__getcharEb(i1, 1) | 0;
}

function __GLOBAL__sub_I_threads_cpp() {
 HEAP32[14940] = 0;
 ___cxa_atexit(285, 59760, ___dso_handle | 0) | 0;
 return;
}

function __ZN4wasm15RemoveUnusedBrsD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm15RemoveUnusedBrsD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function _strncpy(i1, i3, i2) {
 i1 = i1 | 0;
 i3 = i3 | 0;
 i2 = i2 | 0;
 ___stpncpy(i1, i3, i2) | 0;
 return i1 | 0;
}

function _do_read_421(i2, i1, i3) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 i3 = i3 | 0;
 return ___string_read(i2, i1, i3) | 0;
}

function __ZNSt3__218condition_variable10notify_oneEv(i1) {
 i1 = i1 | 0;
 _pthread_cond_signal(i1 | 0) | 0;
 return;
}

function __ZN4wasm14SimplifyLocalsD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm14SimplifyLocalsD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZN4wasm14CoalesceLocalsD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm14CoalesceLocalsD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __GLOBAL__sub_I_Vacuum_cpp() {
 __ZN4wasm12RegisterPassINS_6VacuumEEC2EPKcS4_(65637, 44121, 44128);
 return;
}

function __ZSt15get_new_handlerv() {
 var i1 = 0;
 i1 = HEAP32[15902] | 0;
 HEAP32[15902] = i1 + 0;
 return i1 | 0;
}

function __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1);
 return;
}

function __ZN4wasm13ReorderLocalsD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm13ReorderLocalsD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function setThrew(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 if (!__THREW__) {
  __THREW__ = i1;
  threwValue = i2;
 }
}

function b2(i1, i2, i3, i4, i5) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 i5 = i5 | 0;
 abort(2);
}

function __Z17prepareMajorColorRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE(i1) {
 i1 = i1 | 0;
 return i1 | 0;
}

function _mbsinit(i1) {
 i1 = i1 | 0;
 if (!i1) i1 = 1; else i1 = (HEAP32[i1 >> 2] | 0) == 0;
 return i1 & 1 | 0;
}

function __ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__26locale5__impD0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__26locale5__impD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__26threadD2Ev(i1) {
 i1 = i1 | 0;
 if (!(HEAP32[i1 >> 2] | 0)) return; else __ZSt9terminatev();
}

function _nearbyintf(d1) {
 d1 = +d1;
 var i2 = 0;
 i2 = _fetestexcept(32) | 0;
 d1 = +_rintf(d1);
 return +d1;
}

function __ZNSt3__28numpunctIwED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28numpunctIwED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__28numpunctIcED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28numpunctIcED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function _strtold_l(i3, i2, i1) {
 i3 = i3 | 0;
 i2 = i2 | 0;
 i1 = i1 | 0;
 return +(+_strtox_17(i3, i2, 2));
}

function __ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function b12(i1, i2, i3, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 abort(12);
 return 0;
}

function _nearbyint(d1) {
 d1 = +d1;
 var i2 = 0;
 i2 = _fetestexcept(32) | 0;
 d1 = +_rint(d1);
 return +d1;
}

function __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED2Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 return;
}

function __ZNSt3__210__function6__baseIFPN4wasm10ExpressionEN6cashew3RefEjEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __Z12prepareColorRNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE(i1) {
 i1 = i1 | 0;
 return i1 | 0;
}

function __ZNSt3__218condition_variableD2Ev(i1) {
 i1 = i1 | 0;
 _pthread_cond_destroy(i1 | 0) | 0;
 return;
}

function __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 return;
}

function __ZNSt3__210__function6__baseIFPN4wasm10ExpressionEN6cashew3RefEEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function _catgets(i1, i4, i2, i3) {
 i1 = i1 | 0;
 i4 = i4 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 return i3 | 0;
}

function __ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function dynCall_ii(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return FUNCTION_TABLE_ii[i2 & 255](i1 | 0) | 0;
}

function ___clang_call_terminate(i1) {
 i1 = i1 | 0;
 ___cxa_begin_catch(i1 | 0) | 0;
 __ZSt9terminatev();
}

function __ZNSt12out_of_rangeD0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt11logic_errorD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__28numpunctIwE16do_thousands_sepEv(i1) {
 i1 = i1 | 0;
 return HEAP32[i1 + 12 >> 2] | 0;
}

function __ZNKSt3__25ctypeIwE8do_widenEc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return i1 << 24 >> 24 | 0;
}

function __ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNSt3__28ios_baseD0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__28ios_baseD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt3__25ctypeIcED0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt3__25ctypeIcED2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNSt11logic_errorD0Ev(i1) {
 i1 = i1 | 0;
 __ZNSt11logic_errorD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__28numpunctIwE16do_decimal_pointEv(i1) {
 i1 = i1 | 0;
 return HEAP32[i1 + 8 >> 2] | 0;
}

function __ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_14FunctionHasherENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNKSt3__28numpunctIcE16do_thousands_sepEv(i1) {
 i1 = i1 | 0;
 return HEAP8[i1 + 9 >> 0] | 0;
}

function __ZNKSt3__28numpunctIcE16do_decimal_pointEv(i1) {
 i1 = i1 | 0;
 return HEAP8[i1 + 8 >> 0] | 0;
}

function __ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function _cleanup_435(i1) {
 i1 = i1 | 0;
 if (!(HEAP32[i1 + 68 >> 2] | 0)) ___unlockfile(i1);
 return;
}

function _cleanup_418(i1) {
 i1 = i1 | 0;
 if (!(HEAP32[i1 + 68 >> 2] | 0)) ___unlockfile(i1);
 return;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9underflowEv(i1) {
 i1 = i1 | 0;
 return -1;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9underflowEv(i1) {
 i1 = i1 | 0;
 return -1;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9showmanycEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9showmanycEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNSt3__210__function6__baseIFN4wasm15ThreadWorkStateEvEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function establishStackSpace(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 STACKTOP = i1;
 STACK_MAX = i2;
}

function __ZNKSt3__210moneypunctIwLb1EE16do_thousands_sepEv(i1) {
 i1 = i1 | 0;
 return 2147483647;
}

function __ZNKSt3__210moneypunctIwLb1EE16do_decimal_pointEv(i1) {
 i1 = i1 | 0;
 return 2147483647;
}

function __ZNKSt3__210moneypunctIwLb0EE16do_thousands_sepEv(i1) {
 i1 = i1 | 0;
 return 2147483647;
}

function __ZNKSt3__210moneypunctIwLb0EE16do_decimal_pointEv(i1) {
 i1 = i1 | 0;
 return 2147483647;
}

function __ZN4wasm6VacuumD0Ev(i1) {
 i1 = i1 | 0;
 __ZN4wasm6VacuumD2Ev(i1);
 __ZdlPv(i1);
 return;
}

function b16(i1, i2, i3, i4) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 i4 = i4 | 0;
 abort(16);
}

function _isspace(i1) {
 i1 = i1 | 0;
 return ((i1 | 0) == 32 | (i1 + -9 | 0) >>> 0 < 5) & 1 | 0;
}

function __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4syncEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4syncEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNKSt3__27codecvtIDsc11__mbstate_tE16do_always_noconvEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNKSt3__27codecvtIDic11__mbstate_tE16do_always_noconvEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function _isdigit_l(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 return (i1 + -48 | 0) >>> 0 < 10 | 0;
}

function __ZNKSt3__27codecvtIwc11__mbstate_tE16do_always_noconvEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNKSt3__27codecvtIcc11__mbstate_tE16do_always_noconvEv(i1) {
 i1 = i1 | 0;
 return 1;
}

function __ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE6createEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function dynCall_vi(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 FUNCTION_TABLE_vi[i2 & 511](i1 | 0);
}

function __ZNSt3__25mutexD2Ev(i1) {
 i1 = i1 | 0;
 _pthread_mutex_destroy(i1 | 0) | 0;
 return;
}

function __ZNSt3__25mutex4lockEv(i1) {
 i1 = i1 | 0;
 _pthread_mutex_lock(i1 | 0) | 0;
 return;
}

function __ZN10__cxxabiv121__vmi_class_type_infoD0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__27codecvtIDsc11__mbstate_tE13do_max_lengthEv(i1) {
 i1 = i1 | 0;
 return 4;
}

function __ZNKSt3__27codecvtIDic11__mbstate_tE13do_max_lengthEv(i1) {
 i1 = i1 | 0;
 return 4;
}

function __ZNKSt3__25ctypeIcE8do_widenEc(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return i1 | 0;
}

function __ZN10__cxxabiv120__si_class_type_infoD0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__220__throw_system_errorEiPKc(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 return;
}

function __ZNKSt3__27codecvtIcc11__mbstate_tE13do_max_lengthEv(i1) {
 i1 = i1 | 0;
 return 1;
}

function __ZNSt3__27codecvtIDsc11__mbstate_tED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__27codecvtIDic11__mbstate_tED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__217__widen_from_utf8ILj32EED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__27codecvtIDsc11__mbstate_tE11do_encodingEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNKSt3__27codecvtIDic11__mbstate_tE11do_encodingEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNKSt3__210moneypunctIcLb1EE16do_thousands_sepEv(i1) {
 i1 = i1 | 0;
 return 127;
}

function __ZNKSt3__210moneypunctIcLb1EE16do_decimal_pointEv(i1) {
 i1 = i1 | 0;
 return 127;
}

function __ZNKSt3__210moneypunctIcLb0EE16do_thousands_sepEv(i1) {
 i1 = i1 | 0;
 return 127;
}

function __ZNKSt3__210moneypunctIcLb0EE16do_decimal_pointEv(i1) {
 i1 = i1 | 0;
 return 127;
}

function __ZNSt3__27codecvtIcc11__mbstate_tED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__216__narrow_to_utf8ILj32EED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__27codecvtIcc11__mbstate_tE11do_encodingEv(i1) {
 i1 = i1 | 0;
 return 1;
}

function __ZN10__cxxabiv117__class_type_infoD0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNKSt3__28messagesIwE8do_closeEi(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return;
}

function __ZNKSt3__28messagesIcE8do_closeEi(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return;
}

function b1(i1, i2, i3) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 abort(1);
 return 0;
}

function _strtof(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return +(+_strtox_17(i2, i1, 0));
}

function _strtod(i2, i1) {
 i2 = i2 | 0;
 i1 = i1 | 0;
 return +(+_strtox_17(i2, i1, 1));
}

function __ZNSt3__210__function6__baseIFPN4wasm4PassEvEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNKSt11logic_error4whatEv(i1) {
 i1 = i1 | 0;
 return HEAP32[i1 + 4 >> 2] | 0;
}

function __ZNKSt3__210moneypunctIwLb1EE14do_frac_digitsEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNKSt3__210moneypunctIwLb0EE14do_frac_digitsEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNKSt3__210moneypunctIcLb1EE14do_frac_digitsEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNKSt3__210moneypunctIcLb0EE14do_frac_digitsEv(i1) {
 i1 = i1 | 0;
 return 0;
}

function _isxdigit_l(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 return _isxdigit(i1) | 0;
}

function __ZNSt3__217bad_function_callD0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210moneypunctIwLb1EED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210moneypunctIwLb0EED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210moneypunctIcLb1EED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210moneypunctIcLb0EED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt9bad_allocC2Ev(i1) {
 i1 = i1 | 0;
 HEAP32[i1 >> 2] = 15432;
 return;
}

function __ZN4wasm9isIntegerEd(d1) {
 d1 = +d1;
 return +_fmod(d1, 1.0) == 0.0 | 0;
}

function _copysignl(d1, d2) {
 d1 = +d1;
 d2 = +d2;
 return +(+_copysign(d1, d2));
}

function _scalbnl(d2, i1) {
 d2 = +d2;
 i1 = i1 | 0;
 return +(+_scalbn(d2, i1));
}

function __ZNK10__cxxabiv116__shim_type_info5noop2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNK10__cxxabiv116__shim_type_info5noop1Ev(i1) {
 i1 = i1 | 0;
 return;
}

function _frexpl(d2, i1) {
 d2 = +d2;
 i1 = i1 | 0;
 return +(+_frexp(d2, i1));
}

function __ZNSt3__26locale5facetD0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function b9(i1, i2, i3) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 i3 = i3 | 0;
 abort(9);
}

function __ZNSt3__28messagesIwED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__28messagesIcED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__27collateIwED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__27collateIcED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__210__function6__baseIFhvEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210__function6__baseIFavEED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function _isupper(i1) {
 i1 = i1 | 0;
 return (i1 + -65 | 0) >>> 0 < 26 | 0;
}

function __ZN10__cxxabiv116__shim_type_infoD2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__25ctypeIwED0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function __ZNSt3__221__throw_runtime_errorEPKc(i1) {
 i1 = i1 | 0;
 return;
}

function _fmodl(d1, d2) {
 d1 = +d1;
 d2 = +d2;
 return +(+_fmod(d1, d2));
}

function b14(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 abort(14);
 return 0;
}

function __ZNSt9bad_allocD0Ev(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function _catopen(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 return -1 | 0;
}

function __ZNSt3__210moneypunctIwLb1EED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210moneypunctIwLb0EED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210moneypunctIcLb1EED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__210moneypunctIcLb0EED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__214__shared_countD2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNKSt9exception4whatEv(i1) {
 i1 = i1 | 0;
 return 56458;
}

function __ZNKSt9bad_alloc4whatEv(i1) {
 i1 = i1 | 0;
 return 56443;
}

function dynCall_v(i1) {
 i1 = i1 | 0;
 FUNCTION_TABLE_v[i1 & 3]();
}

function ___cxa_pure_virtual__wrapper() {
 ___cxa_pure_virtual();
}

function __ZNSt3__26locale5facetD2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__212__do_nothingEPv(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__28messagesIwED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__28messagesIcED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function _pthread_cond_broadcast(i1) {
 i1 = i1 | 0;
 return 0;
}

function __ZNSt3__27collateIwED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt3__27collateIcED2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function _pthread_mutex_unlock(i1) {
 i1 = i1 | 0;
 return 0;
}

function _freelocale(i1) {
 i1 = i1 | 0;
 _free(i1);
 return;
}

function b5(i1, i2) {
 i1 = i1 | 0;
 i2 = i2 | 0;
 abort(5);
}

function _pthread_mutex_lock(i1) {
 i1 = i1 | 0;
 return 0;
}

function __Znaj(i1) {
 i1 = i1 | 0;
 return __Znwj(i1) | 0;
}

function __ZdaPv(i1) {
 i1 = i1 | 0;
 __ZdlPv(i1);
 return;
}

function ___cxa_guard_release(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt9type_infoD2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt9exceptionD2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function __ZNSt9bad_allocD2Ev(i1) {
 i1 = i1 | 0;
 return;
}

function stackRestore(i1) {
 i1 = i1 | 0;
 STACKTOP = i1;
}

function __ZdlPv(i1) {
 i1 = i1 | 0;
 _free(i1);
 return;
}

function setTempRet0(i1) {
 i1 = i1 | 0;
 tempRet0 = i1;
}

function ___cxa_guard_abort(i1) {
 i1 = i1 | 0;
 return;
}

function _feclearexcept(i1) {
 i1 = i1 | 0;
 return 0;
}

function b8(i1) {
 i1 = i1 | 0;
 abort(8);
 return 0;
}

function _fetestexcept(i1) {
 i1 = i1 | 0;
 return 0;
}

function ___unlockfile(i1) {
 i1 = i1 | 0;
 return;
}

function ___lockfile(i1) {
 i1 = i1 | 0;
 return 0;
}

function __GLOBAL__sub_I_iostream_cpp() {
 return;
}

function _catclose(i1) {
 i1 = i1 | 0;
 return 0;
}

function ___ctype_tolower_loc() {
 return 10088;
}

function _nan(i1) {
 i1 = i1 | 0;
 return +nan;
}

function ___ctype_toupper_loc() {
 return 8548;
}

function __ZSt17__throw_bad_allocv() {
 return;
}

function getTempRet0() {
 return tempRet0 | 0;
}

function stackSave() {
 return STACKTOP | 0;
}

function b4(i1) {
 i1 = i1 | 0;
 abort(4);
}

function ___ctype_b_loc() {
 return 8544;
}

function _pthread_self() {
 return 0;
}

function b10() {
 abort(10);
}

// emscripten_END_FUNCS
var FUNCTION_TABLE_iiiiiiii = [b0,__ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc,__ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc,__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe,__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE,__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe,__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE,b0];
var FUNCTION_TABLE_iiii = [b1,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6setbufEPci,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPci,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKci,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEEclEOS5_Oj,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEEclEOS5_Oj,___stdio_write,___stdio_seek,___stdout_write,___stdio_read,_sn_write,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6setbufEPwi,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwi,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwi,__ZNSt3__211__stdoutbufIcE6xsputnEPKci,__ZNSt3__211__stdoutbufIwE6xsputnEPKwi,__ZNKSt3__27collateIcE7do_hashEPKcS3_,__ZNKSt3__27collateIwE7do_hashEPKwS3_,__ZNKSt3__28messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE,__ZNKSt3__28messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE,__ZNKSt3__25ctypeIcE10do_toupperEPcPKc,__ZNKSt3__25ctypeIcE10do_tolowerEPcPKc,__ZNKSt3__25ctypeIcE9do_narrowEcc,__ZNKSt3__25ctypeIwE5do_isEtw,__ZNKSt3__25ctypeIwE10do_toupperEPwPKw,__ZNKSt3__25ctypeIwE10do_tolowerEPwPKw,__ZNKSt3__25ctypeIwE9do_narrowEwc,__ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv,_do_read_421
,b1,b1,b1];
var FUNCTION_TABLE_viiiii = [b2,__ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,__ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,__ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib];
var FUNCTION_TABLE_iiiiiid = [b3,__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce,__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe,b3];
var FUNCTION_TABLE_vi = [b4,__ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZNSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZTv0_n12_NSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZTv0_n12_NSt3__219basic_istringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev,__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev,__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev,__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZNSt9exceptionD2Ev,__ZNSt3__217bad_function_callD0Ev,__ZNSt3__210__function6__baseIFhvEED2Ev,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE18destroy_deallocateEv,__ZNSt3__210__function6__baseIFavEED2Ev,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEED0Ev,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE18destroy_deallocateEv,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEED0Ev,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE18destroy_deallocateEv,__ZN4wasm4PassD2Ev,__ZN4wasm4PassD0Ev,__ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZNSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZThn8_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev
,__ZThn8_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZTv0_n12_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZTv0_n12_NSt3__218basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev,__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev,__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev,__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev,__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev,__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev,__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev,__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev,__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev,__ZNSt3__210__function6__baseIFPN4wasm10ExpressionEN6cashew3RefEEED2Ev,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EED0Ev,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE18destroy_deallocateEv,__ZNSt3__210__function6__baseIFPN4wasm10ExpressionEN6cashew3RefEjEED2Ev,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEED0Ev,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE18destroy_deallocateEv,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEED0Ev,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE18destroy_deallocateEv,__ZNSt3__210__function6__baseIFPN4wasm4PassEvEED2Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEED0Ev
,__ZNSt3__210__function6__baseIFN4wasm15ThreadWorkStateEvEED2Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm19DeadCodeEliminationD2Ev,__ZN4wasm19DeadCodeEliminationD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm11MergeBlocksD0Ev,__ZN4wasm7PrinterD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm15MinifiedPrinterD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm11FullPrinterD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv
,__ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm20OptimizeInstructionsD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEED0Ev,__ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11SelectifierD0Ev,__ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEED0Ev,__ZZN4wasm15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEEN11TypeUpdaterD0Ev,__ZN4wasm15RemoveUnusedBrsD2Ev,__ZN4wasm15RemoveUnusedBrsD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv
,__ZN4wasm17RemoveUnusedNamesD2Ev,__ZN4wasm17RemoveUnusedNamesD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm14PostEmscriptenD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEED0Ev,__ZN4wasm15GetLocalCounterD0Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEED0Ev,__ZN4wasm15SetLocalRemoverD0Ev,__ZN4wasm14SimplifyLocalsD2Ev,__ZN4wasm14SimplifyLocalsD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv
,__ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm13ReorderLocalsD2Ev,__ZN4wasm13ReorderLocalsD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEED2Ev,__ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm6VacuumD2Ev,__ZN4wasm6VacuumD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZN4wasm28DuplicateFunctionEliminationD2Ev,__ZN4wasm28DuplicateFunctionEliminationD0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm14CoalesceLocalsD2Ev,__ZN4wasm14CoalesceLocalsD0Ev
,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE18destroy_deallocateEv,__ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEED2Ev,__ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEED0Ev,__ZN4wasm26CoalesceLocalsWithLearningD0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEED0Ev,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7destroyEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE18destroy_deallocateEv,__ZNSt3__28ios_baseD2Ev,__ZNSt3__28ios_baseD0Ev,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED0Ev,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED0Ev,__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev,__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev,__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev,__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev,__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev,__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev,__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev,__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev,__ZNSt3__210__stdinbufIcED0Ev,__ZNSt3__210__stdinbufIwED0Ev,__ZNSt3__211__stdoutbufIcED0Ev,__ZNSt3__211__stdoutbufIwED0Ev
,__ZNSt3__27collateIcED2Ev,__ZNSt3__27collateIcED0Ev,__ZNSt3__26locale5facet16__on_zero_sharedEv,__ZNSt3__27collateIwED2Ev,__ZNSt3__27collateIwED0Ev,__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__210moneypunctIcLb0EED2Ev,__ZNSt3__210moneypunctIcLb0EED0Ev,__ZNSt3__210moneypunctIcLb1EED2Ev,__ZNSt3__210moneypunctIcLb1EED0Ev,__ZNSt3__210moneypunctIwLb0EED2Ev,__ZNSt3__210moneypunctIwLb0EED0Ev,__ZNSt3__210moneypunctIwLb1EED2Ev,__ZNSt3__210moneypunctIwLb1EED0Ev,__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev
,__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev,__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev,__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__28messagesIcED2Ev,__ZNSt3__28messagesIcED0Ev,__ZNSt3__28messagesIwED2Ev,__ZNSt3__28messagesIwED0Ev,__ZNSt3__26locale5facetD2Ev,__ZNSt3__216__narrow_to_utf8ILj32EED0Ev,__ZNSt3__217__widen_from_utf8ILj32EED0Ev,__ZNSt3__27codecvtIwc11__mbstate_tED2Ev,__ZNSt3__27codecvtIwc11__mbstate_tED0Ev,__ZNSt3__26locale5__impD2Ev,__ZNSt3__26locale5__impD0Ev,__ZNSt3__25ctypeIcED2Ev,__ZNSt3__25ctypeIcED0Ev,__ZNSt3__28numpunctIcED2Ev,__ZNSt3__28numpunctIcED0Ev,__ZNSt3__28numpunctIwED2Ev,__ZNSt3__28numpunctIwED0Ev,__ZNSt3__26locale5facetD0Ev,__ZNSt3__25ctypeIwED0Ev,__ZNSt3__27codecvtIcc11__mbstate_tED0Ev,__ZNSt3__27codecvtIDsc11__mbstate_tED0Ev,__ZNSt3__27codecvtIDic11__mbstate_tED0Ev,__ZN10__cxxabiv116__shim_type_infoD2Ev
,__ZN10__cxxabiv117__class_type_infoD0Ev,__ZNK10__cxxabiv116__shim_type_info5noop1Ev,__ZNK10__cxxabiv116__shim_type_info5noop2Ev,__ZN10__cxxabiv120__si_class_type_infoD0Ev,__ZNSt9bad_allocD2Ev,__ZNSt9bad_allocD0Ev,__ZNSt11logic_errorD2Ev,__ZNSt11logic_errorD0Ev,__ZNSt12out_of_rangeD0Ev,__ZN10__cxxabiv121__vmi_class_type_infoD0Ev,__ZN4wasm14ParseExceptionD2Ev,__ZNSt3__213__vector_baseIN6cashew3RefENS_9allocatorIS2_EEED2Ev,__ZN6cashew10IStringSetD2Ev,__ZNSt3__213__vector_baseIN6cashew13OperatorClassENS_9allocatorIS2_EEED2Ev,__ZNSt3__213__vector_baseINS_13unordered_mapIN6cashew7IStringEiNS_4hashIS3_EENS_8equal_toIS3_EENS_9allocatorINS_4pairIKS3_iEEEEEENS8_ISD_EEED2Ev,__ZN6cashew5ArenaD2Ev,__ZNSt3__210unique_ptrIN4wasm10ThreadPoolENS_14default_deleteIS2_EEED2Ev,__ZN4wasm6Thread8mainLoopEPv,_cleanup_418,_cleanup_435,__ZNSt3__28ios_base4InitD2Ev,__ZNSt3__26locale2id6__initEv,__ZNSt3__217__call_once_proxyINS_5tupleIJONS_12_GLOBAL__N_111__fake_bindEEEEEEvPv,___cxx_global_array_dtor,___cxx_global_array_dtor_61,___cxx_global_array_dtor_109,__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev,___cxx_global_array_dtor_46,___cxx_global_array_dtor_85,___cxx_global_array_dtor_112
,__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev,__ZNSt3__212__do_nothingEPv,_free,__ZNSt3__221__thread_specific_ptrINS_15__thread_structEE16__at_thread_exitEPv,__ZN10__cxxabiv112_GLOBAL__N_19destruct_EPv,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4];
var FUNCTION_TABLE_vii = [b5,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE7__cloneEPNS0_6__baseIS7_EE,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7__cloneEPNS0_6__baseIS7_EE,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7__cloneEPNS0_6__baseIS7_EE,__ZZ11instantiateEN19JSExternalInterface4initERN4wasm6ModuleE,__ZZ11instantiateEN19JSExternalInterface4trapEPKc,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE7__cloneEPNS0_6__baseISB_EE,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7__cloneEPNS0_6__baseISB_EE,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7__cloneEPNS0_6__baseISB_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE
,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZN4wasm14CoalesceLocals11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEE,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEPNS0_6__baseISE_EE,__ZN4wasm26CoalesceLocalsWithLearning11pickIndicesERNSt3__26vectorIjNS1_9allocatorIjEEEE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEPNS0_6__baseISD_EE,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE,__ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE,__ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE,__ZNSt3__211__stdoutbufIcE5imbueERKNS_6localeE,__ZNSt3__211__stdoutbufIwE5imbueERKNS_6localeE,__ZNKSt3__210moneypunctIcLb0EE11do_groupingEv,__ZNKSt3__210moneypunctIcLb0EE14do_curr_symbolEv,__ZNKSt3__210moneypunctIcLb0EE16do_positive_signEv,__ZNKSt3__210moneypunctIcLb0EE16do_negative_signEv,__ZNKSt3__210moneypunctIcLb0EE13do_pos_formatEv,__ZNKSt3__210moneypunctIcLb0EE13do_neg_formatEv,__ZNKSt3__210moneypunctIcLb1EE11do_groupingEv,__ZNKSt3__210moneypunctIcLb1EE14do_curr_symbolEv,__ZNKSt3__210moneypunctIcLb1EE16do_positive_signEv,__ZNKSt3__210moneypunctIcLb1EE16do_negative_signEv,__ZNKSt3__210moneypunctIcLb1EE13do_pos_formatEv,__ZNKSt3__210moneypunctIcLb1EE13do_neg_formatEv,__ZNKSt3__210moneypunctIwLb0EE11do_groupingEv,__ZNKSt3__210moneypunctIwLb0EE14do_curr_symbolEv,__ZNKSt3__210moneypunctIwLb0EE16do_positive_signEv
,__ZNKSt3__210moneypunctIwLb0EE16do_negative_signEv,__ZNKSt3__210moneypunctIwLb0EE13do_pos_formatEv,__ZNKSt3__210moneypunctIwLb0EE13do_neg_formatEv,__ZNKSt3__210moneypunctIwLb1EE11do_groupingEv,__ZNKSt3__210moneypunctIwLb1EE14do_curr_symbolEv,__ZNKSt3__210moneypunctIwLb1EE16do_positive_signEv,__ZNKSt3__210moneypunctIwLb1EE16do_negative_signEv,__ZNKSt3__210moneypunctIwLb1EE13do_pos_formatEv,__ZNKSt3__210moneypunctIwLb1EE13do_neg_formatEv,__ZNKSt3__28messagesIcE8do_closeEi,__ZNKSt3__28messagesIwE8do_closeEi,__ZNKSt3__28numpunctIcE11do_groupingEv,__ZNKSt3__28numpunctIcE11do_truenameEv,__ZNKSt3__28numpunctIcE12do_falsenameEv,__ZNKSt3__28numpunctIwE11do_groupingEv,__ZNKSt3__28numpunctIwE11do_truenameEv,__ZNKSt3__28numpunctIwE12do_falsenameEv,__ZN4wasm10PostWalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm19DeadCodeElimination4scanEPS0_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm19DeadCodeElimination17doAfterIfElseTrueEPS0_PPNS_10ExpressionE,__ZN4wasm19DeadCodeElimination18doAfterIfConditionEPS0_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm19DeadCodeElimination10doPreBlockEPS0_PPNS_10ExpressionE,__ZN4wasm19DeadCodeElimination19doAfterBlockElementEPS0_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm15RemoveUnusedBrs4scanEPS0_PPNS_10ExpressionE,__ZN4wasm15RemoveUnusedBrs8visitAnyEPS0_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE
,__ZN4wasm15RemoveUnusedBrs10saveIfTrueEPS0_PPNS_10ExpressionE,__ZN4wasm15RemoveUnusedBrs5clearEPS0_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE4scanEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitBlockEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE9doVisitIfEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE11doVisitLoopEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitBreakEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13doVisitSwitchEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE11doVisitCallEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE17doVisitCallImportEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE19doVisitCallIndirectEPS4_PPNS_10ExpressionE
,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE15doVisitGetLocalEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE15doVisitSetLocalEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE11doVisitLoadEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitStoreEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitConstEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE12doVisitUnaryEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13doVisitBinaryEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13doVisitSelectEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE13doVisitReturnEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE11doVisitHostEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE10doVisitNopEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE18doVisitUnreachableEPS4_PPNS_10ExpressionE,__ZN4wasm10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE4scanEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitBlockEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE9doVisitIfEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE11doVisitLoopEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitBreakEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13doVisitSwitchEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE11doVisitCallEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE17doVisitCallImportEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE19doVisitCallIndirectEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE15doVisitGetLocalEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE15doVisitSetLocalEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE11doVisitLoadEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitStoreEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitConstEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE12doVisitUnaryEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13doVisitBinaryEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13doVisitSelectEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE13doVisitReturnEPS4_PPNS_10ExpressionE
,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE11doVisitHostEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE10doVisitNopEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE18doVisitUnreachableEPS4_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm14SimplifyLocals4scanEPS0_PPNS_10ExpressionE,__ZN4wasm14SimplifyLocals9visitPostEPS0_PPNS_10ExpressionE,__ZN4wasm14SimplifyLocals17doNoteIfElseFalseEPS0_PPNS_10ExpressionE,__ZN4wasm14SimplifyLocals16doNoteIfElseTrueEPS0_PPNS_10ExpressionE,__ZN4wasm14SimplifyLocals21doNoteIfElseConditionEPS0_PPNS_10ExpressionE,__ZN4wasm14SimplifyLocals8visitPreEPS0_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm14SimplifyLocals15doNoteNonLinearEPS0_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE4scanEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitBlockEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE9doVisitIfEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE11doVisitLoopEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitBreakEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13doVisitSwitchEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE11doVisitCallEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE17doVisitCallImportEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE19doVisitCallIndirectEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE15doVisitGetLocalEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE15doVisitSetLocalEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE11doVisitLoadEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitStoreEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitConstEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE12doVisitUnaryEPS4_PPNS_10ExpressionE
,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13doVisitBinaryEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13doVisitSelectEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE13doVisitReturnEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE11doVisitHostEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE10doVisitNopEPS4_PPNS_10ExpressionE,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE18doVisitUnreachableEPS4_PPNS_10ExpressionE,__ZN4wasm6Vacuum4scanEPS0_PPNS_10ExpressionE,__ZN4wasm6Vacuum9visitPostEPS0_PPNS_10ExpressionE,__ZN4wasm6Vacuum8visitPreEPS0_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE10doEndBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE7doEndIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE14doStartIfFalseEPS1_PPNS_10ExpressionE,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE13doStartIfTrueEPS1_PPNS_10ExpressionE,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE9doEndLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE11doStartLoopEPS1_PPNS_10ExpressionE
,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE10doEndBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE11doEndSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEENS_8LivenessEE17doStartBasicBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm14CoalesceLocals15doVisitGetLocalEPS0_PPNS_10ExpressionE,__ZN4wasm14CoalesceLocals15doVisitSetLocalEPS0_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm10PostWalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE4scanEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitBlockEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE9doVisitIfEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE11doVisitLoopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitBreakEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13doVisitSwitchEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE11doVisitCallEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE17doVisitCallImportEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE19doVisitCallIndirectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE15doVisitGetLocalEPS1_PPNS_10ExpressionE
,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE15doVisitSetLocalEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE11doVisitLoadEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitStoreEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitConstEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE12doVisitUnaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13doVisitBinaryEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13doVisitSelectEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE13doVisitReturnEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE11doVisitHostEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE10doVisitNopEPS1_PPNS_10ExpressionE,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE18doVisitUnreachableEPS1_PPNS_10ExpressionE,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5,b5
,b5,b5,b5,b5,b5];
var FUNCTION_TABLE_iiiiiii = [b6,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe,__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe,__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm
,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE,__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6];
var FUNCTION_TABLE_iiiiid = [b7,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe,b7,b7,b7];
var FUNCTION_TABLE_ii = [b8,__ZN4wasm6WalkerINS_13WasmValidatorENS_7VisitorIS1_vEEE6createEv,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4syncEv,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9showmanycEv,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9underflowEv,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5uflowEv,__ZN4wasm6WalkerINS_11BreakSeekerENS_7VisitorIS1_vEEE6createEv,__ZNKSt9exception4whatEv,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEEclEv,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEEclEv,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE7__cloneEv,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7__cloneEv,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE7__cloneEv,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm6WalkerINS_19DeadCodeEliminationENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv
,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm6WalkerINS_11MergeBlocksENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZN4wasm6WalkerINS_14EffectAnalyzerENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm6WalkerINS_20OptimizeInstructionsENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm6WalkerINS_15RemoveUnusedBrsENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv
,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS4_vEEE6createEv,__ZN4wasm6WalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS4_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm6WalkerINS_17RemoveUnusedNamesENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm6WalkerINS_14PostEmscriptenENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm6WalkerINS_14SimplifyLocalsENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZN4wasm6WalkerINS_15GetLocalCounterENS_7VisitorIS1_vEEE6createEv,__ZN4wasm6WalkerINS_15SetLocalRemoverENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv
,__ZN4wasm6WalkerINS_13ReorderLocalsENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZN4wasm6WalkerIZNS_13ReorderLocals13visitFunctionEPNS_8FunctionEE9ReIndexerNS_7VisitorIS4_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm6WalkerINS_6VacuumENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm14FunctionHasher6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZN4wasm6WalkerINS_14FunctionHasherENS_7VisitorIS1_vEEE6createEv,__ZN4wasm16FunctionReplacer6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZN4wasm6WalkerINS_16FunctionReplacerENS_7VisitorIS1_vEEE6createEv,__ZN4wasm6WalkerINS_14CoalesceLocalsENS_7VisitorIS1_vEEE6createEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE11target_typeEv,__ZN4wasm26CoalesceLocalsWithLearning6createEv
,__ZThn16_N4wasm26CoalesceLocalsWithLearning6createEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE7__cloneEv,__ZNSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEEclEv,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE11target_typeEv,__ZN4wasm6WalkerINS_10TypeSeekerENS_7VisitorIS1_vEEE6createEv,___stdio_close,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9underflowEv,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4syncEv,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9showmanycEv,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9underflowEv,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5uflowEv,__ZNSt3__210__stdinbufIcE9underflowEv,__ZNSt3__210__stdinbufIcE5uflowEv,__ZNSt3__210__stdinbufIwE9underflowEv,__ZNSt3__210__stdinbufIwE5uflowEv,__ZNSt3__211__stdoutbufIcE4syncEv,__ZNSt3__211__stdoutbufIwE4syncEv,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv,__ZNKSt3__220__time_get_c_storageIcE7__weeksEv,__ZNKSt3__220__time_get_c_storageIcE8__monthsEv,__ZNKSt3__220__time_get_c_storageIcE7__am_pmEv,__ZNKSt3__220__time_get_c_storageIcE3__cEv,__ZNKSt3__220__time_get_c_storageIcE3__rEv,__ZNKSt3__220__time_get_c_storageIcE3__xEv,__ZNKSt3__220__time_get_c_storageIcE3__XEv,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv,__ZNKSt3__220__time_get_c_storageIwE7__weeksEv
,__ZNKSt3__220__time_get_c_storageIwE8__monthsEv,__ZNKSt3__220__time_get_c_storageIwE7__am_pmEv,__ZNKSt3__220__time_get_c_storageIwE3__cEv,__ZNKSt3__220__time_get_c_storageIwE3__rEv,__ZNKSt3__220__time_get_c_storageIwE3__xEv,__ZNKSt3__220__time_get_c_storageIwE3__XEv,__ZNKSt3__210moneypunctIcLb0EE16do_decimal_pointEv,__ZNKSt3__210moneypunctIcLb0EE16do_thousands_sepEv,__ZNKSt3__210moneypunctIcLb0EE14do_frac_digitsEv,__ZNKSt3__210moneypunctIcLb1EE16do_decimal_pointEv,__ZNKSt3__210moneypunctIcLb1EE16do_thousands_sepEv,__ZNKSt3__210moneypunctIcLb1EE14do_frac_digitsEv,__ZNKSt3__210moneypunctIwLb0EE16do_decimal_pointEv,__ZNKSt3__210moneypunctIwLb0EE16do_thousands_sepEv,__ZNKSt3__210moneypunctIwLb0EE14do_frac_digitsEv,__ZNKSt3__210moneypunctIwLb1EE16do_decimal_pointEv,__ZNKSt3__210moneypunctIwLb1EE16do_thousands_sepEv,__ZNKSt3__210moneypunctIwLb1EE14do_frac_digitsEv,__ZNKSt3__27codecvtIDic11__mbstate_tE11do_encodingEv,__ZNKSt3__27codecvtIDic11__mbstate_tE16do_always_noconvEv,__ZNKSt3__27codecvtIDic11__mbstate_tE13do_max_lengthEv,__ZNKSt3__27codecvtIwc11__mbstate_tE11do_encodingEv,__ZNKSt3__27codecvtIwc11__mbstate_tE16do_always_noconvEv,__ZNKSt3__27codecvtIwc11__mbstate_tE13do_max_lengthEv,__ZNKSt3__28numpunctIcE16do_decimal_pointEv,__ZNKSt3__28numpunctIcE16do_thousands_sepEv,__ZNKSt3__28numpunctIwE16do_decimal_pointEv,__ZNKSt3__28numpunctIwE16do_thousands_sepEv,__ZNKSt3__27codecvtIcc11__mbstate_tE11do_encodingEv,__ZNKSt3__27codecvtIcc11__mbstate_tE16do_always_noconvEv
,__ZNKSt3__27codecvtIcc11__mbstate_tE13do_max_lengthEv,__ZNKSt3__27codecvtIDsc11__mbstate_tE11do_encodingEv,__ZNKSt3__27codecvtIDsc11__mbstate_tE16do_always_noconvEv,__ZNKSt3__27codecvtIDsc11__mbstate_tE13do_max_lengthEv,__ZNKSt9bad_alloc4whatEv,__ZNKSt11logic_error4whatEv,__ZNSt3__214__thread_proxyINS_5tupleIJNS_10unique_ptrINS_15__thread_structENS_14default_deleteIS3_EEEEPFvPvEPN4wasm6ThreadEEEEEES7_S7_,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8];
var FUNCTION_TABLE_viii = [b9,__ZN4wasm4Pass7prepareEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm4Pass8finalizeEPNS_10PassRunnerEPNS_6ModuleE,__ZZ11instantiateEN19JSExternalInterface10growMemoryEN4wasm7AddressES1_,__ZN4wasm10WalkerPassINS_10PostWalkerINS_19DeadCodeEliminationENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerINS_11MergeBlocksENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm7Printer3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm15MinifiedPrinter3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm11FullPrinter3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerINS_20OptimizeInstructionsENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerINS_15RemoveUnusedBrsENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11SelectifierNS_7VisitorIS5_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerIZNS_15RemoveUnusedBrs14doWalkFunctionEPNS_8FunctionEE11TypeUpdaterNS_7VisitorIS5_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerINS_17RemoveUnusedNamesENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerINS_14PostEmscriptenENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_21LinearExecutionWalkerINS_14SimplifyLocalsENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerINS_15GetLocalCounterENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerINS_15SetLocalRemoverENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerINS_13ReorderLocalsENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_10PostWalkerINS_6VacuumENS_7VisitorIS2_vEEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm28DuplicateFunctionElimination3runEPNS_10PassRunnerEPNS_6ModuleE,__ZN4wasm10WalkerPassINS_9CFGWalkerINS_14CoalesceLocalsENS_7VisitorIS2_vEENS_8LivenessEEEE3runEPNS_10PassRunnerEPNS_6ModuleE,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9];
var FUNCTION_TABLE_v = [b10,___cxa_pure_virtual__wrapper,__ZL25default_terminate_handlerv,__ZN10__cxxabiv112_GLOBAL__N_110construct_Ev];
var FUNCTION_TABLE_iiiiiiiii = [b11,__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc,__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc,__ZNKSt3__27codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_,__ZNKSt3__27codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_,__ZNKSt3__27codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_,__ZNKSt3__27codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_,__ZNKSt3__27codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_,__ZNKSt3__27codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_,__ZNKSt3__27codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_,__ZNKSt3__27codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_,b11,b11,b11,b11,b11];
var FUNCTION_TABLE_iiiii = [b12,__ZNKSt3__25ctypeIcE8do_widenEPKcS3_Pc,__ZNKSt3__25ctypeIwE5do_isEPKwS3_Pt,__ZNKSt3__25ctypeIwE10do_scan_isEtPKwS3_,__ZNKSt3__25ctypeIwE11do_scan_notEtPKwS3_,__ZNKSt3__25ctypeIwE8do_widenEPKcS3_Pw,b12,b12];
var FUNCTION_TABLE_viiiiii = [b13,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekoffExNS_8ios_base7seekdirEj,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj,__ZNKSt3__28messagesIcE6do_getEiiiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZNKSt3__28messagesIwE6do_getEiiiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE,__ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,__ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,__ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,b13,b13,b13,b13,b13,b13,b13];
var FUNCTION_TABLE_iii = [b14,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9pbackfailEi,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE8overflowEi,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getU32LEBEvEUlvE_NS_9allocatorIS4_EEFhvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS32LEBEvEUlvE_NS_9allocatorIS4_EEFavEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm17WasmBinaryBuilder9getS64LEBEvEUlvE_NS_9allocatorIS4_EEFavEE6targetERKSt9type_info,__ZNSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EEclEOS5_,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__1NS_9allocatorIS6_EEFPNS2_10ExpressionES5_EE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__2NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm15Asm2WasmBuilder15processFunctionEN6cashew3RefEE3__3NS_9allocatorIS6_EEFPNS2_10ExpressionES5_jEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_19DeadCodeEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_19DeadCodeEliminationENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11MergeBlocksEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_11MergeBlocksENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_7PrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15MinifiedPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_11FullPrinterEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_20OptimizeInstructionsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_20OptimizeInstructionsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_15RemoveUnusedBrsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_15RemoveUnusedBrsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_17RemoveUnusedNamesEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_17RemoveUnusedNamesENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14PostEmscriptenEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14PostEmscriptenENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14SimplifyLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14SimplifyLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_13ReorderLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_13ReorderLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info
,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_6VacuumEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_6VacuumENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_28DuplicateFunctionEliminationEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14FunctionHasherENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_16FunctionReplacerENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm6WalkerINS2_14CoalesceLocalsENS2_7VisitorIS4_vEEE12doWalkModuleEPNS2_6ModuleEEUlvE_NS_9allocatorISA_EEFNS2_15ThreadWorkStateEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_14CoalesceLocalsEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNKSt3__210__function6__funcIZN4wasm12RegisterPassINS2_26CoalesceLocalsWithLearningEEC1EPKcS7_EUlvE_NS_9allocatorIS8_EEFPNS2_4PassEvEE6targetERKSt9type_info,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8overflowEi,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8overflowEj,__ZNSt3__210__stdinbufIcE9pbackfailEi,__ZNSt3__210__stdinbufIwE9pbackfailEj,__ZNSt3__211__stdoutbufIcE8overflowEi,__ZNSt3__211__stdoutbufIwE8overflowEj,__ZNKSt3__25ctypeIcE10do_toupperEc,__ZNKSt3__25ctypeIcE10do_tolowerEc,__ZNKSt3__25ctypeIcE8do_widenEc,__ZNKSt3__25ctypeIwE10do_toupperEw,__ZNKSt3__25ctypeIwE10do_tolowerEw,__ZNKSt3__25ctypeIwE8do_widenEc,b14,b14,b14,b14,b14,b14,b14,b14
,b14,b14,b14,b14,b14];
var FUNCTION_TABLE_iiiiii = [b15,__ZNKSt3__27collateIcE10do_compareEPKcS3_S3_S3_,__ZNKSt3__27collateIwE10do_compareEPKwS3_S3_S3_,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm,__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm,__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv,__ZNKSt3__27codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,__ZNKSt3__27codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_j,__ZNKSt3__27codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,__ZNKSt3__27codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_j,__ZNKSt3__25ctypeIcE9do_narrowEPKcS3_cPc,__ZNKSt3__25ctypeIwE9do_narrowEPKwS3_cPc,__ZNKSt3__27codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,__ZNKSt3__27codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_j,__ZNKSt3__27codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,__ZNKSt3__27codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_j,b15,b15,b15,b15,b15,b15,b15,b15
,b15,b15,b15];
var FUNCTION_TABLE_viiii = [b16,__ZNSt3__215basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekposENS_4fposI11__mbstate_tEEj,__ZZ11instantiateEN19JSExternalInterface10callImportEPN4wasm6ImportERNSt3__26vectorINS0_7LiteralENS3_9allocatorIS5_EEEE,__ZZ11instantiateEN19JSExternalInterface4loadEPN4wasm4LoadENS0_7AddressE,__ZZ11instantiateEN19JSExternalInterface5storeEPN4wasm5StoreENS0_7AddressENS0_7LiteralE,__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj,__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj,__ZNKSt3__27collateIcE12do_transformEPKcS3_,__ZNKSt3__27collateIwE12do_transformEPKwS3_,__ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,__ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,__ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,b16,b16,b16,b16];

  return { _instantiate: _instantiate, ___udivdi3: ___udivdi3, _interpreter_stack_trace: _interpreter_stack_trace, _bitshift64Lshr: _bitshift64Lshr, _bitshift64Shl: _bitshift64Shl, _fflush: _fflush, _load_asm2wasm: _load_asm2wasm, ___cxa_is_pointer_type: ___cxa_is_pointer_type, _bitshift64Ashr: _bitshift64Ashr, _memset: _memset, ___cxa_demangle: ___cxa_demangle, _i64Add: _i64Add, _memcpy: _memcpy, ___muldi3: ___muldi3, ___uremdi3: ___uremdi3, ___divdi3: ___divdi3, _llvm_cttz_i32: _llvm_cttz_i32, _i64Subtract: _i64Subtract, ___udivmoddi4: ___udivmoddi4, _load_s_expr2wasm: _load_s_expr2wasm, _pthread_self: _pthread_self, _pthread_mutex_unlock: _pthread_mutex_unlock, ___remdi3: ___remdi3, _pthread_cond_broadcast: _pthread_cond_broadcast, ___errno_location: ___errno_location, _call_from_js: _call_from_js, ___muldsi3: ___muldsi3, ___cxa_can_catch: ___cxa_can_catch, _free: _free, _load_binary2wasm: _load_binary2wasm, _memmove: _memmove, _malloc: _malloc, _pthread_mutex_lock: _pthread_mutex_lock, __GLOBAL__I_000101: __GLOBAL__I_000101, __GLOBAL__sub_I_Vacuum_cpp: __GLOBAL__sub_I_Vacuum_cpp, __GLOBAL__sub_I_iostream_cpp: __GLOBAL__sub_I_iostream_cpp, __GLOBAL__sub_I_shared_constants_cpp: __GLOBAL__sub_I_shared_constants_cpp, __GLOBAL__sub_I_threads_cpp: __GLOBAL__sub_I_threads_cpp, __GLOBAL__sub_I_optimizer_shared_cpp: __GLOBAL__sub_I_optimizer_shared_cpp, __GLOBAL__sub_I_simple_ast_cpp: __GLOBAL__sub_I_simple_ast_cpp, __GLOBAL__sub_I_parser_cpp: __GLOBAL__sub_I_parser_cpp, __GLOBAL__sub_I_CoalesceLocals_cpp: __GLOBAL__sub_I_CoalesceLocals_cpp, __GLOBAL__sub_I_DuplicateFunctionElimination_cpp: __GLOBAL__sub_I_DuplicateFunctionElimination_cpp, __GLOBAL__sub_I_wasm_js_cpp: __GLOBAL__sub_I_wasm_js_cpp, __GLOBAL__sub_I_ReorderLocals_cpp: __GLOBAL__sub_I_ReorderLocals_cpp, __GLOBAL__sub_I_SimplifyLocals_cpp: __GLOBAL__sub_I_SimplifyLocals_cpp, __GLOBAL__sub_I_PostEmscripten_cpp: __GLOBAL__sub_I_PostEmscripten_cpp, __GLOBAL__sub_I_RemoveUnusedNames_cpp: __GLOBAL__sub_I_RemoveUnusedNames_cpp, __GLOBAL__sub_I_RemoveUnusedBrs_cpp: __GLOBAL__sub_I_RemoveUnusedBrs_cpp, __GLOBAL__sub_I_OptimizeInstructions_cpp: __GLOBAL__sub_I_OptimizeInstructions_cpp, __GLOBAL__sub_I_Print_cpp: __GLOBAL__sub_I_Print_cpp, __GLOBAL__sub_I_MergeBlocks_cpp: __GLOBAL__sub_I_MergeBlocks_cpp, __GLOBAL__sub_I_DeadCodeElimination_cpp: __GLOBAL__sub_I_DeadCodeElimination_cpp, runPostSets: runPostSets, _emscripten_replace_memory: _emscripten_replace_memory, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, establishStackSpace: establishStackSpace, setThrew: setThrew, setTempRet0: setTempRet0, getTempRet0: getTempRet0, dynCall_iiiiiiii: dynCall_iiiiiiii, dynCall_iiii: dynCall_iiii, dynCall_viiiii: dynCall_viiiii, dynCall_iiiiiid: dynCall_iiiiiid, dynCall_vi: dynCall_vi, dynCall_vii: dynCall_vii, dynCall_iiiiiii: dynCall_iiiiiii, dynCall_iiiiid: dynCall_iiiiid, dynCall_ii: dynCall_ii, dynCall_viii: dynCall_viii, dynCall_v: dynCall_v, dynCall_iiiiiiiii: dynCall_iiiiiiiii, dynCall_iiiii: dynCall_iiiii, dynCall_viiiiii: dynCall_viiiiii, dynCall_iii: dynCall_iii, dynCall_iiiiii: dynCall_iiiiii, dynCall_viiii: dynCall_viiii };
})
// emscripten_END_ASM
(Module.asmGlobalArg, Module.asmLibraryArg, buffer);
var __GLOBAL__sub_I_simple_ast_cpp = Module["__GLOBAL__sub_I_simple_ast_cpp"] = asm["__GLOBAL__sub_I_simple_ast_cpp"];
var _instantiate = Module["_instantiate"] = asm["_instantiate"];
var ___udivdi3 = Module["___udivdi3"] = asm["___udivdi3"];
var _interpreter_stack_trace = Module["_interpreter_stack_trace"] = asm["_interpreter_stack_trace"];
var __GLOBAL__sub_I_RemoveUnusedBrs_cpp = Module["__GLOBAL__sub_I_RemoveUnusedBrs_cpp"] = asm["__GLOBAL__sub_I_RemoveUnusedBrs_cpp"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var __GLOBAL__sub_I_DeadCodeElimination_cpp = Module["__GLOBAL__sub_I_DeadCodeElimination_cpp"] = asm["__GLOBAL__sub_I_DeadCodeElimination_cpp"];
var __GLOBAL__sub_I_SimplifyLocals_cpp = Module["__GLOBAL__sub_I_SimplifyLocals_cpp"] = asm["__GLOBAL__sub_I_SimplifyLocals_cpp"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var __GLOBAL__sub_I_parser_cpp = Module["__GLOBAL__sub_I_parser_cpp"] = asm["__GLOBAL__sub_I_parser_cpp"];
var _fflush = Module["_fflush"] = asm["_fflush"];
var _load_asm2wasm = Module["_load_asm2wasm"] = asm["_load_asm2wasm"];
var ___cxa_is_pointer_type = Module["___cxa_is_pointer_type"] = asm["___cxa_is_pointer_type"];
var __GLOBAL__sub_I_optimizer_shared_cpp = Module["__GLOBAL__sub_I_optimizer_shared_cpp"] = asm["__GLOBAL__sub_I_optimizer_shared_cpp"];
var _bitshift64Ashr = Module["_bitshift64Ashr"] = asm["_bitshift64Ashr"];
var _memset = Module["_memset"] = asm["_memset"];
var ___cxa_demangle = Module["___cxa_demangle"] = asm["___cxa_demangle"];
var _load_s_expr2wasm = Module["_load_s_expr2wasm"] = asm["_load_s_expr2wasm"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var ___muldi3 = Module["___muldi3"] = asm["___muldi3"];
var __GLOBAL__sub_I_PostEmscripten_cpp = Module["__GLOBAL__sub_I_PostEmscripten_cpp"] = asm["__GLOBAL__sub_I_PostEmscripten_cpp"];
var _emscripten_replace_memory = Module["_emscripten_replace_memory"] = asm["_emscripten_replace_memory"];
var __GLOBAL__sub_I_shared_constants_cpp = Module["__GLOBAL__sub_I_shared_constants_cpp"] = asm["__GLOBAL__sub_I_shared_constants_cpp"];
var ___uremdi3 = Module["___uremdi3"] = asm["___uremdi3"];
var __GLOBAL__sub_I_Print_cpp = Module["__GLOBAL__sub_I_Print_cpp"] = asm["__GLOBAL__sub_I_Print_cpp"];
var ___divdi3 = Module["___divdi3"] = asm["___divdi3"];
var _llvm_cttz_i32 = Module["_llvm_cttz_i32"] = asm["_llvm_cttz_i32"];
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var ___udivmoddi4 = Module["___udivmoddi4"] = asm["___udivmoddi4"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var _pthread_self = Module["_pthread_self"] = asm["_pthread_self"];
var __GLOBAL__sub_I_OptimizeInstructions_cpp = Module["__GLOBAL__sub_I_OptimizeInstructions_cpp"] = asm["__GLOBAL__sub_I_OptimizeInstructions_cpp"];
var _pthread_mutex_unlock = Module["_pthread_mutex_unlock"] = asm["_pthread_mutex_unlock"];
var __GLOBAL__sub_I_MergeBlocks_cpp = Module["__GLOBAL__sub_I_MergeBlocks_cpp"] = asm["__GLOBAL__sub_I_MergeBlocks_cpp"];
var __GLOBAL__I_000101 = Module["__GLOBAL__I_000101"] = asm["__GLOBAL__I_000101"];
var ___remdi3 = Module["___remdi3"] = asm["___remdi3"];
var __GLOBAL__sub_I_iostream_cpp = Module["__GLOBAL__sub_I_iostream_cpp"] = asm["__GLOBAL__sub_I_iostream_cpp"];
var _pthread_cond_broadcast = Module["_pthread_cond_broadcast"] = asm["_pthread_cond_broadcast"];
var ___errno_location = Module["___errno_location"] = asm["___errno_location"];
var _call_from_js = Module["_call_from_js"] = asm["_call_from_js"];
var ___muldsi3 = Module["___muldsi3"] = asm["___muldsi3"];
var ___cxa_can_catch = Module["___cxa_can_catch"] = asm["___cxa_can_catch"];
var _free = Module["_free"] = asm["_free"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var __GLOBAL__sub_I_wasm_js_cpp = Module["__GLOBAL__sub_I_wasm_js_cpp"] = asm["__GLOBAL__sub_I_wasm_js_cpp"];
var _load_binary2wasm = Module["_load_binary2wasm"] = asm["_load_binary2wasm"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var __GLOBAL__sub_I_threads_cpp = Module["__GLOBAL__sub_I_threads_cpp"] = asm["__GLOBAL__sub_I_threads_cpp"];
var __GLOBAL__sub_I_CoalesceLocals_cpp = Module["__GLOBAL__sub_I_CoalesceLocals_cpp"] = asm["__GLOBAL__sub_I_CoalesceLocals_cpp"];
var __GLOBAL__sub_I_ReorderLocals_cpp = Module["__GLOBAL__sub_I_ReorderLocals_cpp"] = asm["__GLOBAL__sub_I_ReorderLocals_cpp"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _pthread_mutex_lock = Module["_pthread_mutex_lock"] = asm["_pthread_mutex_lock"];
var __GLOBAL__sub_I_DuplicateFunctionElimination_cpp = Module["__GLOBAL__sub_I_DuplicateFunctionElimination_cpp"] = asm["__GLOBAL__sub_I_DuplicateFunctionElimination_cpp"];
var __GLOBAL__sub_I_RemoveUnusedNames_cpp = Module["__GLOBAL__sub_I_RemoveUnusedNames_cpp"] = asm["__GLOBAL__sub_I_RemoveUnusedNames_cpp"];
var __GLOBAL__sub_I_Vacuum_cpp = Module["__GLOBAL__sub_I_Vacuum_cpp"] = asm["__GLOBAL__sub_I_Vacuum_cpp"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_iiiiiid = Module["dynCall_iiiiiid"] = asm["dynCall_iiiiiid"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_iiiiid = Module["dynCall_iiiiid"] = asm["dynCall_iiiiid"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiiiiiii = Module["dynCall_iiiiiiiii"] = asm["dynCall_iiiiiiiii"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = asm["stackAlloc"];
Runtime.stackSave = asm["stackSave"];
Runtime.stackRestore = asm["stackRestore"];
Runtime.establishStackSpace = asm["establishStackSpace"];
Runtime.setTempRet0 = asm["setTempRet0"];
Runtime.getTempRet0 = asm["getTempRet0"];
function ExitStatus(status) {
 this.name = "ExitStatus";
 this.message = "Program terminated with exit(" + status + ")";
 this.status = status;
}
ExitStatus.prototype = new Error;
ExitStatus.prototype.constructor = ExitStatus;
var initialStackTop;
var preloadStartTime = null;
var calledMain = false;
dependenciesFulfilled = function runCaller() {
 if (!Module["calledRun"]) run();
 if (!Module["calledRun"]) dependenciesFulfilled = runCaller;
};
Module["callMain"] = Module.callMain = function callMain(args) {
 args = args || [];
 ensureInitRuntime();
 var argc = args.length + 1;
 function pad() {
  for (var i = 0; i < 4 - 1; i++) {
   argv.push(0);
  }
 }
 var argv = [ allocate(intArrayFromString(Module["thisProgram"]), "i8", ALLOC_NORMAL) ];
 pad();
 for (var i = 0; i < argc - 1; i = i + 1) {
  argv.push(allocate(intArrayFromString(args[i]), "i8", ALLOC_NORMAL));
  pad();
 }
 argv.push(0);
 argv = allocate(argv, "i32", ALLOC_NORMAL);
 try {
  var ret = Module["_main"](argc, argv, 0);
  exit(ret, true);
 } catch (e) {
  if (e instanceof ExitStatus) {
   return;
  } else if (e == "SimulateInfiniteLoop") {
   Module["noExitRuntime"] = true;
   return;
  } else {
   if (e && typeof e === "object" && e.stack) Module.printErr("exception thrown: " + [ e, e.stack ]);
   throw e;
  }
 } finally {
  calledMain = true;
 }
};
function run(args) {
 args = args || Module["arguments"];
 if (preloadStartTime === null) preloadStartTime = Date.now();
 if (runDependencies > 0) {
  return;
 }
 preRun();
 if (runDependencies > 0) return;
 if (Module["calledRun"]) return;
 function doRun() {
  if (Module["calledRun"]) return;
  Module["calledRun"] = true;
  if (ABORT) return;
  ensureInitRuntime();
  preMain();
  if (Module["onRuntimeInitialized"]) Module["onRuntimeInitialized"]();
  if (Module["_main"] && shouldRunNow) Module["callMain"](args);
  postRun();
 }
 if (Module["setStatus"]) {
  Module["setStatus"]("Running...");
  setTimeout((function() {
   setTimeout((function() {
    Module["setStatus"]("");
   }), 1);
   doRun();
  }), 1);
 } else {
  doRun();
 }
}
Module["run"] = Module.run = run;
function exit(status, implicit) {
 if (implicit && Module["noExitRuntime"]) {
  return;
 }
 if (Module["noExitRuntime"]) {} else {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;
  exitRuntime();
  if (Module["onExit"]) Module["onExit"](status);
 }
 if (ENVIRONMENT_IS_NODE) {
  process["exit"](status);
 } else if (ENVIRONMENT_IS_SHELL && typeof quit === "function") {
  quit(status);
 }
 throw new ExitStatus(status);
}
Module["exit"] = Module.exit = exit;
var abortDecorators = [];
function abort(what) {
 if (what !== undefined) {
  Module.print(what);
  Module.printErr(what);
  what = JSON.stringify(what);
 } else {
  what = "";
 }
 ABORT = true;
 EXITSTATUS = 1;
 var extra = "\nIf this abort() is unexpected, build with -s ASSERTIONS=1 which can give more information.";
 var output = "abort(" + what + ") at " + stackTrace() + extra;
 if (abortDecorators) {
  abortDecorators.forEach((function(decorator) {
   output = decorator(output, what);
  }));
 }
 throw output;
}
Module["abort"] = Module.abort = abort;
if (Module["preInit"]) {
 if (typeof Module["preInit"] == "function") Module["preInit"] = [ Module["preInit"] ];
 while (Module["preInit"].length > 0) {
  Module["preInit"].pop()();
 }
}
var shouldRunNow = true;
if (Module["noInitialRun"]) {
 shouldRunNow = false;
}
run();





  return Module;
};

//^wasm.js
/*
 * Copyright 2015 WebAssembly Community Group participants
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

function integrateWasmJS(Module) {
  // wasm.js has several methods for creating the compiled code module here:
  //  * 'native-wasm' : use native WebAssembly support in the browser
  //  * 'interpret-s-expr': load s-expression code from a .wast and interpret
  //  * 'interpret-binary': load binary wasm and interpret
  //  * 'interpret-asm2wasm': load asm.js code, translate to wasm, and interpret
  //  * 'asmjs': no wasm, just load the asm.js code and use that (good for testing)
  // The method can be set at compile time (BINARYEN_METHOD), or runtime by setting Module['wasmJSMethod'].
  // The method can be a comma-separated list, in which case, we will try the
  // options one by one. Some of them can fail gracefully, and then we can try
  // the next.

  // inputs

  var method = Module['wasmJSMethod'] || (Module['wasmJSMethod'] || "native-wasm,interpret-binary") || 'native-wasm,interpret-s-expr'; // by default, try native and then .wast

  var wasmTextFile = Module['wasmTextFile'] || "gunjan.wast";
  var wasmBinaryFile = Module['wasmBinaryFile'] || "gunjan.wasm";
  var asmjsCodeFile = Module['asmjsCodeFile'] || "gunjan.asm.js";

  // utilities

  var wasmPageSize = 64*1024;

  var asm2wasmImports = { // special asm2wasm imports
    "f64-rem": function(x, y) {
      return x % y;
    },
    "f64-to-int": function(x) {
      return x | 0;
    },
    "debugger": function() {
      debugger;
    },
  };

  var info = {
    'global': null,
    'env': null,
    'asm2wasm': asm2wasmImports,
    'parent': Module // Module inside wasm-js.cpp refers to wasm-js.cpp; this allows access to the outside program.
  };

  var exports = null;

  function lookupImport(mod, base) {
    var lookup = info;
    if (mod.indexOf('.') < 0) {
      lookup = (lookup || {})[mod];
    } else {
      var parts = mod.split('.');
      lookup = (lookup || {})[parts[0]];
      lookup = (lookup || {})[parts[1]];
    }
    if (base) {
      lookup = (lookup || {})[base];
    }
    if (lookup === undefined) {
      abort('bad lookupImport to (' + mod + ').' + base);
    }
    return lookup;
  }

  function mergeMemory(newBuffer) {
    // The wasm instance creates its memory. But static init code might have written to
    // buffer already, including the mem init file, and we must copy it over in a proper merge.
    // TODO: avoid this copy, by avoiding such static init writes
    // TODO: in shorter term, just copy up to the last static init write
    var oldBuffer = Module['buffer'];
    if (newBuffer.byteLength < oldBuffer.byteLength) {
      Module['printErr']('the new buffer in mergeMemory is smaller than the previous one. in native wasm, we should grow memory here');
    }
    var oldView = new Int8Array(oldBuffer);
    var newView = new Int8Array(newBuffer);
    if (0) {
      // memory segments arrived in the wast, do not trample them
      oldView.set(newView.subarray(STATIC_BASE, STATIC_BASE + STATIC_BUMP), STATIC_BASE);
    }
    newView.set(oldView);
    updateGlobalBuffer(newBuffer);
    updateGlobalBufferViews();
    Module['reallocBuffer'] = function(size) {
      size = Math.ceil(size / wasmPageSize) * wasmPageSize; // round up to wasm page size
      var old = Module['buffer'];
      exports['__growWasmMemory'](size / wasmPageSize); // tiny wasm method that just does grow_memory
      return Module['buffer'] !== old ? Module['buffer'] : null; // if it was reallocated, it changed
    };
  }

  var WasmTypes = {
    none: 0,
    i32: 1,
    i64: 2,
    f32: 3,
    f64: 4
  };

  // wasm lacks globals, so asm2wasm maps them into locations in memory. that information cannot
  // be present in the wasm output of asm2wasm, so we store it in a side file. If we load asm2wasm
  // output, either generated ahead of time or on the client, we need to apply those mapped
  // globals after loading the module.
  function applyMappedGlobals(globalsFileBase) {
    var mappedGlobals = JSON.parse(Module['read'](globalsFileBase + '.mappedGlobals'));
    for (var name in mappedGlobals) {
      var global = mappedGlobals[name];
      if (!global.import) continue; // non-imports are initialized to zero in the typed array anyhow, so nothing to do here
      var value = lookupImport(global.module, global.base);
      var address = global.address;
      switch (global.type) {
        case WasmTypes.i32: Module['HEAP32'][address >> 2] = value; break;
        case WasmTypes.f32: Module['HEAPF32'][address >> 2] = value; break;
        case WasmTypes.f64: Module['HEAPF64'][address >> 3] = value; break;
        default: abort();
      }
    }
  }

  function fixImports(imports) {
    if (!0) return imports;
    var ret = {};
    for (var i in imports) {
      var fixed = i;
      if (fixed[0] == '_') fixed = fixed.substr(1);
      ret[fixed] = imports[i];
    }
    return ret;
  }

  function getBinary() {
    var binary;
    if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
      binary = Module['wasmBinary'];
      assert(binary, "on the web, we need the wasm binary to be preloaded and set on Module['wasmBinary']. emcc.py will do that for you when generating HTML (but not JS)");
      binary = new Uint8Array(binary);
    } else {
      binary = Module['readBinary'](wasmBinaryFile);
    }
    return binary;
  }

  // do-method functions

  function doJustAsm(global, env, providedBuffer) {
    // if no Module.asm, or it's the method handler helper (see below), then apply
    // the asmjs
    if (typeof Module['asm'] !== 'function' || Module['asm'] === methodHandler) {
      if (!Module['asmPreload']) {
        // you can load the .asm.js file before this, to avoid this sync xhr and eval
        eval(Module['read'](asmjsCodeFile)); // set Module.asm
      } else {
        Module['asm'] = Module['asmPreload'];
      }
    }
    if (typeof Module['asm'] !== 'function') {
      Module['printErr']('asm evalling did not set the module properly');
      return false;
    }
    return Module['asm'](global, env, providedBuffer);
  }

  function doNativeWasm(global, env, providedBuffer) {
    if (typeof Wasm !== 'object') {
      Module['printErr']('no native wasm support detected');
      return false;
    }
    // Load the wasm module and create an instance of using native support in the JS engine.
    info['global'] = {
      'NaN': NaN,
      'Infinity': Infinity
    };
    info['global.Math'] = global.Math;
    info['env'] = env;
    var instance;
    try {
      instance = Wasm['instantiateModule'](getBinary(), info);
    } catch (e) {
      Module['printErr']('failed to compile wasm module: ' + e);
      return false;
    }
    exports = instance.exports;
    mergeMemory(exports.memory);

    applyMappedGlobals(wasmBinaryFile);

    Module["usingWasm"] = true;

    return exports;
  }

  function doWasmPolyfill(global, env, providedBuffer, method) {
    if (typeof WasmJS !== 'function') {
      Module['printErr']('WasmJS not detected - polyfill not bundled?');
      return false;
    }

    // Use wasm.js to polyfill and execute code in a wasm interpreter.
    var wasmJS = WasmJS({});

    // XXX don't be confused. Module here is in the outside program. wasmJS is the inner wasm-js.cpp.
    wasmJS['outside'] = Module; // Inside wasm-js.cpp, Module['outside'] reaches the outside module.

    // Information for the instance of the module.
    wasmJS['info'] = info;

    wasmJS['lookupImport'] = lookupImport;

    assert(providedBuffer === Module['buffer']); // we should not even need to pass it as a 3rd arg for wasm, but that's the asm.js way.

    info.global = global;
    info.env = env;

    wasmJS['providedTotalMemory'] = Module['buffer'].byteLength;

    // Prepare to generate wasm, using either asm2wasm or s-exprs
    var code;
    if (method === 'interpret-binary') {
      code = getBinary();
    } else {
      code = Module['read'](method == 'interpret-asm2wasm' ? asmjsCodeFile : wasmTextFile);
    }
    var temp;
    if (method == 'interpret-asm2wasm') {
      temp = wasmJS['_malloc'](code.length + 1);
      wasmJS['writeAsciiToMemory'](code, temp);
      wasmJS['_load_asm2wasm'](temp);
    } else if (method === 'interpret-s-expr') {
      temp = wasmJS['_malloc'](code.length + 1);
      wasmJS['writeAsciiToMemory'](code, temp);
      wasmJS['_load_s_expr2wasm'](temp);
    } else if (method === 'interpret-binary') {
      temp = wasmJS['_malloc'](code.length);
      wasmJS['HEAPU8'].set(code, temp);
      wasmJS['_load_binary2wasm'](temp, code.length);
    } else {
      throw 'what? ' + method;
    }
    wasmJS['_free'](temp);

    wasmJS['_instantiate'](temp);

    if (Module['newBuffer']) {
      mergeMemory(Module['newBuffer']);
      Module['newBuffer'] = null;
    }

    if (method == 'interpret-s-expr') {
      applyMappedGlobals(wasmTextFile);
    } else if (method == 'interpret-binary') {
      applyMappedGlobals(wasmBinaryFile);
    }

    exports = wasmJS['asmExports'];

    return exports;
  }

  // We may have a preloaded value in Module.asm, save it
  Module['asmPreload'] = Module['asm'];

  // Provide an "asm.js function" for the application, called to "link" the asm.js module. We instantiate
  // the wasm module at that time, and it receives imports and provides exports and so forth, the app
  // doesn't need to care that it is wasm or olyfilled wasm or asm.js.

  Module['asm'] = function(global, env, providedBuffer) {
    global = fixImports(global);
    env = fixImports(env);

    // try the methods. each should return the exports if it succeeded

    var exports;
    var methods = method.split(',');

    for (var i = 0; i < methods.length; i++) {
      var curr = methods[i];

      Module['printErr']('trying binaryen method: ' + curr);

      if (curr === 'native-wasm') {
        if (exports = doNativeWasm(global, env, providedBuffer)) break;
      } else if (curr === 'asmjs') {
        if (exports = doJustAsm(global, env, providedBuffer)) break;
      } else if (curr === 'interpret-asm2wasm' || curr === 'interpret-s-expr' || curr === 'interpret-binary') {
        if (exports = doWasmPolyfill(global, env, providedBuffer, curr)) break;
      } else {
        throw 'bad method: ' + curr;
      }
    }

    if (!exports) throw 'no binaryen method succeeded';

    Module['printErr']('binaryen method succeeded.');

    return exports;
  };

  var methodHandler = Module['asm']; // note our method handler, as we may modify Module['asm'] later
}


// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = (typeof Module !== 'undefined' ? Module : null) || {};

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_WEB = false;
var ENVIRONMENT_IS_WORKER = false;
var ENVIRONMENT_IS_NODE = false;
var ENVIRONMENT_IS_SHELL = false;

// Three configurations we can be running in:
// 1) We could be the application main() thread running in the main JS UI thread. (ENVIRONMENT_IS_WORKER == false and ENVIRONMENT_IS_PTHREAD == false)
// 2) We could be the application main() thread proxied to worker. (with Emscripten -s PROXY_TO_WORKER=1) (ENVIRONMENT_IS_WORKER == true, ENVIRONMENT_IS_PTHREAD == false)
// 3) We could be an application pthread running in a worker. (ENVIRONMENT_IS_WORKER == true and ENVIRONMENT_IS_PTHREAD == true)

if (Module['ENVIRONMENT']) {
  if (Module['ENVIRONMENT'] === 'WEB') {
    ENVIRONMENT_IS_WEB = true;
  } else if (Module['ENVIRONMENT'] === 'WORKER') {
    ENVIRONMENT_IS_WORKER = true;
  } else if (Module['ENVIRONMENT'] === 'NODE') {
    ENVIRONMENT_IS_NODE = true;
  } else if (Module['ENVIRONMENT'] === 'SHELL') {
    ENVIRONMENT_IS_SHELL = true;
  } else {
    throw new Error('The provided Module[\'ENVIRONMENT\'] value is not valid. It must be one of: WEB|WORKER|NODE|SHELL.');
  }
} else {
  ENVIRONMENT_IS_WEB = typeof window === 'object';
  ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
  ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function' && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER;
  ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
}


if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = console.log;
  if (!Module['printErr']) Module['printErr'] = console.warn;

  var nodeFS;
  var nodePath;

  Module['read'] = function read(filename, binary) {
    if (!nodeFS) nodeFS = require('fs');
    if (!nodePath) nodePath = require('path');
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    return binary ? ret : ret.toString();
  };

  Module['readBinary'] = function readBinary(filename) {
    var ret = Module['read'](filename, true);
    if (!ret.buffer) {
      ret = new Uint8Array(ret);
    }
    assert(ret.buffer);
    return ret;
  };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  if (!Module['thisProgram']) {
    if (process['argv'].length > 1) {
      Module['thisProgram'] = process['argv'][1].replace(/\\/g, '/');
    } else {
      Module['thisProgram'] = 'unknown-program';
    }
  }

  Module['arguments'] = process['argv'].slice(2);

  if (typeof module !== 'undefined') {
    module['exports'] = Module;
  }

  process['on']('uncaughtException', function(ex) {
    // suppress ExitStatus exceptions from showing an error
    if (!(ex instanceof ExitStatus)) {
      throw ex;
    }
  });

  Module['inspect'] = function () { return '[Emscripten Module object]'; };
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }

  Module['readBinary'] = function readBinary(f) {
    if (typeof readbuffer === 'function') {
      return new Uint8Array(readbuffer(f));
    }
    var data = read(f, 'binary');
    assert(typeof data === 'object');
    return data;
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  Module['readAsync'] = function readAsync(url, onload, onerror) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, true);
    xhr.responseType = 'arraybuffer';
    xhr.onload = function xhr_onload() {
      if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
        onload(xhr.response);
      } else {
        onerror();
      }
    };
    xhr.onerror = onerror;
    xhr.send(null);
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function printErr(x) {
      console.warn(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WORKER) {
    Module['load'] = importScripts;
  }

  if (typeof Module['setWindowTitle'] === 'undefined') {
    Module['setWindowTitle'] = function(title) { document.title = title };
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
if (!Module['thisProgram']) {
  Module['thisProgram'] = './this.program';
}

// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// Free the object hierarchy contained in the overrides, this lets the GC
// reclaim data used e.g. in memoryInitializerRequest, which is a large typed array.
moduleOverrides = undefined;



integrateWasmJS(Module);
// {{PREAMBLE_ADDITIONS}}

// === Preamble library stuff ===

// Documentation for the public APIs defined in this file must be updated in:
//    site/source/docs/api_reference/preamble.js.rst
// A prebuilt local version of the documentation is available at:
//    site/build/text/docs/api_reference/preamble.js.txt
// You can also build docs locally as HTML or other formats in site/
// An online HTML version (which may be of a different version of Emscripten)
//    is up at http://kripken.github.io/emscripten-site/docs/api_reference/preamble.js.html

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  setTempRet0: function (value) {
    tempRet0 = value;
  },
  getTempRet0: function () {
    return tempRet0;
  },
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  STACK_ALIGN: 16,
  prepVararg: function (ptr, type) {
    if (type === 'double' || type === 'i64') {
      // move so the load is aligned
      if (ptr & 7) {
        assert((ptr & 7) === 4);
        ptr += 4;
      }
    } else {
      assert((ptr & 3) === 0);
    }
    return ptr;
  },
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      assert(args.length == sig.length-1);
      assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
      return Module['dynCall_' + sig].apply(null, [ptr].concat(args));
    } else {
      assert(sig.length == 1);
      assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[sig]) {
      Runtime.funcWrappers[sig] = {};
    }
    var sigCache = Runtime.funcWrappers[sig];
    if (!sigCache[func]) {
      // optimize away arguments usage in common cases
      if (sig.length === 1) {
        sigCache[func] = function dynCall_wrapper() {
          return Runtime.dynCall(sig, func);
        };
      } else if (sig.length === 2) {
        sigCache[func] = function dynCall_wrapper(arg) {
          return Runtime.dynCall(sig, func, [arg]);
        };
      } else {
        // general case
        sigCache[func] = function dynCall_wrapper() {
          return Runtime.dynCall(sig, func, Array.prototype.slice.call(arguments));
        };
      }
    }
    return sigCache[func];
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+15)&-16);(assert((((STACKTOP|0) < (STACK_MAX|0))|0))|0); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + (assert(!staticSealed),size))|0;STATICTOP = (((STATICTOP)+15)&-16); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + (assert(DYNAMICTOP > 0),size))|0;DYNAMICTOP = (((DYNAMICTOP)+15)&-16); if (DYNAMICTOP >= TOTAL_MEMORY) { var success = enlargeMemory(); if (!success) { DYNAMICTOP = ret;  return 0; } }; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 16))*(quantum ? quantum : 16); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*4294967296.0)) : ((+((low>>>0)))+((+((high|0)))*4294967296.0))); return ret; },
  GLOBAL_BASE: 1024,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}



Module["Runtime"] = Runtime;



//========================================
// Runtime essentials
//========================================

var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  var func = Module['_' + ident]; // closure exported function
  if (!func) {
    try { func = eval('_' + ident); } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

var cwrap, ccall;
(function(){
  var JSfuncs = {
    // Helpers for cwrap -- it can't refer to Runtime directly because it might
    // be renamed by closure, instead it calls JSfuncs['stackSave'].body to find
    // out what the minified function name is.
    'stackSave': function() {
      Runtime.stackSave()
    },
    'stackRestore': function() {
      Runtime.stackRestore()
    },
    // type conversion from js to c
    'arrayToC' : function(arr) {
      var ret = Runtime.stackAlloc(arr.length);
      writeArrayToMemory(arr, ret);
      return ret;
    },
    'stringToC' : function(str) {
      var ret = 0;
      if (str !== null && str !== undefined && str !== 0) { // null string
        // at most 4 bytes per UTF-8 code point, +1 for the trailing '\0'
        ret = Runtime.stackAlloc((str.length << 2) + 1);
        writeStringToMemory(str, ret);
      }
      return ret;
    }
  };
  // For fast lookup of conversion functions
  var toC = {'string' : JSfuncs['stringToC'], 'array' : JSfuncs['arrayToC']};

  // C calling interface.
  ccall = function ccallFunc(ident, returnType, argTypes, args, opts) {
    var func = getCFunc(ident);
    var cArgs = [];
    var stack = 0;
    assert(returnType !== 'array', 'Return type should not be "array".');
    if (args) {
      for (var i = 0; i < args.length; i++) {
        var converter = toC[argTypes[i]];
        if (converter) {
          if (stack === 0) stack = Runtime.stackSave();
          cArgs[i] = converter(args[i]);
        } else {
          cArgs[i] = args[i];
        }
      }
    }
    var ret = func.apply(null, cArgs);
    if ((!opts || !opts.async) && typeof EmterpreterAsync === 'object') {
      assert(!EmterpreterAsync.state, 'cannot start async op with normal JS calling ccall');
    }
    if (opts && opts.async) assert(!returnType, 'async ccalls cannot return values');
    if (returnType === 'string') ret = Pointer_stringify(ret);
    if (stack !== 0) {
      if (opts && opts.async) {
        EmterpreterAsync.asyncFinalizers.push(function() {
          Runtime.stackRestore(stack);
        });
        return;
      }
      Runtime.stackRestore(stack);
    }
    return ret;
  }

  var sourceRegex = /^function\s*[a-zA-Z$_0-9]*\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;
  function parseJSFunc(jsfunc) {
    // Match the body and the return value of a javascript function source
    var parsed = jsfunc.toString().match(sourceRegex).slice(1);
    return {arguments : parsed[0], body : parsed[1], returnValue: parsed[2]}
  }

  // sources of useful functions. we create this lazily as it can trigger a source decompression on this entire file
  var JSsource = null;
  function ensureJSsource() {
    if (!JSsource) {
      JSsource = {};
      for (var fun in JSfuncs) {
        if (JSfuncs.hasOwnProperty(fun)) {
          // Elements of toCsource are arrays of three items:
          // the code, and the return value
          JSsource[fun] = parseJSFunc(JSfuncs[fun]);
        }
      }
    }
  }

  cwrap = function cwrap(ident, returnType, argTypes) {
    argTypes = argTypes || [];
    var cfunc = getCFunc(ident);
    // When the function takes numbers and returns a number, we can just return
    // the original function
    var numericArgs = argTypes.every(function(type){ return type === 'number'});
    var numericRet = (returnType !== 'string');
    if ( numericRet && numericArgs) {
      return cfunc;
    }
    // Creation of the arguments list (["$1","$2",...,"$nargs"])
    var argNames = argTypes.map(function(x,i){return '$'+i});
    var funcstr = "(function(" + argNames.join(',') + ") {";
    var nargs = argTypes.length;
    if (!numericArgs) {
      // Generate the code needed to convert the arguments from javascript
      // values to pointers
      ensureJSsource();
      funcstr += 'var stack = ' + JSsource['stackSave'].body + ';';
      for (var i = 0; i < nargs; i++) {
        var arg = argNames[i], type = argTypes[i];
        if (type === 'number') continue;
        var convertCode = JSsource[type + 'ToC']; // [code, return]
        funcstr += 'var ' + convertCode.arguments + ' = ' + arg + ';';
        funcstr += convertCode.body + ';';
        funcstr += arg + '=(' + convertCode.returnValue + ');';
      }
    }

    // When the code is compressed, the name of cfunc is not literally 'cfunc' anymore
    var cfuncname = parseJSFunc(function(){return cfunc}).returnValue;
    // Call the function
    funcstr += 'var ret = ' + cfuncname + '(' + argNames.join(',') + ');';
    if (!numericRet) { // Return type can only by 'string' or 'number'
      // Convert the result to a string
      var strgfy = parseJSFunc(function(){return Pointer_stringify}).returnValue;
      funcstr += 'ret = ' + strgfy + '(ret);';
    }
    funcstr += "if (typeof EmterpreterAsync === 'object') { assert(!EmterpreterAsync.state, 'cannot start async op with normal JS calling cwrap') }";
    if (!numericArgs) {
      // If we had a stack, restore it
      ensureJSsource();
      funcstr += JSsource['stackRestore'].body.replace('()', '(stack)') + ';';
    }
    funcstr += 'return ret})';
    return eval(funcstr);
  };
})();
Module["ccall"] = ccall;
Module["cwrap"] = cwrap;

function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module["setValue"] = setValue;


function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module["getValue"] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module["ALLOC_NORMAL"] = ALLOC_NORMAL;
Module["ALLOC_STACK"] = ALLOC_STACK;
Module["ALLOC_STATIC"] = ALLOC_STATIC;
Module["ALLOC_DYNAMIC"] = ALLOC_DYNAMIC;
Module["ALLOC_NONE"] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [typeof _malloc === 'function' ? _malloc : Runtime.staticAlloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    assert(type, 'Must know what type to store in allocate!');

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module["allocate"] = allocate;

// Allocate memory during any stage of startup - static memory early on, dynamic memory later, malloc when ready
function getMemory(size) {
  if (!staticSealed) return Runtime.staticAlloc(size);
  if ((typeof _sbrk !== 'undefined' && !_sbrk.called) || !runtimeInitialized) return Runtime.dynamicAlloc(size);
  return _malloc(size);
}
Module["getMemory"] = getMemory;

function Pointer_stringify(ptr, /* optional */ length) {
  if (length === 0 || !ptr) return '';
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = 0;
  var t;
  var i = 0;
  while (1) {
    assert(ptr + i < TOTAL_MEMORY);
    t = HEAPU8[(((ptr)+(i))>>0)];
    hasUtf |= t;
    if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (hasUtf < 128) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  return Module['UTF8ToString'](ptr);
}
Module["Pointer_stringify"] = Pointer_stringify;

// Given a pointer 'ptr' to a null-terminated ASCII-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function AsciiToString(ptr) {
  var str = '';
  while (1) {
    var ch = HEAP8[((ptr++)>>0)];
    if (!ch) return str;
    str += String.fromCharCode(ch);
  }
}
Module["AsciiToString"] = AsciiToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in ASCII form. The copy will require at most str.length+1 bytes of space in the HEAP.

function stringToAscii(str, outPtr) {
  return writeAsciiToMemory(str, outPtr, false);
}
Module["stringToAscii"] = stringToAscii;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the given array that contains uint8 values, returns
// a copy of that string as a Javascript String object.

var UTF8Decoder = typeof TextDecoder !== 'undefined' ? new TextDecoder('utf8') : undefined;
function UTF8ArrayToString(u8Array, idx) {
  var endPtr = idx;
  // TextDecoder needs to know the byte length in advance, it doesn't stop on null terminator by itself.
  // Also, use the length info to avoid running tiny strings through TextDecoder, since .subarray() allocates garbage.
  while (u8Array[endPtr]) ++endPtr;

  if (endPtr - idx > 16 && u8Array.subarray && UTF8Decoder) {
    return UTF8Decoder.decode(u8Array.subarray(idx, endPtr));
  } else {
    var u0, u1, u2, u3, u4, u5;

    var str = '';
    while (1) {
      // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
      u0 = u8Array[idx++];
      if (!u0) return str;
      if (!(u0 & 0x80)) { str += String.fromCharCode(u0); continue; }
      u1 = u8Array[idx++] & 63;
      if ((u0 & 0xE0) == 0xC0) { str += String.fromCharCode(((u0 & 31) << 6) | u1); continue; }
      u2 = u8Array[idx++] & 63;
      if ((u0 & 0xF0) == 0xE0) {
        u0 = ((u0 & 15) << 12) | (u1 << 6) | u2;
      } else {
        u3 = u8Array[idx++] & 63;
        if ((u0 & 0xF8) == 0xF0) {
          u0 = ((u0 & 7) << 18) | (u1 << 12) | (u2 << 6) | u3;
        } else {
          u4 = u8Array[idx++] & 63;
          if ((u0 & 0xFC) == 0xF8) {
            u0 = ((u0 & 3) << 24) | (u1 << 18) | (u2 << 12) | (u3 << 6) | u4;
          } else {
            u5 = u8Array[idx++] & 63;
            u0 = ((u0 & 1) << 30) | (u1 << 24) | (u2 << 18) | (u3 << 12) | (u4 << 6) | u5;
          }
        }
      }
      if (u0 < 0x10000) {
        str += String.fromCharCode(u0);
      } else {
        var ch = u0 - 0x10000;
        str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
      }
    }
  }
}
Module["UTF8ArrayToString"] = UTF8ArrayToString;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function UTF8ToString(ptr) {
  return UTF8ArrayToString(HEAPU8,ptr);
}
Module["UTF8ToString"] = UTF8ToString;

// Copies the given Javascript String object 'str' to the given byte array at address 'outIdx',
// encoded in UTF8 form and null-terminated. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outU8Array: the array to copy to. Each index in this array is assumed to be one 8-byte element.
//   outIdx: The starting offset in the array to begin the copying.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=1, only the null terminator will be written and nothing else.
//                    maxBytesToWrite=0 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8Array(str, outU8Array, outIdx, maxBytesToWrite) {
  if (!(maxBytesToWrite > 0)) // Parameter maxBytesToWrite is not optional. Negative values, 0, null, undefined and false each don't write out any bytes.
    return 0;

  var startIdx = outIdx;
  var endIdx = outIdx + maxBytesToWrite - 1; // -1 for string null terminator.
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      if (outIdx >= endIdx) break;
      outU8Array[outIdx++] = u;
    } else if (u <= 0x7FF) {
      if (outIdx + 1 >= endIdx) break;
      outU8Array[outIdx++] = 0xC0 | (u >> 6);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0xFFFF) {
      if (outIdx + 2 >= endIdx) break;
      outU8Array[outIdx++] = 0xE0 | (u >> 12);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x1FFFFF) {
      if (outIdx + 3 >= endIdx) break;
      outU8Array[outIdx++] = 0xF0 | (u >> 18);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x3FFFFFF) {
      if (outIdx + 4 >= endIdx) break;
      outU8Array[outIdx++] = 0xF8 | (u >> 24);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else {
      if (outIdx + 5 >= endIdx) break;
      outU8Array[outIdx++] = 0xFC | (u >> 30);
      outU8Array[outIdx++] = 0x80 | ((u >> 24) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    }
  }
  // Null-terminate the pointer to the buffer.
  outU8Array[outIdx] = 0;
  return outIdx - startIdx;
}
Module["stringToUTF8Array"] = stringToUTF8Array;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF8 form. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8(str, outPtr, maxBytesToWrite) {
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF8(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  return stringToUTF8Array(str, HEAPU8,outPtr, maxBytesToWrite);
}
Module["stringToUTF8"] = stringToUTF8;

// Returns the number of bytes the given Javascript string takes if encoded as a UTF8 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF8(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      ++len;
    } else if (u <= 0x7FF) {
      len += 2;
    } else if (u <= 0xFFFF) {
      len += 3;
    } else if (u <= 0x1FFFFF) {
      len += 4;
    } else if (u <= 0x3FFFFFF) {
      len += 5;
    } else {
      len += 6;
    }
  }
  return len;
}
Module["lengthBytesUTF8"] = lengthBytesUTF8;

// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

var UTF16Decoder = typeof TextDecoder !== 'undefined' ? new TextDecoder('utf-16le') : undefined;
function UTF16ToString(ptr) {
  assert(ptr % 2 == 0, 'Pointer passed to UTF16ToString must be aligned to two bytes!');
  var endPtr = ptr;
  // TextDecoder needs to know the byte length in advance, it doesn't stop on null terminator by itself.
  // Also, use the length info to avoid running tiny strings through TextDecoder, since .subarray() allocates garbage.
  var idx = endPtr >> 1;
  while (HEAP16[idx]) ++idx;
  endPtr = idx << 1;

  if (endPtr - ptr > 32 && UTF16Decoder) {
    return UTF16Decoder.decode(HEAPU8.subarray(ptr, endPtr));
  } else {
    var i = 0;

    var str = '';
    while (1) {
      var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
      if (codeUnit == 0) return str;
      ++i;
      // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
      str += String.fromCharCode(codeUnit);
    }
  }
}


// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF16 form. The copy will require at most str.length*4+2 bytes of space in the HEAP.
// Use the function lengthBytesUTF16() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=2, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<2 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF16(str, outPtr, maxBytesToWrite) {
  assert(outPtr % 2 == 0, 'Pointer passed to stringToUTF16 must be aligned to two bytes!');
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF16(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 2) return 0;
  maxBytesToWrite -= 2; // Null terminator.
  var startPtr = outPtr;
  var numCharsToWrite = (maxBytesToWrite < str.length*2) ? (maxBytesToWrite / 2) : str.length;
  for (var i = 0; i < numCharsToWrite; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[((outPtr)>>1)]=codeUnit;
    outPtr += 2;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[((outPtr)>>1)]=0;
  return outPtr - startPtr;
}


// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF16(str) {
  return str.length*2;
}


function UTF32ToString(ptr) {
  assert(ptr % 4 == 0, 'Pointer passed to UTF32ToString must be aligned to four bytes!');
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}


// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF32 form. The copy will require at most str.length*4+4 bytes of space in the HEAP.
// Use the function lengthBytesUTF32() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null
//                    terminator, i.e. if maxBytesToWrite=4, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<4 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF32(str, outPtr, maxBytesToWrite) {
  assert(outPtr % 4 == 0, 'Pointer passed to stringToUTF32 must be aligned to four bytes!');
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF32(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 4) return 0;
  var startPtr = outPtr;
  var endPtr = startPtr + maxBytesToWrite - 4;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++i);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[((outPtr)>>2)]=codeUnit;
    outPtr += 4;
    if (outPtr + 4 > endPtr) break;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[((outPtr)>>2)]=0;
  return outPtr - startPtr;
}


// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF32(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i);
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) ++i; // possibly a lead surrogate, so skip over the tail surrogate.
    len += 4;
  }

  return len;
}


function demangle(func) {
  var hasLibcxxabi = !!Module['___cxa_demangle'];
  if (hasLibcxxabi) {
    try {
      var buf = _malloc(func.length);
      writeStringToMemory(func.substr(1), buf);
      var status = _malloc(4);
      var ret = Module['___cxa_demangle'](buf, 0, 0, status);
      if (getValue(status, 'i32') === 0 && ret) {
        return Pointer_stringify(ret);
      }
      // otherwise, libcxxabi failed
    } catch(e) {
      // ignore problems here
    } finally {
      if (buf) _free(buf);
      if (status) _free(status);
      if (ret) _free(ret);
    }
    // failure when using libcxxabi, don't demangle
    return func;
  }
  Runtime.warnOnce('warning: build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling');
  return func;
}

function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}

function jsStackTrace() {
  var err = new Error();
  if (!err.stack) {
    // IE10+ special cases: It does have callstack info, but it is only populated if an Error object is thrown,
    // so try that as a special-case.
    try {
      throw new Error(0);
    } catch(e) {
      err = e;
    }
    if (!err.stack) {
      return '(no stack trace available)';
    }
  }
  return err.stack.toString();
}

function stackTrace() {
  var js = jsStackTrace();
  if (Module['extraStackTrace']) js += '\n' + Module['extraStackTrace']();
  return demangleAll(js);
}
Module["stackTrace"] = stackTrace;

// Memory management

var PAGE_SIZE = 4096;

function alignMemoryPage(x) {
  if (x % 4096 > 0) {
    x += (4096 - (x % 4096));
  }
  return x;
}

var HEAP;
var buffer;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

function updateGlobalBuffer(buf) {
  Module['buffer'] = buffer = buf;
}

function updateGlobalBufferViews() {
  Module['HEAP8'] = HEAP8 = new Int8Array(buffer);
  Module['HEAP16'] = HEAP16 = new Int16Array(buffer);
  Module['HEAP32'] = HEAP32 = new Int32Array(buffer);
  Module['HEAPU8'] = HEAPU8 = new Uint8Array(buffer);
  Module['HEAPU16'] = HEAPU16 = new Uint16Array(buffer);
  Module['HEAPU32'] = HEAPU32 = new Uint32Array(buffer);
  Module['HEAPF32'] = HEAPF32 = new Float32Array(buffer);
  Module['HEAPF64'] = HEAPF64 = new Float64Array(buffer);
}

var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk


// Initializes the stack cookie. Called at the startup of main and at the startup of each thread in pthreads mode.
function writeStackCookie() {
  assert((STACK_MAX & 3) == 0);
  HEAPU32[(STACK_MAX >> 2)-1] = 0x02135467;
  HEAPU32[(STACK_MAX >> 2)-2] = 0x89BACDFE;
}

function checkStackCookie() {
  if (HEAPU32[(STACK_MAX >> 2)-1] != 0x02135467 || HEAPU32[(STACK_MAX >> 2)-2] != 0x89BACDFE) {
    abort('Stack overflow! Stack cookie has been overwritten, expected hex dwords 0x89BACDFE and 0x02135467, but received 0x' + HEAPU32[(STACK_MAX >> 2)-2].toString(16) + ' ' + HEAPU32[(STACK_MAX >> 2)-1].toString(16));
  }
  // Also test the global address 0 for integrity. This check is not compatible with SAFE_SPLIT_MEMORY though, since that mode already tests all address 0 accesses on its own.
  if (HEAP32[0] !== 0x63736d65 /* 'emsc' */) throw 'Runtime error: The application has corrupted its heap memory area (address zero)!';
}

function abortStackOverflow(allocSize) {
  abort('Stack overflow! Attempted to allocate ' + allocSize + ' bytes on the stack, but stack has only ' + (STACK_MAX - asm.stackSave() + allocSize) + ' bytes available!');
}

function abortOnCannotGrowMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with  -s TOTAL_MEMORY=X  with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with  -s ALLOW_MEMORY_GROWTH=1  which adjusts the size at runtime but prevents some optimizations, (3) set Module.TOTAL_MEMORY to a higher value before the program runs, or if you want malloc to return NULL (0) instead of this abort, compile with  -s ABORTING_MALLOC=0 ');
}

function enlargeMemory() {
  abortOnCannotGrowMemory();
}


var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 16777216;

var totalMemory = 64*1024;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2*TOTAL_STACK) {
  if (totalMemory < 16*1024*1024) {
    totalMemory *= 2;
  } else {
    totalMemory += 16*1024*1024
  }
}
if (totalMemory !== TOTAL_MEMORY) {
  Module.printErr('increasing TOTAL_MEMORY to ' + totalMemory + ' to be compliant with the asm.js spec (and given that TOTAL_STACK=' + TOTAL_STACK + ')');
  TOTAL_MEMORY = totalMemory;
}

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'JS engine does not provide full typed array support');



// Use a provided buffer, if there is one, or else allocate a new one
if (Module['buffer']) {
  buffer = Module['buffer'];
  assert(buffer.byteLength === TOTAL_MEMORY, 'provided buffer should be ' + TOTAL_MEMORY + ' bytes, but it is ' + buffer.byteLength);
} else {
  buffer = new ArrayBuffer(TOTAL_MEMORY);
}
updateGlobalBufferViews();


// Endianness check (note: assumes compiler arch was little-endian)
  HEAP32[0] = 0x63736d65; /* 'emsc' */
HEAP16[1] = 0x6373;
if (HEAPU8[2] !== 0x73 || HEAPU8[3] !== 0x63) throw 'Runtime error: expected the system to be little-endian!';

Module['HEAP'] = HEAP;
Module['buffer'] = buffer;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;
var runtimeExited = false;


function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  checkStackCookie();
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  checkStackCookie();
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  checkStackCookie();
  callRuntimeCallbacks(__ATEXIT__);
  runtimeExited = true;
}

function postRun() {
  checkStackCookie();
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module["addOnPreRun"] = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module["addOnInit"] = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module["addOnPreMain"] = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module["addOnExit"] = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module["addOnPostRun"] = addOnPostRun;

// Tools


function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var len = length > 0 ? length : lengthBytesUTF8(stringy)+1;
  var u8array = new Array(len);
  var numBytesWritten = stringToUTF8Array(stringy, u8array, 0, u8array.length);
  if (dontAddNull) u8array.length = numBytesWritten;
  return u8array;
}
Module["intArrayFromString"] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      assert(false, 'Character code ' + chr + ' (' + String.fromCharCode(chr) + ')  at offset ' + i + ' not in 0x00-0xFF.');
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module["intArrayToString"] = intArrayToString;

function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))>>0)]=chr;
    i = i + 1;
  }
}
Module["writeStringToMemory"] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[((buffer++)>>0)]=array[i];
  }
}
Module["writeArrayToMemory"] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; ++i) {
    assert(str.charCodeAt(i) === str.charCodeAt(i)&0xff);
    HEAP8[((buffer++)>>0)]=str.charCodeAt(i);
  }
  // Null-terminate the pointer to the HEAP.
  if (!dontAddNull) HEAP8[((buffer)>>0)]=0;
}
Module["writeAsciiToMemory"] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}


// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


if (!Math['clz32']) Math['clz32'] = function(x) {
  x = x >>> 0;
  for (var i = 0; i < 32; i++) {
    if (x & (1 << (31 - i))) return i;
  }
  return 32;
};
Math.clz32 = Math['clz32']

if (!Math['trunc']) Math['trunc'] = function(x) {
  return x < 0 ? Math.ceil(x) : Math.floor(x);
};
Math.trunc = Math['trunc'];

var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;
var Math_clz32 = Math.clz32;
var Math_trunc = Math.trunc;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled
var runDependencyTracking = {};

function getUniqueRunDependency(id) {
  var orig = id;
  while (1) {
    if (!runDependencyTracking[id]) return id;
    id = orig + Math.random();
  }
  return id;
}

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
    if (runDependencyWatcher === null && typeof setInterval !== 'undefined') {
      // Check for missing dependencies every few seconds
      runDependencyWatcher = setInterval(function() {
        if (ABORT) {
          clearInterval(runDependencyWatcher);
          runDependencyWatcher = null;
          return;
        }
        var shown = false;
        for (var dep in runDependencyTracking) {
          if (!shown) {
            shown = true;
            Module.printErr('still waiting on run dependencies:');
          }
          Module.printErr('dependency: ' + dep);
        }
        if (shown) {
          Module.printErr('(end of list)');
        }
      }, 10000);
    }
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module["addRunDependency"] = addRunDependency;

function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module["removeRunDependency"] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data



var memoryInitializer = null;



var /* show errors on likely calls to FS when it was not included */ FS = {
  error: function() {
    abort('Filesystem support (FS) was not included. The problem is that you are using files from JS, but files were not used from C/C++, so filesystem support was not auto-included. You can force-include filesystem support with  -s FORCE_FILESYSTEM=1');
  },
  init: function() { FS.error() },
  createDataFile: function() { FS.error() },
  createPreloadedFile: function() { FS.error() },
  createLazyFile: function() { FS.error() },
  open: function() { FS.error() },
  mkdev: function() { FS.error() },
  registerDevice: function() { FS.error() },
  analyzePath: function() { FS.error() },
  loadFilesFromDB: function() { FS.error() },

  ErrnoError: function ErrnoError() { FS.error() },
};
Module['FS_createDataFile'] = FS.createDataFile;
Module['FS_createPreloadedFile'] = FS.createPreloadedFile;


// === Body ===

var ASM_CONSTS = [];




STATIC_BASE = 1024;

STATICTOP = STATIC_BASE + 5168;
  /* global initializers */  __ATINIT__.push();
  

/* memory initializer */ allocate([4,4,0,0,5,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,44,16,0,0,0,4,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,104,101,108,108,111,44,32,119,111,114,108,100,33,10,0,17,0,10,0,17,17,17,0,0,0,0,5,0,0,0,0,0,0,9,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,15,10,17,17,17,3,10,7,0,1,19,9,11,11,0,0,9,6,11,0,0,11,0,6,17,0,0,0,17,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,10,10,17,17,17,0,10,0,0,2,0,9,11,0,0,0,9,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,4,13,0,0,0,0,9,14,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,0,0,9,16,0,0,0,0,0,16,0,0,16,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,0,9,11,0,0,0,0,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,45,43,32,32,32,48,88,48,120,0,84,33,34,25,13,1,2,3,17,75,28,12,16,4,11,29,18,30,39,104,110,111,112,113,98,32,5,6,15,19,20,21,26,8,22,7,40,36,23,24,9,10,14,27,31,37,35,131,130,125,38,42,43,60,61,62,63,67,71,74,77,88,89,90,91,92,93,94,95,96,97,99,100,101,102,103,105,106,107,108,114,115,116,121,122,123,124,0,73,108,108,101,103,97,108,32,98,121,116,101,32,115,101,113,117,101,110,99,101,0,68,111,109,97,105,110,32,101,114,114,111,114,0,82,101,115,117,108,116,32,110,111,116,32,114,101,112,114,101,115,101,110,116,97,98,108,101,0,78,111,116,32,97,32,116,116,121,0,80,101,114,109,105,115,115,105,111,110,32,100,101,110,105,101,100,0,79,112,101,114,97,116,105,111,110,32,110,111,116,32,112,101,114,109,105,116,116,101,100,0,78,111,32,115,117,99,104,32,102,105,108,101,32,111,114,32,100,105,114,101,99,116,111,114,121,0,78,111,32,115,117,99,104,32,112,114,111,99,101,115,115,0,70,105,108,101,32,101,120,105,115,116,115,0,86,97,108,117,101,32,116,111,111,32,108,97,114,103,101,32,102,111,114,32,100,97,116,97,32,116,121,112,101,0,78,111,32,115,112,97,99,101,32,108,101,102,116,32,111,110,32,100,101,118,105,99,101,0,79,117,116,32,111,102,32,109,101,109,111,114,121,0,82,101,115,111,117,114,99,101,32,98,117,115,121,0,73,110,116,101,114,114,117,112,116,101,100,32,115,121,115,116,101,109,32,99,97,108,108,0,82,101,115,111,117,114,99,101,32,116,101,109,112,111,114,97,114,105,108,121,32,117,110,97,118,97,105,108,97,98,108,101,0,73,110,118,97,108,105,100,32,115,101,101,107,0,67,114,111,115,115,45,100,101,118,105,99,101,32,108,105,110,107,0,82,101,97,100,45,111,110,108,121,32,102,105,108,101,32,115,121,115,116,101,109,0,68,105,114,101,99,116,111,114,121,32,110,111,116,32,101,109,112,116,121,0,67,111,110,110,101,99,116,105,111,110,32,114,101,115,101,116,32,98,121,32,112,101,101,114,0,79,112,101,114,97,116,105,111,110,32,116,105,109,101,100,32,111,117,116,0,67,111,110,110,101,99,116,105,111,110,32,114,101,102,117,115,101,100,0,72,111,115,116,32,105,115,32,100,111,119,110,0,72,111,115,116,32,105,115,32,117,110,114,101,97,99,104,97,98,108,101,0,65,100,100,114,101,115,115,32,105,110,32,117,115,101,0,66,114,111,107,101,110,32,112,105,112,101,0,73,47,79,32,101,114,114,111,114,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,32,111,114,32,97,100,100,114,101,115,115,0,66,108,111,99,107,32,100,101,118,105,99,101,32,114,101,113,117,105,114,101,100,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,0,78,111,116,32,97,32,100,105,114,101,99,116,111,114,121,0,73,115,32,97,32,100,105,114,101,99,116,111,114,121,0,84,101,120,116,32,102,105,108,101,32,98,117,115,121,0,69,120,101,99,32,102,111,114,109,97,116,32,101,114,114,111,114,0,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,0,65,114,103,117,109,101,110,116,32,108,105,115,116,32,116,111,111,32,108,111,110,103,0,83,121,109,98,111,108,105,99,32,108,105,110,107,32,108,111,111,112,0,70,105,108,101,110,97,109,101,32,116,111,111,32,108,111,110,103,0,84,111,111,32,109,97,110,121,32,111,112,101,110,32,102,105,108,101,115,32,105,110,32,115,121,115,116,101,109,0,78,111,32,102,105,108,101,32,100,101,115,99,114,105,112,116,111,114,115,32,97,118,97,105,108,97,98,108,101,0,66,97,100,32,102,105,108,101,32,100,101,115,99,114,105,112,116,111,114,0,78,111,32,99,104,105,108,100,32,112,114,111,99,101,115,115,0,66,97,100,32,97,100,100,114,101,115,115,0,70,105,108,101,32,116,111,111,32,108,97,114,103,101,0,84,111,111,32,109,97,110,121,32,108,105,110,107,115,0,78,111,32,108,111,99,107,115,32,97,118,97,105,108,97,98,108,101,0,82,101,115,111,117,114,99,101,32,100,101,97,100,108,111,99,107,32,119,111,117,108,100,32,111,99,99,117,114,0,83,116,97,116,101,32,110,111,116,32,114,101,99,111,118,101,114,97,98,108,101,0,80,114,101,118,105,111,117,115,32,111,119,110,101,114,32,100,105,101,100,0,79,112,101,114,97,116,105,111,110,32,99,97,110,99,101,108,101,100,0,70,117,110,99,116,105,111,110,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,0,78,111,32,109,101,115,115,97,103,101,32,111,102,32,100,101,115,105,114,101,100,32,116,121,112,101,0,73,100,101,110,116,105,102,105,101,114,32,114,101,109,111,118,101,100,0,68,101,118,105,99,101,32,110,111,116,32,97,32,115,116,114,101,97,109,0,78,111,32,100,97,116,97,32,97,118,97,105,108,97,98,108,101,0,68,101,118,105,99,101,32,116,105,109,101,111,117,116,0,79,117,116,32,111,102,32,115,116,114,101,97,109,115,32,114,101,115,111,117,114,99,101,115,0,76,105,110,107,32,104,97,115,32,98,101,101,110,32,115,101,118,101,114,101,100,0,80,114,111,116,111,99,111,108,32,101,114,114,111,114,0,66,97,100,32,109,101,115,115,97,103,101,0,70,105,108,101,32,100,101,115,99,114,105,112,116,111,114,32,105,110,32,98,97,100,32,115,116,97,116,101,0,78,111,116,32,97,32,115,111,99,107,101,116,0,68,101,115,116,105,110,97,116,105,111,110,32,97,100,100,114,101,115,115,32,114,101,113,117,105,114,101,100,0,77,101,115,115,97,103,101,32,116,111,111,32,108,97,114,103,101,0,80,114,111,116,111,99,111,108,32,119,114,111,110,103,32,116,121,112,101,32,102,111,114,32,115,111,99,107,101,116,0,80,114,111,116,111,99,111,108,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,80,114,111,116,111,99,111,108,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,83,111,99,107,101,116,32,116,121,112,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,78,111,116,32,115,117,112,112,111,114,116,101,100,0,80,114,111,116,111,99,111,108,32,102,97,109,105,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,65,100,100,114,101,115,115,32,102,97,109,105,108,121,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,98,121,32,112,114,111,116,111,99,111,108,0,65,100,100,114,101,115,115,32,110,111,116,32,97,118,97,105,108,97,98,108,101,0,78,101,116,119,111,114,107,32,105,115,32,100,111,119,110,0,78,101,116,119,111,114,107,32,117,110,114,101,97,99,104,97,98,108,101,0,67,111,110,110,101,99,116,105,111,110,32,114,101,115,101,116,32,98,121,32,110,101,116,119,111,114,107,0,67,111,110,110,101,99,116,105,111,110,32,97,98,111,114,116,101,100,0,78,111,32,98,117,102,102,101,114,32,115,112,97,99,101,32,97,118,97,105,108,97,98,108,101,0,83,111,99,107,101,116,32,105,115,32,99,111,110,110,101,99,116,101,100,0,83,111,99,107,101,116,32,110,111,116,32,99,111,110,110,101,99,116,101,100,0,67,97,110,110,111,116,32,115,101,110,100,32,97,102,116,101,114,32,115,111,99,107,101,116,32,115,104,117,116,100,111,119,110,0,79,112,101,114,97,116,105,111,110,32,97,108,114,101,97,100,121,32,105,110,32,112,114,111,103,114,101,115,115,0,79,112,101,114,97,116,105,111,110,32,105,110,32,112,114,111,103,114,101,115,115,0,83,116,97,108,101,32,102,105,108,101,32,104,97,110,100,108,101,0,82,101,109,111,116,101,32,73,47,79,32,101,114,114,111,114,0,81,117,111,116,97,32,101,120,99,101,101,100,101,100,0,78,111,32,109,101,100,105,117,109,32,102,111,117,110,100,0,87,114,111,110,103,32,109,101,100,105,117,109,32,116,121,112,101,0,78,111,32,101,114,114,111,114,32,105,110,102,111,114,109,97,116,105,111,110,0,0,40,110,117,108,108,41,0,45,48,88,43,48,88,32,48,88,45,48,120,43,48,120,32,48,120,0,105,110,102,0,73,78,70,0,110,97,110,0,78,65,78,0,46,0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);




var STATIC_BUMP = 5168;

/* no memory initializer */
var tempDoublePtr = STATICTOP; STATICTOP += 16;

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}

// {{PRE_LIBRARY}}


   
  Module["_i64Subtract"] = _i64Subtract;

   
  Module["_i64Add"] = _i64Add;

   
  Module["_memset"] = _memset;

  function _pthread_cleanup_push(routine, arg) {
      __ATEXIT__.push(function() { Runtime.dynCall('vi', routine, [arg]) })
      _pthread_cleanup_push.level = __ATEXIT__.length;
    }

   
  Module["_bitshift64Lshr"] = _bitshift64Lshr;

   
  Module["_bitshift64Shl"] = _bitshift64Shl;

  function _pthread_cleanup_pop() {
      assert(_pthread_cleanup_push.level == __ATEXIT__.length, 'cannot pop if something else added meanwhile!');
      __ATEXIT__.pop();
      _pthread_cleanup_push.level = __ATEXIT__.length;
    }

  function _abort() {
      Module['abort']();
    }

  function ___lock() {}

  function ___unlock() {}

  
  var SYSCALLS={varargs:0,get:function (varargs) {
        SYSCALLS.varargs += 4;
        var ret = HEAP32[(((SYSCALLS.varargs)-(4))>>2)];
        return ret;
      },getStr:function () {
        var ret = Pointer_stringify(SYSCALLS.get());
        return ret;
      },get64:function () {
        var low = SYSCALLS.get(), high = SYSCALLS.get();
        if (low >= 0) assert(high === 0);
        else assert(high === -1);
        return low;
      },getZero:function () {
        assert(SYSCALLS.get() === 0);
      }};function ___syscall6(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // close
      var stream = SYSCALLS.getStreamFromFD();
      FS.close(stream);
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  
  
  var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_STATIC);function _llvm_cttz_i32(x) {
      x = x|0;
      var ret = 0;
      ret = ((HEAP8[(((cttz_i8)+(x & 0xff))>>0)])|0);
      if ((ret|0) < 8) return ret|0;
      ret = ((HEAP8[(((cttz_i8)+((x >> 8)&0xff))>>0)])|0);
      if ((ret|0) < 8) return (ret + 8)|0;
      ret = ((HEAP8[(((cttz_i8)+((x >> 16)&0xff))>>0)])|0);
      if ((ret|0) < 8) return (ret + 16)|0;
      return (((HEAP8[(((cttz_i8)+(x >>> 24))>>0)])|0) + 24)|0;
    } 
  Module["___udivmoddi4"] = ___udivmoddi4; 
  Module["___udivdi3"] = ___udivdi3;

  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) {
        var success = self.alloc(bytes);
        if (!success) return -1 >>> 0; // sbrk failure code
      }
      return ret;  // Previous break location.
    }

   
  Module["___uremdi3"] = ___uremdi3;

  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 
  Module["_memcpy"] = _memcpy;

   
  Module["_pthread_self"] = _pthread_self;

  function ___syscall140(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // llseek
      var stream = SYSCALLS.getStreamFromFD(), offset_high = SYSCALLS.get(), offset_low = SYSCALLS.get(), result = SYSCALLS.get(), whence = SYSCALLS.get();
      var offset = offset_low;
      assert(offset_high === 0);
      FS.llseek(stream, offset, whence);
      HEAP32[((result)>>2)]=stream.position;
      if (stream.getdents && offset === 0 && whence === 0) stream.getdents = null; // reset readdir state
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall146(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // writev
      // hack to support printf in NO_FILESYSTEM
      var stream = SYSCALLS.get(), iov = SYSCALLS.get(), iovcnt = SYSCALLS.get();
      var ret = 0;
      if (!___syscall146.buffer) {
        ___syscall146.buffers = [null, [], []]; // 1 => stdout, 2 => stderr
        ___syscall146.printChar = function(stream, curr) {
          var buffer = ___syscall146.buffers[stream];
          assert(buffer);
          if (curr === 0 || curr === 10) {
            (stream === 1 ? Module['print'] : Module['printErr'])(UTF8ArrayToString(buffer, 0));
            buffer.length = 0;
          } else {
            buffer.push(curr);
          }
        };
      }
      for (var i = 0; i < iovcnt; i++) {
        var ptr = HEAP32[(((iov)+(i*8))>>2)];
        var len = HEAP32[(((iov)+(i*8 + 4))>>2)];
        for (var j = 0; j < len; j++) {
          ___syscall146.printChar(stream, HEAPU8[ptr+j]);
        }
        ret += len;
      }
      return ret;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }

  function ___syscall54(which, varargs) {SYSCALLS.varargs = varargs;
  try {
   // ioctl
      return 0;
    } catch (e) {
    if (typeof FS === 'undefined' || !(e instanceof FS.ErrnoError)) abort(e);
    return -e.errno;
  }
  }
/* flush anything remaining in the buffer during shutdown */ __ATEXIT__.push(function() { var fflush = Module["_fflush"]; if (fflush) fflush(0); var printChar = ___syscall146.printChar; if (!printChar) return; var buffers = ___syscall146.buffers; if (buffers[1].length) printChar(1, 10); if (buffers[2].length) printChar(2, 10); });;
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

staticSealed = true; // seal the static portion of memory

STACK_MAX = STACK_BASE + TOTAL_STACK;

DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");



function nullFunc_ii(x) { Module["printErr"]("Invalid function pointer called with signature 'ii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vi(x) { Module["printErr"]("Invalid function pointer called with signature 'vi'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

Module.asmGlobalArg = { "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array, "NaN": NaN, "Infinity": Infinity };

Module.asmLibraryArg = { "abort": abort, "assert": assert, "abortStackOverflow": abortStackOverflow, "nullFunc_ii": nullFunc_ii, "nullFunc_iiii": nullFunc_iiii, "nullFunc_vi": nullFunc_vi, "invoke_ii": invoke_ii, "invoke_iiii": invoke_iiii, "invoke_vi": invoke_vi, "_pthread_cleanup_pop": _pthread_cleanup_pop, "_abort": _abort, "___lock": ___lock, "___syscall6": ___syscall6, "_pthread_cleanup_push": _pthread_cleanup_push, "_llvm_cttz_i32": _llvm_cttz_i32, "_sbrk": _sbrk, "___syscall140": ___syscall140, "_emscripten_memcpy_big": _emscripten_memcpy_big, "___syscall54": ___syscall54, "___unlock": ___unlock, "___syscall146": ___syscall146, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8 };
// EMSCRIPTEN_START_ASM
var asm =Module["asm"]// EMSCRIPTEN_END_ASM
(Module.asmGlobalArg, Module.asmLibraryArg, buffer);

var real__i64Subtract = asm["_i64Subtract"]; asm["_i64Subtract"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__i64Subtract.apply(null, arguments);
};

var real__free = asm["_free"]; asm["_free"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__free.apply(null, arguments);
};

var real__main = asm["_main"]; asm["_main"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__main.apply(null, arguments);
};

var real__i64Add = asm["_i64Add"]; asm["_i64Add"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__i64Add.apply(null, arguments);
};

var real____udivmoddi4 = asm["___udivmoddi4"]; asm["___udivmoddi4"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real____udivmoddi4.apply(null, arguments);
};

var real__pthread_self = asm["_pthread_self"]; asm["_pthread_self"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__pthread_self.apply(null, arguments);
};

var real____udivdi3 = asm["___udivdi3"]; asm["___udivdi3"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real____udivdi3.apply(null, arguments);
};

var real__malloc = asm["_malloc"]; asm["_malloc"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__malloc.apply(null, arguments);
};

var real__bitshift64Lshr = asm["_bitshift64Lshr"]; asm["_bitshift64Lshr"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__bitshift64Lshr.apply(null, arguments);
};

var real__fflush = asm["_fflush"]; asm["_fflush"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__fflush.apply(null, arguments);
};

var real____uremdi3 = asm["___uremdi3"]; asm["___uremdi3"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real____uremdi3.apply(null, arguments);
};

var real____errno_location = asm["___errno_location"]; asm["___errno_location"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real____errno_location.apply(null, arguments);
};

var real__bitshift64Shl = asm["_bitshift64Shl"]; asm["_bitshift64Shl"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__bitshift64Shl.apply(null, arguments);
};
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var ___udivmoddi4 = Module["___udivmoddi4"] = asm["___udivmoddi4"];
var _pthread_self = Module["_pthread_self"] = asm["_pthread_self"];
var _memset = Module["_memset"] = asm["_memset"];
var ___udivdi3 = Module["___udivdi3"] = asm["___udivdi3"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var _fflush = Module["_fflush"] = asm["_fflush"];
var ___uremdi3 = Module["___uremdi3"] = asm["___uremdi3"];
var ___errno_location = Module["___errno_location"] = asm["___errno_location"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
;

Runtime.stackAlloc = asm['stackAlloc'];
Runtime.stackSave = asm['stackSave'];
Runtime.stackRestore = asm['stackRestore'];
Runtime.establishStackSpace = asm['establishStackSpace'];

Runtime.setTempRet0 = asm['setTempRet0'];
Runtime.getTempRet0 = asm['getTempRet0'];



// === Auto-generated postamble setup entry stuff ===





function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun']) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString(Module['thisProgram']), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);


  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    exit(ret, /* implicit = */ true);
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}




function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }

  writeStackCookie();

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    if (ABORT) return;

    ensureInitRuntime();

    preMain();

    if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
      Module.printErr('pre-main prep time: ' + (Date.now() - preloadStartTime) + ' ms');
    }

    if (Module['onRuntimeInitialized']) Module['onRuntimeInitialized']();

    if (Module['_main'] && shouldRunNow) Module['callMain'](args);

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
  checkStackCookie();
}
Module['run'] = Module.run = run;

function exit(status, implicit) {
  if (implicit && Module['noExitRuntime']) {
    Module.printErr('exit(' + status + ') implicitly called by end of main(), but noExitRuntime, so not exiting the runtime (you can use emscripten_force_exit, if you want to force a true shutdown)');
    return;
  }

  if (Module['noExitRuntime']) {
    Module.printErr('exit(' + status + ') called, but noExitRuntime, so halting execution but not exiting the runtime or preventing further async execution (you can use emscripten_force_exit, if you want to force a true shutdown)');
  } else {

    ABORT = true;
    EXITSTATUS = status;
    STACKTOP = initialStackTop;

    exitRuntime();

    if (Module['onExit']) Module['onExit'](status);
  }

  if (ENVIRONMENT_IS_NODE) {
    process['exit'](status);
  } else if (ENVIRONMENT_IS_SHELL && typeof quit === 'function') {
    quit(status);
  }
  // if we reach here, we must throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;

var abortDecorators = [];

function abort(what) {
  if (what !== undefined) {
    Module.print(what);
    Module.printErr(what);
    what = JSON.stringify(what)
  } else {
    what = '';
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '';

  var output = 'abort(' + what + ') at ' + stackTrace() + extra;
  if (abortDecorators) {
    abortDecorators.forEach(function(decorator) {
      output = decorator(output, what);
    });
  }
  throw output;
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}


run();

// {{POST_RUN_ADDITIONS}}





// {{MODULE_ADDITIONS}}



